#include "stdafx.h"
#include "engine32.h"
//#include "aclib.h"
#include <string.h>

static HANDLE l_hInst;
static UINT   l_cbFormat;

static UINT   l_ddeConvInitRetries    = 10;
static UINT   l_ddeConvInitSleepTime  = 1000;

#ifdef _DEBUG
  static BOOL l_traceDdeTransaction   = TRUE;
  static BOOL l_traceEvalStringResult = TRUE;
#else
  static BOOL l_traceDdeTransaction   = FALSE;
  static BOOL l_traceEvalStringResult = FALSE;
#endif

////////////////////////////////////////////////////////////////////////////////
//
// DDE Callback
//

HDDEDATA APIENTRY DdeCallback (UINT uType, UINT uFmt, HCONV hConv,
                               HSZ hsz1, HSZ hsz2, HDDEDATA hData,
                               DWORD dwData1, DWORD dwData2)
{
  return NULL;
}

////////////////////////////////////////////////////////////////////////////////
//
// local functions
//

CString LTrim(CString s, CString separators = " ")
{
  if (s.GetLength() == 0) return "";
  int firstGoodCharPos = 0;
  while (s.GetLength() > firstGoodCharPos && separators.Find(s[firstGoodCharPos]) != -1)
    firstGoodCharPos++;
  if (firstGoodCharPos == s.GetLength()) // only separators
    return "";
  else
    return s.Mid(firstGoodCharPos);
}

CString RTrim(CString s, CString separators = " ")
{
  if (s.GetLength() == 0) return "";
  int lastGoodCharPos = s.GetLength()-1;
  while (lastGoodCharPos >= 0 && separators.Find(s[lastGoodCharPos]) != -1)
    lastGoodCharPos--;
  if (lastGoodCharPos == -1) // only separators
    return "";
  else
    return s.Left(lastGoodCharPos+1);
}

CString Trim(CString s, CString separators = " ")
{
  return LTrim(RTrim(s,separators),separators);
}

CString RemoveWord(CString &input_string, CString separators = " ")
//
// Return the next word from input string and remove this word
// from the original string. The word separator is a space.
//
// Entry Parameters:
//   input_string: original string.
//   separators:   each character in the string is a possible separator
//
// Exit Parameters:
//   input_string: origianl string without the first word.
//
// Return value:
//   Next word from input string.
//---------------------------------------------------------------------------
{
  CString t_input_string = input_string;
  t_input_string = Trim (t_input_string,separators);
  if (t_input_string.GetLength() == 0 || t_input_string.FindOneOf(separators) == -1)
  {
    input_string = "";
    return t_input_string;
  }
  else
  { 
    int space_pos = input_string.FindOneOf(separators);
    int total_len = input_string.GetLength();
    CString first_word = input_string.Left(space_pos);
    input_string = LTrim(input_string.Mid(space_pos),separators);
    return first_word;
  } 
}

BOOL GetMatlabVersion(Engine *pEngine, CString *pVersion, CString *pSiteId)
{
  char *pOldBuf = pEngine->m_pBuf;
  int oldBufLen = pEngine->m_bufLen;
  CString buf;
  engOutputBuffer(pEngine, buf.GetBuffer(1024), 1024);
  engEvalString(pEngine,"ver('Matlab')");
  buf.ReleaseBuffer();
  pEngine->m_pBuf = pOldBuf;
  pEngine->m_bufLen = oldBufLen;

  // seperate lines in response
  if (buf.GetLength() == 0) return FALSE;
  int pos = buf.Find("\r\n");
  if (pos == -1) return FALSE;
  CString versionLine = buf.Left(pos);
  if (buf.GetLength() < pos+3) return FALSE;
  buf = buf.Mid(pos+2);
  pos = buf.Find("\r\n");
  if (pos == -1) return FALSE;
  CString siteIdLine = buf.Left(pos);
  for (UINT i=0; i<3; i++) *pVersion = RemoveWord(versionLine);
  for (     i=0; i<5; i++) *pSiteId  = RemoveWord(siteIdLine);
  return TRUE;
}

CString GetDdeErrorMsg (DWORD lastDdeError)
{
  CString tmp;
  switch (lastDdeError)
  {
    case DMLERR_NO_ERROR                    : tmp = "DMLERR_NO_ERROR"; break;
    case DMLERR_ADVACKTIMEOUT               : tmp = "DMLERR_ADVACKTIMEOUT"; break;
    case DMLERR_BUSY                        : tmp = "DMLERR_BUSY"; break;
    case DMLERR_DATAACKTIMEOUT              : tmp = "DMLERR_DATAACKTIMEOUT"; break;
    case DMLERR_DLL_NOT_INITIALIZED         : tmp = "DMLERR_DLL_NOT_INITIALIZED"; break;
    case DMLERR_DLL_USAGE                   : tmp = "DMLERR_DLL_USAGE"; break;
    case DMLERR_EXECACKTIMEOUT              : tmp = "DMLERR_EXECACKTIMEOUT"; break;
    case DMLERR_INVALIDPARAMETER            : tmp = "DMLERR_INVALIDPARAMETER"; break;
    case DMLERR_LOW_MEMORY                  : tmp = "DMLERR_LOW_MEMORY"; break;
    case DMLERR_MEMORY_ERROR                : tmp = "DMLERR_MEMORY_ERROR"; break;
    case DMLERR_NOTPROCESSED                : tmp = "DMLERR_NOTPROCESSED"; break;
    case DMLERR_NO_CONV_ESTABLISHED         : tmp = "DMLERR_NO_CONV_ESTABLISHED"; break;
    case DMLERR_POKEACKTIMEOUT              : tmp = "DMLERR_POKEACKTIMEOUT"; break;
    case DMLERR_POSTMSG_FAILED              : tmp = "DMLERR_POSTMSG_FAILED"; break;
    case DMLERR_REENTRANCY                  : tmp = "DMLERR_REENTRANCY"; break;
    case DMLERR_SERVER_DIED                 : tmp = "DMLERR_SERVER_DIED"; break;
    case DMLERR_SYS_ERROR                   : tmp = "DMLERR_SYS_ERROR"; break;
    case DMLERR_UNADVACKTIMEOUT             : tmp = "DMLERR_UNADVACKTIMEOUT"; break;
    case DMLERR_UNFOUND_QUEUE_ID            : tmp = "DMLERR_UNFOUND_QUEUE_ID"; break;
    default: tmp = "Unknown DDE error"; break;
  }
  return tmp;
}

Engine::Engine()
{
  m_timeout = 3000; // 3 seconds
  m_idInst = NULL;
  // m_hConv = uninitialized
  m_pBuf = NULL;
  m_bufLen = -1;
}

///////////////////////////////////////////////////////////////////////////////////////
//
// exported functions
//

void SetDdeConvInitValues (UINT ddeConvInitRetries /*= 10*/, UINT ddeConvInitSleepTime /*= 1000*/)
{
  l_ddeConvInitRetries = ddeConvInitRetries;
  l_ddeConvInitSleepTime = ddeConvInitSleepTime;
}

void GetDdeConvInitValues (UINT *pDdeConvInitRetries, UINT *pDdeConvInitSleepTime)
{
  *pDdeConvInitRetries = l_ddeConvInitRetries;
  *pDdeConvInitSleepTime = l_ddeConvInitSleepTime;
}

void SetTraceOptions (BOOL traceDdeTransaction /*= TRUE*/, BOOL traceEvalStringResult  /*= TRUE*/)
{
  l_traceDdeTransaction = traceDdeTransaction;
  l_traceEvalStringResult = traceEvalStringResult;
}

void GetTraceOptions (BOOL *pTraceDdeTransaction, BOOL *pTraceEvalStringResult)
{
  *pTraceDdeTransaction = l_traceDdeTransaction;
  *pTraceEvalStringResult = l_traceEvalStringResult;
}

void mxFree(void *p)
{
  double *pD = (double*)p;
  delete [] pD;
}

void engWinInit(HANDLE hInst)
{
  ASSERT (hInst);
  l_hInst = hInst;
  // Register the clipboard format
  l_cbFormat = RegisterClipboardFormat((LPSTR)"MatlabMatrix");
  return;
}

Engine *engOpen(const char *startcmd)
{
  ASSERT (startcmd);
  // Connect to DDEML
  Engine *ep = new Engine;
  FARPROC  pfnDdeCallback ;
  pfnDdeCallback = MakeProcInstance ((FARPROC) DdeCallback, l_hInst);
  if (DdeInitialize (&(ep->m_idInst), (PFNCALLBACK) pfnDdeCallback,
                        APPCLASS_STANDARD | APPCMD_CLIENTONLY, 0L))
  {
    TRACE0("engOpen: could not initialize DDEML\n");
    delete ep;
    return NULL;
  }
  // Start conversation
  HSZ hszService = DdeCreateStringHandle (ep->m_idInst, "Matlab", 0);
  HSZ hszTopic   = DdeCreateStringHandle (ep->m_idInst, "Engine", 0);
  ep->m_hConv = DdeConnect (ep->m_idInst, hszService, hszTopic, NULL);
  DdeFreeStringHandle (ep->m_idInst, hszService);
  DdeFreeStringHandle (ep->m_idInst, hszTopic);
  if (ep->m_hConv == NULL)
  {
    TRACE0("engOpen: could not establish DDE conversion with Matlab, trying to start Matlab...\n");
    // try to start Matlab
    PROCESS_INFORMATION pi;
    LPSTARTUPINFO pStartupInfo = new STARTUPINFO;
    pStartupInfo->cb = (sizeof STARTUPINFO);
    pStartupInfo->lpReserved = NULL;
    pStartupInfo->lpDesktop = NULL;
    pStartupInfo->lpTitle = NULL;
    pStartupInfo->dwFlags = STARTF_USESHOWWINDOW | 
                            STARTF_FORCEONFEEDBACK;
    pStartupInfo->wShowWindow = SW_SHOWMINIMIZED;
    pStartupInfo->cbReserved2 = 0;
    pStartupInfo->lpReserved2 = NULL;

    if (!CreateProcess (startcmd,NULL,
                        NULL,NULL,FALSE,CREATE_SEPARATE_WOW_VDM,NULL,NULL,
                        pStartupInfo,&pi))
    {
      TRACE0("Could not create the Matlab process\n");
      delete ep;
      delete pStartupInfo;
      return NULL;
    }
    // The WaitForInputIdle is not enough to successfully synchonize with Matlab
    DWORD resCode = WaitForInputIdle(pi.hProcess,INFINITE); // Wait until Matlab has started, but wait maximum 30 seconds
    if (resCode == -1)
    {
      TRACE0("engOpen: Wait for input idle failed\n");
      DWORD lastError = GetLastError();
      delete ep;
      delete pStartupInfo;
      return NULL;
    }
    else if (resCode == WAIT_TIMEOUT)
    {
      TRACE0("engOpen: Impossible error: timeout is set to INFINITE so there should be no time out\n");
      delete ep;
      delete pStartupInfo;
      return NULL;
    }
    delete pStartupInfo;
    HSZ hszService = DdeCreateStringHandle (ep->m_idInst, "Matlab", 0);
    HSZ hszTopic   = DdeCreateStringHandle (ep->m_idInst, "Engine", 0);
    for (UINT i = 0; i < l_ddeConvInitRetries; i++)
    {
      ep->m_hConv = DdeConnect (ep->m_idInst, hszService, hszTopic, NULL);
      if (ep->m_hConv)
      { // successful connection
        TRACE2("DDE conversion established on trial %d with %d ms wait time between trials.\n",i+1,l_ddeConvInitSleepTime);
        break;
      }
      Sleep(l_ddeConvInitSleepTime); // sleep for some time
    }
    DdeFreeStringHandle (ep->m_idInst, hszService);
    DdeFreeStringHandle (ep->m_idInst, hszTopic);
    if (!ep->m_hConv)
    {
      TRACE0("engOpen: could still not establish DDE conversion with Matlab even after starting Matlab.\n");
      TRACE2("Tried %d times with %d ms wait time inbetween each.\n",l_ddeConvInitRetries,l_ddeConvInitSleepTime);
      UINT lastError = DdeGetLastError(ep->m_idInst);
      TRACE0((const char*)("The DDE error code is: "+GetDdeErrorMsg(lastError)+"\n"));
      delete ep;
      return NULL;
    }

    // Execute a simple DDE transaction to make sure the Matlab server is ready. This is necessary with Matlab
    // version 4.2x because sometimes even if the DDE conversion could be established Matlab is not quite ready.
    BOOL transactionOk = FALSE;
    for (i = 0; i < l_ddeConvInitRetries; i++)
    {
      CString version, siteId;
      if (GetMatlabVersion(ep,&version,&siteId))
      { // successful first DDE transaction
        TRACE2("engOpen: first DDE transaction successfull on trial %d with %d ms wait time between trials.\n",i+1,l_ddeConvInitSleepTime);
        TRACE2("Matlab Version %s, site ID %s\n",(const char*)version, (const char*)siteId);
        transactionOk = TRUE;
        break;
      }
      Sleep(l_ddeConvInitSleepTime); // sleep for some time
    }
    if (!transactionOk)
    {
      TRACE0("engOpen: could establish DDE conversion with Matlab but the test transaction doesn't succeed.\n");
      TRACE2("Tried %d times with %d ms wait time inbetween each.\n",l_ddeConvInitRetries,l_ddeConvInitSleepTime);
      engClose(ep);
      return NULL;
    }
  }
  return ep;
}

int engClose(Engine *ep)
{
  ASSERT (ep);
  DdeUninitialize (ep->m_idInst);
  if (l_traceDdeTransaction) { TRACE0("engClose: DdeUninitialized called\n"); }
  delete ep;
  return 0;
}

int engEvalString(Engine *ep, const char *string)
{
  ASSERT (ep);
  ASSERT (string);
  HSZ hszItem = DdeCreateStringHandle (ep->m_idInst, "EngEvalString", 0);
  //Two alternatives for the transaction:
  //both work (well, I thought, but the second does not under Win32s ...)
  HDDEDATA hCmd = DdeCreateDataHandle(ep->m_idInst,(LPBYTE)string,strlen(string)+1,0,
                                      NULL,CF_TEXT,NULL);
  HDDEDATA res = DdeClientTransaction((LPBYTE)hCmd,0xFFFFFFFF,ep->m_hConv,hszItem,CF_TEXT,XTYP_EXECUTE,ep->m_timeout,NULL);
  DdeFreeStringHandle (ep->m_idInst, hszItem);

  if (l_traceDdeTransaction) { TRACE1("engEvalString: Execute transaction done. The command was:\n%s\n",string); }
  
  //Alternative 2: using the CString object directly in the function call
  //HDDEDATA res = DdeClientTransaction((LPBYTE)string,strlen(string)+1,
  //                     ep->m_hConv,hszItem,CF_TEXT,XTYP_EXECUTE,
  //                     ep->m_timeout,NULL);

  if (!res)
  {
    DWORD error = DdeGetLastError (ep->m_idInst);
    CString errMsg = "engEvalString: DDE Error: " + GetDdeErrorMsg(error);
    TRACE0(errMsg+"\n");
    return 1;
  }

  // Get the result of the execution (if output buffer has been defined or tracing is on)
  if (ep->m_bufLen != -1 || l_traceEvalStringResult)
  {
    if (ep->m_bufLen != -1)
      ASSERT (ep->m_pBuf);
    else
      ASSERT (!ep->m_pBuf);
    HSZ hszItem = DdeCreateStringHandle(ep->m_idInst,"EngStringResult", 0);
    HDDEDATA hData = DdeClientTransaction(NULL,0,ep->m_hConv,hszItem,CF_TEXT,XTYP_REQUEST,ep->m_timeout,NULL);
    if (l_traceDdeTransaction) { TRACE0("engEvalString: Request 'EngStringResult' transaction done.\n"); }
    DdeFreeStringHandle (ep->m_idInst, hszItem);
    if (!hData)
    {
      DWORD error = DdeGetLastError (ep->m_idInst);
      CString errMsg = "engEvalString: DDE Error when retrieving EngStringResult: " + GetDdeErrorMsg(error);
      TRACE0(errMsg+"\n");
      return 1;
    }
    DWORD dataSize;
    LPBYTE pData = DdeAccessData(hData,&dataSize);
    DWORD maxI=dataSize;
    if (maxI >= DWORD(ep->m_bufLen)) maxI = DWORD(ep->m_bufLen)-1; // don't use the last character because
                                                     // it is for the null-termination of the string.
    char *pBuf = new char[dataSize+1];
    // fill at the same time pBuf which will be used for the trace command
    // and ep->m_pBuf which is the buffer set by engOutputBuffer()
    for (DWORD i=0; i<dataSize; i++)
    {
      pBuf[i] = *(pData+i);
      if (i<maxI) ep->m_pBuf[i] = pBuf[i]; // if no engOutputBuffer() defined => gets never executed
    }
    if (ep->m_pBuf) ep->m_pBuf[min(i,maxI+1)] = '\0';
    DdeUnaccessData(hData);
    if (l_traceEvalStringResult) { TRACE1("engEvalString: result of command is:\n%s\n",pBuf); }
    delete [] pBuf;
  }
  return 0;
}

int engGetFull(Engine *ep, const char *name, int *m, int *n, double **pr, double **pi)
{
  ASSERT (ep);
  ASSERT (name);
  ASSERT (m);
  ASSERT (n);
  ASSERT (pr);
  Matrix *pMatrix = engGetMatrix(ep, name);
  if (!pMatrix)
    return 1; // error
  *m = pMatrix->dim[0];
  *n = pMatrix->dim[1];
  *pr = pMatrix->pr;
  *pi = pMatrix->pi;
  // Delete pMatrix: instead of using the mxFreeMatrix I use a simple 
  // "delete pMatrix" so that the arrays of double pointed to by
  // pr and pi are not deleted.
  delete pMatrix;
  return 0;
}

int engPutFull(Engine *ep, const char *name, int m, int n, double *pr, double *pi)
{
  ASSERT (ep);
  ASSERT (name);
  ASSERT (m>0);
  ASSERT (n>0);
  ASSERT (pr);
  long imag_flag = REAL;
  if (pi) imag_flag = COMPLEX;
  Matrix *pMatrix = mxCreateFull(m,n,imag_flag);
  mxSetName(pMatrix,name);
  // The allocated double arrays are not needed, delete them
  delete pMatrix->pr;
  delete pMatrix->pi;
  pMatrix->pr = pr;
  pMatrix->pi = pi;
  int res = engPutMatrix(ep, pMatrix);
  // Delete pMatrix: instead of using the mxFreeMatrix I use a simple 
  // "delete pMatrix" so that the arrays of double pointed to by
  // pr and pi are not deleted.
  delete pMatrix;
  return res;
}

Matrix *engGetMatrix(Engine *ep, const char *name)
{
  HSZ hszItem = DdeCreateStringHandle(ep->m_idInst,(char*)name, 0);
  HDDEDATA hData = DdeClientTransaction(NULL,0,ep->m_hConv,hszItem,l_cbFormat,XTYP_REQUEST,ep->m_timeout,NULL);
  DdeFreeStringHandle (ep->m_idInst, hszItem);
  if (l_traceDdeTransaction) { TRACE1("engGetMatrix: Request '%s' transaction done.\n",name); }
  if (!hData)
  {
    DWORD error = DdeGetLastError (ep->m_idInst);
    CString errMsg = "engGetMatrix: DDE Error: " + GetDdeErrorMsg(error);
    TRACE0(errMsg+"\n");
    return NULL;
  }

  // decode header
  UINT dOffset = 64;
  BOOL real = TRUE;
  BOOL string = FALSE;
  DWORD dataSize;
  LPBYTE pData = DdeAccessData(hData,&dataSize);
  if (*(pData+28))
    string = TRUE;
  if (*(pData+48))
    real = FALSE;
  UINT m = *(UINT*)(pData+36);
  UINT n = *(UINT*)(pData+40);

  // create matrix structure and fill in header information
  long imag_flag;
  if (real) imag_flag = REAL; else imag_flag = COMPLEX;
  Matrix *pMatrix = mxCreateFull (m,n,imag_flag);
  if (string) mxSetString(pMatrix);
  UINT imOffset = m*n*8;
  for (UINT i=0; i<m; i++)
  {
    for (UINT j=0; j<n; j++)
    {
      *(pMatrix->pr+(j*m+i)) = *(double*)(pData+dOffset+(j*m+i)*8);
      if (!real)
        *(pMatrix->pi+(j*m+i)) = *(double*)(pData+dOffset+imOffset+(j*m+i)*8);
    }
  }
  DdeUnaccessData(hData);
  //TraceDdeData (hData);
  return pMatrix;
}

int engPutMatrix(Engine *ep, Matrix *mp)
{
  ASSERT(ep);
  ASSERT(mp);
  UINT m,n;
  m = mp->dim[0];
  n = mp->dim[1];
  UINT dOffset = 64;
  UINT imOffset = m*n*8;
  BOOL real = TRUE;
  if (mp->pi) real = FALSE;
  BOOL string = TRUE;
  if (!mxIsString(mp)) string = FALSE;
  int dataSize = dOffset + imOffset;
  if (!real) dataSize += imOffset;
  LPBYTE pData = new BYTE [dataSize];
  memset (pData,0,dataSize);
  char *p = mp->name;
  for (UINT i=0; i<mxMAXNAM && *p ; (i++,p++))
    *(pData+i) = (BYTE)*p;
  *(pData+28)= (BYTE)string;
  *(UINT*)(pData+36)= m;
  *(UINT*)(pData+40)= n;
  if (!real)
  {
    *(pData+48) = 1;
    *(pData+49) = 1;
    *(pData+50) = 1;
  }
  for (i=0; i<m; i++)
  {
    for (UINT j=0; j<n; j++)
    {
      *(double*)(pData+dOffset+(j*m+i)*8) = *(mp->pr+(j*m+i));
      if (!real)
        *(double*)(pData+dOffset+imOffset+(j*m+i)*8) = *(mp->pi+(j*m+i));
    }
  }
  HSZ hszItem = DdeCreateStringHandle(ep->m_idInst,mp->name, 0);
  HDDEDATA hData = DdeCreateDataHandle(ep->m_idInst,pData,dataSize,0,hszItem,l_cbFormat,NULL);
  //TraceDdeData (hData);
  HDDEDATA hData2 = DdeClientTransaction((LPBYTE)hData,0xFFFFFFFF,ep->m_hConv,hszItem,l_cbFormat,XTYP_POKE,ep->m_timeout,NULL);
  if (l_traceDdeTransaction) { TRACE1("engPutMatrix: Poke '%s' transaction done.\n",mp->name); }
  delete [] pData;
  if (!hData2)
  {
    DWORD error = DdeGetLastError (ep->m_idInst);
    CString errMsg = "engPutMatrix: DDE Error: " + GetDdeErrorMsg(error);
    TRACE0(errMsg+"\n");
    return 1;
  }
  return 0;
}

void engSetEvalTimeout(Engine *ep, unsigned long timeout)
{
  ASSERT (ep);
  ep->m_timeout = timeout;
}

void engOutputBuffer(Engine *ep, char *p, int n)
{
  ASSERT (ep);
  ep->m_pBuf = p;
  if (!ep->m_pBuf)
    ep->m_bufLen = -1;
  else
    ep->m_bufLen = n;
}

// Matrix handling

/* 
 * Get pointer to matrix name.
 */
char  *mxGetName(
	const Matrix *pm					/* pointer to matrix */
	)
{
  ASSERT(pm);
  return (char*)pm->name;
}


/* 
 * Set matrix name.  This routine copies the string pointed to by s
 * into the mxMAXNAM length character name field.
 */
void  mxSetName(
	Matrix *pm,					/* pointer to matrix */
	const char *s				/* string to copy into name */
	)
{
  ASSERT(pm);
  memset(pm->name,'\0',mxMAXNAM);
  UINT iMax = min (strlen(s),mxMAXNAM);
  for (UINT i=0; i<iMax; i++)
    pm->name[i] = s[i];
}


/* 
 * Get matrix structure
 */
mxMatrixStructure mxGetStruc(	
	const Matrix *pm	/* pointer to matrix */
	)
{
  ASSERT(pm);
  return pm->struc;
}


/* 
 * Set matrix structure
 */
//extern	void mxSetStruc(			
//	Matrix *pm,			/* pointer to matrix */
//	mxMatrixStructure k	/* matrix structure type */
//	);


/* 
 * Get matrix type
 */
mxMatrixType mxGetType(	
	const Matrix *pm	/* pointer to matrix */
	)
{
  ASSERT(pm);
  return pm->type;
}


/* 
 * Set matrix type
 */
//extern	void mxSetType(			
//	Matrix *pm,			/* pointer to matrix */
//	mxMatrixType k		/* matrix structure type */
//	);


/* 
 * Get matrix display mode
 */
mxDisplayMode mxGetDispMode(	
	const Matrix *pm	/* pointer to matrix */
	)
{
  ASSERT(pm);
  return pm->dmode;
}


/* 
 * Set matrix display mode
 */
void mxSetDispMode(		
	Matrix *pm,			/* pointer to matrix */
	mxDisplayMode k		/* display mode */
	)
{
  ASSERT(pm);
  pm->dmode = k;
}

/* 
 * Set matrix display mode to STRING
 */
void mxSetString(
	Matrix *pm					/* pointer to matrix */
	)
{
  ASSERT(pm);
  pm->dmode = mxSTRING;
}


/* 
 * Get pointer to matrix tag.
 */
//extern	char *mxGetTag(
//	const Matrix *pm					/* pointer to matrix */
//	);

 
/* 
 * Set matrix tag.  This routine copies the string pointed to by s
 * into the mxMAXTAG character tag field.
 */
//extern	void mxSetTag(
//	Matrix *pm,					/* pointer to matrix */
//	const char *s);					/* string to copy into tag */

 
/* 
 * Get row dimension
 */
FOUR_BYTE_INT  mxGetM(
	const Matrix *pm					/* pointer to matrix */
	)
{
  ASSERT(pm);
  return pm->dim[0];
}

 
/* 
 * Set row dimension
 */
//extern	void  mxSetM(
//	Matrix *pm,					/* pointer to matrix */
//	FOUR_BYTE_INT m						/* row dimension */
//	);

 
/* 
 * Get column dimension
 */
FOUR_BYTE_INT  mxGetN(
	const Matrix *pm					/* pointer to matrix */
	)
{
  ASSERT(pm);
  return pm->dim[1];
}

 
/* 
 * Set column dimension
 */
//extern	void  mxSetN(
//	Matrix *pm,					/* pointer to matrix */
//	FOUR_BYTE_INT n						/* column dimension */
//	);

 
/* 
 * Get pointer to real part
 */
double  *mxGetPr(
	const Matrix *pm					/* pointer to matrix */
	)
{
  ASSERT(pm);
  return pm->pr;
}

 
/* 
 * Set pointer to real part
 */
//extern	void  mxSetPr(		
//	Matrix *pm,					/* pointer to matrix */	
//	double *pr					/* pointer to real part */
//	);

 
/* 
 * Get pointer to imag part
 */
double *mxGetPi(
	const Matrix *pm					/* pointer to matrix */	
	)
{
  ASSERT(pm);
  return pm->pi;
}

 
/* 
 * Set pointer to imag part
 */
//extern	void  mxSetPi(		
//	Matrix *pm,					/* pointer to matrix */
//	double *pi					/* pointer to imag part */
//	);


/* 
 * Get pointer to dimension array.
 */
//extern	FOUR_BYTE_INT *mxGetDim(
//	const Matrix *pm					/* pointer to matrix */
//	);


/* 
 * Set dimension array.  This routine copies the array pointed
 * to by pdim into the mxMAXDIM length dimension field.
 */
//extern	void mxSetDim(
//	Matrix *pm,					/* pointer to matrix */
//	FOUR_BYTE_INT *pdim					/* dimension array */
//	);

 
/* 
 * Get number of nonzero elements of sparse matrix
 */
//extern	FOUR_BYTE_INT  mxGetNzmax(		
//	const Matrix *pm					/* pointer to matrix */
//	);

 
/* 
 * Set number of nonzero elements of sparse matrix
 */
//extern	void  mxSetNzmax(
//	Matrix *pm,					/* pointer to matrix */
//	FOUR_BYTE_INT nzmax					/* number of nonzero elements */
//	);

 
/* 
 * Get pointer to sparse ir array
 */
//extern	FOUR_BYTE_INT  *mxGetIr(
//	const Matrix *pm					/* pointer to matrix */
//	);	

 
/* 
 * Set pointer to sparse ir array
 */
//extern	void  mxSetIr(		
//	Matrix *pm,					/* pointer to matrix */
//	FOUR_BYTE_INT *ir						/* pointer to ir array */
//	);

 
/* 
 * Get pointer to sparse jc array
 */
//extern	FOUR_BYTE_INT  *mxGetJc(	
//	const Matrix *pm					/* pointer to matrix */
//	);	

 
/*
 * Set pointer to sparse jc array 
 */
//extern	void  mxSetJc(		
//	Matrix *pm,					/* pointer to matrix */
//	FOUR_BYTE_INT *jc						/* pointer to sparse jc array */
//	);

 
/*
 * Indicate if there is a complex part to the matrix
 */
int mxIsComplex(
	const Matrix	*pm						/* pointer to matrix */
	)
{
  ASSERT(pm);
  if (pm->pi) return 1; else return 0;
}
 
/*
 * Indicate if matrix argument is of type real
 */
int mxIsDouble(
	const Matrix *pm					/* pointer to matrix */
	)
{
  ASSERT (pm);
  ASSERT (pm->type == mxDOUBLE); // this implementation does not allow any other type
  return pm->type == mxDOUBLE;
}

 
/*
 * Indicate if matrix argument is full
 */
//extern	int  mxIsFull(
//	const Matrix *pm					/* pointer to matrix */
//	);

 
/*
 * Indicate if data is to be represented as a string
 */
int mxIsNumeric(const Matrix	*pm	/* pointer to matrix */)
{
  return !mxIsString(pm);
}
 
/*
 * Indicate if matrix argument is sparse
 */
//extern	int  mxIsSparse(
//	const Matrix *pm					/* pointer to matrix */
//	);

 
/* 
 * Return 1 if matrix contains a string, 0 otherwise
 */
int mxIsString(const Matrix *pm /* pointer to matrix */)
{
  ASSERT (pm);
  return pm->dmode == mxSTRING;
}

 
/*
 * Convert MATLAB string to C string
 */
int mxGetString(
	Matrix	*pm,					/* pointer to matrix */
	char 	*str_ptr,				/* pointer to string holding results */
	FOUR_BYTE_INT str_len			/* length of string that holds results */
	)
{
  ASSERT(pm);
  ASSERT(str_ptr);
  ASSERT (pm->struc == mxFULL);
  ASSERT (pm->type == mxDOUBLE);
  ASSERT (pm->dim[0] > 0);
  ASSERT (pm->dim[1] > 0);
  if (pm->dmode != mxSTRING) return 1; // matrix is not of type string => error
  int curPos = 0;
  for (int i=0; i<pm->dim[0] && curPos < str_len; i++) // each row
  {
    for (int j=0; j<pm->dim[1] && curPos < str_len; (j++,curPos++)) // each columns
      str_ptr[curPos] = (char)pm->pr[j*pm->dim[0]+i];
    str_ptr[curPos++] = '\0';
  }
  if (pm->dim[0]*(pm->dim[1]+1) > str_len)
    return 1; // error: not all characters could be copied to destination
  else
    return 0;
}

 
/*
 * Return first value of double matrix
 */
double mxGetScalar(Matrix	*pm)
{
  ASSERT (pm);
  ASSERT (pm->struc == mxFULL);
  ASSERT (pm->type == mxDOUBLE);
  ASSERT (pm->dim[0] > 0);
  ASSERT (pm->dim[1] > 0);
  return pm->pr[0];
}

#define REAL    0
#define COMPLEX 1
#define IMAG    1

Matrix *mxCreateFull(long m, long n, long imag_flag)
{
  Matrix *pMatrix = new Matrix;
  pMatrix->struc = mxFULL;
  pMatrix->type = mxDOUBLE;
  pMatrix->dmode = mxNUMBER;
  pMatrix->tag[0] = '\0';
  pMatrix->dim[0] = m; // number of rows
  pMatrix->dim[1] = n; // number of columns
  pMatrix->pr = new double [m*n];
  for (int i=0; i<m*n; i++) pMatrix->pr[i] = 0.0;
  if (imag_flag == COMPLEX || imag_flag == IMAG)
  {
    pMatrix->pi = new double [m*n];
    for (int i=0; i<m*n; i++) pMatrix->pi[i] = 0.0;
  }
  else
    pMatrix->pi = NULL;
  return pMatrix;
}

void mxFreeMatrix(Matrix *pmat)
{
  ASSERT (pmat);
  ASSERT (pmat->pr);
  delete [] pmat->pr;
  if (pmat->pi) delete [] pmat->pi;
  delete pmat;
}

//extern	void *mxCalloc(unsigned int n, unsigned int size);
//Use normal memory allocation schemes for all allocation except for the
//allocation of Matrix sturctures which you should do through mxCreateFull() or mxCreateString().

//extern	void    mxFree(void *p);

//extern	Matrix  *mxCreateSparse(
//	long    m,
//	long    n,
//	long    nzmax,
//	long    cmplx
//	);


Matrix *mxCreateString(const char *str_ptr)
{
  UINT len = strlen(str_ptr);
  Matrix *pMatrix = mxCreateFull(1,len,REAL);
  double *pR = mxGetPr (pMatrix);
  for (UINT i=0; i<len; i++)
    pR[i] = double(str_ptr[i]);
  mxSetDispMode(pMatrix,mxSTRING);
  return pMatrix;
}
