#ifdef HTRACE
#pragma message ("-engine32.h")
#endif

#ifndef _engine_h_

#ifdef HTRACE
#pragma message (">engine32.h")
#endif

#define _engine32_h_


// this library should be used only for 32-bit developments
// use the Mathworks provided library for 16-bit developments

#ifdef WIN32

#include <windows.h>
#include <ddeml.h>

class Engine
{
  public:
    Engine();
    unsigned long  m_timeout;
    DWORD          m_idInst;
    HCONV          m_hConv;
    char          *m_pBuf;
    int            m_bufLen;
};

#define FOUR_BYTE_INT int

/*
 * Enumerate matrix structures
 */
typedef FOUR_BYTE_INT mxMatrixStructure;
#define	mxFULL			0	/* full matrix */
// not used:
//#define	mxSPARSE		1	/* sparse matrix */
//#define	mxCOLON			2	/* colon operator */
//#define	mxGLOBAL		3	/* global (internal parse only) */
//#define	mxUNASSIGNED	4	/* unassigned variable flag */
//#define	mxCLEARMAT		5	/* cleared variable flag */
//#define	mxUNASSARG		6	/* unassigned M-file arg */
//#define	mxRHSUNASSIGNED	7	/* undefined symbol */
//#define	mxASSIGNED		8	/* assigned variable flag */
//#define	mxSPAM			9	/* spam format matrix */

/*
 * Enumerate matrix types
 */
typedef FOUR_BYTE_INT mxMatrixType;
#define	mxDOUBLE		0	/* double precision */
// not used:
//#define	mxFLOAT			1	/* single precision */
//#define	mxLONGINT		2	/* 32 bit signed int */
//#define	mxSHORTINT		3	/* 16 bit signed int */
//#define	mxUSHORTINT		4	/* 16 bit unsigned int */
//#define	mxUCHAR			5	/* 8 bit unsigned char/int */

/*
 * Enumerate display modes
 */
typedef FOUR_BYTE_INT mxDisplayMode;
#define	mxNUMBER 		0	/* Display as a number */
#define	mxSTRING 		1	/* Display as a string */

#define mxMAXNAM	20	/* maximum name length */
#define mxMAXTAG	4	/* maximum tag length */
#define	mxMAXDIM	2	/* maximum array dimension */

#define HUGE

class Matrix
{
  public:
    char name[mxMAXNAM];
  	FOUR_BYTE_INT   struc;
  	FOUR_BYTE_INT   type;
  	FOUR_BYTE_INT   dmode;
  	char            tag[mxMAXTAG];
  	FOUR_BYTE_INT   dim[mxMAXDIM];  /* array of dimensions */
  	double          HUGE *pr;       /* pointer to real part */
  	double          HUGE *pi;       /* pointer to imag part */

    // Not used
//  	FOUR_BYTE_INT	  nzmax;          /* number of nonzero sparse entries */
//  	FOUR_BYTE_INT	  HUGE *jc;       /* sparse indices */
//  	FOUR_BYTE_INT   HUGE *ir;       /* sparse indices */
};

void SetDdeConvInitValues (UINT ddeConvInitRetries = 10, UINT ddeConvInitSleepTime = 1000);
//
// Set the DDE conversation initialization values:
//   ddeConvInitRetries:   defines the number of times engOpen will try to connect
//                         to the Matlab server before returning an error.
//   ddeConvInitSleepTime: defines the time (in ms) that engOpen will wait between
//                         retries.
//----------------------------------------------------------------------------------------

void GetDdeConvInitValues (UINT *pDdeConvInitRetries, UINT *pDdeConvInitSleepTime);
//
// Get the current DDE converstaion initialization values.
//----------------------------------------------------------------------------------------

void SetTraceOptions (BOOL traceDdeTransaction = TRUE, BOOL traceEvalStringResult = TRUE);
//
// Defines the trace options (MFC tracing):
//   traceDdeTransaction   : if TRUE each DDE transaction is traced
//   traceEvalStringResult : if TRUE each engEvalString call traces the result string.
//----------------------------------------------------------------------------------------

void GetTraceOptions (BOOL *pTraceDdeTransaction, BOOL *pTraceEvalStringResult);
//
// Get the current trace options.
//----------------------------------------------------------------------------------------

void engWinInit(HANDLE hInst);
Engine *engOpen(const char *startcmd);
int engClose(Engine *ep);

int engEvalString(Engine *ep, const char *string);
int engGetFull(Engine *ep, const char *name, int *m, int *n, double **pr, double **pi);
int engPutFull(Engine *ep, const char *name, int m, int n, double *pr, double *pi);
Matrix *engGetMatrix(Engine *ep, const char *name);
int engPutMatrix(Engine *ep, Matrix *mp);

void engSetEvalTimeout(Engine *ep, unsigned long timeout);
void engOutputBuffer(Engine *ep, char *p, int n);



// Matrix handling

/* 
 * Get pointer to matrix name.
 */
extern  char  *mxGetName(
	const Matrix *pm					/* pointer to matrix */
	);


/* 
 * Set matrix name.  This routine copies the string pointed to by s
 * into the mxMAXNAM length character name field.
 */
extern	void  mxSetName(
	Matrix *pm,					/* pointer to matrix */
	const char *s				/* string to copy into name */
	);			


/* 
 * Get matrix structure
 */
extern	mxMatrixStructure mxGetStruc(	
	const Matrix *pm	/* pointer to matrix */
	);


/* 
 * Set matrix structure
 */
//extern	void mxSetStruc(			
//	Matrix *pm,			/* pointer to matrix */
//	mxMatrixStructure k	/* matrix structure type */
//	);


/* 
 * Get matrix type
 */
extern	mxMatrixType mxGetType(	
	const Matrix *pm	/* pointer to matrix */
	);


/* 
 * Set matrix type
 */
//extern	void mxSetType(			
//	Matrix *pm,			/* pointer to matrix */
//	mxMatrixType k		/* matrix structure type */
//	);


/* 
 * Get matrix display mode
 */
extern	mxDisplayMode mxGetDispMode(	
	const Matrix *pm	/* pointer to matrix */
	);


/* 
 * Set matrix display mode
 */
extern	void mxSetDispMode(		
	Matrix *pm,			/* pointer to matrix */
	mxDisplayMode k		/* display mode */
	);


/* 
 * Set matrix display mode to STRING
 */
extern	void mxSetString(
	Matrix *pm					/* pointer to matrix */
	);


/* 
 * Get pointer to matrix tag.
 */
//extern	char *mxGetTag(
//	const Matrix *pm					/* pointer to matrix */
//	);

 
/* 
 * Set matrix tag.  This routine copies the string pointed to by s
 * into the mxMAXTAG character tag field.
 */
//extern	void mxSetTag(
//	Matrix *pm,					/* pointer to matrix */
//	const char *s);					/* string to copy into tag */

 
/* 
 * Get row dimension
 */
extern	FOUR_BYTE_INT  mxGetM(
	const Matrix *pm					/* pointer to matrix */
	);	

 
/* 
 * Set row dimension
 */
//extern	void  mxSetM(
//	Matrix *pm,					/* pointer to matrix */
//	FOUR_BYTE_INT m						/* row dimension */
//	);

 
/* 
 * Get column dimension
 */
extern	FOUR_BYTE_INT  mxGetN(
	const Matrix *pm					/* pointer to matrix */
	);

 
/* 
 * Set column dimension
 */
//extern	void  mxSetN(
//	Matrix *pm,					/* pointer to matrix */
//	FOUR_BYTE_INT n						/* column dimension */
//	);

 
/* 
 * Get pointer to real part
 */
extern	double  *mxGetPr(
	const Matrix *pm					/* pointer to matrix */
	);

 
/* 
 * Set pointer to real part
 */
//extern	void  mxSetPr(		
//	Matrix *pm,					/* pointer to matrix */	
//	double *pr					/* pointer to real part */
//	);

 
/* 
 * Get pointer to imag part
 */
extern	double  *mxGetPi(
	const Matrix *pm					/* pointer to matrix */	
	);	

 
/* 
 * Set pointer to imag part
 */
//extern	void  mxSetPi(		
//	Matrix *pm,					/* pointer to matrix */
//	double *pi					/* pointer to imag part */
//	);


/* 
 * Get pointer to dimension array.
 */
//extern	FOUR_BYTE_INT *mxGetDim(
//	const Matrix *pm					/* pointer to matrix */
//	);


/* 
 * Set dimension array.  This routine copies the array pointed
 * to by pdim into the mxMAXDIM length dimension field.
 */
//extern	void mxSetDim(
//	Matrix *pm,					/* pointer to matrix */
//	FOUR_BYTE_INT *pdim					/* dimension array */
//	);

 
/* 
 * Get number of nonzero elements of sparse matrix
 */
//extern	FOUR_BYTE_INT  mxGetNzmax(		
//	const Matrix *pm					/* pointer to matrix */
//	);

 
/* 
 * Set number of nonzero elements of sparse matrix
 */
//extern	void  mxSetNzmax(
//	Matrix *pm,					/* pointer to matrix */
//	FOUR_BYTE_INT nzmax					/* number of nonzero elements */
//	);

 
/* 
 * Get pointer to sparse ir array
 */
//extern	FOUR_BYTE_INT  *mxGetIr(
//	const Matrix *pm					/* pointer to matrix */
//	);	

 
/* 
 * Set pointer to sparse ir array
 */
//extern	void  mxSetIr(		
//	Matrix *pm,					/* pointer to matrix */
//	FOUR_BYTE_INT *ir						/* pointer to ir array */
//	);

 
/* 
 * Get pointer to sparse jc array
 */
//extern	FOUR_BYTE_INT  *mxGetJc(	
//	const Matrix *pm					/* pointer to matrix */
//	);	

 
/*
 * Set pointer to sparse jc array 
 */
//extern	void  mxSetJc(		
//	Matrix *pm,					/* pointer to matrix */
//	FOUR_BYTE_INT *jc						/* pointer to sparse jc array */
//	);

 
/*
 * Indicate if there is a complex part to the matrix
 */
extern	int  mxIsComplex(
	const Matrix	*pm						/* pointer to matrix */
	);

 
/*
 * Indicate if matrix argument is of type real
 */
extern	int  mxIsDouble(
	const Matrix *pm					/* pointer to matrix */
	);

 
/*
 * Indicate if matrix argument is full
 */
//extern	int  mxIsFull(
//	const Matrix *pm					/* pointer to matrix */
//	);

 
/*
 * Indicate if data is to be represented as a string
 */
extern	int mxIsNumeric(
	const Matrix	*pm						/* pointer to matrix */
	);

 
/*
 * Indicate if matrix argument is sparse
 */
//extern	int  mxIsSparse(
//	const Matrix *pm					/* pointer to matrix */
//	);

 
/* 
 * Return 1 if matrix contains a string, 0 otherwise
 */
extern	int  mxIsString(
	const Matrix *pm					/* pointer to matrix */
	);

 
/*
 * Convert MATLAB string to C string
 */
extern	int  mxGetString(
	Matrix	*pm,					/* pointer to matrix */
	char 	*str_ptr,				/* pointer to string holding results */
	FOUR_BYTE_INT str_len			/* length of string that holds results */
	);

 
/*
 * Return first value of double matrix
 */
extern	double  mxGetScalar(
	Matrix	*pm
	);



#define REAL    0
#define COMPLEX 1
#define IMAG    1



extern	Matrix  *mxCreateFull(long m, long n, long imag_flag);


extern	void    mxFreeMatrix(Matrix     *pmat);


//extern	void *mxCalloc(unsigned int n, unsigned int size);
//Use normal memory allocation schemes for all allocation except for the
//allocation of Matrix sturctures which you should do through mxCreateFull() or mxCreateString().

//extern	void    mxFree(void *p);
void mxFree(void *p); // to be used only to delete arrays of doubles returned
                      // by engGetFull(...)



//extern	Matrix  *mxCreateSparse(
//	long    m,
//	long    n,
//	long    nzmax,
//	long    cmplx
//	);


extern	Matrix  *mxCreateString(const char *str_ptr);



#else
  #error "This library is for 32-bit developments only"
#endif

#ifdef HTRACE
#pragma message ("<engine.h")
#endif

#endif /* _engine32_h_ */
