#include "stdafx.h"
#include <ddeml.h>
//#include <rw\cgenmat.h>
//#include <rw\dgenmat.h>
//#include <rw\pstream.h>
#include <fstream.h>
#include <memory.h>
#include "..\\src\\engine32.h"
#include "mldde.h"
#include "optdlg.h"

/////////////////////////////////////////////////////////////////////////////////////
//
// Reference data
//

const int NB_ROWS = 3;
const int NB_COLS = 4;
double MAT_REAL[NB_ROWS][NB_COLS] = {1,2,3.1415,-234.324,
                                    75.25,-5.347,1.7e-5,5.05,
                                   -2.23,-1.1254,0,1.58795e7};
double MAT_IMAG[NB_ROWS][NB_COLS] = {0.5,-2.2,-360,0.0254,
                                    1.7584,-1.523547,-0.2514,0,
                                    3.33325,6.666666667,-1.2,-2.7};


/////////////////////////////////////////////////////////////////////////////////////
//
//
//


void TraceDdeData (const HDDEDATA &hData);

CString SubString(char *s, int len, int index)
{
  CString s0;
  int i = -1;
  int pos = 0;
  while (i != index && pos < len)
  {
    s0 = "";
    while (pos < len && s[pos] != '\0')
      s0 += s[pos++];
    i++;
    pos++; // to skip the '\0' char.
  }
  if (i == index)
    return s0;
  else
    return "";
}

CMyApp::CMyApp()
{
}

CMyApp NEAR cMyApp;

BEGIN_MESSAGE_MAP( CMyApp, CWinApp )
  ON_COMMAND (ID_MATLABENGINE_SENDCOMMAND, OnSendCommand)
  ON_COMMAND (ID_MATLABENGINE_SENDMATRIX, OnSendMatrix)
  ON_COMMAND (ID_MATLABENGINE_GETMATRIX, OnGetMatrix)
  ON_COMMAND (ID_TOOLS_OPTIONS, OnOptions)
  ON_COMMAND (ID_TOOLS_TEST, OnTest)
END_MESSAGE_MAP()

#define new DEBUG_NEW

BOOL CMyApp::InitInstance()
{
  // Init windows
  CFrameWnd *pWnd;
  pWnd = new CFrameWnd;
  pWnd->LoadFrame(IDR_MAINFRAME);
  pWnd->ActivateFrame();
  m_pMainWnd = pWnd;

  // Init misc. vars
  m_matlabExe = "c:\\matlab\\bin\\matlab.exe";
  m_getVarName = "testget";
  m_putVarName = "testput";
  m_evalCmd = "h_temp = figure;, set(h_temp,'visible','on'), clear h_temp";
  m_ddeRetries = 10;
  m_ddeSleepTime = 1000;
  SetTraceOptions(TRUE,TRUE);
  OnOptions(); // Give a chance to change the dde initialization values
  SetDdeConvInitValues (m_ddeRetries, m_ddeSleepTime);
  {
    UINT ddeRetries;
    UINT ddeSleepTime;
    GetDdeConvInitValues(&ddeRetries,&ddeSleepTime);
    TRACE2("DdeConvInitValues: %d, %d\n",ddeRetries,ddeSleepTime);
  }

  // Init DDE link to Matlab.
  engWinInit (m_hInstance);
  int mbRes;
  do
  {
    m_ep = engOpen (m_matlabExe);
    if (!m_ep)
      mbRes = AfxMessageBox("Could not open Matlab engine.",MB_RETRYCANCEL);
  } while (!m_ep && IDCANCEL != mbRes);
  if (!m_ep) return FALSE;
  engOutputBuffer(m_ep,m_outputBuffer,OUTPUT_BUFFER_LEN);
  return TRUE;
}

int CMyApp::ExitInstance()
{
  if (m_ep) engClose (m_ep);
  return CWinApp::ExitInstance();
}

void TraceDdeData (const HDDEDATA &hData)
{
  DWORD dataSize;
  LPBYTE pData = DdeAccessData(hData,&dataSize);
  UINT relAddr = 0;
  CString temp;
  BYTE line[8];
  TRACE2("Data size: %d 0x%x\n\n",dataSize,dataSize);
  while (relAddr < dataSize)
  {
    for (UINT i=0; i<8;i++) line[i] = 0;
    UINT maxI;
    if (relAddr + 8 < dataSize)
    {
      for (i=0; i<8; i++) line[i] = *(pData+relAddr+i);
      sprintf (temp.GetBuffer(256),"%5d %4x: %2x %2x %2x %2x %2x %2x %2x %2x\n",
               relAddr,relAddr,line[0],line[1],line[2],line[3],line[4],line[5],line[6],line[7]);
      temp.ReleaseBuffer();
    }
    else
    {
      sprintf (temp.GetBuffer(256),"%5d %4x:",relAddr,relAddr);
      temp.ReleaseBuffer();
      CString t;
      maxI = dataSize - relAddr;
      for (i=0; i<maxI; i++)
      {
        line[i] = *(pData+relAddr+i);
        sprintf (t.GetBuffer(256)," %2x",line[i]);
        t.ReleaseBuffer();
        temp += t;
      }
      temp += '\n';
    }
    TRACE0(temp);
    relAddr += 8;
  }
  TRACE0("\n\nInterpretation:\n");
  UINT m = *(UINT*)(pData+36);
  UINT n = *(UINT*)(pData+40);
  TRACE2("%d x %d",m,n);
  BOOL string = FALSE;
  if (*(pData+28))
    string = TRUE;
  BOOL real = TRUE;
  if (*(pData+48))
    real = FALSE;
  if (string)
    TRACE0(" string matrix\n");
  else if (real)
    TRACE0(" real matrix\n");
  else
    TRACE0(" complex matrix\n");
  UINT dOffset = 64;
  UINT imOffset = m*n*8;
  if (string)
    for (UINT i=0; i<m; i++)
    {
      for (UINT j=0; j<n; j++)
      {
        TRACE1("%c",int(*(double*)(pData+dOffset+(j*m+i)*8)));
      }
      TRACE0("\n");
    }
  else
    for (UINT i=0; i<m; i++)
    {
      for (UINT j=0; j<n; j++)
      {
        TRACE1("%g",*(double*)(pData+dOffset+(j*m+i)*8));
        if (!real)
        {
          TRACE1(" + %gi",*(double*)(pData+dOffset+imOffset+(j*m+i)*8));
        }
        TRACE0("   ");
      }
      TRACE0("\n");
    }
  TRACE0("\n*****************************\n");
  DdeUnaccessData(hData);
}

////////////////////////////////////////////////////////////////////////////////
//
// Message handler
//

void CMyApp::OnSendCommand()
{
  engEvalString(m_ep,m_evalCmd);
  AfxMessageBox(CString("Result of engEvalString is:\n\"") + m_outputBuffer + "\"");
}

void CMyApp::OnSendMatrix()
{
  double *pr = NULL, *pi = NULL, *pr2 = NULL, *pi2 = NULL;
  pr = new double [NB_ROWS*NB_COLS];
  pr2 = pr;
  pi = new double [NB_ROWS*NB_COLS];
  pi2 = pi;
  for (UINT i=0; i<NB_ROWS; i++)
  {
    for (UINT j=0; j<NB_COLS; j++)
    {
      *pr2 = MAT_REAL[i][j];
      pr2++;
      *pi2 = MAT_IMAG[i][j];
      pi2++;
    }
  }
  if (engPutFull(m_ep,m_putVarName,NB_ROWS,NB_COLS,pr,pi))
  {
    AfxMessageBox ("OnSendMatrix: Problem sending the data to Matlab");
    return;
  }
  delete [] pr;
  delete [] pi;
}

void CMyApp::OnGetMatrix()
{
  int m,n;
  double *pr, *pi;
  if (engGetFull(m_ep,m_getVarName,&m,&n,&pr,&pi))
  {
    AfxMessageBox ("Problem getting the data");
    return;
  }
  // Compare data
  // 1) compare matrix sizes
  if (m != NB_ROWS)
    AfxMessageBox("OnGetMatrix: number of rows is wrong.");
  if (n != NB_COLS)
    AfxMessageBox("OnGetMatrix: number of columns is wrong.");
  BOOL dataOk = TRUE;
  for (int i=0; i<m; i++)
    for (int j=0; j<n; j++)
    {
      if (MAT_REAL[i][j] != pr[i*n+j]) dataOk = FALSE;
      if (pi)
        if (MAT_IMAG[i][j] != pi[i*n+j]) dataOk = FALSE;
    }
  if (dataOk)
    AfxMessageBox("OnGetMatrix: data received is identical to the data previously sent");
  else
    AfxMessageBox("OnGetMatrix: data received differs from the data previously sent");
  mxFree(pr);
  if (pi)
    mxFree(pi);
}

void CMyApp::OnOptions()
{
  UOptionsDlg dlg (m_evalCmd,m_matlabExe,m_getVarName,m_putVarName,m_ddeRetries,m_ddeSleepTime);
  if (IDOK == dlg.DoModal())
  {
  	m_evalCmd = dlg.m_evalCmd;
  	m_matlabExe = dlg.m_matlabExe;
  	m_getVarName = dlg.m_getVarName;
  	m_putVarName = dlg.m_putVarName;
    m_ddeRetries = dlg.m_ddeRetries;
    m_ddeSleepTime = dlg.m_ddeSleepTime;
    SetDdeConvInitValues (m_ddeRetries, m_ddeSleepTime);
  }
}

void CMyApp::OnTest()
{
  BeginWaitCursor();
  if (IDOK != AfxMessageBox ("This will test the Matlab engine library\n"
                             "It does all types of matrix allocations and manipulations\n"
                             "and does DDE exchanges with Matlab\n\n"
                             "You should run this program in debug mode and check\n"
                             "that there are no memory leaks",MB_OKCANCEL))
    return;
  BOOL err = FALSE;
  char string[] = "This is a string";
  char other[]  = "...........................";
  // I) Test Matrix manipulation routines
  //    1) string matrices
  Matrix *pMat = mxCreateString (string);
  if (!mxIsString(pMat))  { AfxMessageBox("Matrix should be a string matrix but is not"); err = TRUE; }
  if (mxGetM(pMat) != 1)  { AfxMessageBox("Number of rows in string matrix is not 1"); err = TRUE; }
  if (mxGetN(pMat) != 16) { AfxMessageBox("Number of cols in string matrix is not 16"); err = TRUE; }
  mxGetString (pMat,other,strlen(other));
  if (strcmp(string,other) != 0) { AfxMessageBox ("String matrix does not work correctly"); err = TRUE; }
  mxSetName(pMat,"StringVar");
  if (strcmp(mxGetName(pMat),"StringVar") != 0) { AfxMessageBox ("Matrix name is not set correctly"); err = TRUE; }
  mxFreeMatrix(pMat);

  //    2) real matrices
  pMat = mxCreateFull (3,4,REAL);
  if (!mxIsNumeric(pMat)) { AfxMessageBox("Matrix should be a numeric matrix but is not"); err = TRUE; }
  if (!mxIsDouble(pMat)) { AfxMessageBox("Matrix should be a of type double but is not"); err = TRUE; }
  if (mxIsComplex(pMat)) { AfxMessageBox("Matrix should be a real matrix but is complex"); err = TRUE; }
  if (mxGetM(pMat) != 3) { AfxMessageBox("Number of rows in real matrix is not 3"); err = TRUE; }
  if (mxGetN(pMat) != 4) { AfxMessageBox("Number of cols in real matrix is not 4"); err = TRUE; }
  double *pr = mxGetPr(pMat);
  for (UINT i=0; i<3*4; i++)
    pr[i] = 3*4-i;
  if (mxGetScalar(pMat) != 3*4) { AfxMessageBox("mxGetScalar does not return 12"); err = TRUE; }
  mxFreeMatrix(pMat);

  //    3) complex matrices
  pMat = mxCreateFull (5,6,COMPLEX);
  if (!mxIsNumeric(pMat)) { AfxMessageBox("Matrix should be a numeric matrix but is not"); err = TRUE; }
  if (!mxIsDouble(pMat)) { AfxMessageBox("Matrix should be a of type double but is not"); err = TRUE; }
  if (!mxIsComplex(pMat)) { AfxMessageBox("Matrix should be a complex matrix but is real"); err = TRUE; }
  if (mxGetM(pMat) != 5) { AfxMessageBox("Number of rows in real matrix is not 3"); err = TRUE; }
  if (mxGetN(pMat) != 6) { AfxMessageBox("Number of cols in real matrix is not 4"); err = TRUE; }
  pr = mxGetPr(pMat);
  double *pi = mxGetPi(pMat);
  for (i=0; i<5*6; i++)
  {
    pr[i] = 5*6-i;
    pi[i] = 2*(5*6-i);
  }
  if (mxGetScalar(pMat) != 5*6) { AfxMessageBox("mxGetScalar does not return 30"); err = TRUE; }
  mxFreeMatrix(pMat);

  // II) DDE link to Matlab
  //    1) evalString and simple 1x1 real matrix retreival
  engEvalString(m_ep,"test = 748;");
  pMat = engGetMatrix(m_ep,"test");
  if (mxGetScalar(pMat) != 748) { AfxMessageBox("engEvalString or engGetMatrix did not work"); err = TRUE; }
  if (strcmp(m_outputBuffer,"") != 0) { AfxMessageBox("engEvalString result in output-buffer should be empty but is not"); err = TRUE; }
  mxFreeMatrix(pMat);

  //    2) check if result from evalString is ok
  engEvalString(m_ep,"test = 0 / 0;");
  if (strcmp(m_outputBuffer,"\r\nWarning: Divide by zero\r\n") != 0) { AfxMessageBox("engEvalString result in output-buffer is wrong"); err = TRUE; }

  //    3) send and get real matrix
  pMat = mxCreateFull (3,4,REAL);
  mxSetName(pMat,"test");
  pr = mxGetPr(pMat);
  for (i=0; i<3*4; i++)
    pr[i] = 3*4-i;
  engPutMatrix (m_ep,pMat);
  mxFreeMatrix(pMat);

  engEvalString(m_ep,"test = test * 2;");
  pMat = engGetMatrix(m_ep,"test");
  if (!mxIsNumeric(pMat)) { AfxMessageBox("Matrix should be a numeric matrix but is not"); err = TRUE; }
  if (!mxIsDouble(pMat)) { AfxMessageBox("Matrix should be a of type double but is not"); err = TRUE; }
  if (mxIsComplex(pMat)) { AfxMessageBox("Matrix should be a real matrix but is complex"); err = TRUE; }
  if (mxGetM(pMat) != 3) { AfxMessageBox("Number of rows in real matrix is not 3"); err = TRUE; }
  if (mxGetN(pMat) != 4) { AfxMessageBox("Number of cols in real matrix is not 4"); err = TRUE; }
  pr = mxGetPr(pMat);
  BOOL ok = TRUE;
  for (i=0; i<3*4; i++)
    if (pr[i] != 2*(3*4-i)) ok = FALSE;
  if (!ok) { AfxMessageBox("One or more values in the real matrix are wrong"); err = TRUE; }
  mxFreeMatrix (pMat);

  //    4) send and get complex matrix
  pMat = mxCreateFull (5,6,COMPLEX);
  mxSetName(pMat,"test");
  pr = mxGetPr(pMat);
  pi = mxGetPi(pMat);
  for (i=0; i<5*6; i++)
  {
    pr[i] = 5*6-i;
    pi[i] = 2*(5*6-i);
  }
  engPutMatrix (m_ep,pMat);
  mxFreeMatrix(pMat);

  engEvalString(m_ep,"test = test * 2;");
  pMat = engGetMatrix(m_ep,"test");
  if (!mxIsNumeric(pMat)) { AfxMessageBox("Matrix should be a numeric matrix but is not"); err = TRUE; }
  if (!mxIsDouble(pMat)) { AfxMessageBox("Matrix should be a of type double but is not"); err = TRUE; }
  if (!mxIsComplex(pMat)) { AfxMessageBox("Matrix should be a complex matrix but is real"); err = TRUE; }
  if (mxGetM(pMat) != 5) { AfxMessageBox("Number of rows in real matrix is not 3"); err = TRUE; }
  if (mxGetN(pMat) != 6) { AfxMessageBox("Number of cols in real matrix is not 4"); err = TRUE; }
  pr = mxGetPr(pMat);
  pi = mxGetPi(pMat);
  ok = TRUE;
  for (i=0; i<5*6; i++)
    if (pr[i] != 2*(5*6-i) || pi[i] != 4*(5*6-i)) ok = FALSE;
  if (!ok) { AfxMessageBox("One or more values in the complex matrix are wrong"); err = TRUE; }
  mxFreeMatrix (pMat);

  //    5) send and get string matrix
  pMat = mxCreateString ("This is a string");
  mxSetName(pMat,"test");
  engPutMatrix (m_ep,pMat);
  mxFreeMatrix(pMat);

  engEvalString(m_ep,"test = [test test];");
  pMat = engGetMatrix(m_ep,"test");
  if (!mxIsString(pMat))  { AfxMessageBox("Matrix should be a string matrix but is not"); err = TRUE; }
  if (mxGetM(pMat) != 1)  { AfxMessageBox("Number of rows in string matrix is not 1"); err = TRUE; }
  if (mxGetN(pMat) != 32) { AfxMessageBox("Number of cols in string matrix is not 16"); err = TRUE; }
  CString s;
  char *pS = s.GetBuffer(255);
  mxGetString(pMat,pS,255);
  s.ReleaseBuffer();
  if (s != "This is a stringThis is a string") { AfxMessageBox("String matrix retrieved from Matlab has wrong contents"); err = TRUE; }
  mxFreeMatrix (pMat);

  //    6) get an array of strings
  engEvalString(m_ep,"test = str2mat ('this','is','a','string');");
  pMat = engGetMatrix(m_ep,"test");
  if (!mxIsString(pMat))  { AfxMessageBox("Matrix should be a string matrix but is not"); err = TRUE; }
  if (mxGetM(pMat) != 4)  { AfxMessageBox("Number of rows in string matrix is not 4"); err = TRUE; }
  if (mxGetN(pMat) != 6)  { AfxMessageBox("Number of cols in string matrix is not 6"); err = TRUE; }
  pS = s.GetBuffer(255);
  mxGetString(pMat,pS,255);
  if (SubString(pS,4*(6+1),0) != "this  ") { AfxMessageBox("First string in string array is not 'this'"); err = TRUE; }
  if (SubString(pS,4*(6+1),1) != "is    ") { AfxMessageBox("Second string in string array is not 'is'"); err = TRUE; }
  if (SubString(pS,4*(6+1),2) != "a     ") { AfxMessageBox("Third string in string array is not 'a'"); err = TRUE; }
  if (SubString(pS,4*(6+1),3) != "string") { AfxMessageBox("Forth string in string array is not 'string'"); err = TRUE; }
  s.ReleaseBuffer();
  mxFreeMatrix (pMat);

  // Final message
  if (err)
    AfxMessageBox ("Test FAILED!\nMatlab engine library has bugs");
  else
    AfxMessageBox ("Test SUCCESSFUL!\nMatlab engine library appears to run correctly");
  EndWaitCursor();
}
