//---------------------------------------------------------------------------
#include <stdio.h>
#include "windows.h"
#include "ddeml.h"
#include "matdrv.h"

static	const	RESULTSIZE		= 1024;
static	BOOL 	DDEInited		= FALSE;
static	DWORD	DDEInstID		= 0;
static	HSZ		hszService		= (HSZ) NULL;		// DDE HSZ containing service name
static	HSZ		hszTopic		= (HSZ) NULL;		// DDE HSZ containing topic name
static	HSZ		hszStringItem	= (HSZ) NULL;
static	HSZ		hszFigureItem	= (HSZ) NULL;
static	FARPROC	lpProc			= (FARPROC) NULL;

typedef struct {
	HGLOBAL	hGlobalMeta;	// handle to global memory containing the actual metafile; this MUST...
							// be the first element in this struct since I cast pointers to this...
							// struct freely between LPIPC and HGLOBAL*. This is because I can't...
							// include both the DDEML and VB headers in the same source due to type...
							// name clashes between VB and DDEML for HSZ data types. Therefore, I...
							// can't include this struct (which requires DDEML types) in the VB source,...
							// so the VB source assumes this field is first in the struct.
	HCONV	hConv;			// conversation handle
	HDDEDATA hMetaData;		// the DDE buffer for the metafilepict, which cannot be deleted until...
							// we're finished with it (basically, until the next metafile comes by) 
} IPC, FAR *LPIPC;


//---------------------------------------------------------------------------

HDDEDATA EXPENTRY DDEMLCallback (WORD wType, WORD wFmt, HCONV hConv, HSZ hsz1, HSZ hsz2,
							HDDEDATA hData, DWORD dwData1, DWORD dwData2)
{
    switch (wType) {
        case XTYP_REGISTER:
        case XTYP_UNREGISTER:
        case XTYP_ADVDATA:
        case XTYP_XACT_COMPLETE:
        case XTYP_DISCONNECT:
        default:
            return (HDDEDATA) NULL;
    }
}


//---------------------------------------------------------------------------
// Called from VBInitCC

void StartupMatlab (HANDLE hmodDLL)
{
  // we SHOULD find a way to INVOKE matlab and then start a DDE conv with THAT instance
  // also we might want to find a way to not timeout, since we might try to start the DDE
  // conv before this guy gets running

  // it looks like the Win16 GetModuleHandle doesn't find Win32 apps (since LoadModule
  // doesn't work them)
	if (!GetModuleHandle ("matlab.exe"))
		WinExec ((LPSTR) "matlab.exe -nosplash", SW_SHOWMINNOACTIVE);	// hope for the best
	
	if (!DDEInited)			/* only initialize DDE once per DLL */
	{
		lpProc = MakeProcInstance ((FARPROC) DDEMLCallback, hmodDLL);
		if (DdeInitialize (&DDEInstID, (PFNCALLBACK) lpProc, CBF_FAIL_ALLSVRXACTIONS, 0) == DMLERR_NO_ERROR) {
			DDEInited		= TRUE;
			hszService		= DdeCreateStringHandle (DDEInstID, "matlab", CP_WINANSI);
			hszTopic		= DdeCreateStringHandle (DDEInstID, "engine", CP_WINANSI);
			hszStringItem	= DdeCreateStringHandle (DDEInstID, "EngStringResult", CP_WINANSI);	
			hszFigureItem	= DdeCreateStringHandle (DDEInstID, "EngFigureResult", CP_WINANSI);	
		}
	}
}


//---------------------------------------------------------------------------
// Called from VBTermCC

void ShutdownMatlab (void)
{
	if (DDEInited) {
		DdeFreeStringHandle (DDEInstID, hszService);
		DdeFreeStringHandle (DDEInstID, hszTopic);
		DdeFreeStringHandle (DDEInstID, hszStringItem);
		DdeFreeStringHandle (DDEInstID, hszFigureItem);
		DdeUninitialize (DDEInstID);
		
		FreeProcInstance (lpProc);
		lpProc= (FARPROC) NULL;
		hszService = hszTopic = hszStringItem = hszFigureItem = (HSZ) NULL;
		DDEInstID = 0;
		DDEInited = FALSE;
	}
}


//---------------------------------------------------------------------------
// Called from the WM_NCCREATE message for the control window.

void FAR *ConnectMatlab (void)
{
	LPIPC	lpIPC = new IPC;
	
	
	lpIPC->hConv = DdeConnect (DDEInstID, hszService, hszTopic, NULL);
	lpIPC->hGlobalMeta = (HGLOBAL) NULL;
	lpIPC->hMetaData = (HDDEDATA) NULL;
	
	return ((void FAR *) lpIPC);
}


//---------------------------------------------------------------------------
// Called from the WM_NCDESTROY message for the control window.

void FAR *DisconnectMatlab (void FAR *lpVoid)
{
	LPIPC lpIPC = (LPIPC) lpVoid;
	
// I'm ASSUMING that the windows get destroyed BEFORE the VBTermCC function is called
// so that this happens before we uninitialize DDE
	
	if (lpIPC && lpIPC->hConv) {
		DdeDisconnect (lpIPC->hConv);
		delete lpIPC;
	}
	return ((void FAR *) NULL);
}

//---------------------------------------------------------------------------
// Called when the value of the "Command" property changes

char FAR *ExecuteMatlab (void FAR * lpVoid, LPSTR pszCommand, LPCMDRESULT lpCommand)
{
	LPIPC		lpIPC;
	static char	Result[RESULTSIZE];
	HDDEDATA	hData;
	char FAR 	*r = (char FAR *) NULL;

	
	if (lpVoid)
		lpIPC = (LPIPC) lpVoid;
	else							// bail if it looks hopeless
		return (r);
		
		
	if (lpIPC->hConv &&
		(hData = DdeClientTransaction (pszCommand, lstrlen (pszCommand) + 1, lpIPC->hConv, NULL,
										CF_TEXT, XTYP_EXECUTE, 10000, NULL)))
	{                                                                         
		// No data is returned from the EXECUTE transaction (hData is a BOOL for this)
		if (hData = DdeClientTransaction (NULL, 0, lpIPC->hConv, hszStringItem,
											CF_TEXT, XTYP_REQUEST, 10000, NULL))
		{
			if (DdeGetData (hData, Result, RESULTSIZE, 0))
				Result[RESULTSIZE-1] = '\0';
			else
    			lstrcpy (Result, "empty result");
	    	DdeFreeDataHandle (hData);
    	}
    	else
    		lstrcpy (Result, "empty result");
    		
		if (hData = DdeClientTransaction (NULL, 0, lpIPC->hConv, hszFigureItem,
											CF_METAFILEPICT, XTYP_REQUEST, 10000, NULL))
		{
			HGLOBAL	FAR *ph;
			DWORD	length;

			lpCommand->bNewMetafile = TRUE;
			if (lpIPC->hMetaData) {		// free the old handle first 
				METAFILEPICT FAR *m = (METAFILEPICT FAR *) GlobalLock (lpIPC->hGlobalMeta);
				DeleteMetaFile (m->hMF);
				GlobalUnlock (lpIPC->hGlobalMeta);
				
				// HACK! for some reason, DDEML frees the METAFILEPICT global handle when we do the
				// DdeFreeDataHandle, but only on honest-to-God Windows. on NT we need to do it
#define WF_WINNT 0x4000		// this constant is not defined in the WIN16 dev kit
				if (GetWinFlags() & WF_WINNT)
					GlobalFree (lpIPC->hGlobalMeta);
					
	    		DdeFreeDataHandle (lpIPC->hMetaData); // frees the METAFILEPICT as well as the DDE buffer on Windows
			}
			lpIPC->hMetaData = hData;	// store the new handle
			ph = (HGLOBAL FAR *) DdeAccessData (lpIPC->hMetaData, &length);
			lpIPC->hGlobalMeta = *ph;	// and the metafilepict handle
			DdeUnaccessData (lpIPC->hMetaData);
    	}
    	else
			lpCommand->bNewMetafile = FALSE;
			
    	r = (char FAR *) Result;
	}
	else {
    	lstrcpy (Result, "DDE transaction failed");
    	r = (char FAR *) Result;
    }

	return (r);
}
