//---------------------------------------------------------------------------

#include <windows.h>
#include <vbapi.h>
#include <string.h>
#include "matlab.h"
#include "matdrv.h"


//---------------------------------------------------------------------------
// Global Variables
//---------------------------------------------------------------------------
static HANDLE	hmodDLL;
static WORD		cVbxUsers		= 0;
static BOOL		fDevTimeInited	= FALSE;


//---------------------------------------------------------------------------
// Matlab Control Procedure
//---------------------------------------------------------------------------
LONG FAR PASCAL _export MatlabCtlProc
(
    HCTL   hctl,
    HWND   hwnd,
    USHORT msg,
    USHORT wp,
    LONG   lp
)
{
    switch (msg)
	{
		case VBM_SETPROPERTY:
			switch (wp)
			{
				case IPROP_ML_COMMAND:
				{
					char FAR *lpStr;
					CMDRESULT	c;

					LPML   lpml = (LPML) VBDerefControl (hctl);
					c.bNewMetafile = FALSE;
					if (lpStr = ExecuteMatlab (lpml->lpIPC, (LPSTR) lp, (LPCMDRESULT) &c)) {
						if (c.bNewMetafile)
							InvalidateRect (hwnd, NULL, TRUE);	// force the window to draw the new metafile
				    	VBSetControlProperty (hctl, IPROP_ML_RESULT, (LONG) lpStr);
				    }
				}
				break;
			
				case IPROP_ML_RESULT:
					break;
			}
			break;

		case VBM_GETPROPERTY:
		case VBM_DATA_AVAILABLE:
		case VBM_DATA_REQUEST:
			break;

		case WM_NCCREATE:
			{	
				LPML   lpml = (LPML) VBDerefControl (hctl);
				lpml->lpIPC = ConnectMatlab ();
			}
			break;
	
		case WM_NCDESTROY:
			{	
				LPML   lpml = (LPML) VBDerefControl (hctl);
				lpml->lpIPC = DisconnectMatlab (lpml->lpIPC);
			}
			break;

        case WM_GETTEXT:
			*(LPSTR)lp = 0L;
	    	return (LONG)(wp - 1);
			break;
	    	
        case WM_LBUTTONDOWN:
        case WM_LBUTTONDBLCLK:
        case WM_LBUTTONUP:
        case WM_SETFONT:
        case WM_GETFONT:
        case WM_SETTEXT:
		case WM_GETTEXTLENGTH:
			break;

        case WM_PAINT:
            if (wp) {
				// paint to printer display context
			}
	    	else {
                PAINTSTRUCT ps;
				LPML   lpml = (LPML) VBDerefControl (hctl);
				HGLOBAL	hGlobalMeta;
				RECT	r;

				BeginPaint (hwnd, &ps);
                if (hGlobalMeta = *((HGLOBAL FAR *) lpml->lpIPC))
				{           
					METAFILEPICT	FAR *m;
					
					if (m = (METAFILEPICT FAR *) GlobalLock (hGlobalMeta)) {
						SetMapMode (ps.hdc, m->mm) ;
						SetWindowExt (ps.hdc, m->xExt, m->yExt) ;
						GetClientRect (hwnd, &r);
						SetViewportExt (ps.hdc, r.right, r.bottom) ;
						if (!PlayMetaFile (ps.hdc, m->hMF))
							TextOut (ps.hdc, 0, 40, "bad metafile", 12); 
						GlobalUnlock (hGlobalMeta);
					}
			    }
				else	/* display bitmap */
				{
					HDC		hdcMem;
					HBITMAP	hBitmap, hOldBitmap;
					BITMAP	bm;

					if (hdcMem = CreateCompatibleDC (ps.hdc)) {
						hBitmap = LoadBitmap (hmodDLL, MAKEINTRESOURCE (IDBMP_MEMBRANE));
						hOldBitmap = SelectObject (hdcMem, hBitmap);
						GetObject (hBitmap, sizeof(BITMAP), &bm);
						GetClientRect (hwnd, &r);
						StretchBlt (ps.hdc, 0, 0, r.right, r.bottom, hdcMem, 0, 0, bm.bmWidth, bm.bmHeight, SRCCOPY);
						SelectObject (hdcMem, hOldBitmap);
						DeleteObject (hBitmap);
						DeleteDC (hdcMem);
					}
				}
				EndPaint (hwnd, &ps);
			}
            break;

        case WM_SIZE:
            break;

		case VBM_HELP:
    		break;
	}

    return VBDefControlProc (hctl, hwnd, msg, wp, lp);
}

//---------------------------------------------------------------------------
// Register custom control. This routine is called by VB when the custom
// control DLL is loaded for use.
//---------------------------------------------------------------------------
BOOL FAR PASCAL _export VBINITCC
(
    USHORT usVersion,
    BOOL   fRuntime
)
{
    // Count the number of hosts using this VBX.  A host can be vb.exe,
    // any .exe compiled from vb which uses this custom control, or any
    // other program which loads and uses VBX files.
    ++cVbxUsers;

    // if this is from the development environment.
    if (!fRuntime && !fDevTimeInited)
	{
		// We successfully initialized the stuff we need at dev time
		fDevTimeInited = TRUE;
	}
	
	if (cVbxUsers == 1)	// the DLL has just been loaded for the first time
		StartupMatlab (hmodDLL);
	
    // Register control(s)
	return VBRegisterModel(hmodDLL, &modelMatlab);
}


//---------------------------------------------------------------------------
// Unregister custom control.  This routine is called by VB when the custom
// control DLL is being unloaded.
//---------------------------------------------------------------------------
VOID FAR PASCAL _export VBTERMCC
(
    VOID
)
{
    --cVbxUsers;
    if (cVbxUsers == 0)
		ShutdownMatlab ();
}


//---------------------------------------------------------------------------
// Provide custom control model information to host environment.
//---------------------------------------------------------------------------
LPMODELINFO FAR PASCAL _export VBGetModelInfo
(
    USHORT usVersion
)
{
	return &modelinfoMatlab;
}


//---------------------------------------------------------------------------
// Initialize library.	This routine is called when the first client loads
// the DLL.
//---------------------------------------------------------------------------
int FAR PASCAL LibMain
(
    HANDLE hModule,
    WORD   wDataSeg,
    WORD   cbHeapSize,
    LPSTR  lpszCmdLine
)
{
    // Avoid warnings on unused (but required) formal parameters
    wDataSeg	= wDataSeg;
    cbHeapSize	= cbHeapSize;
    lpszCmdLine = lpszCmdLine;

    hmodDLL = hModule;

    return 1;
}

