function anedit(Action,WorkingFig,Flag)
%ANEDIT	Animation edit menu function.
%	ANEDIT(ACTION,WORKINGIFG) is the callback function for the Edit menu on 
%	the animation figure window.
%
%	ACTION may be one of 7 strings:
%	    '#Delete'  Delete the selected object.
%	    '#Modify'  Modify the selected object.
%	  '#Deselect'  Deselect all objects.
%	'#ButtonDown'  Perform button operation.
%	  '#KeyPress'  Perform key press operation.
%
%	See also ANSIMINI.

%	Loren Dean   March, 1995.
%	Copyright (c) 1995 by The MathWorks, Inc.
if nargin==1,
  WorkingFig=findobj(0,'type','figure','Tag','WorkingFig');
end

if nargin<3,Flag=0;end

FigData=get(WorkingFig,'UserData');
WorkingAxes=FigData(2);
DeleteHandle=findobj(WorkingFig,'Type','uimenu','Tag','MenuEditDelete');
ModifyHandle=findobj(WorkingFig,'Type','uimenu','Tag','MenuEditModify');

%%%%%%%%%%%%%%%%%%
%%% ButtonDown %%%
%%%%%%%%%%%%%%%%%%
if strcmp(Action,'#ButtonDown'),
  CurrentPt=get(WorkingFig,'CurrentObject');
  anedit('#Deselect',WorkingFig,1)
  set([DeleteHandle,ModifyHandle],'Enable','on');

  [SelectColor,DeselectColor]=angetclr('#GetColor',CurrentPt);
  if strcmp('surface',get(CurrentPt,'Type')) | ...
     strcmp('patch',get(CurrentPt,'Type')),
    set(CurrentPt,'FaceColor',SelectColor);
  else,
    set(CurrentPt,'Color',SelectColor); 
  end % if strcmp
  
  if strcmp(get(WorkingFig,'SelectionType'),'open'),
    anedit('#Modify',WorkingFig)
  else,
    andrag #Down
  end % if strcmp

%%%%%%%%%%%%%%
%%% Delete %%%
%%%%%%%%%%%%%%
elseif strcmp(Action,'#Delete'),
  AllPtData=get(WorkingAxes,'UserData');
  CurrentPt=AllPtData(:,1);
  [SelectColor,DeselectColor]=angetclr('#GetColor',CurrentPt);
  
  CurrentObj=ancurobj(WorkingFig);

  angetclr('#Delete',CurrentObj);
  delete(CurrentObj);
  AllPtData(find(AllPtData(:,1)==CurrentObj),:) = [];
  set(WorkingAxes,'UserData',AllPtData);

  HStatus=findobj(WorkingFig,'Type','uicontrol','Tag','StatusBar');
  if isempty(AllPtData),
    set(HStatus,'String','Use Object toolbar to add animation objects.');
    MenuHandles=findobj(WorkingFig,'type','uimenu');
    ModifyHandle=findobj(MenuHandles,'flat','Tag','MenuEditModify');
    DeleteAllHandle=findobj(MenuHandles,'flat','Tag','MenuEditDeleteAll');
    DeleteHandle=findobj(MenuHandles,'flat','Tag','MenuEditDelete');
    set([DeleteHandle,DeleteAllHandle,ModifyHandle],'Enable','off');
  end
%%%%%%%%%%%%%%%%%
%%% DeleteAll %%%
%%%%%%%%%%%%%%%%%
elseif strcmp(Action,'#DeleteAll'),
  
  AllPtData=get(WorkingAxes,'UserData');
  CurrentPt=AllPtData(:,1);
  angetclr('#Delete',CurrentPt);
  delete(CurrentPt);
  AllPtData= [];
  set(WorkingAxes,'UserData',AllPtData);

  HStatus=findobj(WorkingFig,'Type','uicontrol','Tag','StatusBar');
  set(HStatus,'String','Use Object toolbar to add animation objects.');
  MenuHandles=findobj(WorkingFig,'type','uimenu');
  ModifyHandle=findobj(MenuHandles,'flat','Tag','MenuEditModify');
  DeleteAllHandle=findobj(MenuHandles,'flat','Tag','MenuEditDeleteAll');
  DeleteHandle=findobj(MenuHandles,'flat','Tag','MenuEditDelete');
  set([DeleteHandle,DeleteAllHandle,ModifyHandle],'Enable','off');

%%%%%%%%%%%%%%
%%% Modify %%%
%%%%%%%%%%%%%%
elseif strcmp(Action,'#Modify'),
  
  CurrentPt=ancurobj(WorkingFig);
  Data=get(WorkingAxes,'UserData');
  Loc=find(CurrentPt==Data(:,1));
  FcnName=deblank(setstr(Data(Loc,2:9)));  
  set(WorkingFig,'Pointer','watch');
  feval(FcnName,'#Modify',CurrentPt,WorkingFig);  
  set(WorkingFig,'Pointer','arrow');
  
%%%%%%%%%%%%%%%%
%%% Deselect %%%
%%%%%%%%%%%%%%%%
elseif strcmp(Action,'#Deselect'),

  if Flag==0,
    btnpress(WorkingFig,'ObjectButtons',1);
  end

  set([DeleteHandle,ModifyHandle],'Enable','off');

  WorkingData=get(WorkingAxes,'UserData');
  
  StartHandle=findobj(WorkingFig,'Type','uicontrol','Tag','StartButton');
  StaticData=get(StartHandle,'UserData');
  if prod(size(StaticData))~=1,WorkingData=[WorkingData;StaticData];end
  
  if ~isempty(WorkingData),
    NumPts=length(WorkingData(:,1));
    [SelectColor,DeselectColor]=angetclr('#GetColor',WorkingData(:,1));

    for lp=1:NumPts,
      if strcmp('surface',get(WorkingData(lp,1),'Type')) | ...
           strcmp('patch',get(WorkingData(lp,1),'Type')),
        set(WorkingData(lp,1),'FaceColor',DeselectColor(lp,:));
      else,
        set(WorkingData(lp,1),'Color',DeselectColor(lp,:)); 
      end % if strcmp
    end % for lp
  end % if WorkingData

%%%%%%%%%%%%%%%%
%%% KeyPress %%%
%%%%%%%%%%%%%%%%
elseif strcmp(Action,'#KeyPress'),
%  if abs(get(PrpDlgFig,'CurrentCharacter'))==9, % TAB
%  end


end % if strcmp    