function [SelectColor,DeselectColor]=angetclr(Action,CurrentPt,Color)
%ANGETCLR Return select and deselect colors for animations.
%	[SELECTCOLOR,DESELECTCOLOR]=ANGETCLR(ACTION,CURRENTPT,COLOR) returns 
%	the object select and deselect colors in [R G B] format.
%
%	SELECTCOLOR is the mx3 element color matrix for selected objects.
%
%	DESELECTCOLOR is the mx3 element color matrix for deselected objects.
%
%	SELECTCOLOR and DESELECTCOLOR are only used for '#New' and '#Modify'.
%
%	ACTION is one of 4 text strings:
%	     '#New'  Stores the objects color in the MenuEditModify UserData.
%	'#GetColor'  Gets the colors from the MenuEditModify UserData.
%	  '#Modify'  Modifies the colors in the MenuEditModify UserData.
%	  '#Delete'  Deletes colors from the MenuEditModify UserData.
%
%	CURRENTPT is the vector of handles for the objects on the figure.
%
%	COLOR is the current color of the object to be added.  It is only used
%	    with the '#New' and '#Modify' actions.

%	Loren Dean  March, 1995.
%	Copyright (c) 1995 by The MathWorks, Inc.

WorkingAxes=get(CurrentPt(1),'Parent');
WorkingFig=get(WorkingAxes,'Parent');
NumPts=length(CurrentPt);
ModifyHandle=findobj(WorkingFig,'Type','uimenu','Tag','MenuEditModify');
ColorData=get(ModifyHandle,'UserData');

if strcmp(Action,'#New'),
  if nargin<3,Color=[1 1 1];end
  ColorData=[ColorData;[CurrentPt Color]];
  set(ModifyHandle,'UserData',ColorData)
  
  if nargout~=0, 
    [SelectColor,DeselectColor]=angetclr('#GetColor',CurrentPt);
  end 
  
elseif strcmp(Action,'#GetColor'),

  DeselectColor=zeros(NumPts,3);
  SelectColor=zeros(NumPts,3);

  for lp=1:NumPts,
    DeselectColor(lp,:)=ColorData(find(ColorData(:,1)==CurrentPt(lp)),2:4);

    % To Use the conjugate
    %TempColor=1-DeselectColor(lp,:);
    %if ~any(TempColor),TempColor=[1 0 0];end

    % Force Select Color to be red except when starting color is red
    if DeselectColor(lp,:)==[1 0 0],
      TempColor=[1 1 1];
    else,
      TempColor=[1 0 0];
    end
    
    SelectColor(lp,:)=TempColor;
  end
  
elseif strcmp(Action,'#Modify'),
  for lp=1:NumPts,
    ColorData(find(ColorData(:,1)==CurrentPt(lp)),2:4)=Color(lp,:);
  end
  
  set(ModifyHandle,'UserData',ColorData);
  
elseif strcmp(Action,'#Delete'),
  for lp=1:NumPts,
    ColorData(find(ColorData(:,1)==CurrentPt(lp)),:)=[];
  end
  set(ModifyHandle,'UserData',ColorData);
  
end % if strcmp






