function [XPos,YPos]=angetpos(WorkingFig,OpenFlag)
%ANGETPOS Get new object position.
%	[XPOS,YPOS]=ANGETPOS(WORKINGFIG,OPENFLAG) returns an acceptable
%	position for new objects that are created.
%
%	WORKINGFIG is the handle for the figure that the objects are
%	displayed on.
%
%	OPENFLAG is a boolean flag specifying whether the type of 
%	object creation that is going to take place (i.e. menu creation,
%	double click creation, object button creation).
%
%	See also ANDOT, ANEDIT, ANRECT, ANSIMINI, ANTEXT.

%	Loren Dean  March, 1995.
%	Copyright (c) 1995 by The MathWorks, Inc.

Data=get(WorkingFig,'UserData');
WorkingAxes=Data(2);
WorkingData=get(WorkingAxes,'UserData');
anedit('#Deselect',WorkingFig)
WorkingXLim=get(WorkingAxes,'XLim');
WorkingYLim=get(WorkingAxes,'YLim');

if nargin==2, % ButtonClick Open
  CurrentPt=get(WorkingAxes,'CurrentPoint');
  XPos=CurrentPt(1,1);YPos=CurrentPt(1,2);
else,
  XPos=inf;YPos=inf;
end % if nargin

if XPos<WorkingXLim(1)|XPos>WorkingXLim(2),
  XPos=sum(WorkingXLim)/2;
end

if YPos<WorkingYLim(1)|YPos>WorkingYLim(2),
  YPos=sum(WorkingYLim)/2;
end

if ~isempty(WorkingData),
  NumPts=length(WorkingData(:,1));
  CurXPos=zeros(NumPts,1);
  CurYPos=zeros(NumPts,1);
  for lp=1:NumPts,
    if strcmp('text',get(WorkingData(lp,1),'Type')),
      Position=get(WorkingData(lp,1),'Position');
      CurXPos(lp)=Position(1);
      CurYPos(lp)=Position(2);
    else,
      Position=get(WorkingData(lp,1),'XData');
      CurXPos(lp)=Position(1);
      Position=get(WorkingData(lp,1),'YData');
      CurYPos(lp)=Position(1);
    end % if strcmp
  end % for lp
      
  XDiff=abs(CurXPos-XPos);
  YDiff=abs(CurYPos-YPos);
  XLimDiff=abs(WorkingXLim(2)-WorkingXLim(1))/40;
  YLimDiff=abs(WorkingYLim(2)-WorkingYLim(1))/40;
  while (any(XDiff<XLimDiff) | any(YDiff<YLimDiff)),
    XPos=XPos+XLimDiff;
    XDiff=abs(XPos-CurXPos);
    YPos=YPos-YLimDiff;
    YDiff=abs(CurYPos-YPos);
  end % while
end % if ~isempty

set(WorkingFig,'CurrentAxes',WorkingAxes);