function BtnObjHandles=anobj(WorkingFig,NewHandle)
%ANOBJ	Initialize object icons for animations.
%	ANOBJ(WORKINGFIG,NEWHANDLE) initializes object icons on the 
%	animation figure window.  This function is where additional
%       objects are added.
%	
%	WORKINGFIG is the handle for the figure that the icons are
%	to be displayed on.
%
%	NEWHANDLE is the handle for the EditNew Menu.
%
%	------------------------------------------------------------------
%	Adding Additional Objects:
%
%	  OBJTYPE(ACTION,OBJHANDLE,WORKINGFIGURE,U)
%	  
%	  Must contain subroutines for ACTION types '#Draw','#New','#Modify'.
%
%	  UserData for the object is used to store information.
%
%
%	See also ANSIMINI.

%	Loren Dean  March, 1995.
%	Copyright (c) 1995 by The MathWorks, Inc.


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%% Additional objects are added here %%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Function to draw button icons
% See the btnicon function for help.
BtnObjIconFunctions=str2mat(                          ...
                           'btnicon(''fillcircle'')', ...
                           'btnicon(''rect'')'      , ...
                           'btnicon(''text'')'      , ...
                           'animicon(''lineobj'')'   , ...
                           'animicon(''patchobj'')'    ...
                           );

% Tags for button icons
BtnObjButtonIDs=str2mat(                 ...
                       'BtnObjectDot'  , ...
                       'BtnObjectRect' , ...
                       'BtnObjectText' , ...
                       'BtnObjectLine' , ...
                       'BtnObjectPatch'  ...
                       );
                       

% Labels in the New Menu
% See the makemenu function for help.
MenuInfoLabels=str2mat(                  ...
                      '&Dot'           , ...
                      '&Rectangle'     , ...
                      '&Text'          , ...
                      'Generic &Line'  , ...
                      'Generic &Patch'  ...
                      );
                      
% Function Calls for the New menu and Button Callbacks
% #New will be appended to the function call for the New Menu
FunctionCalls=str2mat(          ...
                     'andot'  , ...
                     'anrect' , ...
                     'antext' , ...
                     'anline' , ...
                     'anpatch'  ...
                     );


% Tags for the New menu
% The standard of MenuEditNewOBJECT is recommended.
MenuInfoTags=str2mat(   ....
                    'MenuEditNewDot'      , ...
                    'MenuEditNewRectangle', ...
                    'MenuEditNewText'     , ...
                    'MenuEditNewLine'     , ...
                    'MenuEditNewPatch'      ...
                    );





%%% !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!! %%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%% Do not change anything after this %%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%% !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!! %%%
                   
set(0,'CurrentFigure',WorkingFig);
BtnObjIconFunctions=str2mat(                      ...
                           'btnicon(''select'')', ...
                           BtnObjIconFunctions    ...
                           );
Len=length(BtnObjIconFunctions(:,1));

BtnObjButtonIDs=str2mat(                  ...
                       'BtnObjectSelect', ...
                       BtnObjButtonIDs    ...
                       );
                       
BtnObjCallBack='';
                       
BtnObjGroupID='ObjectButtons';
   
BtnObjPressTypes='toggle';

BtnObjInitialState=zeros(Len,1);
BtnObjInitialState(1)=1;

BtnObjExclusive='yes';
                       
BtnObjGroupSize=[Len 1];
BtnObjPosition=[0.03 0.82-0.06*Len 0.06 0.06*Len];
BtnObjOrientation='vertical';
BtnObjHandles=btngroup(                                    ...
                      'IconFunctions',BtnObjIconFunctions, ...
                      'GroupID'      ,BtnObjGroupID      , ...
                      'ButtonID'     ,BtnObjButtonIDs    , ...
                      'PressType'    ,BtnObjPressTypes   , ...
                      'InitialState' ,BtnObjInitialState , ...
                      'Exclusive'    ,BtnObjExclusive    , ...
                      'Callbacks'    ,BtnObjCallBack     , ...
                      'GroupSize'    ,BtnObjGroupSize    , ...
                      'Units'        ,'normalized'       , ...
                      'Position'     ,BtnObjPosition     , ...
                      'Orientation'  ,BtnObjOrientation    ...
                      );
BtnObjText=text(                                          ...
                0.5, 1              ,'Objects'          , ...
               'Tag'                ,'ObjectButtonsText', ...
               'HorizontalAlignment','center'           , ...
               'VerticalAlignment'  ,'bottom'             ...
               );


BtnObjHandles=findobj(BtnObjHandles);

NewHandle=findobj(WorkingFig,'Type','uimenu','Tag','MenuEditNew');
set(NewHandle,'UserData',FunctionCalls);

MenuInfoCalls=[setstr(ones(Len-1,1)*'a=gcbf;set(a,''Pointer'',''watch'');') ...
               FunctionCalls                                               ...
               setstr(ones(Len-1,1)*' #New;')                              ...
               setstr(ones(Len-1,1)*'set(a,''Pointer'',''arrow'');')       ...
              ];
                                    
MenuHandles=makemenu(NewHandle     , ...
                     MenuInfoLabels, ...
                     MenuInfoCalls , ...
                     MenuInfoTags    ...
                     );
                     
set(MenuHandles,'Interruptible','off','BusyAction','queue');

