function anpatch(Action,Handle,WorkingFig,u)
%ANPATCH Generic line creation and display function.
%	ANPATCH(ACTION,HANDLE,WORKINGFIG,U) is the creation and display 
%	function for the generic line object in the simulation animation
%	block.
%
%	ACTION may be one of four strings:
%	    '#Draw'  Draw line object.
%	     '#New'  Create new line object.
%	  '#Modify'  Modify line object parameters.
%	  '#Update'  Update object paramaters as entered in currently
%	             displayed dialog.
%
%	HANDLE is a vector of line object handles.
%
%	WORKINGFIG is the handle for the figure that the objects are 
%	drawn on.
%
%	U is the vector of inputs to the animation block.  It is used
%	in the '#Draw' area only.
%
%	See also ANPATCH, ANRECT, ANTEXT, ANOBJ.

%	Loren Dean March, 1995.
%	Copyright (c) 1995 by The MathWorks, Inc.
%

%%%%%%%%%%%
%%% Draw %%%
%%%%%%%%%%%
if strcmp(Action,'#Draw'),

  NumObjs=length(Handle);
  
  NumDataPts=zeros(NumObjs,1);
  Color=zeros(NumObjs,3);
  XData=[];
  YData=[];
  Data=[];
  
  for lp=1:NumObjs,
    TempData=eval(get(Handle(lp),'UserData')           , ...
                ['[length(get(Handle(lp),''XData'')),'  ...
                 'get(Handle(lp),''XData''),'           ...
                 'get(Handle(lp),''YData''),'           ...
                 'get(Handle(lp),''Color'')]'           ...
                ]                                       ...
                 );
                 
    NumDataPts(lp)=TempData(1);
    Data=[Data
          TempData(2:NumDataPts(lp)+1)'                   ...
          TempData(NumDataPts(lp)+2:2*NumDataPts(lp)+1)'  ...
         ];
    Color(lp,:)=TempData(2*NumDataPts(lp)+2:2*NumDataPts(lp)+4);
  end % for lp
    
  FigData=get(WorkingFig,'UserData');
  WorkingAxes=FigData(2);
  
  [Data(:,1),Data(:,2)] = andraw(WorkingFig ,[Handle NumDataPts], ...
                                 Data(:,1)  ,Data(:,2)          , ...
                                 get(WorkingAxes,'XLim')        , ...
                                 get(WorkingAxes,'YLim')          ...
                                 );
  
  for lp=1:NumObjs,
   LocStart=sum(NumDataPts(1:lp-1))+1;
   LocEnd=sum(NumDataPts(1:lp));
   set(Handle(lp) , ...
       'XData'     ,Data(LocStart:LocEnd,1)    , ...
       'YData'     ,Data(LocStart:LocEnd,2)    , ...
       'FaceColor' ,abs(Color(lp,:))             ...
       );
  end % for lp
  
%%%%%%%%%%%
%%% New %%%
%%%%%%%%%%%
elseif strcmp(Action,'#New'),
  % All Cases except Load from file and double click open
  if nargin==1,
    WorkingFig=findobj(0,'type','figure','Tag','WorkingFig');
    Handle=[];
  end % if
  
  FigData=get(WorkingFig,'UserData');
  WorkingAxes=FigData(2);
  set(WorkingFig,'CurrentAxes',WorkingAxes);
  
  LoadFromFileFlag=length(Handle)>1;

  if LoadFromFileFlag,
    u=angetic(WorkingFig);
    
    X=sum(get(WorkingAxes,'XLim'))/2;
    Y=sum(get(WorkingAxes,'YLim'))/2;
    W=diff(get(WorkingAxes,'XLim'))/8;
    H=diff(get(WorkingAxes,'YLim'))/8;
    
    Data=eval(Handle,'[5 X X+W X+W X X Y Y Y+H Y+H Y 1 1 1 1]');
    NumDataPts=Data(1);
    XPos=Data(2:NumDataPts+1);
    YPos=Data(NumDataPts+2:2*NumDataPts+1);
    Color=abs(Data(2*NumDataPts+2:2*NumDataPts+4));
    
  else,
    if nargin==4,  % Double click open
      [X,Y]=angetpos(WorkingFig,1);
    else,
      [X,Y]=angetpos(WorkingFig);
    end % if nargin
    
    X=chop(X,3);
    Y=chop(Y,3);
    W=diff(get(WorkingAxes,'XLim'))/8;
    H=diff(get(WorkingAxes,'YLim'))/8;
    XPos=[X X+W X+W];
    YPos=[Y Y   Y+H];
    NumDataPts=3;
    Color=[1 1 1];
  end %if LoadFromFileFlag

  CurrentPt=patch(                                       ...
                  XPos          , YPos                 , ...
                  Color                                , ...
                 'ButtonDownFcn', 'anedit #ButtonDown' , ...
                 'EraseMode'    , 'normal'             , ...
                 'Parent',WorkingAxes, ...                
                 'BusyAction','queue', ...                
                 'Interruptible', 'off'                 , ...
                 'Tag'          , 'AnimPatch'            ...
                 );
 
  if LoadFromFileFlag,
    WorkingData=Handle;
  else,
    WorkingData=['[' num2str(NumDataPts)   ',' mat2str(XPos)     ',' ...
                     mat2str(YPos)        ','  mat2str(Color)   ',]' ...
                ];
  end % if LoadFromFileFlag
  
  [SelectColor,DeselectColor]=angetclr('#New',CurrentPt,Color);
  set(CurrentPt,'UserData',WorkingData,'FaceColor',SelectColor);
  
  AxesData=get(WorkingAxes,'UserData');
  set(WorkingAxes,'UserData',[]); %Done for speed purposes (not necessary)
  AxesData=[CurrentPt abs('anpatch ');AxesData];
  set(WorkingAxes,'UserData',AxesData);

  
  andraw(WorkingFig             , [CurrentPt NumDataPts] , ...
         XPos                   , YPos                   , ...
         get(WorkingAxes,'XLim'), get(WorkingAxes,'YLim')  ...
        );

  if ~LoadFromFileFlag,
    anpatch('#Modify',CurrentPt,WorkingFig)
  end
  

%%%%%%%%%%%%%%
%%% Modify %%%
%%%%%%%%%%%%%%
elseif strcmp(Action,'#Modify'),

  List='NXYC';
  CurrentData=get(Handle,'UserData');

  CommaLocs=ancomloc(CurrentData);
  CurrentN=CurrentData(1,             2:CommaLocs(1)-1);
  for lp=2:length(List),
    eval(['Current' List(lp) '=CurrentData(1,CommaLocs(' num2str(lp-1) ...
          ')+1:CommaLocs(' num2str(lp) ')-1);']);
  end % for lp

  TextStrings=str2mat('X Data:','Y Data:','Color ([R,G,B]):');
  
  Values=str2mat(CurrentX,CurrentY,CurrentC);
  Callbacks=setstr(ones(length(Values(:,1))+1,1)*'anpatch #Update');

  List(1)=[];
  Tags=List';

  FigTag='PrpDlgFig';
  FigData=get(WorkingFig,'UserData');
  SimHandle=FigData(1);
  FigTitle=['Patch Object Properties: ' get_param(SimHandle,'Name')];
  
  Handles = anprpdlg('#Initialize', Handle, WorkingFig, ...
                     TextStrings  , Values, Callbacks , ...
                     Tags         , FigTag, FigTitle    ...
                     );

%%%%%%%%%%%%%%
%%% Update %%%
%%%%%%%%%%%%%%
elseif strcmp(Action,'#Update'),

  PrpDlgFig=get(0,'CurrentFigure');
  Data=get(PrpDlgFig,'UserData');
  WorkingFig=Data(1);
  WorkingAxes=findobj(WorkingFig,'Type','axes','Tag','WorkingAxes');

  CurrentPt=Data(2);
  
  List='XYC';
  for lp=1:length(List),
    %%% Get Handles
    eval([ List(lp) 'Handle=findobj(PrpDlgFig,', ...
          ' ''Type'',''uicontrol'',''Tag'',''' List(lp) ''');']);

    %%% Get Strings for Edit Text Blocks
    eval(['Current' List(lp) '=get(' List(lp) 'Handle,''String'');']);

    %%% Remove all leading and trailing spaces from CurrentX and CurrentY
    eval(['Current' List(lp) '=deblank(fliplr(Current' List(lp) '));']);
    eval(['Current' List(lp) '=deblank(fliplr(Current' List(lp) '));']);
  end % for lp
  
  u=angetic(WorkingFig);
  
  eval(['XFlag=0;CurrentXPos=' CurrentX ';']           , ...
        'XFlag=1;CurrentXPos=get(CurrentPt,''XData'');'  ...
      );
  eval(['YFlag=0;CurrentYPos=' CurrentY ';']           , ...
        'YFlag=1;CurrentYPos=get(CurrentPt,''YData'');'  ...
      );
  eval(['CFlag=0;CurrentCVal=' CurrentC ';']            , ...
        'CFlag=1;CurrentCVal=get(CurrentPt,''FaceColor'');'  ...
      );
  HCancel=findobj(PrpDlgFig,'Type','uicontrol','Tag','Cancel');
  CurrentData=get(HCancel,'UserData');
  CommaLocs=ancomloc(CurrentData(1,:));
  
  ListLoc=0;
  if XFlag,Low=CommaLocs(1)+1;High=CommaLocs(2)-1;ListLoc=1;end
  if YFlag,Low=CommaLocs(2)+1;High=CommaLocs(3)-1;ListLoc=2;end
  if CFlag,Low=CommaLocs(3)+1;High=CommaLocs(4)-1;ListLoc=3;end
  
  if ListLoc,
    CurrentString=CurrentData(1,Low:High);
    eval(['Current' List(ListLoc) '=CurrentString;']);
    eval(['set(' List(ListLoc) 'Handle,''String'',CurrentString)']);
    disp([7,7,7 'Last entry was invalid.  Old being used.']);disp(' ');
  end
  
  if length(CurrentXPos)~=length(CurrentYPos),
    disp(str2mat(setstr(7)                                      , ...
                'Please Make sure that vectors are equal sizes.', ...
                'Using Old Data for entry:'                     , ...
                CurrentX                                        , ...
                CurrentY                                          ...
                ) ...
        );
    CurrentXPos=get(CurrentPt,'XData');
    CurrentYPos=get(CurrentPt,'YData');
    CurrentX=mat2str(CurrentXPos,3);
    CurrentY=mat2str(CurrentYPos,3);
  end
  
  CurrentN=num2str(length(CurrentXPos));
  
  AllPtData =[ '[' CurrentN ',' CurrentX ','  ...
                   CurrentY ',' CurrentC ',]' ...
             ];
  
  set(HCancel,'UserData',str2mat(AllPtData,CurrentData(2,:)));
  
  set(CurrentPt  , ...
     'Xdata'     , CurrentXPos, ...
     'Ydata'     , CurrentYPos, ...
     'FaceColor' , CurrentCVal, ...
     'UserData'  , AllPtData    ...
     );

  angetclr('#Modify',CurrentPt,CurrentCVal);
  
  ansimltn('#Reset',WorkingFig)
  
end % if strcmp action
