function cofs=bescof(u,v)
%  cofs = bescof(u,v)
%
%  This function determines coefficients needed to perform
%  piecewise cubic Bessel interpolation

%           H. B. Wilson,  Spring 1990
%	    Updated by D.Thomas 5/21/93

%n=length(u); s=zeros(u); w=s; z=s; n1=n-1;	
n=length(u); s=u*0; w=s; z=s; n1=n-1;	% DT

%  Get slopes at points as a weighted average of cord slopes

i=2:n1; d2=u(i+1)-u(i); d1=u(i)-u(i-1);
s(i)=(d1.*(v(i+1)-v(i))./d2+d2.*(v(i)-v(i-1))./d1)./(d1+d2);

%  Find slopes to make v'' equal zero at first and last points

s(1)=1.5*(v(2)-v(1))/(u(2)-u(1))-.5*s(2);
s(n)=1.5*(v(n)-v(n1))/(u(n)-u(n1))-.5*s(n1);

%  Determine coefficients needed for cubic interpolation

i=1:n1; d1=u(i+1)-u(i); s1=(v(i+1)-v(i))./d1;
z(i)=(s(i+1)+s(i)-2.*s1)./(d1.*d1);
w(i)=(s1-s(i))./d1-z(i).*d1;
cofs=[u(:),v(:),s(:),w(:),z(:)];
