function [y,yprime]=bestrp(x,cofs)
%  [y,yprime] = bestrp(x,cofs)
%
%  Corresponding to argument x and data points u(j),v(j)
%  for j=1 to n, this function interpolates y(x) and y'(x)
%  using the piecewise cubic Bessel approximation. Function
%  bescof must be called first to create array cofs which
%  contains the necessary polynomial coefficeients.

%           H. B. Wilson,  Spring 1990
%  Modified by D.Thomas 5/21/93

%n=length(u); n1=n-1; u=cofs(:,1); v=cofs(:,2);
u=cofs(:,1); v=cofs(:,2);n=length(u); n1=n-1;  % DT
s=cofs(:,3); w=cofs(:,4); z=cofs(:,5); k=findseg(x,u);
u=u(k); v=v(k); s=s(k); w=w(k); z=z(k); dx=x(:)-u;
yprime=s+dx.*(2.*w+3.*dx.*z);
y=v+dx.*(s+dx.*(w+dx.*z));
