% This script file illustrates use of piecewise cubic
% interpolation to define a closed curve through a set of
% data points. The chosen points are on an ellipse.

%  by Howard Wilson, U. of Alabama, Spring 1990

% Generate a set of points on a rotated ellipse

ns=16; dtheta=(2*pi)/ns; theta=dtheta*(0:ns-1);
i=sqrt(-1); zd=(2*cos(theta)+i*sin(theta))*exp(i*pi/6);
xd=real(zd); yd=imag(zd);

% Use piecewise cubic interpolation to connect the points

nout=81; [xout,yout]=spacurv(xd,yd,nout);
axis('square'); axis([-2,2,-2,2]);
plot(xout,yout,'.',xd,yd,'o')
xlabel('x axis'); ylabel('y axis')
title('INTERPOLATION THROUGH POINTS ON A SPACE CURVE')
text(-1.5,1.60,'o o o -> input data points')
text(-1.5,-1.75,'dots -> interpolated points')
axis('normal'); axis;
