function [xout,yout]=spacurv(xd,yd,nout,opencrv)
% [xout,yout]=spacurv(xd,yd,nout,opencrv)
% This function determines nout points on a closed or open
% curve passed through data points defined by vectors xd
% and yd. A closure point is added to make the curve close.
% Then additional points are added to achieve slope conti-
% nuity at the ends. The x and y variables are interpolated
% as functions of a parameter variable s which increases by
% one between successive points. Finally, a set of nout
% points on the curve defined by taking equal increments in
% the s variable are computed. The output points are generated
% using piecewise cubic Bessel interpolation.

%   by H. B. Wilson, Spring 1990

n=length(xd); xd=xd(:); yd=yd(:);
if nargin>3
  % Case for an open curve
  s=(1:n)'; cofx=bescof(s,xd); cofy=bescof(s,yd);
  sout=1+(0:nout-1)*((n-1)/(nout-1));
  xout=bestrp(sout,cofx); yout=bestrp(sout,cofy);
else
  % Case for a closed curve. First we add data points at both
  % ends to generate a closed curve with overlapping ends.

  xd=[xd(n);xd(:);xd(1);xd(2)];yd=[yd(n);yd(:);yd(1);yd(2)];

  % Generate the parameterization and perform
  % Bessel interpolation

  s=(0:n+2)'; cofx=bescof(s,xd); cofy=bescof(s,yd);
  sout=1+(0:nout-1)'*(n/(nout-1));
  xout=bestrp(sout,cofx); yout=bestrp(sout,cofy);
end
