% This file generates several approximations to map
% the interior of a circle onto the interior of an
% ellipse which has a major diameter twice as large
% as the minor diameter. The results demonstrate that
% even though polynomial approximations converge slowly,
% a rational function approximation gives good results.

%     Howard Wilson, Spring 1989

clear; hold off; clg
[zeta,z,theta,tau]=ellipse(2,256,50);
[a,b]=ratcof(zeta.^2,z./zeta,8);
zeta1=cgrid(1,1,1,0,90,100,1);
zeta2=cgrid(1,1,1,90,180,100,1);
zeta3=cgrid(1,1,1,180,270,100,1);
zrat1=raterp(a,b,zeta1.^2).*zeta1;
zpoly2=vndmon(zeta2,1,19,2)*(vndmon(zeta,1,19,2)\z);
zpoly3=vndmon(zeta3,1,15,2)*(vndmon(zeta,1,15,2)\z);
axis('square'); axis([-1.5,1.5,-1.5,1.5]);
plot(conj(z(1:65))); xlabel('x axis'); ylabel('y axis');
title('MAPPING A CIRCLE ONTO THE INTERIOR OF AN ELLIPSE');
text(-1.25, 1.00, 'upper_left  => 10 term polynomial')
text(-1.25, 1.25, 'upper_right => 8 term rational')
text(-1.25,-1.00, 'lower_left  => 8 term polynomial')
text(-1.25,-1.25, 'lower_right => exact ellipse')
hold on; plot(zrat1); plot(zpoly2); plot(zpoly3);
hold off; % meta elpsplt.met %DT


