      subroutine npsrch( needfd, inform, n, ncnln,
     $                   ldcJ, ldcJu, nfun, ngrad,
     $                   needc, funcon, funobj,
     $                   alfa, alfbnd, alfmax, alfsml, dxnorm,
     $                   epsrf, eta, gdx, grdalf, glf1, glf,
     $                   objf, objalf, qpcurv, xnorm,
     $                   c, c2, cJac, cJacu, cJdx, cJdx2,
     $                   cmul1, cmul, cs1, cs, dx, dlam, dslk,
     $                   grad, gradu, qpmul, rho, slk1, slk, x1, x,
     $                   work, w, lenw )

      implicit           double precision (a-h,o-z)
      logical            needfd
      integer            needc(*)
      double precision   dx(n), grad(n), gradu(n), x1(n), x(n)
      double precision   c(*), c2(*), cJac(ldcJ,*), cJacu(ldcJu,*),
     $                   cJdx(*), cJdx2(*), cmul1(*), cmul(*)
      double precision   cs1(*), cs(*), dlam(*), dslk(*), qpmul(*),
     $                   rho(*), slk1(*), slk(*),  work(*)
      double precision   w(lenw)
      external           funobj, funcon

*     ==================================================================
*     npsrch finds the steplength alfa that gives sufficient decrease in
*     the augmented Lagrangian merit function.
*
*     On exit, if inform = 1, 2 or 3,  alfa will be a nonzero steplength
*     with an associated merit function value  objalf  which is lower
*     than that at the base point. If  inform = 4, 5, 6, 7 or 8,  alfa
*     is zero and  objalf will be the merit value at the base point.
*
*     Original version written  27-May-1985.
*     Level 2 BLAS added 12-June-1986.
*     13-Oct-1994: MXS added backtrack if functions return mode = -1.
*     Prev version of npsrch dated  14-Sep-92.
*     This version of npsrch dated  13-Oct-94.
*     ==================================================================
      double precision   wmach
      common    /solmch/ wmach(15)
      save      /solmch/

      common    /sol1cm/ nout  , iPrint, iSumm , lines1, lines2
      common    /sol4cm/ epspt3, epspt5, epspt8, epspt9
      common    /sol4np/ lvldif, ncdiff, nfdiff, lfdset
      logical            incrun
      common    /sol6np/ rhomax, rhonrm, rhodmp, scale, incrun

      logical            npdbg
      parameter        ( ldbg = 5 )
      common    /npdebg/ inpdbg(ldbg), npdbg

      logical            debug , done  , first , imprvd
      external           ddot
      intrinsic          abs   , max   , min   , sqrt
      parameter        ( zero   =0.0d+0, half   =0.5d+0, one   =1.0d+0 )
      parameter        ( two    =2.0d+0                                )
      parameter        ( tolg   =1.0d-1                                )
      parameter        ( rmu    =1.0d-4                                )

      epsmch = wmach(3)

      if (.not. needfd  .and.  ncnln .gt. 0)
     $   cs1jdx = ddot( ncnln, cs1, 1, cJdx, 1 )

*     ------------------------------------------------------------------
*     Set the input parameters and tolerances for srchc and srchq.
*
*     tolrx   is the tolerance on relative changes in dx resulting from
*             changes in alfa.
*
*     tolax   is the tolerance on absolute changes in dx resulting from
*             changes in alfa.
*
*     tolabs  is the tolerance on absolute changes in alfa.
*
*     tolrel  is the tolerance on relative changes in alfa.
*
*     toltny  is the magnitude of the smallest allowable value of alfa.
*             if  M(tolabs) - M(0) .gt. epsaf,  the linesearch tries
*             steps in the range  toltny .le. alfa .le. tolabs.
*     ------------------------------------------------------------------
      nstate = 0
      debug  = npdbg  .and.  inpdbg(4) .gt. 0

      if (needfd) then
         maxf = 15
      else
         maxf = 10
      end if

      epsaf  = epsrf*(one + abs( objalf ))
      tolax  = epspt8
      tolrx  = epspt8

      if (tolrx*xnorm + tolax .lt. dxnorm*alfmax) then
         tolabs = (tolrx*xnorm + tolax) /  dxnorm
      else
         tolabs = alfmax
      end if
      tolrel = max( tolrx , epsmch )

      t      = zero
      do 10, j = 1, n
         s = abs( dx(j) )
         q = abs( x(j) )*tolrx + tolax
         if (s .gt. t*q) t = s / q
   10 continue

      if (t*tolabs .gt. one) then
         toltny = one / t
      else
         toltny = tolabs
      end if

      oldf   = objalf
      oldg   = grdalf
      
   50 alfbst = zero
      fbest  = zero
      gbest  = (one - rmu)*oldg
      targtg = (rmu - eta)*oldg
      g0     = gbest

      if (ncnln .gt. 0) call iload ( ncnln, (1), needc, 1 )

      if (needfd) then
         mode = 0
      else
         mode = 2
      end if

      first  = .true.

*     ------------------------------------------------------------------
*     Commence main loop, entering srchc or srchq two or more times.
*     first = true for the first entry,  false for subsequent entries.
*     done  = true indicates termination, in which case the value of
*     inform gives the result of the search.
*     inform = 1 if the search is successful and alfa < alfmax.
*            = 2 if the search is successful and alfa = alfmax.
*            = 3 if a better point was found but too many functions
*                were needed (not sufficient decrease).
*            = 4 if alfmax < tolabs (too small to do a search).
*            = 5 if alfa < alfsml (srchq only -- maybe want to switch
*                to central differences to get a better direction).
*            = 6 if the search found that there is no useful step.
*                The interval of uncertainty is less than 2*tolabs.
*                The minimizer is very close to alfa = zero
*                or the gradients are not sufficiently accurate.
*            = 7 if there were too many function calls.
*            = 8 if the input parameters were bad
*                (alfmax le toltny  or  oldg ge 0).
*     ------------------------------------------------------------------
*+    repeat
  100    if (needfd) then
            call srchq ( first , debug , done  , imprvd, inform,
     $                   maxf  , numf  , iPrint, 
     $                   alfmax, alfsml, epsaf , 
     $                   g0    , targtg, ftry  ,         
     $                   tolabs, tolrel, toltny,
     $                   alfa  , alfbst, fbest  )
         else
            call srchc ( first , debug , done  , imprvd, inform,
     $                   maxf  , numf  , iPrint,
     $                   alfmax,         epsaf , 
     $                   g0    , targtg, ftry  , gtry  , 
     $                   tolabs, tolrel, toltny,
     $                   alfa  , alfbst, fbest , gbest )
         end if

         if (imprvd) then
            objf   = tobj
            objalf = tobjM

            if (ncnln .gt. 0)
     $         call dcopy ( ncnln, c2, 1, c, 1 )

            if (.not. needfd) then
               call dcopy ( n, gradu, 1, grad, 1 )
               gdx    = tgdx
               glf    = tglf

               if (ncnln .gt. 0) then
                  call dcopy ( ncnln, cJdx2, 1, cJdx, 1 )
                  call f06qff( 'General', ncnln, n, cJacu, ldcJu,
     $                         cJac, ldcJ )
               end if
            end if
         end if

*        ---------------------------------------------------------------
*        If done = false,  the problem functions must be computed for
*        the next entry to srchc or srchq.
*        If done = true,   this is the last time through.
*        ---------------------------------------------------------------
         if (.not. done) then
            call dcopy ( n,       x1, 1, x, 1 )
            call daxpy ( n, alfa, dx, 1, x, 1 )

            if (ncnln .gt. 0) then

*              Compute the new estimates of the multipliers and slacks.
*              If the step length is greater than one,  the multipliers
*              are fixed as the QP-multipliers.

               if (alfa .le. one) then
                  call dcopy ( ncnln,       cmul1, 1, cmul, 1 )
                  call daxpy ( ncnln, alfa, dlam , 1, cmul, 1 )
               end if
               call dcopy ( ncnln,       slk1, 1, slk, 1 )
               call daxpy ( ncnln, alfa, dslk, 1, slk, 1 )

*              ---------------------------------------------------------
*              Compute the new constraint vector and Jacobian.
*              ---------------------------------------------------------
               call funcon( mode, ncnln, n, ldcJu,
     $                      needc, x, c2, cJacu, nstate )
               if (mode .lt. 0) go to 999

               call dcopy ( ncnln,         c2 , 1, cs, 1 )
               call daxpy ( ncnln, (-one), slk, 1, cs, 1 )

               call dcopy ( ncnln, cs , 1,  work, 1 )
               call ddscl ( ncnln, rho, 1,  work, 1 )

               fterm  =            ddot( ncnln, cmul, 1, cs, 1 ) -
     $                  half*scale*ddot( ncnln, work, 1, cs, 1 )
            end if

*           ------------------------------------------------------------
*           Compute the value and gradient of the objective function.
*           ------------------------------------------------------------
            call funobj( mode, n, x, tobj, gradu, nstate )
            if (mode .lt. 0) go to 999

            if (ncnln .gt. 0) then
               tobjM = tobj  - fterm
            else
               tobjM = tobj
            end if

            ftry  = tobjM - oldf - rmu*oldg*alfa 

*           ------------------------------------------------------------
*           Compute auxiliary gradient information.
*           ------------------------------------------------------------
            if (.not. needfd) then
               gtry   = ddot( n, gradu, 1, dx, 1 )
               tgdx   = gtry
               tglf   = gtry
               if (ncnln .gt. 0) then

*                 Compute the Jacobian times the search direction.

                  call dgemv ( 'n', ncnln, n, one, cJacu, ldcJu, dx, 1,
     $                         zero, cJdx2, 1 )

                  call dcopy ( ncnln,         cJdx2, 1, work, 1 )
                  call daxpy ( ncnln, (-one), dslk , 1, work, 1 )

                  gtry   = gtry - ddot( ncnln, cmul, 1, work, 1 )
                  if (alfa .le. one)
     $               gtry   = gtry - ddot( ncnln, dlam, 1, cs      , 1 )

                  call ddscl ( ncnln, rho , 1, work, 1 )
                  gtry = gtry  +
     $                     scale*ddot( ncnln, work, 1, cs   , 1 )

                  tglf = tgdx  - ddot( ncnln, cJdx2, 1, qpmul, 1 )

*                 ------------------------------------------------------
*                 If alfbnd .le. alfa .lt. alfmax and the norm of the
*                 quasi-Newton update is bounded, set alfmax to be alfa.
*                 This will cause the linesearch to stop if the merit
*                 function is decreasing at the boundary.
*                 ------------------------------------------------------
                  if (alfbnd .le. alfa  .and.  alfa .lt. alfmax) then
                     csjdx  = ddot   ( ncnln, cs, 1, cJdx2, 1 )
                     curvlf = tglf  - glf1
                     curvc  = abs( csjdx - cs1jdx )
                     rhobfs = max( qpcurv*tolg - curvlf, zero )
                     if (rhobfs .le. curvc*rhomax) then
                        alfmax = alfa
                     else
                        alfbnd = min( two*alfa, alfmax )
                     end if

                     if (npdbg  .and.  inpdbg(1) .gt. 0) then
                        write(iPrint, 1400) csjdx , cs1jdx, curvlf
                        write(iPrint, 1300) alfbnd, alfa  , alfmax
                     end if
                  end if
               end if

               gtry = gtry  - rmu*oldg

            end if
         end if
*+    until (      done)
      if    (.not. done) go to 100

      nfun = nfun + numf
      if (.not. needfd) ngrad = ngrad + numf
      alfa = alfbst

      if (.not. imprvd) then
         call dcopy ( n,       x1, 1, x, 1 )
         call daxpy ( n, alfa, dx, 1, x, 1 )
         if (ncnln .gt. 0) then
            if (alfa .le. one) then
               call dcopy ( ncnln,       cmul1, 1, cmul, 1 )
               call daxpy ( ncnln, alfa, dlam , 1, cmul, 1 )
            end if
            call dcopy ( ncnln,         slk1 , 1, slk, 1 )
            call daxpy ( ncnln,   alfa, dslk , 1, slk, 1 )
            call dcopy ( ncnln,         c    , 1, cs , 1 )
            call daxpy ( ncnln, (-one), slk  , 1, cs , 1 )
         end if
      end if

      if (npdbg  .and.  inpdbg(1) .gt. 0)
     $   write(iPrint, 1200) inform

      return

*     ------------------------------------------------------------------
*     One of the function routines set mode < 0.
*     mode = -1 means "undefined function at step alfa".
*     We start the whole search again with a smaller alfmax and alfa.
*     (The search routines will say if this is too small.)
*     ------------------------------------------------------------------
  999 if (mode .eq. -1) then
         alfmax = 0.1d+0 * alfa
         alfa   = alfmax
         go to 50
      end if

*     The user wants to stop.  Who am I to object?

      inform = mode
      return

 1200 format(/ ' //npsrch// inform  = ', i4 )
 1300 format(/ ' //npsrch//        alfbnd          alfa        alfmax'
     $       / ' //npsrch//', 1p, 3e14.2 )
 1400 format(/ ' //npsrch//         csjdx        cs1jdx        curvlf'
     $       / ' //npsrch//', 1p, 3e14.2 )

*     end of npsrch
      end

