function drct = conj_grad(grad,Scale,I)

% Polak-Ribiere conjugate gradient method.
% grad is a column vector.

% Works will with the quadratic fit at the end of line-search.
% Implementation uses only inactive constraint subspace in the
% inner-product calculations.  NOTE: must not change scaling except at
% resetting times because a change of scaling will destroy conjugacy.

%
% Copyright (c) 1996 by Adam L. Schwartz
% All right reserved.  
%
     
global COUNT old_grad old_drct DISP

RESET_INTERVAL = 0;   % RESET_INTERVAL = 0 implies no periodic resetting.
Tol1 = 0.2;           % Sufficient decrease factor.
Tol2 = 10;            % Factor for testing whether search direction too big.

grad = Scale*grad;
drct = -grad;

if RESET_INTERVAL, COUNT = rem(COUNT,RESET_INTERVAL+1); end

if COUNT == 0 
  disp('CG: resetting.')
  COUNT = COUNT+1;
else
  num  = grad(I)'*(grad(I)-old_grad(I));
  den  = old_grad(I)'*old_grad(I);
  beta = num/den;
  trial_drct = -grad(I) + beta*old_drct(I);

  norm_g = norm(grad(I));
  if trial_drct'*grad(I) > -Tol1*norm_g^2,
    if DISP, disp('CG direction not sufficiently downhill....resetting.'), end
    COUNT = 1;                 % Act as if this was the first iteration.
                               % Use steepest descent on this iteration.
  elseif norm(trial_drct) > Tol2*norm_g,
    if DISP, disp('CG direction too big....resetting.'), end
    COUNT = 1;                 % Act as if this was the first iteration.
                               % Use steepest descent on this iteration.
  else
    drct(I) = trial_drct;
    COUNT = COUNT+1;
  end
end

old_grad = grad;
old_drct = drct;
