/******************************************/
/*                                        */
/* Copyright (c) 1996 by Adam L. Schwartz */
/*          All right reserved.           */
/*                                        */
/******************************************************************/
/* exist_in_workspace('var_name') returns 0 if 'var_name' doesn't */
/* exist in MATLAB's workspace, 1 if 'var_name' does exist.       */
/* The Matlab command exist() is much to slow because it checks   */
/* the whole path.                                                */
/*                                                                */
/* Author: Adam L. Schwartz (adams@eecs.berkeley.edu).            */
/******************************************************************/

#include <stdio.h>
#include <mex.h>
#ifdef __STDC__
void 
#else
int
#endif
mexFunction(nlhs, lhs, nrhs, rhs)
     int nlhs, nrhs;
     Matrix *lhs[], *rhs[];
{
  char name[20];
  register int i;

  if ( nrhs != 1 ) mexErrMsgTxt("Usage: exists = exist_in_workspace('name')");
  if ( !mxIsString(rhs[0]) ) mexErrMsgTxt("Input must be a string.");
  
  for ( i = 0 ; i < mxGetN(rhs[0]) ; i++ )
    name[i] = mxGetPr(rhs[0])[i];
  name[i] = '\0';
  
  lhs[0] = mxCreateFull(1,1,0);		     /* Starts out initialized to 0. */

  /* if 'name' exists then mexGetMatrixPtr(name) returns non-zero. */
  if ( mexGetMatrixPtr(name) )
    mxGetPr(lhs[0])[0] = 1.0;
}
