% This function extends a set of indices, Iin, corresponding to a
% matrix with Nrows rows and Ncols columns.  Iin must be a column
% vector.  The indices corresponding to each row of the matrix are
% extended separately from the other rows.
% 
% For each portion, I, of Iin corresponding to a row of the matrix,
% Iout is I extended with extra indices around each disjoint set of
% indices.  For example, I = [2 3 4 9 10 11 13 14 17 18]' --> [1 2 3 4
% 5 8 9 10 11 12 13 14 15 16 17 18 19]'.

%
% Copyright (c) 1996 by Adam L. Schwartz
% All right reserved.  
%
 
function Iout = fill_indices(Iin,Nrows,Ncols)

Iout = [];
for i = 1:Nrows

  % I are the inactive indices for the i-th input.
  I = Iin( Iin > (i-1)*Ncols  &  Iin <= i*Ncols );

  % I1 indicates where breaks in the indices are.
  if I ~= []
    I1 = find(diff([(i-1)*Ncols ; I ; i*Ncols+1]) > 1);
    s1 = length(I1);
    I2 = sort([I ; I(I1(1:s1-1))-1 ; I(I1(2:s1)-1)+1]);
    II = find(diff(I2) == 0);
    I2(II) = [];
  else
    I2 = [];
  end

  Iout = [Iout ; I2];
end
