% So far, this function assumes a uniform grid if interpolating in
% original coordinates.

%
% Copyright (c) 1996 by Adam L. Schwartz
% All right reserved.  
%

function [new_R,Q] = lift_Hessian(R,factored,n_free_x0,method,K,ninputs)

% method == 1 : Lift Hessian in orthogonal coordinates.
% method == 2 : Interpolate Hessian in original coordinates.

if nargin == 0
 disp('Usage: [new_R,Q] = lift_Hessian(R,factored,n_free_x0,method,K,ninputs)')
 return
end
disp('Lifting current Hessian approximation into higher dimensional space.')
if K < 0 | K > 2, error('lift_hessian only works for K=0,1,2.'), end

ct = cputime;
N = size(R,1)-n_free_x0;

FINITE_DIFFERENCE=0;  % Only works for unconstrained, fixed initial conditions.

if FINITE_DIFFERENCE == 1
  global x0 new_u new_t ialg
  if x0==[] | new_u==[] | new_t==[] | ialg==[]
    error('type: global x0 new_u new_t ialg') 
  end
  H = comp_hess(x0,new_u,new_t,ialg);
  if K == 1,
    NN = 2*N;
    if method == 1
      new_R = chol(NN*H);
    else
      new_R = chol(H);
    end
  else
    NN = 2*N-1;
    if method == 1
      Q2_inv = diag( ones(1,NN) ./ sqrt([1/2 ones(1,NN-2) 1/2]/(NN-1)) );
      new_R  = chol(Q2_inv'*H*Q2_inv);
    else
      new_R = chol(H);
    end
  end
  return
elseif FINITE_DIFFERENCE == 2
  global x0 u t ialg
  if x0==[] | u==[] | t==[] | ialg==[]
    error('type: global x0 u t ialg') 
  end
  H = comp_hess(x0,u,t,ialg);
  if method == 1
    if K == 1
      H = H*N;
    else
      Q2_inv = diag( ones(1,N) ./ sqrt([1/2 ones(1,N-2) 1/2]/(N-1)) );
      new_R  = Q2_inv'*H*Q2_inv;
    end
  end
else
  if factored,
    R = triu(R);
    H = R'*R;
  else
    H = R;
  end
end

if method == 1,
  if K == 1,
    if 1
      NN = 2*N;
      Huu = H(1:N,1:N);
      I = ones(1,N);
      I(ninputs+1:ninputs:N) = (ninputs+1)*ones(1,N/ninputs-1);
      I = cumsum(I);
      H2uu = zeros(NN,NN);
      H2uu(I,I) = Huu;
      H2uu(I+ninputs,I+ninputs) = Huu;
      if n_free_x0 > 0
        Hux = H(1:N,N+1:N+n_free_x0);
	H2ux = zeros(1,NN);
	H2ux(I) = Hux;
        H2xx = H(N+n_free_x0,N+n_free_x0);
      else
       H2ux = []; H2xx = [];
      end
      H2 = [ H2uu H2ux ; H2ux' H2xx ];
    else
      % This (Carlos' method) only implemented for single input systems.
      Q1 = eye(N,N); Q2 = Q1;
      Q1 = kron(Q1,[1;1]/sqrt(2));
      Q2 = kron(Q2,[1;-1]/sqrt(2));
      Q = [Q1 Q2];
      Huu = H(1:N,1:N);
      H2uu = [Huu zeros(N,N) ; zeros(N,N) Huu];
      if n_free_x0 > 0,
      Q=[Q zeros(2*N,n_free_x0);zeros(n_free_x0,2*N) eye(n_free_x0,n_free_x0)];
        Hux  = H(1:N,N+1:N+n_free_x0);
        H2ux = [Hux ; 0*Hux];
        H2xx = H(N+n_free_x0,N+n_free_x0);
      else
        H2ux = [] ; H2xx = [];
      end
      H2 = Q*[H2uu H2ux ; H2ux' H2xx]*Q';
    end
  else
    NN = 2*N-ninputs;
    I = ones(1,N);
    I(ninputs+1:ninputs:N) = (ninputs+1)*ones(1,N/ninputs-1);
    I = cumsum(I);
    Huu = H(1:N,1:N);
    H2uu = zeros(NN,NN);
    H2uu(I,I) = Huu;
    H2uu(I(1:N-ninputs)+ninputs,I(1:N-ninputs)+ninputs) = ...
             (Huu(1:N-ninputs,1:N-ninputs) + Huu(1+ninputs:N,1+ninputs:N))/2;
    if n_free_x0 > 0,
      Hux = H(1:N,N+1:N+n_free_x0);
      H2ux = zeros(NN,n_free_x0);
      H2ux(I,:) = Hux;
%      H2ux(2:2:NN,:) = (Hux(1:N-1,:)+Hux(2:N,:))/2;
      H2xx = H(N+n_free_x0,N+n_free_x0);
    else
      H2ux = []; H2xx = [];
    end
    H2 = [ H2uu H2ux ; H2ux' H2xx ];
  end

  if 0,
    % This (Carlos' method) only implemented for single input systems.
    V1 = zeros(2*N-1,N);
    V1(1:2*N+1:N*(2*N-1)) = ones(1,N);
    I = 2:2*N+1:N*(2*N-1);
    V1(I) = 1/2*ones(1,N-1);
    V1(I+2*N-1) = 1/2*ones(1,N-1);
  %  V1(2,1) = 1;
  %  V1(2*N-2,N) = 1;
    V2 = zeros(2*N-1,N-1);
    V2(2:2*N+1:(2*N-1)*(N-1)) = ones(1,N-1);
    if 1,
      Q1_inv = diag( ones(1,N) ./ sqrt([1/2 ones(1,N-2) 1/2]/(N-1)) );
      Q2     = diag( sqrt([1/2 ones(1,2*N-3) 1/2]/(2*N-1)) );
      Q = [Q2*V1*Q1_inv V2];
    else
      Q1 = diag([2 4*ones(1,N-2) 2]);
      Q1 = Q1+diag(ones(1,N-1),1)+diag(ones(1,N-1),-1);
      Q1 = Q1/6/(N-1);
      Q2 = diag([2 4*ones(1,2*N-3) 2]);
      Q2 = Q2+diag(ones(1,2*(N-1)),1)+diag(ones(1,2*(N-1)),-1);
      Q2 = Q2/6/(2*(N-1));
      Q = [sqrtm(Q2)*V1*sqrtm(inv(Q1)) V2];
    end
    if n_free_x0 > 0,
      Q=[Q zeros(2*N,n_free_x0);zeros(n_free_x0,2*N) eye(n_free_x0,n_free_x0)];
      Huu = H(1:N,1:N);
      Hux = H(1:N,N+1:N+n_free_x0);
      H2xx = H(N+n_free_x0,N+n_free_x0);
      H2uu = [Huu zeros(N,N-1) ; zeros(N-1,N) eye(N-1,N-1)];
      H2ux = [Hux ; 0*Hux];
      H2 = [H2uu H2ux ; H2ux' H2xx];
    else
      H2 = [H zeros(N,N-1) ; zeros(N-1,N) eye(N-1,N-1)];
  %    H2 = [H zeros(N,N-1) ; zeros(N-1,N) conv2(H,[1 1;1 1]/4,'valid')];
    end
    H2 = Q*H2/Q;
  end 

else

% The non-transformed interpolation is implemented for single
% input systems only.	
  if K == 1
    NN = 2*N;
    Huu = H(1:N,1:N)/2;
    H2uu = zeros(NN,NN);
    H2uu(1:2:NN,1:2:NN) = Huu;
    H2uu(2:2:NN,2:2:NN) = Huu;
    if n_free_x0 > 0
      Hux = H(1:N,N+1:N+n_free_x0)/sqrt(2);
%      H2ux = kron(Hux,[1;1]);
      H2ux = kron(Hux,[1;0]);
      H2xx = H(N+n_free_x0,N+n_free_x0);
    else
      H2ux = []; H2xx = [];
    end
  else
    NN = 2*N-1;
    Q1_inv = ones(1,N) ./ sqrt([1/2 ones(1,N-2) 1/2]/(N-1));
    Q2     = sqrt([1/2 ones(1,NN-2) 1/2]/(NN-1));
    Huu = Q1_inv(ones(N,1),:)'.*H(1:N,1:N).*Q1_inv(ones(N,1),:);
    H2uu = zeros(NN,NN);
    H2uu(1:2:NN,1:2:NN) = Huu;
    H2uu = Q2(ones(NN,1),:)'.* ....
          (H2uu + conv2(H2uu,[1 0 0;0 0 0;0 0 1]/2,'same')).*Q2(ones(NN,1),:);
    if n_free_x0 > 0
      Hux = Q1_inv(ones(n_free_x0,1),:)'.*H(1:N,N+1:N+n_free_x0);
      H2ux = zeros(NN,n_free_x0);
      H2ux(1:2:NN,:) = Hux;
%      H2ux(2:2:NN,:) = (Hux(1:N-1,:)+Hux(2:N,:))/2;
      H2ux = Q2(ones(n_free_x0,1),:)'.*H2ux;
      H2xx = H(N+n_free_x0,N+n_free_x0);
    else
      H2ux = []; H2xx = [];
    end
  end
  H2 = [ H2uu H2ux ; H2ux' H2xx ];

end

ct1 = cputime;
fprintf('Time to compute lifted Hessian = %g seconds.\n',ct1-ct)

if factored
  new_R = chol(H2);
else
  new_R = H2;
end

fprintf('Time to do linear algebra on Hessian = %g seconds.\n',cputime-ct1)

