function [xc,I_a,I_i] = project(x,d,blower,bupper,margin,grad)

%  [xc,I_a,I_i] = project(x,d,blower,bupper,{margin,grad})
%
%  x is current iterate
%  d is current search direction, if d==[], then don't compute x_c.
%  blower and bupper are upper and lower bounds with same dimension as x.
%  margin is a matrix with same dimension as x that is used to determing
%    when a constraint becomes active.
%  grad (optional) is the gradient at x.
%
%  I_a I_i are only returned if grad is specified (can't determine
%  active constraint without knowing the gradient).
%
%  Projects x+d into the bounds, returns xc.
%  The active constraint index I_a list is returned ([] if empty)
%  and the inactive constraint index I_i list is returned ([] if empty).
%  If grad is specified and margin isn't, then margin is set to 0.001

%
% Copyright (c) 1996 by Adam L. Schwartz
% All right reserved.  
%

if d ~= []
  xc = max(min(x+d,bupper),blower);
else
  xc = [];
end

if nargin == 6
  w = norm(x - max(min(x-grad,bupper),blower));
  margin = min(margin,w);
  clip = (x < blower+margin & grad > 0) | (x > bupper-margin & grad < 0);
  I_a = find(clip);
  I_i = find(~clip);
end
