/***********************************************************/
/* CALLING EXAMPLE:                                        */
/* >> N = 100;                                             */
/* >> t = [0:1/N:1];                                       */
/* >> u0 = zeros(1,N+1);                                   */
/* >> x0 = 1;                                              */
/* >> [u,x,f]=riots(x0,u0,t,[],[],[],100,2);               */
/* or                                                      */
/* >> [u,x,f]=pdmin(x0,u0,t,[],[],[],100,2);               */
/***********************************************************/
/* PROBLEM DESCRIPTION:                                    */
/* x_dot = x/2 + u  ; x(0) = 1.                            */
/*                                                         */
/* min J(u) = int_0^1 (0.625*x^2 + 0.5*x*u + 0.5*u^2) dt   */
/***********************************************************/

#define NSTATES 1
#define NINPUTS 1
#define NPARAMS 0
#define LTI 4        /* Linear, time-invariant dynamics with quadratic cost. */

void activate(message)
     char **message;
{
  *message = "LQR";
} 

void init(neq,params)
     int neq[];
     double *params;
{
  if ( params == 0 ) {
    neq[0] = NSTATES;
    neq[1] = NINPUTS;
    neq[2] = NPARAMS;
    neq[12] = LTI;
  }
}

void h(neq,t,x,u,xdot)
     int neq[];
     double *t,x[NSTATES],u[NINPUTS],xdot[NSTATES];
{
  xdot[0] = 0.5*x[0] + u[0];
}

void Dh(neq,t,x,u,h_x,h_u)
     int neq[];
     double *t,x[NSTATES],u[NINPUTS];
     double h_x[NSTATES][NSTATES],h_u[NSTATES][NINPUTS];
{
  h_x[0][0] = 0.5;
  h_u[0][0] = 1.0;
}

double l(neq,t,x,u)
     int neq[];
     double *t,x[NSTATES],u[NINPUTS];
{
  return 0.625*x[0]*x[0] + 0.5*(x[0] + u[0])*u[0];
}

double Dl(neq,t,x,u,l_x,l_u)
     int neq[];
     double *t,x[NSTATES],u[NINPUTS],l_x[NSTATES],l_u[NINPUTS];
{
  l_x[0] = 1.25*x[0] + 0.5*u[0];
  l_u[0] = u[0] + 0.5*x[0];
  return 0.0;
}

double g(neq,t,x0,xf)
     int neq[];
     double *t,x0[NSTATES],xf[NSTATES];
{
  return 0.0;
}

double Dg(neq,t,x0,xf,J_x0,J_xf)
     int neq[];
     double *t,x0[NSTATES],xf[NSTATES],J_x0[NSTATES],J_xf[NSTATES];
{
  return 0.0;
}
