/***********************************************************/
/* CALLING EXAMPLE:                                        */
/* >> N = 50;                                              */
/* >> t = [0:1/N:1];                                       */
/* >> u0 = zeros(1,N+1);                                   */
/* >> x0 = [0 -1]';                                        */
/* >> [u,x,f]=riots(x0,u0,t,[],[],[],100,2);               */
/***********************************************************/
/* PROBLEM DESCRIPTION:                                    */
/*
   x1_dot = x2       ; x1(0) = 0
   x2_dot = -x2 + u  ; x2(0) = -1

   cost = int_0^1 x1^2 + x2^2 + 0.005*u^2 dt

   State Constraint: x2(t) - 8*(t-0.5)^2 + 0.5 <= 0
*/

#define SQP_XU 0

#define NSTATES 2
#define NINPUTS 1
#if SQP_XU
#define LT_INEQ  0
#else
#define LT_INEQ  1
#endif
#define LTI     4

extern int points;
extern double *Y;

void activate(message)
     char **message;
{
  *message = "parabola";
  return;
} 

void init(neq,params)
     int neq[];
     double *params;
{
  if ( params == 0 ) {
    neq[0] = NSTATES;
    neq[1] = NINPUTS;
    neq[7] = LT_INEQ;
    neq[12] = LTI;
  }
  return;
}

void h(neq,t,x,u,xdot)
     int neq[];
     double *t,x[NSTATES],u[NINPUTS],xdot[NSTATES];
{
  xdot[0] = x[1];
  xdot[1] = u[0]-x[1];
}

void Dh(neq,t,x,u,A,B)
int neq[];
double *t,x[NSTATES],u[NINPUTS],A[NSTATES][NSTATES],B[NSTATES][NINPUTS];
{
  A[0][1] = 1.0;
  A[1][1] = -1.0;

  B[1][0] = 1.0;
}

double l(neq,t,x,u)
     int neq[];
     double *t,x[NSTATES],u[NINPUTS];
{
  double zdot;

  if ( neq[4] == 1 ) 
    zdot = x[0]*x[0] + x[1]*x[1] + 0.005*u[0]*u[0];
  else
    zdot = x[1] - 8*(*t-0.5)*(*t-0.5) + 0.5;

  return zdot;
}

double Dl(neq,t,x,u,l_x,l_u)
int neq[];
double *t,x[NSTATES],u[NINPUTS],l_x[NSTATES],l_u[NINPUTS];
{
  if ( neq[4] == 1 ) {
    l_x[0] = 2*x[0];
    l_x[1] = 2*x[1];
    l_u[0] = 0.01*u[0];
  }
  else {
    l_x[1] = 1.0;
  }
  return 0.0;
}

double g(neq,t,x0,x)
int neq[];
double *t,x0[NSTATES],x[NSTATES];
{
  return 0.0;
}


double Dg(neq,t,x0,x,J_x0,J_xf)
int neq[];
double *t,x0[NSTATES],x[NSTATES],J_x0[NSTATES],J_xf[NSTATES];
{
  return 0.0;
}
