/***********************************************************/
/* CALLING EXAMPLE:                                        */
/* >> N = 50;                                              */
/* >> T = 2.5;                                             */
/* >> t = [0:T/N:T];                                       */
/* >> u0 = zeros(1,N+1);                                   */
/* >> x0 = [-5 -5]';                                       */
/* >> [u,x,f]=riots(x0,u0,t,0,3.5,[],100,2);               */
/* or,                                                     */
/* >> [u,x,f]=pdmin(x0,u0,t,0,3.5,[],100,2);               */
/* or,                                                     */
/* >> FLAGS = 1;                                           */
/* >> clear simulate;                                      */
/* >> [u,x,f]=riots(x0,u0,t,0,3.5,[],100,2);               */
/* or,                                                     */
/* >> [u,x,f]=aug_lagrng(x0,u0,t,0,3.5,[],10,10,2);        */
/***********************************************************/
/* PROBLEM DESCRIPTION:                                    */
/* This defines Rayleigh's equations
   x1dot = x2
   x2dot = -x1+(1.4-.14*x2^2)*x2 + 4*u

   x0=[-5;-5]

   J = \int_0^{2.5} x1^2 + u^2

From IEEE TAC Dec. 1989, pp. 1308-1311, D. Talwar and R. Sivan
"An Efficient Numerical Algorithm for the Solution of a Class
of Optimal Control Problems," and lots of other places.
*/

#define F_NUM neq[4]

#define NSTATES 2
#define NINPUTS 1

extern int get_flags();
static int Constraints;

void activate(message)
     char **message;
{
  int n,flags[1];

  *message = "Rayleigh";
  n = 1;
  if ( get_flags(flags,&n) > 0 ) 
    Constraints = flags[0];
  else 
    Constraints = 0;
  if ( Constraints > 0 )
    printf("Constrained problem.\n");
  else
    printf("Unconstrained problem.\n");
} 

void init(neq,params)
     int neq[];
     double *params;
{
  if ( params == 0 ) {
    neq[0] = NSTATES;
    neq[1] = NINPUTS;
    neq[11] = Constraints;
  }
}

void h(neq,t,x,u,xdot)
     int neq[];
     double *t,x[NSTATES],u[NINPUTS],xdot[NSTATES];
{
  xdot[0] = x[1];
  xdot[1] = -x[0] + (1.4-.14*x[1]*x[1])*x[1] + 4*u[0];
}

double Dh(neq,t,x,u,h_x,h_u)
     int neq[];
     double *t,x[NSTATES],u[NINPUTS];
     double h_x[NSTATES][NSTATES],h_u[NSTATES][NINPUTS];
{
  h_x[0][1] = 1.0;
  h_x[1][0] = -1.0;
  h_x[1][1] = 1.4 - 0.42*x[1]*x[1];

  h_u[1][0] = 4.0;
  return 0.0;
}

double l(neq,t,x,u)
int neq[];
double *t,x[NSTATES],u[NINPUTS];
{
  double control;
   
  control = u[0];
  return x[0]*x[0] + control*control;
}

void Dl(neq,t,x,u,l_x,l_u)
     int neq[];
     double *t,x[NSTATES],u[NINPUTS],l_x[NSTATES],l_u[NINPUTS];
{
  l_x[0] = 2*x[0];
  l_u[0] = 2*u[0];
}

double g(neq,t,x0,xf)
     int neq[];
     double *t,x0[NSTATES],xf[NSTATES];
{

  switch (F_NUM) {
  case 1:
    return 0.0;
  case 2:
    return xf[0];
  case 3: 
    return xf[1];
  }
}

double Dg(neq,t,x0,xf,J_x0,J_xf)
     int neq[];
     double *t,x0[NSTATES],xf[NSTATES],J_x0[NSTATES],J_xf[NSTATES];
{
  if (F_NUM == 2)
    J_xf[0] = 1.0;
  if (F_NUM == 3)
    J_xf[1] = 1.0;
  return 0.0;
}
