function [x,p,dJdu] = sys_resp(tf,t,sys_num,x0,u0,u1)

%  This function gives the responses for system 3,4 
%  'u0' is a constant (step function).
%  System 1 not implemented.
%
%  For systems 4, I also allow an optional argument u1.  if
%  u1 is specified the control is assumed to be of the form
%  u(t) = u0 + t*u1
%
%  We need the final time, tf, specified because tf may not be
%  equal to the last element of t (unless c_r = 1).   

if nargin < 5
   disp('Usage: [x,p,dJdu] = sys_resp(tf,t,sys_num,x0,u0,u1)'),
   return,
end

if (sys_num < 3 | sys_num > 4)
  error('Haven''t implemented this system yet.')
end

if ~( nargin == 5 | ( nargin == 6 & sys_num == 4 ) )
  error('Wrong number of input arguments.')
end

if (length(tf) ~= 1)
  error('sys_resp(tf,t,sys_num,x0,u0{u1})')
end

if (sys_num == 3)
  x = exp(.5*t).*(x0 + 2*u0*(1-exp(-.5*t)));
  p0 = -(1-2*exp(tf))*x0 + 4*u0*(1+exp(tf)-2*exp(tf/2));
  p = exp(-t/2).*(p0 + (1-2*exp(t))*x0 - 4*u0*(1+exp(t)-2*exp(t/2)));

  if exist('u1')
    x = x + u1*(4*exp(.5*t) - 4 - 2*t);
    temp = 8*u1*(1 + t.*exp(.5*t) - exp(t));
    temp_tf = 8*u1*(1 + tf.*exp(.5*tf) - exp(tf));
    p = p + exp(-t/2).*(temp - temp_tf);
  end

  dJdu = p + u0*ones(size(t));

  if exist('u1'), dJdu = dJdu + u1*t; end

end

if (sys_num == 4)
  x = exp(.5*t).*(x0 + 2*u0*(1-exp(-.5*t)));
  p0 = -1.25*(1-exp(tf))*x0 + u0*(1.5+2.5*exp(tf)-4*exp(tf/2));
  p = exp(-t/2).*(p0 + 1.25*(1-exp(t))*x0 - u0*(1.5+2.5*exp(t)-4*exp(t/2)));

  if exist('u1')
     x = x + u1*(4*exp(.5*t)-4-2*t);
     temp = u1*(5*exp(t) - (2+4*t).*exp(.5*t) - 3);
     temp_tf = u1*(5*exp(tf) - (2+4*tf).*exp(.5*tf) - 3);
     p = p - exp(-t/2).*(temp - temp_tf);
  end

  dJdu = p + .5*x + u0*ones(size(t));

  if exist('u1'), dJdu = dJdu + u1*t; end

end

