/* Below, NPARAMS refers to the number of fixed parameters (like a penalty).
 * For variable parameters, append an extra state z(0) = parameter and
 * z_dot(t) = 0.
*/
/* NOTE: There is no error checking on array bounds for the
 *       state and control.  Writting outside the bounds will
 *       cause errors.
 */

#define NSTATES 1          /* Number of states.                            */
#define NINPUTS 1          /* Number of inputs.                            */
#define NPARAMS 0          /* Number of (fixed) system parameters.         */
#define NFUNCTIONS 1       /* Number of objective functions.               */
#define NLTC  0            /* Nonlinear trajectory inequality constraints. */
#define LTC   0            /* Linear trajectory inequality constraints.    */
#define NLEIC 0            /* Nonlinear endpoint inequality constraints.   */
#define LEIC  0            /* Linear endpoint inequality constraints.      */
#define NLEEC 0            /* Nonlinear endpoint equality constraints.     */
#define LEEC  0            /* Linear endpoint equality constraints.        */
#define LTI   0            /* 1 => Linear, 2 => LTI, 3 => LQ, 4 => LQTI    */

#define F_NUM neq[4]

/*-------------------------------------------------------------------------*/
/* This function is called once at dynamic link time.                      */
/* If message is supplied, it will be displayed in the command window      */
/* when simulate(0) is invoked. You can use it to initialize constants     */
/* and arrays and so forth.  Parameters that can change, however, should   */
/* be passed throught the init() functions.                                */

void activate(message)
     char **message;
{
  *message = "my_system_name";
} 

/*-------------------------------------------------------------------------*/

/*-------------------------------------------------------------------------*/
/* if params = 0 (NULL), then the driver is sending the initial initialization
   request.  Otherwise, init() is called once at the beginning of each
   simulation iff there are constant parameters to be passed to the system.
*/
/* neq[0]  = number of state variables.
 * neq[1]  = number of inputs.
 * neq[2]  = number of parameters.
 * neq[3]  = current time index.  If user sets neq[3] = -1 when l()
             then it is assumed that l=0.
 * neq[4]  = number of function to evaluate (1 is first function).
 * neq[5]  = number of objective functions.
 * neq[6]  = number of nonlinear trajectory constraints.
 * neq[7]  = number of linear trajectory constraints.
 * neq[8]  = number of nonlinear endpoint inequality constraints.
 * neq[9]  = number of linear endpoint inequality constraints.
 * neq[10] = number of nonlinear endpoint equality constraints.
 * neq[11] = number of linear endpoint equality constraints.
 * neq[12] = 0 => nonlinear, 1 => linear, 2 => LTI, 3 => LQR, 4 => LQR and LTI.
 */
void init(neq,params)
     int neq[13];
     double *params;
{
  if ( params == 0 ) {
    neq[0]  = NSTATES;
    neq[1]  = NINPUTS;
    neq[2]  = NPARAMS;
    neq[5]  = NFUNCTIONS;
    neq[6]  = NLTC;
    neq[7]  = LTC;
    neq[8]  = NLEIC;
    neq[9]  = LEIC;
    neq[10] = NLEEC;
    neq[11] = LEEC;
    neq[12] = LTI;
  }
  else {
    /* Load parameters from params[]. */
  }
  return;
}
/*-------------------------------------------------------------------------*/

/******************************************************************/
/*                S Y S T E M    D Y N A M I C S                  */
/******************************************************************/
/* State equations: x_dot(t) = h(t,x(t),u(t))       */
/* This function should ignore the value in neq[4]. */
void h(neq,t,x,u,xdot)
     int neq[];
     double *t,x[NSTATES],u[NINPUTS],xdot[NSTATES];
{
}

/* Dh returns the linearization of h(t,x,u) w.r.t x and u.*/
/* h_x is NxN where N  is the number of states x.         */
/* h_u is NxM where M  is the number of controls u.       */
void Dh(neq,t,x,u,h_x,h_u)
     int neq[];
     double *t,x[NSTATES],u[NINPUTS];
     double h_x[NSTATES][NSTATES],h_u[NSTATES][NINPUTS];
{
}

/******************************************************************/
/*           I N T E G R A L   C O S T  F U N C T I O N           */
/******************************************************************/
/* Integral cost l(t,x(t),u(t).                                */
/* If no integral cost, set zdot = 0.0 or set neq[3] = -1.     */
/* If there are traj. constraints, then when F_NUM > NFUNCS,   */
/* this function should put the value of the (F_NUM - NFUNCS)  */
/* constraint, evaluted at time t, in zdot.                    */
/* Put nonlinear constraints first, linear constraints after.  */
/* 
   REMEMBER: You must specify an l-function for each function and each
             trajectory constraint.
*/
double l(neq,t,x,u)
     int neq[];
     double *t,x[NSTATES],u[NINPUTS];
{
  double zdot;

  return zdot;
}

/* Dl returns the linearization of l(t,x,u) w.r.t x and u. */
/* l_x is 1xN and l_u is 1xM.                              */
double Dl(neq,t,x,u,l_x,l_u)
     int neq[];
     double *t,x[NSTATES],u[NINPUTS],l_x[NSTATES],l_u[NINPUTS];
{
  return 0.0;
}

/******************************************************************/
/*             F I N A L   C O S T   F U N C T I O N              */
/******************************************************************/
/* This function returns the final state cost, g(x(a),x(b)) in
 * J = g(x(a),x(b)) + int_a^b l(t,x,u) dt
 *
 * If there are endpoint constraints and F_NUM > NFUNCS, 
 * this function should return the value of the (F_NUM - NFUNCS) 
 * endpoint constraint.
 * The order of the constraints should be as followS:
 *      nonlinear inequality
 *      linear    inequality
 *      nonlinear equality
 *      linear    equality
*/
double g(neq,t,x0,xf)
     int neq[];
     double *t,x0[NSTATES],xf[NSTATES];
{
}

/* This function computes the linearization of F().      */
/* J_xf is 1xN, J_x0 is 1xN and the return value is J_t. */
double Dg(neq,t,x0,xf,J_x0,J_xf)
     int neq[]; 
     double *t,x0[NSTATES],xf[NSTATES],J_x0[NSTATES],J_xf[NSTATES];
{
  return 0.0;
}
