function [rav]=urlaz(rev)
%URLAZ    Umrechnung von Reglerparametern zwischen Laplace- und Z-Bereich
%         [rav]=urlaz bzw. [rav]=urlaz(rev)
% Umrechnung auf Grundlage von Naeherungen - wahlweise menuegefuehrt
%         Belegung des Eingangsvektors: rev=[T Ri Bp Sz Fo x1 x2 x3 x4]
%             "     "  Ausgangs   "     rav=[y1,y2,y3,y4]
% Einsetzbar zum quasikontinuierlichen Verstaendnis mit dem Digitalen Betrags-
% optimum (BOD) entworfener digitaler Regler
%
%  T: Abtastzeit (alle Zeitgroessen muessen die gleiche Zeiteinheit besitzen)
% Ri: Umrechnungsrichtung (0) z in p oder (1) p in z
%
%                                               x1,y1  x2,y2  x3,y3   x4,y4
% Bp: Beschreibung im p-Bereich (Empfehlung: 0)
%     (0) additiv:  Kp(gamma+1/pTN+pTV/(1+pTZ))   Kp     TN     TV     TZ
%         (I-Struktur: gamma=0, sonst gamma=1)
%     (1) multiplikativ:(1+pT1)(1+pT2)/pT0        T1     T2     T0      0
%
%     Im Z-Bereich gilt der Zusammenhang:         Vr     d1     d2   d3,b1,d0
%     Vr(beta+d1(z^-1)+d2(z^-2)+d3(z^-3))/((1+alpha(z^-1))(1+b1(z^-1)))
%
% Sz: Struktureinstellung
%            Z-Bereich:                  p-Bereich:
%     (0) alpha=-1; beta=1; x4=d3     PID- und PI-Struktur
%     (1) alpha=-1; beta=0; x4=d0     I -Struktur
%     (2) alpha= 0; beta=1; x4=0      PD-Struktur
%     (3) alpha=-1; beta=1; x4=b1     PID-Struktur mit verz. D-Anteil
%     (4) alpha= 0; beta=1; x4=b1     PD -    "     "    "      "
%
% Fo: Auswahl einer Naeherung (Empfehlung: 4 bzw. 8)
%     (1) Diff mit 1.Ordnung     - oder - Int mit RF bei positivem Fehler
%     (2) Trans mit HG 0.Ordnung - oder -  "   "  RF  "  negativem   "
%     (3) Diff erste Ableitung 2.Ordnung, zweite Ableitung 1.Ordnung
%     (4) Int mit TF und Diff mit 1.Ordnung
%     (8) wie (4) aber mit Verzoegerung des D-Anteiles: 1/(1+pTZ)
%
%   S O N D E R F A E L L E (Wegen ueberbestimmter Ordnung im Z-Bereich
%                            nicht zu empfehlen! - nur fuer Vergleiche):
%     (5) Diff mit 2.Ordnung
%     (6) Int mit TF und Diff mit 2.Ordnung
%     (7) Trans mit HG 1.Ordnung
%
% verwendete Abkuerzungen:
%            Diff  - Differentationsnachbildung
%            Int   - Integrationsnachbildung
%            RF    - Rechteckformel
%            TF    - Trapezformel
%            Trans - Z-Transformation des Reglers
%            HG    - Halteglied
% ACHTUNG: Bei nicht sinnvollen Kombinationen erfolgt Fehlermeldung

% SCHLUESSELWORTE: Quasianaloge Nherung, Trapezformel, Rechteckformel,
%                  Differentationsnachbildung, verzgerter D-Anteil,
%                  Quasikontinuierliches Verstndnis digitaler Regler,

%  Copyright (c) 1993 Dr. Gert-Helge Geitner; TU Dresden, Fak. ET,
%                     Elektrotechnisches Institut (ETI); Mommsenstr. 13;
%                     D-01062 Dresden, Germany;
%                     Tel./Fax (0351)-463-2917/7280
%                     e-mail: geitner@eeiwzb.et.tu-dresden.de
%  Literatur zum Digitalen Betragsoptimum: Geitner, G.-H.:
%                     Entwurf digitaler Regler fr elektrische Antriebe.
%                     VDE-Verlag GmbH Berlin und Offenbach 1995

if nargin==1
   [me,ne]=size(rev);
   if ((ne~=9)|(me>1))
   error('Dimensionsfehler im Eingangsvektor')
   end
else
input('Abtastzeit =');
     if ans>0 rev(1)=ans; else error('Keine sinnvolle Abtastzeit'); end
input('Umrechnungsrichtung: z2p(bel.)/p2z(1) =');
     if ans==1; else ans=0; end; rev(2)=ans;
input('Beschreibung im p-Bereich: add(bel.)/mul(1) =');
     if ans==1; else ans=0; end; rev(3)=ans;
input('Struktureinstellung: PID/PI(bel.),I(1),PD(2),PIDTZ(3),PDTZ(4) =');
     if ans==1|ans==2|ans==3|ans==4; else ans=0; end; rev(4)=ans;
input('Nherungsformel (1...8) ='); h4=0;
     if ans>=1 else ans=0; end; rev(5)=ans;
       if rev(2)==1
          if rev(3)==1
             h1=input('Zhlerzeitkonstante1 =');
             h2=input('Zhlerzeitkonstante2 =');
             h3=input('Nennerzeitkonstante0 =');
          else
             h1=input('Proportionalverstrkung =');
             h2=input('Nachstellzeit =');
             h3=input('Vorhaltezeit =');
             if rev(5)==8
                h4=input('Dmpfungszeitkonstante =');
             end
          end
          if h1>=0&h2>=0&h3>=0&h4>=0
          else error('Fehler in Reglerparametereingabe'); end
       else
          h1=input('Verstrkung =');
          h2=input('d1 =');
          h3=input('d2 =');
          if rev(5)==8
             h4=input('b1 =');
          elseif rev(5)==5|rev(5)==6|rev(5)==7
             h4=input('d3 =');
          elseif rev(4)==1
             h4=input('d0 =');
          end
          if h1>=0&abs(h2)<5&abs(h3)<5&abs(h4)<5
          else error('Fehler in Reglerparametereingabe'); end
       end
rev(6)=h1; rev(7)=h2; rev(8)=h3; rev(9)=h4;
end
if (rev(6)==0)&((rev(2)==0)|(rev(3)==0))
   error('Verstrkung=0 ist nicht sinnvoll!')
end
if ((rev(7)==0)&(rev(8)==0)&(rev(9)==0))&((rev(2)==0)|(rev(3)==0))
   error('Fr P-Regler entfllt die Umrechnung!')
end
T=rev(1); Ri=rev(2); Bp=rev(3); Sz=rev(4); Fo=rev(5);
if ~((Ri==0)|(Ri==1))|~((Bp==0)|(Bp==1))|(Sz<0)|(Sz>4)|(rem(Sz,1)~=0)...
    |(Fo<1)|(Fo>8)|(rem(Fo,1)~=0)|((Bp==1)&(Sz>1))
   error('Unzulssige Einstellung der Eingabeschalter!')
end
if ~(((Fo==8)&((Sz==3)|(Sz==4))&(Bp==0))|((Sz==0)&(Fo~=8))|...
   ((Sz==1)&~((Fo==3)|(Fo==5)|(Fo==6)|(Fo==8)))|...
   (((Sz==4)|(Sz==2))&~((Fo==4)|(Fo==6))))
error('Keine Berechnung fr gewhlte Struktur-Nherungsformel-Kombination!')
end
if (rev(9)~=0)&(((Bp==1)&((Ri==1)|((Ri==0)&(Sz>1))))|...
               ((Bp==0)&(((Ri==1)&(Fo~=8))|((Ri==0)&(Fo<5)&(Sz~=1)))))
   error('Fr gewhlte Struktur mu x4=0 gelten!')
end
if Ri==1
   if Bp==1
      if Sz~=1
           TN=rev(6)+rev(7); V=TN/rev(8); TV=rev(6)*rev(7)/TN;
      else TN=rev(8); V=1; TV=0;
      end
   else
      TN=rev(7); V=rev(6); TV=rev(8);
   end
   TZ=rev(9);
   d2=0; d3=0; b1=0;
else
   V=rev(6); d1=rev(7); d2=rev(8);
   if Fo==8   b1=rev(9);
   elseif Sz==1 d0=rev(9);
   else   b1=0; d3=rev(9);
   end
   TN=0; TV=0; TZ=0;
end
if (Sz==0)|(Sz==3)                 % PID- oder PI-Struktur
if Ri==1
   b=T/TN; c=TV/T; d=TZ/T;
   if Fo==1
                  N=1+b+c;   d1=-(1+2*c); d2=c;
   elseif Fo==2
                  N=1+c;     d1=-1+b-2*c; d2=c;
   elseif Fo==3
                  N=1.5+b+c; d1=-2*(1+c); d2=0.5+c;
   elseif (Fo==4)|(Fo==8)
                  N=(1+d*b+b/2+c+d)/(1+d); d1=-(1+d*b-b/2+2*(c+d))/(1+d);
                  d2=(c+d)/(1+d);          b1=-d/(1+d);
   elseif Fo==5
                  N=1.5+b+2*c;   d1=-2-5*c;       d2=0.5+4*c; d3=-c;
   elseif Fo==6
                  N=1+b/2+3*c/2; d1=-1+b/2-7*c/2; d2=5*c/2;   d3=-c/2;
   elseif Fo==7
                  N=1+2*c;       d1=-1+3*b/2-5*c; d2=4*c-b/2; d3=-c;
   end
   V=V*N; d1=d1/N; d2=d2/N; d3=d3/N;
else
   if Fo==1
                  N=-(d1+2*d2); TN=1+d1+d2; TV=-d2;
   elseif Fo==2
                  N=1-d2;       TN=1+d1+d2; TV=-d2;
   elseif Fo==3
                  N=-(d1+2*d2); TN=1+d1+d2; TV=-0.5*d1-2*d2;
   elseif (Fo==4)|(Fo==8)
                  N=0.5*(1+3*b1-d1*(1-b1)-d2*(3+b1))/((1+b1)^2);
                  TZ=-T*b1/(1+b1); TN=(1+d1+d2)/(1+b1);
                  TV=-((1+3*b1-d1*(1-b1))*b1+d2*(2+b1+b1^2))/(2*((1+b1)^3));
   elseif Fo==5
      if ~(abs(d1+4*d2+11*d3)<1E-5)
         error('Nur zulssig fr d1=-(4*d2+11*d3)')
      end
      N=2*d2+8*d3; TN=1-3*d2-10*d3; TV=d3;
   elseif Fo==6
      if ~(abs(d2+5*d3)<1E-5)
         error('Nur zulssig fr d2=-5*d3')
      end
      N=(1-d1+10*d3)/2; TN=1+d1-4*d3; TV=2*d3;
   elseif Fo==7
      if ~(abs(d1+1+3*d2+9*d3)<1E-5)
         error('Nur zulssig fr d1=-(1+3*d2+9*d3)')
      end
      N=1+2*d3; TN=-2*(d2+4*d3); TV=d3;
   end
   V=V*N; TN=N*T/TN; TV=-TV*T/N;
end
elseif Sz==1                     % I-Struktur
if Ri==1
   if TV~=0 error('Fr gewhlte Struktur mu TV=0 gelten!'); end
   V=T*V/TN;
   if (Fo==1)|(Fo==2)
      if Fo==1
         d0=1; d1=0;
      else
         d0=0; d1=1;
      end
   elseif (Fo==4)|(Fo==7)
      if Fo==4
         d0=1; d1=1;
      else
         d0=0; d1=3; d2=-1;
      end
      V=V/2;
   end
else
   TN=T/V;
   if (Fo==1)|(Fo==2)
      if ~((d0==1)&(d1==0)&(d2==0))&(Fo==1)
         error('Nherung 1 nur zulssig fr d0=1 und d1=0 (d2=0)')
      elseif ~((d0==0)&(d1==1)&(d2==0))&(Fo==2)
         error('Nherung 2 nur zulssig fr d0=0 und d1=1 (d2=0)')
      end
   elseif (Fo==4)|(Fo==7)
      if ~((d0==1)&(d1==1)&(d2==0))&(Fo==4)
         error('Nherung 4 nur zulssig fr d0=d1=1 (d2=0)')
      elseif ~((d0==0)&(d1==3)&(d2==-1))&(Fo==7)
         error('Nherung 7 nur zulssig fr d0=0, d1=3 und d2=-1')
      end
      TN=TN/2;
   end
   V=1;
end
if d0==0 disp('WARNUNG: Sonderfall d0=0 liegt vor!');
end
elseif (Sz==2)|(Sz==4)          % PD-Struktur
if Ri==1
   if TN~=0 error('Fr gewhlte Struktur mu TN=0 gelten!'); end
   c=TV/T; d=TZ/T;
   if (Fo==1)|(Fo==2)|(Fo==8)
      N=(1+c+d)/(1+d); d1=-(c+d)/(N*(1+d)); b1=-d/(1+d);
   elseif (Fo==3)|(Fo==5)
      N=1+3*c/2; d1=-2*c/N; d2=0.5*c/N;
   elseif Fo==7
      N=1+2*c; d1=-3*c/N; d2=c/N;
   end
   V=V*N;
else
   if (Fo==1)|(Fo==2)|(Fo==8)
      N=1+d1; V=V/(1+b1); TV=(d1-b1)/(1+b1); TZ=-b1*T/(1+b1);
   elseif (Fo==3)|(Fo==5)
      if ~(abs(d1+4*d2)<1E-5)
         error('Nur zulssig fr d1=-4*d2')
      end
      N=1+3*d1/4; TV=0.5*d1;
   elseif Fo==7
      if ~(abs(d1+3*d2)<1E-5)
         error('Nur zulssig fr d1=-3*d2')
      end
      N=1+2*d1/3; TV=d1/3;
   end
   V=V*N; TV=-TV*T/N;
end
end
y1=V;
if Ri==1
   y2=d1; y3=d2;
      if     Sz==1   y4=d0;
      elseif Fo==8 y4=b1;
      else           y4=d3;
      end
else
   if Bp==0
   y2=TN; y3=TV; y4=TZ;
   else
     if Sz==0
        y3=TN/V; wu=sqrt(-TV*TN+(TN/2)^2);
        if imag(wu)~=0 error('Keine reelle multiplikative Lsung!')
        end
        y1=TN/2+wu; y2=TN-y1;
     else
        y1=0; y2=0; y3=TN;
     end
   end
end
rav=[y1 y2 y3 y4];