function [Reg]=bod_es(name,T,Par,SV,AWV,OPT,P1,P2)
%BOD_ES   Betragsoptimierung fr in "struc..." definierte Regelstruktur
%        [Reg]=bod_es(name,T,Par(,SV)(,AWV)(,OPT)(,P1,P2))
%        name=Filename als string; File mu Definition der Strecken- und
%             Regelstruktur enthalten (Formular:struc999.m/Def.:struc000.m)
%        T=   Skalar mit Abtastzeit
%             Spaltenvektor bei Parametervarianten
%        Par= Parameterzeilenvektor mit Zahlenwerten der Streckenparameter
%             (Reihenfolge und Bedeutung mu in File name definiert sein.)
%             Matrix bei Parametervariation
%        Reg= Reglerparameter-Zeilenvektor
%             (Reihenfolge und Bedeutung mu in File name definiert sein.)
%             Matrix bei Parametervariation;
%             falls SV(2)=1: Streckennullstellen und Pole im Z-Bereich
%
%	 (,SV=Steuervektor fr Arbeitsweise von bod_es - nur bei Bedarf!
%	   SV(1)=0 MATLAB-interne Gradientenschtzung (Standardeinstellung)
%                  Achtung: OPTIONS(9)=1 hierfr nicht zulssig !
%               =1 Gradientenberechnung fr strucxxx mittels bod_esp
%                  nur fr Parameterprodukte mit Potenz "1" zulssig
%          SV(2)=1 Keine Optimierung, sondern Berechnung der Nullstellen
%                  und Pole der transformierten Strecken (ohne zus. Totz.)
%                  Spalte_1=Nullst./Pol(0/inf); Spalte_2=jeweilige Anzahl;
%                  ab Spalte_3 Werte)
%        (,AWV=Anfangswertevorgabe von auen - nur bei Bedarf!)
%	 (,OPT=OPTIONS-Vektor siehe:Optimization Handbuch - nur bei Bedarf!)
%        (,P1,P2=Parameterbergabe an STRUCxxx - nur bei Bedarf!)
%
% Achtung: *  Voraussetzungen: Optimization Toolbox sowie bod_esg.m
%             trans.m, minreal1.m, (bod_esp.m nur bei SV(1)=1)
%          *  Bei Berechnung mehrerer Parametervarianten mssen length(T)
%             und Zeilenanzahl von Par bereinstimmen

% SCHLUESSELWORTE: Digitales Betragsoptimum, Zustandsregelstruktur;
%                  Kaskadenregelstruktur, Einzelregelkreis
%		   Stroptimierung, Fhrungsoptimierung,
%		   Fhrungsgrenfilter, Symmetrisches Optimum,
%		   Symbolische Streckenvorgabe (Definition in STRUC000.M),
%		   Symbolische Regelstrukturvorgabe (Def. in STRUC000.M),
%		   beliebige Totzeit, wahlweise Mittelwertmessung
%                  Parametervariation

%  Copyright (c) 1996 Dr. Gert-Helge Geitner; TU Dresden, Fak. ET,
%                     Elektrotechnisches Institut (ETI); Mommsenstr. 13;
%                     D-01062 Dresden, Germany;
%                     Tel./Fax ++49-351-463-2917/7280
%                     e-mail: geitner@eeiwzb.et.tu-dresden.de
%  Literatur zum Digitalen Betragsoptimum: Geitner, G.-H.:
%                     Entwurf digitaler Regler fr elektrische Antriebe.
%                     VDE-Verlag GmbH Berlin und Offenbach 1996

error(nargchk(3,8,nargin));
if nargin==3 SV=[]; AWV=[]; OPT=[]; P1=[]; P2=[];
elseif nargin==4 AWV=[]; OPT=[]; P1=[]; P2=[];
elseif nargin==5 OPT=[]; P1=[]; P2=[];
elseif nargin==6 P1=[]; P2=[];
elseif nargin==7 P2=[]; end
if SV==[] SV=[0 0]; end; if length(SV)==1 SV(2)=0; end
if OPT==[] OPT=[0 0 0 0 1 0 1]; end
if SV(1)==0 GRAD=[]; else GRAD='bod_esp'; end
i=length(T); [BerS,An]=size(Par); Reg=[];
if BerS~=i error('Zeilenanzahl von T und Par ungleich!'), end

for iBerS=1:BerS  % BerS=Berechnungsschleifen

%Vom Anwender definierte Streckenstruktur laden
[ZVe,NVe,Q,IN,OU,MT,NV]=feval(name,0,0,P1,P2);
if iBerS==1
   disp('Vorausgesetzte Strecken-Parameterreihenfolge in Par :'),
   disp(NV),      % Einmalige Ausschrift fr Nutzer
end

%Namen-Vektor der Streckenparameter auspacken und Werte zuordnen:
 i=0; n0=0; k=length(NV);
 while i<k n0=n0+1; i=i+1; j=1; vtext=0;     %i um "2" erhhen wegen: "; "
       while NV(i)~=';' vtext(j)=NV(i); i=i+1; j=j+1; end
       eval([vtext '=Par(' num2str(iBerS) ',' num2str(n0) ');']);
       i=i+1; end
if n0~=An
  error('Fehler im Vektor NV der Streckenparameternamen oder in Matrix Par!'),
end

%Zhler-Vektoren der einzelnen Blcke auspacken
 s=1; i=0; n1=0; k=length(ZVe);
 while i<k n1=n1+1; i=i+1; j=1; vtext=0;
       while ZVe(i)~=';'  vtext(j)=ZVe(i); i=i+1;  j=j+1; end
       eval(['sz' num2str(n1) '=' vtext ';']); end

%Nenner-Vektoren der einzelnen Blcke auspacken
 i=0; n=0; k=length(NVe);
 while i<k n=n+1; i=i+1; j=1; vtext=0;
       while NVe(i)~=';'  vtext(j)=NVe(i); i=i+1;  j=j+1; end
       eval(['sn' num2str(n) '=' vtext ';']); end
if n~=n1 error('Zhler-/Nenneranzahl der Streckenblcke ungleich !!!'), end

%Unverbundenes Diagonalsystem erzeugen:
a=[];b=[];c=[];d=[];
for i=1:n
    [at,bt,ct,dt]=tf2ss(eval(['sz' num2str(i)]),eval(['sn' num2str(i)]));
    [a,b,c,d]=append(a,b,c,d,at,bt,ct,dt); end
%Blockverbindungen vorgeben (Q=Verbindungsmatrix;IN=Eingang;OU=Ausgnge):
[i1,j1]=size(Q); [i2,j2]=size(IN); [i3,j3]=size(OU); [i4,j4]=size(MT);
if i1~=n|i2~=1|j2~=1|i3~=1
 error('Fehler in Blockverbindungsmatrix, Ein- oder Ausgangsvektor'), end
if i4~=j3|j4~=2
 error('Fehler in Angaben zur Transformation der Teilstrecken'), end
[ac,bc,cc,dc]=connect(a,b,c,d,Q,IN,OU); %Verbundenes System
[ap,bp,cp,dp]=minreal1(ac,bc,cc,dc);    %Zustandselimination
[ZL,NL]=ss2tf(ap,bp,cp,dp,1);           %bertragungsfunktionen fr OU/IN
for i=1:j3                              %Es mu gelten: ii=j3, i=1
    [zl,nl]=minreal1(ZL(i,:),NL);
    eval(['[zz' num2str(i) ',nz' num2str(i) ']=trans(zl,nl,T(iBerS),' ...
            num2str(MT(i,1)) ',' num2str(MT(i,2)) ');']);
    if SV(2)==1  %Nullstellen-/Polanzeige im Z-Bereich statt Optimierung
                 %Nachgestellte Nullen vor "roots"-Berechnung entfernen:
           eval(['zz=zz' num2str(i) ';']); j=length(zz); ro=0;
           while zz(j)==0; j=j-1; end; for jj=1:j ro(jj)=zz(jj); end
           ro=roots(ro); j=length(ro);
           HiM(2*i-1,1)=0; HiM(2*i-1,2)=j;  %Kode: Nullstellen, Anzahl
           if j~=0 HiM(2*i-1,3:3+j-1)=ro(1:j,1)'; end
           eval(['nz=nz' num2str(i) ';']); j=length(nz); ro=0;
           while nz(j)==0; j=j-1; end; for jj=1:j ro(jj)=nz(jj); end
           ro=roots(ro); j=length(ro);
           HiM(2*i,1)=inf; HiM(2*i,2)=j;    %Kode: Pole, Anzahl
           if j~=0 HiM(2*i,3:3+j-1)=ro(1:j,1)'; end
    % zz1,nz1 % bei Freigabe Anzeige der Z-Uebertragungsfunktionen
    end
zl=0; nl=0; end

if SV(2)==1
     % Nur Anzeige der Streckennullstellen und -pole im Z-Bereich
   if iBerS==1
      disp('Nullstellen(Spalte1=0) und Pole(Spalte1=inf) der definierten');
disp('Streckenuebertragungsfunktionen im Z-Bereich (Spalte2=Anzahl): ');end
   disp(HiM);            % Ablaufkontrolle durch Ergebnisanzeige
   Reg=[Reg;HiM]; HiM=0;

else % Weitere Berechnung mit Optimierung

%Die wegen wahlweise nicht ganzzahliger Totzeit sowie den Varianten fr
%Kopplung/Messung einzeln transformierten bertragungsfunktionen werden
%wieder in Zustandsdarstellung zusammengefat:
%Unverbundenes System erzeugen - hier Variablenanfangswerte:
    a=[];b=[];c=[];d=[];at=[];bt=[];ct=[];dt=[];ac=[];bc=[];cc=[];dc=[];Q=0;
%Zustzlichen Block als Systemeingang fr "connect" bereit stellen:
    eval(['zz' num2str(j3+1) '=1;']); eval(['nz' num2str(j3+1) '=1;'])
%Unverbundenes System erzeugen - hier Zustandsdarstellung + append:
    for i=1:j3+1
    [at,bt,ct,dt]=tf2ss(eval(['zz' num2str(i)]),eval(['nz' num2str(i)]));
    [a,b,c,d]=append(a,b,c,d,at,bt,ct,dt); end
%Verbundenes System - hier Verbindungsmatrix + IN/OU-Vektoren erzeugen:
    for i=1:j3+1 Q(i,1)=i; Q(i,2)= j3+1; end
    Q(j3+1,2)=0; IN=[j3+1]; OU=[1:j3];
[ac,bc,cc,dc]=connect(a,b,c,d,Q,IN,OU); %Verbundenes System
[a,b,c,d]=minreal1(ac,bc,cc,dc);        %Zustandselimination
if j3~=1 b(1,j3)=0; d(j3,j3)=0; end     %Anpassung an connect bei nblock>1

%Regelstruktur laden
[ZVe,NVe,QQ,BME,BMA,BM,NV,BRF]=feval(name,1,OU,P1,P2);
%berprfung der vom Anwender definierten Matrizen:
[i1,j1]=size(BME);[i2,j2]=size(BMA);[i4,j4]=size(BM);[i5,j5]=size(QQ);
if i1~=i2|i2~=i4-1|j1~=j2|j2~=j4
      error('Fehler in BME/BMA/BM-Matrizen'), end; TV=BM(i4,:);
if sum(TV)~=0 error('Falsche letzte Zeile in BM-Matrix'), end
if BRF<1|BRF>j1|rem(BRF,1)~=0 error('Falscher Wert fr BRF'), end
if max(max(BMA))>j3
   error('Ausgangsblocknr. im Z-Bereich in BMA> length(OU)'), end
if max(max(BME))>i5
   error('Eingangsblocknr. im Z-Bereich in BME> Zeilenanzahl von QQ'), end
j=0; for i=1:length(NV) if NV(i)==' ' j=j+1; end, end %j=Anzahl Unbekannte
if j~=sum(sum(BM))/j4
   error('Fehler in NV-Vektor oder BM-Matrix'), end

PA=sum(BM);      % Parameteranzahl pro Variante (Spalte) bestimmen
PA_BRF=PA(BRF);  % Parameteranzahl der ausgewhlten Variante
awv=length(AWV); % Lnge des externen Anfangswertvektors
if awv~=0&PA_BRF~=awv
                 error('Falsche Anzahl externer Anfangswerte'), end
[i,j]=min(BM);   % i: Minima (0!) pro Spalte; j: zugehrige Zeilennummer
SZ=j(BRF)-1;     % Schleifenzhler fr fsolve-Aufrufe
enr=1;           % Ergebnisnummer
erg=[];          % Anfangswert Ergebnisvektor
for iS=1:SZ
   TAZ=BM(iS,BRF);       % Transiente Anzahl
   % bergabeargumente fr fsolve packen, da nur zehn zulssig
   knr=length(erg);
   EZW=[BRF PA_BRF TAZ iS knr];             % Einzelwerte packen
   if   awv==0 AW=rand(1,TAZ)*10,           % Variable Anfangswerteanzahl
   else AW=0; AW(1:TAZ)=AWV(knr+1:knr+TAZ), % intern / extern
   end
   for i=1:knr EZW(2,i)=erg(i); end
   BMEA=[BME BMA];
q=fsolve('bod_esg',AW',OPT,GRAD,a,b,c,d,EZW,QQ,BMEA,ZVe,NVe,NV);
   for j=1:TAZ erg(enr)=q(j); enr=enr+1; end
       if iBerS==1&iS==1
       disp('Interpretation der Spalten des Ergebnisses:'),
       disp(NV),
       end
   disp(erg);             % Ablaufkontrolle durch Ergebnisanzeige
end

Reg(iBerS,:)=erg(1,:);
end % Ende der Optimierung

end % Ende der iBerS-Schleife
