function [ZVe,NVe,Q,IN,OU,MT,NV,BRF]=struc000(SOR,OU,P1,P2)
%STRUC000 K(3S):Par=[V11 T11 V12 T12 V13 T21 V21 T31];Reg=[VR1 d11 VR2 d12 VR3];
%         Dreischleifige Kaskadenstruktur mit Erluterungen zu Definitionen
%         fr Regler und Strecke;
%	  Struktur und Simulation siehe SIST000; Schleifenaufbau:
%         Innen: PI-Regler,2 Verzgerungsglieder,Mittelwertmessung
%         Mitte: Vorfilter, PI-Regler, Verstrkung, rckgekoppelte
%                          Integration, Mittelwertmessung
%	  Auen: P-Regler, Integrator

%HILFSFILE zur symbolischen Definition - kein selbstndiger Aufruf !!!
%	  SOR: Schalter - zur Auswahl der Strecken oder Regelstruktur
%	  OU:  Vektor mit fortlaufenden Nummern der Ausgnge der diskreti-
%              sierten Streckenzustandsdarstellung
%         P1,P2: Parameterweitergabemglichkeit ber bod_es.m

% SCHLUESSELWORTE: Digitales Betragsoptimum, Symbolische Strecken-
%                  und Regel-Strukturdefinition fr bod_es/bod_esg

%  Copyright (c) 1996 Dr. Gert-Helge Geitner; TU Dresden, Fak. ET,
%                     Elektrotechnisches Institut (ETI); Mommsenstr. 13;
%                     D-01062 Dresden, Germany;
%                     Tel./Fax ++49-0351-463-2917/7280
%                     e-mail: geitner@eeiwzb.et.tu-dresden.de
%  Literatur zum Digitalen Betragsoptimum: Geitner, G.-H.:
%                     Entwurf digitaler Regler fr elektrische Antriebe.
%                     VDE-Verlag GmbH Berlin und Offenbach 1996

if SOR==0  %Streckendefinition

% Definition der einzelnen Streckenbertragungsfunktionen des kontinuier-
% lichen Teils als String (vollstndig mit Zhler und Nenner und fort-
% laufend mit sz1 bis szx bzw. sn1 bis snx numeriert), sowie mit
% Q =Blockverbindungsmatrix (Zeilenanzahl=Blockanzahl, 1.Spalte=Blocknummer,
%    weitere Spalten = vorzeichenbehaftete Nummern der jeweiligen Vorgnger-
%                      blcke des betrachteten Blocks);
% IN=Nummer des Eingangsblockes fr Gesamtstruktur;
% OU=Nummern der interessierenden Ausgangsblcke)
% MT=Matrix mit Angaben zur Transformation der Teilstrecken mit den Aus-
%    gngen "OU" (Zeilenanzahl=Ausgangsanzahl "OU" in gleicher Reihenfolge,
%    1.Spalte=echte nicht ganzzahlige Zeitverschiebung (siehe auch trans.m)
%    2.Spalte=Kode fr Kopplung/Messung: 0 = T/A
%                                        1 = T/M bzw. H/A
%                                        2 = H/M   siehe auch trans.m)
% NV=String-Namenvektor, der die Reihenfolge der Streckenverstrkungen,
%    Streckenzeitkonstanten etc. bei der bergabe von Zahlenwerten festlegt.
%    Die Namen mssen durch Semikolon und Leerzeichen abgeschlossen werden.
%
% Ganzzahlige Totzeiten innerhalb des Streckenmodells knnen an die Schnitt-
% stellen zwischen den zwei Teilen der Gesamtstruktur (sx Streckenblcke,
% dx Reglerblcke) geschoben werden. Damit ist fr die Struktureingabe eine
% Zuordnung zu den dx Blcken mglich.


% ****** Beginn
 sz1='V11;';			sn1='[T11 1];';
 sz2='V12;';			sn2='[T12 1];';
 sz3='V13;';			sn3='1;';
 sz4='1;';			sn4='[T21 0];';
 sz5='V21;';			sn5='1;';
 sz6='1;';			sn6='[T31 0];';
 Q=[1 0  0
    2 1  0
    3 2  0
    4 3 -5
    5 4  0
    6 4  0]; IN=[1]; OU=[2 4 6];
 MT=[0 2
     0 2
     0 1];
 NV=['V11; T11; V12; T12; V13; T21; V21; T31; '];
% ****** Ende


s=0; zae=0; ZVe=[]; NVe=[]; BRF=0;
while s==0 zae=zae+1;  eval(['ZVe=[ZVe sz' num2str(zae) '];'],'s=1;');
                       eval(['NVe=[NVe sn' num2str(zae) '];'],'s=1;'); end

else  %Regelstrukturdefinition
% Definition der einzelnen Reglerbertragungsfunktionen des diskontinuier-
% lichen Teils als String (vollstndig mit Zhler und Nenner). Die fort-
% laufende Numerierung erfolgt dabei so, da die fr die kontinuierliche
% Strecke angegebenen Ausgnge im Vektor "OU" die ersten Blcke (also be-
% zglich "IN" diskretisierten bertragungsfunktionen) der hier zu defi-
% nierenden digitalen Struktur darstellen.
% Beispiel: Sind fr die kontinuierliche Strecke 5 Ausgnge vorgegeben, so
%           gilt fr die Numerierung der Reglerzhler- und Reglernenner-
%           polynome >>>  rz6 bis rzy bzw. rn6 bis rny  <<<
% Hinweis: Um eine sptere nderung der Numerierung zu vermeiden, sollten
%          von Anfang an alle eventuell fr die Optimierung interessieren-
%          den Ausgnge der kontinuierlichen Streckenstruktur angegeben
%          werden. Es mssen nicht notwendig immer alle verwendet werden.
% ACHTUNG: Bei Fhrungsgrenfiltern Polynomgleichsetzen (Reglerzhler=Fil-
%          ternenner) sowie stationres Verhalten des Filters (Limes) un-
%          mittelbar bei Definition der bertragungsfunktionen beachten!
% QQ =Blockverbindungsmatrix fr diskontinuierliche Struktur. Die ersten
%     "length(OU)" Blocknummern stehen, wie oben erlutert, fr das mit
%     IN/OU beschriebene Ein- Ausgangsmodell der Gesamtstrecke. Daraus
%     folgt, da die ersten "length(OU)"-Blcke die gleiche Eingangsblock-
%     Belegung in der QQ-Matrix haben mssen!
%     Aufbau: wie Q (siehe oben)
% BME/BMA=Matrizen mit Nummer des jeweiligen Eingangs(BME)- bzw. Ausgangs-
%   blockes(BMA) fr zu optimierende Teilstruktur und Berechnungsvariante.
%   Definition des Spaltenaufbaus:
%   a, Jede Spalte entspricht einer Berechnungsvariante. Die Anzahl der von
%      Null verschiedenen Elemente einer Spalte entspricht der Anzahl der
%      Berechnungslufe.
%   b, Der Inhalt eines Elementes bezeichnet einen Eingangs(BME)- bzw. Aus-
%      gangsblock(BMA).
%   Definition des Zeilenaufbaus:
%   a, Die Berechnung (Optimierung) erfolgt beginnend mit Zeile 1 einer
%      ausgewhlten Spalte. BME liefert den Eingangsblock, BMA den Ausgangs-
%      block der betrachteten Regel-(Teil-)Struktur.
%   b, Beispiel 1:
%      BME=[3];  BMA=[1];  Eine Berechnungs-(Optimierungs-)variante mit
%                          einem Durchlauf. Eingangsblock fr die Optimie-
%                          rung ist Nr. 3, Ausgangsblock ist Nr. 1
%   c, Beispiel 2:
%      BME=[1 1 7   BMA=[2 1 3   Es werden drei Optimierungsvarianten un-
%           7 1 0        4 2 0   tersucht. Die 2. erfordert 3, die 1. zwei
%           0 7 0];      0 3 0]; und die 3. Variante einen Optimierungslauf.
%                                Ablauf Variante 1: erste Berechnung mit
%                                Block 1 als Eingang, Block 2 als Ausgang,
%           zweite Berechnung mit Block 7 als Eingang, Block 4 als Ausgang.
% BRF=Auswahl einer Brechnungsvariante aus BME/BMA-Spalten
% BM= Matrix vom Aufbau der BME-/BMA-Matrizen. Jedoch mu mindestens das
%     letzte Element einer Spalte Null sein. Damit besitzt die BM-Matrix
%     stets eine Zeile mehr als die BME-/BMA-Matrizen. Der Inhalt der Ele-
%     mente gibt die Anzahl der zu berechnenden Unbekannten an.
% NV= String-Namenvektor, der die Reihenfolge der Reglerparameter (Verstr-
%     kungen, Polynomkoeffizienten), bei der bergabe von Zahlenwerten fest-
%     legt. Zusammen mit der BM-Matrix liegt damit auch die Berechnungsrei-
%     henfolge fest. Die Namen mssen durch Semikolon und Leerzeichen ab-
%     geschlossen werden.
% Eventuelle ganzzahlige Totzeiten des Streckenmodells knnen, wie oben an-
% gegeben, hier im diskontinuierlichen Teil als Reglerblock mit bekannten
% Parametern definiert und bercksichtigt werden.


%******* Beginn
 rz4='VR1*[1 d11];';              rn4='[1 -1];';
 rz5='VR2*[1 d12];';              rn5='[1 -1];';
%Vorgabe fr Filter: VFi=1+d12 (Limes) und bf1=d12 (Polynomgleichsetzen)
 rz6='VR3;';                      rn6='1;';
 rz7='(1+d12);';                  rn7='[1 d12];';

QQ=[1  4 0
    2  4 0
    3  4 0
    4 -1 5
    5 -2 7
    6 -3 0
    7  6 0];
BME=[4 7 6]'; BMA=[1 2 3]'; BRF=1; BM=[2 2 1 0]';
NV=['VR1; d11; VR2; d12; VR3; '];
%****** Ende


s=0; zae=length(OU); ZVe=[]; NVe=[];
while s==0 zae=zae+1;  eval(['ZVe=[ZVe rz' num2str(zae) '];'],'s=1;');
                       eval(['NVe=[NVe rn' num2str(zae) '];'],'s=1;'); end
Q=QQ;IN=BME;OU=BMA;MT=BM;
end
