function [ret,x0,str,ts,xts]=sist000(t,x,u,flag);
%SIST000	is the M-file description of the SIMULINK system named SIST000.
%	The block-diagram can be displayed by typing: SIST000.
%
%	SYS=SIST000(T,X,U,FLAG) returns depending on FLAG certain
%	system values given time point, T, current state vector, X,
%	and input vector, U.
%	FLAG is used to indicate the type of output to be returned in SYS.
%
%	Setting FLAG=1 causes SIST000 to return state derivatives, FLAG=2
%	discrete states, FLAG=3 system outputs and FLAG=4 next sample
%	time. For more information and other options see SFUNC.
%
%	Calling SIST000 with a FLAG of zero:
%	[SIZES]=SIST000([],[],[],0),  returns a vector, SIZES, which
%	contains the sizes of the state vector and other parameters.
%		SIZES(1) number of states
%		SIZES(2) number of discrete states
%		SIZES(3) number of outputs
%		SIZES(4) number of inputs
%		SIZES(5) number of roots (currently unsupported)
%		SIZES(6) direct feedthrough flag
%		SIZES(7) number of sample times
%
%	For the definition of other parameters in SIZES, see SFUNC.
%	See also, TRIM, LINMOD, LINSIM, EULER, RK23, RK45, ADAMS, GEAR.

% Note: This M-file is only used for saving graphical information;
%       after the model is loaded into memory an internal model
%       representation is used.

% the system will take on the name of this mfile:
sys = mfilename;
new_system(sys)
simver(1.3)
if (0 == (nargin + nargout))
     set_param(sys,'Location',[4,56,620,460])
     open_system(sys)
end;
set_param(sys,'algorithm',     'RK-45')
set_param(sys,'Start time',    '0.0')
set_param(sys,'Stop time',     '25')
set_param(sys,'Min step size', '0.000000001')
set_param(sys,'Max step size', '10')
set_param(sys,'Relative error','1e-3')
set_param(sys,'Return vars',   '')

add_block('built-in/Zero-Order Hold',[sys,'/','S//H_1'])
set_param([sys,'/','S//H_1'],...
		'position',[90,209,115,241])

add_block('built-in/Filter',[sys,'/','rz4//rn4'])
set_param([sys,'/','rz4//rn4'],...
		'Numerator','[1.7787 -1.5715]',...
		'Denominator','[1 -1]',...
		'position',[130,204,220,246])

add_block('built-in/Filter',[sys,'/','rz5//rn5'])
set_param([sys,'/','rz5//rn5'],...
		'Numerator','[1.2516 -1.1775]',...
		'Denominator','[1 -1]',...
		'position',[135,134,225,176])

add_block('built-in/Gain',[sys,'/','sz3//sn3'])
set_param([sys,'/','sz3//sn3'],...
		'Gain','2',...
		'position',[255,147,280,173])

add_block('built-in/Sum',[sys,'/','M2'])
set_param([sys,'/','M2'],...
		'inputs','+-',...
		'position',[60,145,80,165])

add_block('built-in/Transfer Fcn',[sys,'/','sz1//sn1'])
set_param([sys,'/','sz1//sn1'],...
		'Denominator','[1.5 1]',...
		'position',[245,206,300,244])

add_block('built-in/Transfer Fcn',[sys,'/','sz2//sn2'])
set_param([sys,'/','sz2//sn2'],...
		'Denominator','[8 1]',...
		'position',[325,205,375,245])


%     Subsystem  'MWM_1'.

new_system([sys,'/','MWM_1'])
set_param([sys,'/','MWM_1'],'Location',[308,190,600,325])

add_block('built-in/Zero-Order Hold',[sys,'/','MWM_1/ABT1'])
set_param([sys,'/','MWM_1/ABT1'],...
		'Sample time','T',...
		'position',[120,64,155,96])

add_block('built-in/Filter',[sys,'/','MWM_1/Diff.1'])
set_param([sys,'/','MWM_1/Diff.1'],...
		'Numerator','[1 -1]',...
		'Denominator','[1]',...
		'Sample time','T',...
		'position',[170,63,210,97])

add_block('built-in/Transfer Fcn',[sys,'/','MWM_1/Int1'])
set_param([sys,'/','MWM_1/Int1'],...
		'Denominator','[T 0]',...
		'position',[60,62,95,98])

add_block('built-in/Outport',[sys,'/','MWM_1/out_1'])
set_param([sys,'/','MWM_1/out_1'],...
		'position',[240,70,260,90])

add_block('built-in/Inport',[sys,'/','MWM_1/in_1'])
set_param([sys,'/','MWM_1/in_1'],...
		'position',[10,70,30,90])
add_line([sys,'/','MWM_1'],[100,80;115,80])
add_line([sys,'/','MWM_1'],[160,80;165,80])
add_line([sys,'/','MWM_1'],[215,80;235,80])
add_line([sys,'/','MWM_1'],[35,80;55,80])
set_param([sys,'/','MWM_1'],...
		'Mask Display','plot([0 1 2 3 4 5],[0 1 2 3 4 5],[0 1 1 2 2 3 3 4 4 5],[ 0 0 0.5 0.5 1.5 1.5 2.5 2.5 3.5 3.5])',...
		'Mask Type','Messung',...
		'Mask Dialogue','Mittelwertmessung|Abtastzeit T=')
set_param([sys,'/','MWM_1'],...
		'Mask Translate','T=@1',...
		'Mask Help','Mittelwermessung',...
		'Mask Entries','1\/')


%     Finished composite block 'MWM_1'.

set_param([sys,'/','MWM_1'],...
		'position',[405,205,450,245])

add_block('built-in/Sum',[sys,'/','M5'])
set_param([sys,'/','M5'],...
		'orientation',2,...
		'inputs','--',...
		'position',[310,95,330,115])

add_block('built-in/Sum',[sys,'/','M4'])
set_param([sys,'/','M4'],...
		'position',[310,145,330,165])

add_block('built-in/Transfer Fcn',[sys,'/','sz4//sn4'])
set_param([sys,'/','sz4//sn4'],...
		'Denominator','[20 0]',...
		'position',[350,136,385,174])

add_block('built-in/To Workspace',[sys,'/','"rz2//rn2"'])
set_param([sys,'/','"rz2//rn2"'],...
		'mat-name','OU_2',...
		'position',[525,143,560,167])

add_block('built-in/To Workspace',[sys,'/','"rz3//rn3"'])
set_param([sys,'/','"rz3//rn3"'],...
		'mat-name','OU_3',...
		'position',[525,44,560,66])

add_block('built-in/Mux',[sys,'/','Multiplexer'])
set_param([sys,'/','Multiplexer'],...
		'inputs','5',...
		'position',[525,81,555,109])


%     Subsystem  'Oszi'.

new_system([sys,'/','Oszi'])
set_param([sys,'/','Oszi'],'Location',[0,59,274,252])

add_block('built-in/Inport',[sys,'/','Oszi/x'])
set_param([sys,'/','Oszi/x'],...
		'position',[65,55,85,75])

add_block('built-in/S-Function',[sys,'/',['Oszi/S-function',13,'M-file which plots',13,'lines',13,'']])
set_param([sys,'/',['Oszi/S-function',13,'M-file which plots',13,'lines',13,'']],...
		'function name','sfuny',...
		'parameters','ax, color,dt',...
		'position',[130,55,180,75])
add_line([sys,'/','Oszi'],[90,65;125,65])
set_param([sys,'/','Oszi'],...
		'Mask Display','plot(0,0,100,100,[90,10,10,10,90,90,10],[65,65,90,40,40,90,90],[90,78,69,54,40,31,25,10],[77,60,48,46,56,75,81,84])',...
		'Mask Type','Graph scope.')
set_param([sys,'/','Oszi'],...
		'Mask Dialogue','Graph scope using MATLAB graph window.\nEnter plotting ranges and line type.|Time range:|y-min:|y-max:|Line type (rgbw-:*). Seperate each plot by ''/'':')
set_param([sys,'/','Oszi'],...
		'Mask Translate','color = @4; ax = [0, @1, @2, @3]; dt = -1;')
set_param([sys,'/','Oszi'],...
		'Mask Help','This block plots to the MATLAB graph window and can be used as an improved version of the Scope block. Look at the m-file sfuny.m to see how it works. This block can take scalar or vector input signal.')
set_param([sys,'/','Oszi'],...
		'Mask Entries','25\/-0.2\/1.2\/''k/b/r/m/g''\/')


%     Finished composite block 'Oszi'.

set_param([sys,'/','Oszi'],...
		'position',[570,80,600,110])


%     Subsystem  'unger. Strecke'.

new_system([sys,'/','unger. Strecke'])
set_param([sys,'/','unger. Strecke'],'Location',[-15,262452,440,262632])

add_block('built-in/Transfer Fcn',[sys,'/','unger. Strecke/sz1//sn2'])
set_param([sys,'/','unger. Strecke/sz1//sn2'],...
		'Denominator','[1.5 1]',...
		'position',[55,96,110,134])

add_block('built-in/Transfer Fcn',[sys,'/','unger. Strecke/sz2//sn3'])
set_param([sys,'/','unger. Strecke/sz2//sn3'],...
		'Denominator','[8 1]',...
		'position',[130,95,180,135])

add_block('built-in/Gain',[sys,'/','unger. Strecke/sz3//sn4'])
set_param([sys,'/','unger. Strecke/sz3//sn4'],...
		'Gain','2',...
		'position',[200,102,225,128])

add_block('built-in/Transfer Fcn',[sys,'/','unger. Strecke/sz6//sn7'])
set_param([sys,'/','unger. Strecke/sz6//sn7'],...
		'Denominator','[50 0]',...
		'position',[370,91,410,129])

add_block('built-in/Gain',[sys,'/','unger. Strecke/sz5//sn6'])
set_param([sys,'/','unger. Strecke/sz5//sn6'],...
		'orientation',2,...
		'Gain','0.01',...
		'position',[295,52,320,78])

add_block('built-in/Sum',[sys,'/','unger. Strecke/M6'])
set_param([sys,'/','unger. Strecke/M6'],...
		'orientation',2,...
		'inputs','--',...
		'position',[255,50,275,70])

add_block('built-in/Sum',[sys,'/','unger. Strecke/M7'])
set_param([sys,'/','unger. Strecke/M7'],...
		'position',[255,100,275,120])

add_block('built-in/Transfer Fcn',[sys,'/','unger. Strecke/sz4//sn5'])
set_param([sys,'/','unger. Strecke/sz4//sn5'],...
		'Denominator','[20 0]',...
		'position',[295,91,330,129])

add_block('built-in/Inport',[sys,'/','unger. Strecke/in_1'])
set_param([sys,'/','unger. Strecke/in_1'],...
		'orientation',2,...
		'position',[305,45,325,65])

add_block('built-in/Outport',[sys,'/','unger. Strecke/out_1'])
set_param([sys,'/','unger. Strecke/out_1'],...
		'position',[440,100,460,120])

add_block('built-in/Inport',[sys,'/','unger. Strecke/in_2'])
set_param([sys,'/','unger. Strecke/in_2'],...
		'Port','2',...
		'position',[20,105,35,125])
add_line([sys,'/','unger. Strecke'],[115,115;125,115])
add_line([sys,'/','unger. Strecke'],[185,115;195,115])
add_line([sys,'/','unger. Strecke'],[230,115;250,115])
add_line([sys,'/','unger. Strecke'],[280,110;290,110])
add_line([sys,'/','unger. Strecke'],[250,60;240,60;250,105])
add_line([sys,'/','unger. Strecke'],[290,65;280,65])
add_line([sys,'/','unger. Strecke'],[335,110;365,110])
add_line([sys,'/','unger. Strecke'],[335,110;325,65])
add_line([sys,'/','unger. Strecke'],[300,55;280,55])
add_line([sys,'/','unger. Strecke'],[415,110;435,110])
add_line([sys,'/','unger. Strecke'],[40,115;50,115])


%     Finished composite block 'unger. Strecke'.

set_param([sys,'/','unger. Strecke'],...
		'position',[525,264,560,286])

add_block('built-in/To Workspace',[sys,'/','"rz1//rn1"'])
set_param([sys,'/','"rz1//rn1"'],...
		'mat-name','OU_1',...
		'position',[525,184,560,206])

add_block('built-in/To Workspace',[sys,'/','"Eingang"'])
set_param([sys,'/','"Eingang"'],...
		'mat-name','IN',...
		'position',[525,224,560,246])

add_block('built-in/Filter',[sys,'/','rz7//rn7'])
set_param([sys,'/','rz7//rn7'],...
		'Numerator','[0.0592]',...
		'Denominator','[1 -0.9408]',...
		'position',[215,64,280,106])

add_block('built-in/Filter',[sys,'/','rz6//rn6'])
set_param([sys,'/','rz6//rn6'],...
		'Numerator','[1.5193]',...
		'Denominator','[1]',...
		'position',[155,64,200,106])

add_block('built-in/Sum',[sys,'/','M3'])
set_param([sys,'/','M3'],...
		'inputs','-+',...
		'position',[70,75,90,95])

add_block('built-in/Step Fcn',[sys,'/','Sollwert'])
set_param([sys,'/','Sollwert'],...
		'Time','0',...
		'position',[25,79,45,101])

add_block('built-in/Step Fcn',[sys,'/','Last'])
set_param([sys,'/','Last'],...
		'After','0',...
		'position',[25,34,45,56])


%     Subsystem  'MWM_2'.

new_system([sys,'/','MWM_2'])
set_param([sys,'/','MWM_2'],'Location',[365,262334,600,262469])

add_block('built-in/Zero-Order Hold',[sys,'/','MWM_2/ABT1'])
set_param([sys,'/','MWM_2/ABT1'],...
		'Sample time','T',...
		'position',[120,64,155,96])

add_block('built-in/Filter',[sys,'/','MWM_2/Diff.1'])
set_param([sys,'/','MWM_2/Diff.1'],...
		'Numerator','[1 -1]',...
		'Denominator','[1]',...
		'Sample time','T',...
		'position',[170,63,210,97])

add_block('built-in/Transfer Fcn',[sys,'/','MWM_2/Int1'])
set_param([sys,'/','MWM_2/Int1'],...
		'Denominator','[T 0]',...
		'position',[60,62,95,98])

add_block('built-in/Outport',[sys,'/','MWM_2/out_1'])
set_param([sys,'/','MWM_2/out_1'],...
		'position',[240,70,260,90])

add_block('built-in/Inport',[sys,'/','MWM_2/in_1'])
set_param([sys,'/','MWM_2/in_1'],...
		'position',[10,70,30,90])
add_line([sys,'/','MWM_2'],[100,80;115,80])
add_line([sys,'/','MWM_2'],[160,80;165,80])
add_line([sys,'/','MWM_2'],[215,80;235,80])
add_line([sys,'/','MWM_2'],[35,80;55,80])
set_param([sys,'/','MWM_2'],...
		'Mask Display','plot([0 1 2 3 4 5],[0 1 2 3 4 5],[0 1 1 2 2 3 3 4 4 5],[ 0 0 0.5 0.5 1.5 1.5 2.5 2.5 3.5 3.5])',...
		'Mask Type','Messung',...
		'Mask Dialogue','Mittelwertmessung|Abtastzeit T=')
set_param([sys,'/','MWM_2'],...
		'Mask Translate','T=@1',...
		'Mask Help','Mittelwermessung',...
		'Mask Entries','1\/')


%     Finished composite block 'MWM_2'.

set_param([sys,'/','MWM_2'],...
		'position',[420,135,465,175])

add_block('built-in/Transfer Fcn',[sys,'/','sz6//sn6'])
set_param([sys,'/','sz6//sn6'],...
		'Denominator','[50 0]',...
		'position',[420,66,460,104])

add_block('built-in/Gain',[sys,'/','sz5//sn5'])
set_param([sys,'/','sz5//sn5'],...
		'orientation',2,...
		'Gain','0.01',...
		'position',[345,100,390,120])

add_block('built-in/Zero-Order Hold',[sys,'/','S//H_3'])
set_param([sys,'/','S//H_3'],...
		'position',[105,67,130,103])

add_block('built-in/Zero-Order Hold',[sys,'/','S//H_2'])
set_param([sys,'/','S//H_2'],...
		'position',[95,136,120,174])

add_block('built-in/Clock',[sys,'/','Clock'])
set_param([sys,'/','Clock'],...
		'position',[490,310,510,330])

add_block('built-in/To Workspace',[sys,'/','x-Achse'])
set_param([sys,'/','x-Achse'],...
		'mat-name','Zeit',...
		'position',[540,309,575,331])

add_block('built-in/Sum',[sys,'/','M1'])
set_param([sys,'/','M1'],...
		'inputs','+-',...
		'position',[50,215,70,235])
add_line(sys,[305,225;320,225])
add_line(sys,[135,85;150,85])
add_line(sys,[95,85;100,85])
add_line(sys,[560,95;565,95])
add_line(sys,[205,85;210,85])
add_line(sys,[125,155;130,155])
add_line(sys,[85,155;90,155])
add_line(sys,[120,225;125,225])
add_line(sys,[225,225;240,225])
add_line(sys,[380,225;400,225])
add_line(sys,[230,155;230,195;35,195;45,220])
add_line(sys,[390,155;415,155])
add_line(sys,[285,160;305,160])
add_line(sys,[50,90;65,90])
add_line(sys,[390,225;390,195;240,195;250,160])
add_line(sys,[455,225;495,225;495,260;35,260;45,230])
add_line(sys,[470,155;490,155;490,270;25,270;25,160;55,160])
add_line(sys,[465,85;520,85])
add_line(sys,[285,85;285,125;35,125;35,150;55,150])
add_line(sys,[340,110;335,110])
add_line(sys,[305,105;295,105;305,150])
add_line(sys,[50,45;345,45;335,100])
add_line(sys,[335,155;345,155])
add_line(sys,[565,275;575,275;575,130;505,130;505,105;520,105])
add_line(sys,[345,45;475,45;475,245;510,245;520,270])
add_line(sys,[225,225;225,280;500,280;500,100;520,100])
add_line(sys,[490,85;490,55;55,55;65,80])
add_line(sys,[490,55;520,55])
add_line(sys,[490,155;490,90;520,90])
add_line(sys,[495,225;495,95;520,95])
add_line(sys,[490,155;520,155])
add_line(sys,[495,195;520,195])
add_line(sys,[500,235;520,235])
add_line(sys,[50,90;50,50;470,50;470,250;505,250;505,280;520,280])
add_line(sys,[405,155;415,85])
add_line(sys,[405,110;395,110])
add_line(sys,[515,320;535,320])
add_line(sys,[75,225;85,225])

drawnow

% Return any arguments.
if (nargin | nargout)
	% Must use feval here to access system in memory
	if (nargin > 3)
		if (flag == 0)
			eval(['[ret,x0,str,ts,xts]=',sys,'(t,x,u,flag);'])
		else
			eval(['ret =', sys,'(t,x,u,flag);'])
		end
	else
		[ret,x0,str,ts,xts] = feval(sys);
	end
else
	drawnow % Flash up the model and execute load callback
end
