function [ret,x0,str,ts,xts]=sist001(t,x,u,flag);
%SIST001	is the M-file description of the SIMULINK system named SIST001.
%	The block-diagram can be displayed by typing: SIST001.
%
%	SYS=SIST001(T,X,U,FLAG) returns depending on FLAG certain
%	system values given time point, T, current state vector, X,
%	and input vector, U.
%	FLAG is used to indicate the type of output to be returned in SYS.
%
%	Setting FLAG=1 causes SIST001 to return state derivatives, FLAG=2
%	discrete states, FLAG=3 system outputs and FLAG=4 next sample
%	time. For more information and other options see SFUNC.
%
%	Calling SIST001 with a FLAG of zero:
%	[SIZES]=SIST001([],[],[],0),  returns a vector, SIZES, which
%	contains the sizes of the state vector and other parameters.
%		SIZES(1) number of states
%		SIZES(2) number of discrete states
%		SIZES(3) number of outputs
%		SIZES(4) number of inputs
%		SIZES(5) number of roots (currently unsupported)
%		SIZES(6) direct feedthrough flag
%		SIZES(7) number of sample times
%
%	For the definition of other parameters in SIZES, see SFUNC.
%	See also, TRIM, LINMOD, LINSIM, EULER, RK23, RK45, ADAMS, GEAR.

% Note: This M-file is only used for saving graphical information;
%       after the model is loaded into memory an internal model
%       representation is used.

% the system will take on the name of this mfile:
sys = mfilename;
new_system(sys)
simver(1.3)
if (0 == (nargin + nargout))
     set_param(sys,'Location',[4,74,620,446])
     open_system(sys)
end;
set_param(sys,'algorithm',     'RK-45')
set_param(sys,'Start time',    '0.0')
set_param(sys,'Stop time',     '30')
set_param(sys,'Min step size', '0.0001')
set_param(sys,'Max step size', '10')
set_param(sys,'Relative error','1e-3')
set_param(sys,'Return vars',   '')

add_block('built-in/Zero-Order Hold',[sys,'/','S//H_2'])
set_param([sys,'/','S//H_2'],...
		'Sample time','2',...
		'position',[120,49,155,81])

add_block('built-in/Sum',[sys,'/','M1'])
set_param([sys,'/','M1'],...
		'inputs','+-',...
		'position',[120,120,140,140])

add_block('built-in/Zero-Order Hold',[sys,'/','S//H_1'])
set_param([sys,'/','S//H_1'],...
		'Sample time','2',...
		'position',[165,114,200,146])

add_block('built-in/Sum',[sys,'/','M2'])
set_param([sys,'/','M2'],...
		'inputs','-+',...
		'position',[85,55,105,75])

add_block('built-in/Transfer Fcn',[sys,'/','sz3//sn3'])
set_param([sys,'/','sz3//sn3'],...
		'Denominator','[5 1]',...
		'position',[400,45,450,85])

add_block('built-in/Transfer Fcn',[sys,'/','sz2//sn2'])
set_param([sys,'/','sz2//sn2'],...
		'Denominator','[2.5 1]',...
		'position',[320,46,375,84])

add_block('built-in/Transfer Fcn',[sys,'/','sz1//sn1'])
set_param([sys,'/','sz1//sn1'],...
		'Denominator','[3.75 1]',...
		'position',[320,109,375,151])

add_block('built-in/Mux',[sys,'/','Mux'])
set_param([sys,'/','Mux'],...
		'inputs','3',...
		'position',[505,127,535,163])


%     Subsystem  'Graph'.

new_system([sys,'/','Graph'])
set_param([sys,'/','Graph'],'Location',[0,59,274,252])

add_block('built-in/Inport',[sys,'/','Graph/x'])
set_param([sys,'/','Graph/x'],...
		'position',[65,55,85,75])

add_block('built-in/S-Function',[sys,'/',['Graph/S-function',13,'M-file which plots',13,'lines',13,'']])
set_param([sys,'/',['Graph/S-function',13,'M-file which plots',13,'lines',13,'']],...
		'function name','sfuny',...
		'parameters','ax, color,dt',...
		'position',[130,55,180,75])
add_line([sys,'/','Graph'],[90,65;125,65])
set_param([sys,'/','Graph'],...
		'Mask Display','plot(0,0,100,100,[90,10,10,10,90,90,10],[65,65,90,40,40,90,90],[90,78,69,54,40,31,25,10],[77,60,48,46,56,75,81,84])',...
		'Mask Type','Graph scope.')
set_param([sys,'/','Graph'],...
		'Mask Dialogue','Graph scope using MATLAB graph window.\nEnter plotting ranges and line type.|Time range:|y-min:|y-max:|Line type (rgbw-:*). Seperate each plot by ''/'':')
set_param([sys,'/','Graph'],...
		'Mask Translate','color = @4; ax = [0, @1, @2, @3]; dt = -1;')
set_param([sys,'/','Graph'],...
		'Mask Help','This block plots to the MATLAB graph window and can be used as an improved version of the Scope block. Look at the m-file sfuny.m to see how it works. This block can take scalar or vector input signal.')
set_param([sys,'/','Graph'],...
		'Mask Entries','30\/-0.2\/1.2\/''b/r/k''\/')


%     Finished composite block 'Graph'.

set_param([sys,'/','Graph'],...
		'position',[550,126,580,164])

add_block('built-in/To Workspace',[sys,'/','"rz1//rn1"'])
set_param([sys,'/','"rz1//rn1"'],...
		'mat-name','OU_1',...
		'position',[525,92,575,108])

add_block('built-in/To Workspace',[sys,'/','"rz2//rn2"'])
set_param([sys,'/','"rz2//rn2"'],...
		'mat-name','OU_2',...
		'position',[525,57,575,73])


%     Subsystem  'unger. Strecke'.

new_system([sys,'/','unger. Strecke'])
set_param([sys,'/','unger. Strecke'],'Location',[120,262379,385,262499])

add_block('built-in/Transfer Fcn',[sys,'/','unger. Strecke/PT1'])
set_param([sys,'/','unger. Strecke/PT1'],...
		'Denominator','[3.75 1]',...
		'position',[60,49,115,91])

add_block('built-in/Transfer Fcn',[sys,'/','unger. Strecke/PT2'])
set_param([sys,'/','unger. Strecke/PT2'],...
		'Denominator','[2.5 1]',...
		'position',[130,51,185,89])

add_block('built-in/Transfer Fcn',[sys,'/','unger. Strecke/PT3'])
set_param([sys,'/','unger. Strecke/PT3'],...
		'Denominator','[5 1]',...
		'position',[200,50,250,90])

add_block('built-in/Inport',[sys,'/','unger. Strecke/in_1'])
set_param([sys,'/','unger. Strecke/in_1'],...
		'position',[10,60,30,80])

add_block('built-in/Outport',[sys,'/','unger. Strecke/out_1'])
set_param([sys,'/','unger. Strecke/out_1'],...
		'position',[280,60,300,80])
add_line([sys,'/','unger. Strecke'],[120,70;125,70])
add_line([sys,'/','unger. Strecke'],[190,70;195,70])
add_line([sys,'/','unger. Strecke'],[35,70;55,70])
add_line([sys,'/','unger. Strecke'],[255,70;275,70])


%     Finished composite block 'unger. Strecke'.

set_param([sys,'/','unger. Strecke'],...
		'position',[420,142,475,168])

add_block('built-in/Step Fcn',[sys,'/','Sollwert'])
set_param([sys,'/','Sollwert'],...
		'Time','2',...
		'position',[25,60,45,80])

add_block('built-in/Filter',[sys,'/','rz4//rn4'])
set_param([sys,'/','rz4//rn4'],...
		'Numerator','[2.03 -2.27 0.61]',...
		'Denominator','[1 -1]',...
		'Sample time','2',...
		'position',[170,44,280,86])

add_block('built-in/Filter',[sys,'/','rz3//rn3'])
set_param([sys,'/','rz3//rn3'],...
		'Numerator','[2.42 -1.42]',...
		'Denominator','[1 -1]',...
		'Sample time','2',...
		'position',[215,109,285,151])

add_block('built-in/To Workspace',[sys,'/','"Eingang"'])
set_param([sys,'/','"Eingang"'],...
		'mat-name','IN',...
		'position',[525,22,575,38])
add_line(sys,[380,65;395,65])
add_line(sys,[160,65;165,65])
add_line(sys,[205,130;210,130])
add_line(sys,[145,130;160,130])
add_line(sys,[110,65;115,65])
add_line(sys,[290,130;315,130])
add_line(sys,[380,130;390,130;390,100;305,100;315,65])
add_line(sys,[285,65;290,65;290,100;100,100;100,125;115,125])
add_line(sys,[390,130;390,165;100,165;100,135;115,135])
add_line(sys,[540,145;545,145])
add_line(sys,[455,65;520,65])
add_line(sys,[485,65;485,145;500,145])
add_line(sys,[50,70;80,70])
add_line(sys,[485,65;485,35;65,35;65,60;80,60])
add_line(sys,[480,155;500,155])
add_line(sys,[65,70;65,170;405,170;415,155])
add_line(sys,[390,100;520,100])
add_line(sys,[490,100;500,135])
add_line(sys,[300,130;300,30;520,30])

drawnow

% Return any arguments.
if (nargin | nargout)
	% Must use feval here to access system in memory
	if (nargin > 3)
		if (flag == 0)
			eval(['[ret,x0,str,ts,xts]=',sys,'(t,x,u,flag);'])
		else
			eval(['ret =', sys,'(t,x,u,flag);'])
		end
	else
		[ret,x0,str,ts,xts] = feval(sys);
	end
else
	drawnow % Flash up the model and execute load callback
end
