function [ret,x0,str,ts,xts]=sist010(t,x,u,flag);
%SIST010	is the M-file description of the SIMULINK system named SIST010.
%	The block-diagram can be displayed by typing: SIST010.
%
%	SYS=SIST010(T,X,U,FLAG) returns depending on FLAG certain
%	system values given time point, T, current state vector, X,
%	and input vector, U.
%	FLAG is used to indicate the type of output to be returned in SYS.
%
%	Setting FLAG=1 causes SIST010 to return state derivatives, FLAG=2
%	discrete states, FLAG=3 system outputs and FLAG=4 next sample
%	time. For more information and other options see SFUNC.
%
%	Calling SIST010 with a FLAG of zero:
%	[SIZES]=SIST010([],[],[],0),  returns a vector, SIZES, which
%	contains the sizes of the state vector and other parameters.
%		SIZES(1) number of states
%		SIZES(2) number of discrete states
%		SIZES(3) number of outputs
%		SIZES(4) number of inputs
%		SIZES(5) number of roots (currently unsupported)
%		SIZES(6) direct feedthrough flag
%		SIZES(7) number of sample times
%
%	For the definition of other parameters in SIZES, see SFUNC.
%	See also, TRIM, LINMOD, LINSIM, EULER, RK23, RK45, ADAMS, GEAR.

% Note: This M-file is only used for saving graphical information;
%       after the model is loaded into memory an internal model
%       representation is used.

% the system will take on the name of this mfile:
sys = mfilename;
new_system(sys)
simver(1.3)
if (0 == (nargin + nargout))
     set_param(sys,'Location',[4,42,628,468])
     open_system(sys)
end;
set_param(sys,'algorithm',     'RK-45')
set_param(sys,'Start time',    '0.0')
set_param(sys,'Stop time',     '50')
set_param(sys,'Min step size', '0.0001')
set_param(sys,'Max step size', '10')
set_param(sys,'Relative error','1e-3')
set_param(sys,'Return vars',   '')

add_block('built-in/Step Fcn',[sys,'/','Sollwert'])
set_param([sys,'/','Sollwert'],...
		'orientation',3,...
		'Time','T',...
		'position',[40,315,60,335])


%     Subsystem  [' Beispiel 1 // Abschnitt 3 // Buch',13,' - in MATLAB vorgeben:',13,'T=1; T1=5; VS=0.2'].

new_system([sys,'/',[' Beispiel 1 // Abschnitt 3 // Buch',13,' - in MATLAB vorgeben:',13,'T=1; T1=5; VS=0.2']])
set_param([sys,'/',[' Beispiel 1 // Abschnitt 3 // Buch',13,' - in MATLAB vorgeben:',13,'T=1; T1=5; VS=0.2']],'Location',[4,42,628,468])

add_block('built-in/Sum',[sys,'/',[' Beispiel 1 // Abschnitt 3 // Buch',13,' - in MATLAB vorgeben:',13,'T=1; T1=5; VS=0.2/Sum1']])
set_param([sys,'/',[' Beispiel 1 // Abschnitt 3 // Buch',13,' - in MATLAB vorgeben:',13,'T=1; T1=5; VS=0.2/Sum1']],...
		'inputs','+-',...
		'position',[55,190,75,210])

add_block('built-in/Sum',[sys,'/',[' Beispiel 1 // Abschnitt 3 // Buch',13,' - in MATLAB vorgeben:',13,'T=1; T1=5; VS=0.2/Sum']])
set_param([sys,'/',[' Beispiel 1 // Abschnitt 3 // Buch',13,' - in MATLAB vorgeben:',13,'T=1; T1=5; VS=0.2/Sum']],...
		'inputs','+-',...
		'position',[45,105,65,125])

add_block('built-in/Gain',[sys,'/',[' Beispiel 1 // Abschnitt 3 // Buch',13,' - in MATLAB vorgeben:',13,'T=1; T1=5; VS=0.2/Gain']])
set_param([sys,'/',[' Beispiel 1 // Abschnitt 3 // Buch',13,' - in MATLAB vorgeben:',13,'T=1; T1=5; VS=0.2/Gain']],...
		'orientation',2,...
		'position',[30,15,60,45])

add_block('built-in/Inport',[sys,'/',[' Beispiel 1 // Abschnitt 3 // Buch',13,' - in MATLAB vorgeben:',13,'T=1; T1=5; VS=0.2/in_1']])
set_param([sys,'/',[' Beispiel 1 // Abschnitt 3 // Buch',13,' - in MATLAB vorgeben:',13,'T=1; T1=5; VS=0.2/in_1']],...
		'orientation',2,...
		'position',[110,20,130,40])

add_block('built-in/Sum',[sys,'/',[' Beispiel 1 // Abschnitt 3 // Buch',13,' - in MATLAB vorgeben:',13,'T=1; T1=5; VS=0.2/Sum2']])
set_param([sys,'/',[' Beispiel 1 // Abschnitt 3 // Buch',13,' - in MATLAB vorgeben:',13,'T=1; T1=5; VS=0.2/Sum2']],...
		'inputs','+-',...
		'position',[125,275,145,295])

add_block('built-in/Filter',[sys,'/',[' Beispiel 1 // Abschnitt 3 // Buch',13,' - in MATLAB vorgeben:',13,'T=1; T1=5; VS=0.2/Filter4']])
set_param([sys,'/',[' Beispiel 1 // Abschnitt 3 // Buch',13,' - in MATLAB vorgeben:',13,'T=1; T1=5; VS=0.2/Filter4']],...
		'Numerator','0.3532',...
		'Denominator','[1 -0.6468]',...
		'Sample time','T',...
		'position',[35,261,95,299])

add_block('built-in/Zero-Order Hold',[sys,'/',[' Beispiel 1 // Abschnitt 3 // Buch',13,' - in MATLAB vorgeben:',13,'T=1; T1=5; VS=0.2/Zero-Order',13,'Hold2']])
set_param([sys,'/',[' Beispiel 1 // Abschnitt 3 // Buch',13,' - in MATLAB vorgeben:',13,'T=1; T1=5; VS=0.2/Zero-Order',13,'Hold2']],...
		'Sample time','T',...
		'position',[165,269,200,301])

add_block('built-in/Transfer Fcn',[sys,'/',[' Beispiel 1 // Abschnitt 3 // Buch',13,' - in MATLAB vorgeben:',13,'T=1; T1=5; VS=0.2/Strecke2']])
set_param([sys,'/',[' Beispiel 1 // Abschnitt 3 // Buch',13,' - in MATLAB vorgeben:',13,'T=1; T1=5; VS=0.2/Strecke2']],...
		'Numerator','[VS]',...
		'Denominator','[T1 1]',...
		'position',[345,265,385,305])

add_block('built-in/Filter',[sys,'/',[' Beispiel 1 // Abschnitt 3 // Buch',13,' - in MATLAB vorgeben:',13,'T=1; T1=5; VS=0.2/Diff.2']])
set_param([sys,'/',[' Beispiel 1 // Abschnitt 3 // Buch',13,' - in MATLAB vorgeben:',13,'T=1; T1=5; VS=0.2/Diff.2']],...
		'Numerator','[1 -1]',...
		'Denominator','[1]',...
		'Sample time','T',...
		'position',[510,268,550,302])

add_block('built-in/Zero-Order Hold',[sys,'/',[' Beispiel 1 // Abschnitt 3 // Buch',13,' - in MATLAB vorgeben:',13,'T=1; T1=5; VS=0.2/ABT2']])
set_param([sys,'/',[' Beispiel 1 // Abschnitt 3 // Buch',13,' - in MATLAB vorgeben:',13,'T=1; T1=5; VS=0.2/ABT2']],...
		'Sample time','T',...
		'position',[460,269,495,301])

add_block('built-in/Transfer Fcn',[sys,'/',[' Beispiel 1 // Abschnitt 3 // Buch',13,' - in MATLAB vorgeben:',13,'T=1; T1=5; VS=0.2/Int2']])
set_param([sys,'/',[' Beispiel 1 // Abschnitt 3 // Buch',13,' - in MATLAB vorgeben:',13,'T=1; T1=5; VS=0.2/Int2']],...
		'Denominator','[T 0]',...
		'position',[415,267,450,303])

add_block('built-in/Transfer Fcn',[sys,'/',[' Beispiel 1 // Abschnitt 3 // Buch',13,' - in MATLAB vorgeben:',13,'T=1; T1=5; VS=0.2/ungeregelte Strecke']])
set_param([sys,'/',[' Beispiel 1 // Abschnitt 3 // Buch',13,' - in MATLAB vorgeben:',13,'T=1; T1=5; VS=0.2/ungeregelte Strecke']],...
		'Numerator','[VS]',...
		'Denominator','[T1 1]',...
		'position',[285,43,330,77])

add_block('built-in/Transfer Fcn',[sys,'/',[' Beispiel 1 // Abschnitt 3 // Buch',13,' - in MATLAB vorgeben:',13,'T=1; T1=5; VS=0.2/Strecke']])
set_param([sys,'/',[' Beispiel 1 // Abschnitt 3 // Buch',13,' - in MATLAB vorgeben:',13,'T=1; T1=5; VS=0.2/Strecke']],...
		'Numerator','[VS]',...
		'Denominator','[T1 1]',...
		'position',[255,95,295,135])

add_block('built-in/Filter',[sys,'/',[' Beispiel 1 // Abschnitt 3 // Buch',13,' - in MATLAB vorgeben:',13,'T=1; T1=5; VS=0.2/Diff.']])
set_param([sys,'/',[' Beispiel 1 // Abschnitt 3 // Buch',13,' - in MATLAB vorgeben:',13,'T=1; T1=5; VS=0.2/Diff.']],...
		'Numerator','[1 -1]',...
		'Denominator','[1]',...
		'Sample time','T',...
		'position',[430,98,470,132])

add_block('built-in/Zero-Order Hold',[sys,'/',[' Beispiel 1 // Abschnitt 3 // Buch',13,' - in MATLAB vorgeben:',13,'T=1; T1=5; VS=0.2/ABT']])
set_param([sys,'/',[' Beispiel 1 // Abschnitt 3 // Buch',13,' - in MATLAB vorgeben:',13,'T=1; T1=5; VS=0.2/ABT']],...
		'Sample time','T',...
		'position',[380,99,415,131])

add_block('built-in/Transfer Fcn',[sys,'/',[' Beispiel 1 // Abschnitt 3 // Buch',13,' - in MATLAB vorgeben:',13,'T=1; T1=5; VS=0.2/Int']])
set_param([sys,'/',[' Beispiel 1 // Abschnitt 3 // Buch',13,' - in MATLAB vorgeben:',13,'T=1; T1=5; VS=0.2/Int']],...
		'Denominator','[T 0]',...
		'position',[320,97,355,133])

add_block('built-in/Zero-Order Hold',[sys,'/',[' Beispiel 1 // Abschnitt 3 // Buch',13,' - in MATLAB vorgeben:',13,'T=1; T1=5; VS=0.2/Zero-Order',13,'Hold']])
set_param([sys,'/',[' Beispiel 1 // Abschnitt 3 // Buch',13,' - in MATLAB vorgeben:',13,'T=1; T1=5; VS=0.2/Zero-Order',13,'Hold']],...
		'Sample time','T',...
		'position',[85,99,120,131])

add_block('built-in/Filter',[sys,'/',[' Beispiel 1 // Abschnitt 3 // Buch',13,' - in MATLAB vorgeben:',13,'T=1; T1=5; VS=0.2/Regler: Formel 3.20']])
set_param([sys,'/',[' Beispiel 1 // Abschnitt 3 // Buch',13,' - in MATLAB vorgeben:',13,'T=1; T1=5; VS=0.2/Regler: Formel 3.20']],...
		'Numerator','[14.14 -11.5792]',...
		'Denominator','[1 -1]',...
		'Sample time','T')
set_param([sys,'/',[' Beispiel 1 // Abschnitt 3 // Buch',13,' - in MATLAB vorgeben:',13,'T=1; T1=5; VS=0.2/Regler: Formel 3.20']],...
		'position',[140,94,235,136])

add_block('built-in/Zero-Order Hold',[sys,'/',[' Beispiel 1 // Abschnitt 3 // Buch',13,' - in MATLAB vorgeben:',13,'T=1; T1=5; VS=0.2/Zero-Order',13,'Hold1']])
set_param([sys,'/',[' Beispiel 1 // Abschnitt 3 // Buch',13,' - in MATLAB vorgeben:',13,'T=1; T1=5; VS=0.2/Zero-Order',13,'Hold1']],...
		'Sample time','T',...
		'position',[90,184,125,216])

add_block('built-in/Filter',[sys,'/',[' Beispiel 1 // Abschnitt 3 // Buch',13,' - in MATLAB vorgeben:',13,'T=1; T1=5; VS=0.2/Regler1: Formel 3.20']])
set_param([sys,'/',[' Beispiel 1 // Abschnitt 3 // Buch',13,' - in MATLAB vorgeben:',13,'T=1; T1=5; VS=0.2/Regler1: Formel 3.20']],...
		'Numerator','[23.90 -23.5965 3.2552]',...
		'Denominator','[1 -1]',...
		'Sample time','T')
set_param([sys,'/',[' Beispiel 1 // Abschnitt 3 // Buch',13,' - in MATLAB vorgeben:',13,'T=1; T1=5; VS=0.2/Regler1: Formel 3.20']],...
		'position',[140,179,285,221])

add_block('built-in/Filter',[sys,'/',[' Beispiel 1 // Abschnitt 3 // Buch',13,' - in MATLAB vorgeben:',13,'T=1; T1=5; VS=0.2/Regler2: Formel 3.25//27']])
set_param([sys,'/',[' Beispiel 1 // Abschnitt 3 // Buch',13,' - in MATLAB vorgeben:',13,'T=1; T1=5; VS=0.2/Regler2: Formel 3.25//27']],...
		'Numerator','[17.87 -11.5583]',...
		'Denominator','[1 -1]',...
		'Sample time','T')
set_param([sys,'/',[' Beispiel 1 // Abschnitt 3 // Buch',13,' - in MATLAB vorgeben:',13,'T=1; T1=5; VS=0.2/Regler2: Formel 3.25//27']],...
		'position',[225,264,325,306])

add_block('built-in/Transfer Fcn',[sys,'/',[' Beispiel 1 // Abschnitt 3 // Buch',13,' - in MATLAB vorgeben:',13,'T=1; T1=5; VS=0.2/Strecke1']])
set_param([sys,'/',[' Beispiel 1 // Abschnitt 3 // Buch',13,' - in MATLAB vorgeben:',13,'T=1; T1=5; VS=0.2/Strecke1']],...
		'Numerator','[VS]',...
		'Denominator','[T1 1]',...
		'position',[300,180,340,220])

add_block('built-in/Transfer Fcn',[sys,'/',[' Beispiel 1 // Abschnitt 3 // Buch',13,' - in MATLAB vorgeben:',13,'T=1; T1=5; VS=0.2/Int1']])
set_param([sys,'/',[' Beispiel 1 // Abschnitt 3 // Buch',13,' - in MATLAB vorgeben:',13,'T=1; T1=5; VS=0.2/Int1']],...
		'Denominator','[T 0]',...
		'position',[355,182,390,218])

add_block('built-in/Zero-Order Hold',[sys,'/',[' Beispiel 1 // Abschnitt 3 // Buch',13,' - in MATLAB vorgeben:',13,'T=1; T1=5; VS=0.2/ABT1']])
set_param([sys,'/',[' Beispiel 1 // Abschnitt 3 // Buch',13,' - in MATLAB vorgeben:',13,'T=1; T1=5; VS=0.2/ABT1']],...
		'Sample time','T',...
		'position',[405,184,440,216])

add_block('built-in/Filter',[sys,'/',[' Beispiel 1 // Abschnitt 3 // Buch',13,' - in MATLAB vorgeben:',13,'T=1; T1=5; VS=0.2/Diff.1']])
set_param([sys,'/',[' Beispiel 1 // Abschnitt 3 // Buch',13,' - in MATLAB vorgeben:',13,'T=1; T1=5; VS=0.2/Diff.1']],...
		'Numerator','[1 -1]',...
		'Denominator','[1]',...
		'Sample time','T',...
		'position',[455,183,495,217])

add_block('built-in/Outport',[sys,'/',[' Beispiel 1 // Abschnitt 3 // Buch',13,' - in MATLAB vorgeben:',13,'T=1; T1=5; VS=0.2/out_1']])
set_param([sys,'/',[' Beispiel 1 // Abschnitt 3 // Buch',13,' - in MATLAB vorgeben:',13,'T=1; T1=5; VS=0.2/out_1']],...
		'position',[525,20,545,40])

add_block('built-in/Mux',[sys,'/',[' Beispiel 1 // Abschnitt 3 // Buch',13,' - in MATLAB vorgeben:',13,'T=1; T1=5; VS=0.2/Multiplexer']])
set_param([sys,'/',[' Beispiel 1 // Abschnitt 3 // Buch',13,' - in MATLAB vorgeben:',13,'T=1; T1=5; VS=0.2/Multiplexer']],...
		'position',[545,89,580,156])
add_line([sys,'/',[' Beispiel 1 // Abschnitt 3 // Buch',13,' - in MATLAB vorgeben:',13,'T=1; T1=5; VS=0.2']],[80,200;85,200])
add_line([sys,'/',[' Beispiel 1 // Abschnitt 3 // Buch',13,' - in MATLAB vorgeben:',13,'T=1; T1=5; VS=0.2']],[70,115;80,115])
add_line([sys,'/',[' Beispiel 1 // Abschnitt 3 // Buch',13,' - in MATLAB vorgeben:',13,'T=1; T1=5; VS=0.2']],[130,200;135,200])
add_line([sys,'/',[' Beispiel 1 // Abschnitt 3 // Buch',13,' - in MATLAB vorgeben:',13,'T=1; T1=5; VS=0.2']],[125,115;135,115])
add_line([sys,'/',[' Beispiel 1 // Abschnitt 3 // Buch',13,' - in MATLAB vorgeben:',13,'T=1; T1=5; VS=0.2']],[585,125;590,125;590,60;505,60;505,30;520,30])
add_line([sys,'/',[' Beispiel 1 // Abschnitt 3 // Buch',13,' - in MATLAB vorgeben:',13,'T=1; T1=5; VS=0.2']],[105,30;65,30])
add_line([sys,'/',[' Beispiel 1 // Abschnitt 3 // Buch',13,' - in MATLAB vorgeben:',13,'T=1; T1=5; VS=0.2']],[25,30;15,30;15,195;50,195])
add_line([sys,'/',[' Beispiel 1 // Abschnitt 3 // Buch',13,' - in MATLAB vorgeben:',13,'T=1; T1=5; VS=0.2']],[15,110;40,110])
add_line([sys,'/',[' Beispiel 1 // Abschnitt 3 // Buch',13,' - in MATLAB vorgeben:',13,'T=1; T1=5; VS=0.2']],[150,285;160,285])
add_line([sys,'/',[' Beispiel 1 // Abschnitt 3 // Buch',13,' - in MATLAB vorgeben:',13,'T=1; T1=5; VS=0.2']],[555,285;570,285;570,335;105,335;105,290;120,290])
add_line([sys,'/',[' Beispiel 1 // Abschnitt 3 // Buch',13,' - in MATLAB vorgeben:',13,'T=1; T1=5; VS=0.2']],[100,280;120,280])
add_line([sys,'/',[' Beispiel 1 // Abschnitt 3 // Buch',13,' - in MATLAB vorgeben:',13,'T=1; T1=5; VS=0.2']],[15,195;15,280;30,280])
add_line([sys,'/',[' Beispiel 1 // Abschnitt 3 // Buch',13,' - in MATLAB vorgeben:',13,'T=1; T1=5; VS=0.2']],[360,115;375,115])
add_line([sys,'/',[' Beispiel 1 // Abschnitt 3 // Buch',13,' - in MATLAB vorgeben:',13,'T=1; T1=5; VS=0.2']],[420,115;425,115])
add_line([sys,'/',[' Beispiel 1 // Abschnitt 3 // Buch',13,' - in MATLAB vorgeben:',13,'T=1; T1=5; VS=0.2']],[300,115;315,115])
add_line([sys,'/',[' Beispiel 1 // Abschnitt 3 // Buch',13,' - in MATLAB vorgeben:',13,'T=1; T1=5; VS=0.2']],[240,115;250,115])
add_line([sys,'/',[' Beispiel 1 // Abschnitt 3 // Buch',13,' - in MATLAB vorgeben:',13,'T=1; T1=5; VS=0.2']],[395,200;400,200])
add_line([sys,'/',[' Beispiel 1 // Abschnitt 3 // Buch',13,' - in MATLAB vorgeben:',13,'T=1; T1=5; VS=0.2']],[445,200;450,200])
add_line([sys,'/',[' Beispiel 1 // Abschnitt 3 // Buch',13,' - in MATLAB vorgeben:',13,'T=1; T1=5; VS=0.2']],[345,200;350,200])
add_line([sys,'/',[' Beispiel 1 // Abschnitt 3 // Buch',13,' - in MATLAB vorgeben:',13,'T=1; T1=5; VS=0.2']],[455,285;455,285])
add_line([sys,'/',[' Beispiel 1 // Abschnitt 3 // Buch',13,' - in MATLAB vorgeben:',13,'T=1; T1=5; VS=0.2']],[500,285;505,285])
add_line([sys,'/',[' Beispiel 1 // Abschnitt 3 // Buch',13,' - in MATLAB vorgeben:',13,'T=1; T1=5; VS=0.2']],[390,285;410,285])
add_line([sys,'/',[' Beispiel 1 // Abschnitt 3 // Buch',13,' - in MATLAB vorgeben:',13,'T=1; T1=5; VS=0.2']],[290,200;295,200])
add_line([sys,'/',[' Beispiel 1 // Abschnitt 3 // Buch',13,' - in MATLAB vorgeben:',13,'T=1; T1=5; VS=0.2']],[335,60;495,60;495,100;540,100])
add_line([sys,'/',[' Beispiel 1 // Abschnitt 3 // Buch',13,' - in MATLAB vorgeben:',13,'T=1; T1=5; VS=0.2']],[15,60;280,60])
add_line([sys,'/',[' Beispiel 1 // Abschnitt 3 // Buch',13,' - in MATLAB vorgeben:',13,'T=1; T1=5; VS=0.2']],[205,285;220,285])
add_line([sys,'/',[' Beispiel 1 // Abschnitt 3 // Buch',13,' - in MATLAB vorgeben:',13,'T=1; T1=5; VS=0.2']],[330,285;340,285])
add_line([sys,'/',[' Beispiel 1 // Abschnitt 3 // Buch',13,' - in MATLAB vorgeben:',13,'T=1; T1=5; VS=0.2']],[475,115;485,115;485,160;30,160;40,120])
add_line([sys,'/',[' Beispiel 1 // Abschnitt 3 // Buch',13,' - in MATLAB vorgeben:',13,'T=1; T1=5; VS=0.2']],[485,115;540,115])
add_line([sys,'/',[' Beispiel 1 // Abschnitt 3 // Buch',13,' - in MATLAB vorgeben:',13,'T=1; T1=5; VS=0.2']],[500,200;515,200;515,245;35,245;35,205;50,205])
add_line([sys,'/',[' Beispiel 1 // Abschnitt 3 // Buch',13,' - in MATLAB vorgeben:',13,'T=1; T1=5; VS=0.2']],[515,200;515,130;540,130])
add_line([sys,'/',[' Beispiel 1 // Abschnitt 3 // Buch',13,' - in MATLAB vorgeben:',13,'T=1; T1=5; VS=0.2']],[570,285;570,245;530,245;540,145])


%     Finished composite block [' Beispiel 1 // Abschnitt 3 // Buch',13,' - in MATLAB vorgeben:',13,'T=1; T1=5; VS=0.2'].

set_param([sys,'/',[' Beispiel 1 // Abschnitt 3 // Buch',13,' - in MATLAB vorgeben:',13,'T=1; T1=5; VS=0.2']],...
		'position',[255,30,285,80])


%     Subsystem  ['Beispiel 2 // Abschnitt 3 // Buch',13,' - in MATLAB vorgeben:',13,'T=1; T1=10; T2=4; VS=1'].

new_system([sys,'/',['Beispiel 2 // Abschnitt 3 // Buch',13,' - in MATLAB vorgeben:',13,'T=1; T1=10; T2=4; VS=1']])
set_param([sys,'/',['Beispiel 2 // Abschnitt 3 // Buch',13,' - in MATLAB vorgeben:',13,'T=1; T1=10; T2=4; VS=1']],'Location',[4,42,628,468])

add_block('built-in/Outport',[sys,'/',['Beispiel 2 // Abschnitt 3 // Buch',13,' - in MATLAB vorgeben:',13,'T=1; T1=10; T2=4; VS=1/out_1']])
set_param([sys,'/',['Beispiel 2 // Abschnitt 3 // Buch',13,' - in MATLAB vorgeben:',13,'T=1; T1=10; T2=4; VS=1/out_1']],...
		'position',[555,10,575,30])

add_block('built-in/Inport',[sys,'/',['Beispiel 2 // Abschnitt 3 // Buch',13,' - in MATLAB vorgeben:',13,'T=1; T1=10; T2=4; VS=1/in_1']])
set_param([sys,'/',['Beispiel 2 // Abschnitt 3 // Buch',13,' - in MATLAB vorgeben:',13,'T=1; T1=10; T2=4; VS=1/in_1']],...
		'position',[40,20,60,40])

add_block('built-in/Gain',[sys,'/',['Beispiel 2 // Abschnitt 3 // Buch',13,' - in MATLAB vorgeben:',13,'T=1; T1=10; T2=4; VS=1/Gain']])
set_param([sys,'/',['Beispiel 2 // Abschnitt 3 // Buch',13,' - in MATLAB vorgeben:',13,'T=1; T1=10; T2=4; VS=1/Gain']],...
		'position',[80,15,110,45])


%     Subsystem  ['Beispiel 2 // Abschnitt 3 // Buch',13,' - in MATLAB vorgeben:',13,'T=1; T1=10; T2=4; VS=1/Fh//PI'].

new_system([sys,'/',['Beispiel 2 // Abschnitt 3 // Buch',13,' - in MATLAB vorgeben:',13,'T=1; T1=10; T2=4; VS=1/Fh//PI']])
set_param([sys,'/',['Beispiel 2 // Abschnitt 3 // Buch',13,' - in MATLAB vorgeben:',13,'T=1; T1=10; T2=4; VS=1/Fh//PI']],'Location',[4,87,604,316])

add_block('built-in/Filter',[sys,'/',['Beispiel 2 // Abschnitt 3 // Buch',13,' - in MATLAB vorgeben:',13,'T=1; T1=10; T2=4; VS=1/Fh//PI/Regler: Formel 3.20']])
set_param([sys,'/',['Beispiel 2 // Abschnitt 3 // Buch',13,' - in MATLAB vorgeben:',13,'T=1; T1=10; T2=4; VS=1/Fh//PI/Regler: Formel 3.20']],...
		'Numerator','[1.35 -1.2267]',...
		'Denominator','[1 -1]',...
		'Sample time','T')
set_param([sys,'/',['Beispiel 2 // Abschnitt 3 // Buch',13,' - in MATLAB vorgeben:',13,'T=1; T1=10; T2=4; VS=1/Fh//PI/Regler: Formel 3.20']],...
		'position',[140,40,240,80])

add_block('built-in/Zero-Order Hold',[sys,'/',['Beispiel 2 // Abschnitt 3 // Buch',13,' - in MATLAB vorgeben:',13,'T=1; T1=10; T2=4; VS=1/Fh//PI/Zero-Order',13,'Hold']])
set_param([sys,'/',['Beispiel 2 // Abschnitt 3 // Buch',13,' - in MATLAB vorgeben:',13,'T=1; T1=10; T2=4; VS=1/Fh//PI/Zero-Order',13,'Hold']],...
		'Sample time','T',...
		'position',[90,44,125,76])

add_block('built-in/Sum',[sys,'/',['Beispiel 2 // Abschnitt 3 // Buch',13,' - in MATLAB vorgeben:',13,'T=1; T1=10; T2=4; VS=1/Fh//PI/Sum']])
set_param([sys,'/',['Beispiel 2 // Abschnitt 3 // Buch',13,' - in MATLAB vorgeben:',13,'T=1; T1=10; T2=4; VS=1/Fh//PI/Sum']],...
		'inputs','+-',...
		'position',[55,50,75,70])

add_block('built-in/Inport',[sys,'/',['Beispiel 2 // Abschnitt 3 // Buch',13,' - in MATLAB vorgeben:',13,'T=1; T1=10; T2=4; VS=1/Fh//PI/in_1']])
set_param([sys,'/',['Beispiel 2 // Abschnitt 3 // Buch',13,' - in MATLAB vorgeben:',13,'T=1; T1=10; T2=4; VS=1/Fh//PI/in_1']],...
		'position',[15,45,30,65])

add_block('built-in/Outport',[sys,'/',['Beispiel 2 // Abschnitt 3 // Buch',13,' - in MATLAB vorgeben:',13,'T=1; T1=10; T2=4; VS=1/Fh//PI/out_1']])
set_param([sys,'/',['Beispiel 2 // Abschnitt 3 // Buch',13,' - in MATLAB vorgeben:',13,'T=1; T1=10; T2=4; VS=1/Fh//PI/out_1']],...
		'position',[515,50,535,70])

add_block('built-in/Transfer Fcn',[sys,'/',['Beispiel 2 // Abschnitt 3 // Buch',13,' - in MATLAB vorgeben:',13,'T=1; T1=10; T2=4; VS=1/Fh//PI/PT1_2']])
set_param([sys,'/',['Beispiel 2 // Abschnitt 3 // Buch',13,' - in MATLAB vorgeben:',13,'T=1; T1=10; T2=4; VS=1/Fh//PI/PT1_2']],...
		'Denominator','[T2 1]',...
		'position',[355,39,400,81])

add_block('built-in/Transfer Fcn',[sys,'/',['Beispiel 2 // Abschnitt 3 // Buch',13,' - in MATLAB vorgeben:',13,'T=1; T1=10; T2=4; VS=1/Fh//PI/PT1_1']])
set_param([sys,'/',['Beispiel 2 // Abschnitt 3 // Buch',13,' - in MATLAB vorgeben:',13,'T=1; T1=10; T2=4; VS=1/Fh//PI/PT1_1']],...
		'Numerator','[VS]',...
		'Denominator','[T1 1]',...
		'position',[285,40,330,80])
add_line([sys,'/',['Beispiel 2 // Abschnitt 3 // Buch',13,' - in MATLAB vorgeben:',13,'T=1; T1=10; T2=4; VS=1/Fh//PI']],[405,60;510,60])
add_line([sys,'/',['Beispiel 2 // Abschnitt 3 // Buch',13,' - in MATLAB vorgeben:',13,'T=1; T1=10; T2=4; VS=1/Fh//PI']],[495,60;495,110;40,110;50,65])
add_line([sys,'/',['Beispiel 2 // Abschnitt 3 // Buch',13,' - in MATLAB vorgeben:',13,'T=1; T1=10; T2=4; VS=1/Fh//PI']],[245,60;280,60])
add_line([sys,'/',['Beispiel 2 // Abschnitt 3 // Buch',13,' - in MATLAB vorgeben:',13,'T=1; T1=10; T2=4; VS=1/Fh//PI']],[335,60;350,60])
add_line([sys,'/',['Beispiel 2 // Abschnitt 3 // Buch',13,' - in MATLAB vorgeben:',13,'T=1; T1=10; T2=4; VS=1/Fh//PI']],[130,60;135,60])
add_line([sys,'/',['Beispiel 2 // Abschnitt 3 // Buch',13,' - in MATLAB vorgeben:',13,'T=1; T1=10; T2=4; VS=1/Fh//PI']],[80,60;85,60])
add_line([sys,'/',['Beispiel 2 // Abschnitt 3 // Buch',13,' - in MATLAB vorgeben:',13,'T=1; T1=10; T2=4; VS=1/Fh//PI']],[35,55;50,55])


%     Finished composite block ['Beispiel 2 // Abschnitt 3 // Buch',13,' - in MATLAB vorgeben:',13,'T=1; T1=10; T2=4; VS=1/Fh//PI'].

set_param([sys,'/',['Beispiel 2 // Abschnitt 3 // Buch',13,' - in MATLAB vorgeben:',13,'T=1; T1=10; T2=4; VS=1/Fh//PI']],...
		'position',[170,65,200,115])


%     Subsystem  ['Beispiel 2 // Abschnitt 3 // Buch',13,' - in MATLAB vorgeben:',13,'T=1; T1=10; T2=4; VS=1/Fh//PID'].

new_system([sys,'/',['Beispiel 2 // Abschnitt 3 // Buch',13,' - in MATLAB vorgeben:',13,'T=1; T1=10; T2=4; VS=1/Fh//PID']])
set_param([sys,'/',['Beispiel 2 // Abschnitt 3 // Buch',13,' - in MATLAB vorgeben:',13,'T=1; T1=10; T2=4; VS=1/Fh//PID']],'Location',[4,167,564,312])

add_block('built-in/Filter',[sys,'/',['Beispiel 2 // Abschnitt 3 // Buch',13,' - in MATLAB vorgeben:',13,'T=1; T1=10; T2=4; VS=1/Fh//PID/Regler1: Formel 3.20']])
set_param([sys,'/',['Beispiel 2 // Abschnitt 3 // Buch',13,' - in MATLAB vorgeben:',13,'T=1; T1=10; T2=4; VS=1/Fh//PID/Regler1: Formel 3.20']],...
		'Numerator','[24.88 -41.9054 17.5479]',...
		'Denominator','[1 -1]',...
		'Sample time','T')
set_param([sys,'/',['Beispiel 2 // Abschnitt 3 // Buch',13,' - in MATLAB vorgeben:',13,'T=1; T1=10; T2=4; VS=1/Fh//PID/Regler1: Formel 3.20']],...
		'position',[150,44,315,86])

add_block('built-in/Zero-Order Hold',[sys,'/',['Beispiel 2 // Abschnitt 3 // Buch',13,' - in MATLAB vorgeben:',13,'T=1; T1=10; T2=4; VS=1/Fh//PID/Zero-Order',13,'Hold1']])
set_param([sys,'/',['Beispiel 2 // Abschnitt 3 // Buch',13,' - in MATLAB vorgeben:',13,'T=1; T1=10; T2=4; VS=1/Fh//PID/Zero-Order',13,'Hold1']],...
		'Sample time','T',...
		'position',[100,49,135,81])

add_block('built-in/Sum',[sys,'/',['Beispiel 2 // Abschnitt 3 // Buch',13,' - in MATLAB vorgeben:',13,'T=1; T1=10; T2=4; VS=1/Fh//PID/Sum1']])
set_param([sys,'/',['Beispiel 2 // Abschnitt 3 // Buch',13,' - in MATLAB vorgeben:',13,'T=1; T1=10; T2=4; VS=1/Fh//PID/Sum1']],...
		'inputs','+-',...
		'position',[65,55,85,75])

add_block('built-in/Inport',[sys,'/',['Beispiel 2 // Abschnitt 3 // Buch',13,' - in MATLAB vorgeben:',13,'T=1; T1=10; T2=4; VS=1/Fh//PID/in_1']])
set_param([sys,'/',['Beispiel 2 // Abschnitt 3 // Buch',13,' - in MATLAB vorgeben:',13,'T=1; T1=10; T2=4; VS=1/Fh//PID/in_1']],...
		'position',[15,50,30,70])

add_block('built-in/Outport',[sys,'/',['Beispiel 2 // Abschnitt 3 // Buch',13,' - in MATLAB vorgeben:',13,'T=1; T1=10; T2=4; VS=1/Fh//PID/out_1']])
set_param([sys,'/',['Beispiel 2 // Abschnitt 3 // Buch',13,' - in MATLAB vorgeben:',13,'T=1; T1=10; T2=4; VS=1/Fh//PID/out_1']],...
		'position',[510,55,530,75])

add_block('built-in/Transfer Fcn',[sys,'/',['Beispiel 2 // Abschnitt 3 // Buch',13,' - in MATLAB vorgeben:',13,'T=1; T1=10; T2=4; VS=1/Fh//PID/PT1_1']])
set_param([sys,'/',['Beispiel 2 // Abschnitt 3 // Buch',13,' - in MATLAB vorgeben:',13,'T=1; T1=10; T2=4; VS=1/Fh//PID/PT1_1']],...
		'Numerator','[VS]',...
		'Denominator','[T1 1]',...
		'position',[335,45,380,85])

add_block('built-in/Transfer Fcn',[sys,'/',['Beispiel 2 // Abschnitt 3 // Buch',13,' - in MATLAB vorgeben:',13,'T=1; T1=10; T2=4; VS=1/Fh//PID/PT1_2']])
set_param([sys,'/',['Beispiel 2 // Abschnitt 3 // Buch',13,' - in MATLAB vorgeben:',13,'T=1; T1=10; T2=4; VS=1/Fh//PID/PT1_2']],...
		'Denominator','[T2 1]',...
		'position',[395,45,440,85])
add_line([sys,'/',['Beispiel 2 // Abschnitt 3 // Buch',13,' - in MATLAB vorgeben:',13,'T=1; T1=10; T2=4; VS=1/Fh//PID']],[385,65;390,65])
add_line([sys,'/',['Beispiel 2 // Abschnitt 3 // Buch',13,' - in MATLAB vorgeben:',13,'T=1; T1=10; T2=4; VS=1/Fh//PID']],[320,65;330,65])
add_line([sys,'/',['Beispiel 2 // Abschnitt 3 // Buch',13,' - in MATLAB vorgeben:',13,'T=1; T1=10; T2=4; VS=1/Fh//PID']],[140,65;145,65])
add_line([sys,'/',['Beispiel 2 // Abschnitt 3 // Buch',13,' - in MATLAB vorgeben:',13,'T=1; T1=10; T2=4; VS=1/Fh//PID']],[90,65;95,65])
add_line([sys,'/',['Beispiel 2 // Abschnitt 3 // Buch',13,' - in MATLAB vorgeben:',13,'T=1; T1=10; T2=4; VS=1/Fh//PID']],[35,60;60,60])
add_line([sys,'/',['Beispiel 2 // Abschnitt 3 // Buch',13,' - in MATLAB vorgeben:',13,'T=1; T1=10; T2=4; VS=1/Fh//PID']],[445,65;505,65])
add_line([sys,'/',['Beispiel 2 // Abschnitt 3 // Buch',13,' - in MATLAB vorgeben:',13,'T=1; T1=10; T2=4; VS=1/Fh//PID']],[445,65;445,110;45,110;45,70;60,70])


%     Finished composite block ['Beispiel 2 // Abschnitt 3 // Buch',13,' - in MATLAB vorgeben:',13,'T=1; T1=10; T2=4; VS=1/Fh//PID'].

set_param([sys,'/',['Beispiel 2 // Abschnitt 3 // Buch',13,' - in MATLAB vorgeben:',13,'T=1; T1=10; T2=4; VS=1/Fh//PID']],...
		'position',[170,130,200,180])


%     Subsystem  ['Beispiel 2 // Abschnitt 3 // Buch',13,' - in MATLAB vorgeben:',13,'T=1; T1=10; T2=4; VS=1/St//PI'].

new_system([sys,'/',['Beispiel 2 // Abschnitt 3 // Buch',13,' - in MATLAB vorgeben:',13,'T=1; T1=10; T2=4; VS=1/St//PI']])
set_param([sys,'/',['Beispiel 2 // Abschnitt 3 // Buch',13,' - in MATLAB vorgeben:',13,'T=1; T1=10; T2=4; VS=1/St//PI']],'Location',[4,247,628,428])

add_block('built-in/Filter',[sys,'/',['Beispiel 2 // Abschnitt 3 // Buch',13,' - in MATLAB vorgeben:',13,'T=1; T1=10; T2=4; VS=1/St//PI/Filter4']])
set_param([sys,'/',['Beispiel 2 // Abschnitt 3 // Buch',13,' - in MATLAB vorgeben:',13,'T=1; T1=10; T2=4; VS=1/St//PI/Filter4']],...
		'Numerator','0.1312',...
		'Denominator','[1 -0.8688]',...
		'Sample time','T')
set_param([sys,'/',['Beispiel 2 // Abschnitt 3 // Buch',13,' - in MATLAB vorgeben:',13,'T=1; T1=10; T2=4; VS=1/St//PI/Filter4']],...
		'position',[45,50,120,90])

add_block('built-in/Inport',[sys,'/',['Beispiel 2 // Abschnitt 3 // Buch',13,' - in MATLAB vorgeben:',13,'T=1; T1=10; T2=4; VS=1/St//PI/in_1']])
set_param([sys,'/',['Beispiel 2 // Abschnitt 3 // Buch',13,' - in MATLAB vorgeben:',13,'T=1; T1=10; T2=4; VS=1/St//PI/in_1']],...
		'position',[15,60,30,80])

add_block('built-in/Outport',[sys,'/',['Beispiel 2 // Abschnitt 3 // Buch',13,' - in MATLAB vorgeben:',13,'T=1; T1=10; T2=4; VS=1/St//PI/out_1']])
set_param([sys,'/',['Beispiel 2 // Abschnitt 3 // Buch',13,' - in MATLAB vorgeben:',13,'T=1; T1=10; T2=4; VS=1/St//PI/out_1']],...
		'position',[575,65,595,85])

add_block('built-in/Zero-Order Hold',[sys,'/',['Beispiel 2 // Abschnitt 3 // Buch',13,' - in MATLAB vorgeben:',13,'T=1; T1=10; T2=4; VS=1/St//PI/Zero-Order',13,'Hold2']])
set_param([sys,'/',['Beispiel 2 // Abschnitt 3 // Buch',13,' - in MATLAB vorgeben:',13,'T=1; T1=10; T2=4; VS=1/St//PI/Zero-Order',13,'Hold2']],...
		'Sample time','T',...
		'position',[175,59,210,91])

add_block('built-in/Sum',[sys,'/',['Beispiel 2 // Abschnitt 3 // Buch',13,' - in MATLAB vorgeben:',13,'T=1; T1=10; T2=4; VS=1/St//PI/Sum2']])
set_param([sys,'/',['Beispiel 2 // Abschnitt 3 // Buch',13,' - in MATLAB vorgeben:',13,'T=1; T1=10; T2=4; VS=1/St//PI/Sum2']],...
		'inputs','+-',...
		'position',[140,65,160,85])

add_block('built-in/Filter',[sys,'/',['Beispiel 2 // Abschnitt 3 // Buch',13,' - in MATLAB vorgeben:',13,'T=1; T1=10; T2=4; VS=1/St//PI/Regler2: Formel 3.25//27']])
set_param([sys,'/',['Beispiel 2 // Abschnitt 3 // Buch',13,' - in MATLAB vorgeben:',13,'T=1; T1=10; T2=4; VS=1/St//PI/Regler2: Formel 3.25//27']],...
		'Numerator','[1.41 -1.2250]',...
		'Denominator','[1 -1]',...
		'Sample time','T')
set_param([sys,'/',['Beispiel 2 // Abschnitt 3 // Buch',13,' - in MATLAB vorgeben:',13,'T=1; T1=10; T2=4; VS=1/St//PI/Regler2: Formel 3.25//27']],...
		'position',[230,54,320,96])

add_block('built-in/Transfer Fcn',[sys,'/',['Beispiel 2 // Abschnitt 3 // Buch',13,' - in MATLAB vorgeben:',13,'T=1; T1=10; T2=4; VS=1/St//PI/PT1_2']])
set_param([sys,'/',['Beispiel 2 // Abschnitt 3 // Buch',13,' - in MATLAB vorgeben:',13,'T=1; T1=10; T2=4; VS=1/St//PI/PT1_2']],...
		'Denominator','[T2 1]',...
		'position',[400,55,445,95])

add_block('built-in/Transfer Fcn',[sys,'/',['Beispiel 2 // Abschnitt 3 // Buch',13,' - in MATLAB vorgeben:',13,'T=1; T1=10; T2=4; VS=1/St//PI/PT1_1']])
set_param([sys,'/',['Beispiel 2 // Abschnitt 3 // Buch',13,' - in MATLAB vorgeben:',13,'T=1; T1=10; T2=4; VS=1/St//PI/PT1_1']],...
		'Numerator','[VS]',...
		'Denominator','[T1 1]',...
		'position',[340,55,385,95])
add_line([sys,'/',['Beispiel 2 // Abschnitt 3 // Buch',13,' - in MATLAB vorgeben:',13,'T=1; T1=10; T2=4; VS=1/St//PI']],[390,75;395,75])
add_line([sys,'/',['Beispiel 2 // Abschnitt 3 // Buch',13,' - in MATLAB vorgeben:',13,'T=1; T1=10; T2=4; VS=1/St//PI']],[125,70;135,70])
add_line([sys,'/',['Beispiel 2 // Abschnitt 3 // Buch',13,' - in MATLAB vorgeben:',13,'T=1; T1=10; T2=4; VS=1/St//PI']],[325,75;335,75])
add_line([sys,'/',['Beispiel 2 // Abschnitt 3 // Buch',13,' - in MATLAB vorgeben:',13,'T=1; T1=10; T2=4; VS=1/St//PI']],[215,75;225,75])
add_line([sys,'/',['Beispiel 2 // Abschnitt 3 // Buch',13,' - in MATLAB vorgeben:',13,'T=1; T1=10; T2=4; VS=1/St//PI']],[165,75;170,75])
add_line([sys,'/',['Beispiel 2 // Abschnitt 3 // Buch',13,' - in MATLAB vorgeben:',13,'T=1; T1=10; T2=4; VS=1/St//PI']],[35,70;40,70])
add_line([sys,'/',['Beispiel 2 // Abschnitt 3 // Buch',13,' - in MATLAB vorgeben:',13,'T=1; T1=10; T2=4; VS=1/St//PI']],[450,75;570,75])
add_line([sys,'/',['Beispiel 2 // Abschnitt 3 // Buch',13,' - in MATLAB vorgeben:',13,'T=1; T1=10; T2=4; VS=1/St//PI']],[455,75;455,120;125,120;135,80])


%     Finished composite block ['Beispiel 2 // Abschnitt 3 // Buch',13,' - in MATLAB vorgeben:',13,'T=1; T1=10; T2=4; VS=1/St//PI'].

set_param([sys,'/',['Beispiel 2 // Abschnitt 3 // Buch',13,' - in MATLAB vorgeben:',13,'T=1; T1=10; T2=4; VS=1/St//PI']],...
		'position',[170,200,200,250])


%     Subsystem  ['Beispiel 2 // Abschnitt 3 // Buch',13,' - in MATLAB vorgeben:',13,'T=1; T1=10; T2=4; VS=1/St//PID'].

new_system([sys,'/',['Beispiel 2 // Abschnitt 3 // Buch',13,' - in MATLAB vorgeben:',13,'T=1; T1=10; T2=4; VS=1/St//PID']])
set_param([sys,'/',['Beispiel 2 // Abschnitt 3 // Buch',13,' - in MATLAB vorgeben:',13,'T=1; T1=10; T2=4; VS=1/St//PID']],'Location',[4,250,628,444])

add_block('built-in/Filter',[sys,'/',['Beispiel 2 // Abschnitt 3 // Buch',13,' - in MATLAB vorgeben:',13,'T=1; T1=10; T2=4; VS=1/St//PID/Filter5']])
set_param([sys,'/',['Beispiel 2 // Abschnitt 3 // Buch',13,' - in MATLAB vorgeben:',13,'T=1; T1=10; T2=4; VS=1/St//PID/Filter5']],...
		'Numerator','0.1155',...
		'Denominator','[1 -1.3899 0.5054]',...
		'Sample time','T')
set_param([sys,'/',['Beispiel 2 // Abschnitt 3 // Buch',13,' - in MATLAB vorgeben:',13,'T=1; T1=10; T2=4; VS=1/St//PID/Filter5']],...
		'position',[40,49,160,91])

add_block('built-in/Inport',[sys,'/',['Beispiel 2 // Abschnitt 3 // Buch',13,' - in MATLAB vorgeben:',13,'T=1; T1=10; T2=4; VS=1/St//PID/in_1']])
set_param([sys,'/',['Beispiel 2 // Abschnitt 3 // Buch',13,' - in MATLAB vorgeben:',13,'T=1; T1=10; T2=4; VS=1/St//PID/in_1']],...
		'position',[10,60,30,80])

add_block('built-in/Outport',[sys,'/',['Beispiel 2 // Abschnitt 3 // Buch',13,' - in MATLAB vorgeben:',13,'T=1; T1=10; T2=4; VS=1/St//PID/out_1']])
set_param([sys,'/',['Beispiel 2 // Abschnitt 3 // Buch',13,' - in MATLAB vorgeben:',13,'T=1; T1=10; T2=4; VS=1/St//PID/out_1']],...
		'position',[590,65,610,85])

add_block('built-in/Zero-Order Hold',[sys,'/',['Beispiel 2 // Abschnitt 3 // Buch',13,' - in MATLAB vorgeben:',13,'T=1; T1=10; T2=4; VS=1/St//PID/Zero-Order',13,'Hold3']])
set_param([sys,'/',['Beispiel 2 // Abschnitt 3 // Buch',13,' - in MATLAB vorgeben:',13,'T=1; T1=10; T2=4; VS=1/St//PID/Zero-Order',13,'Hold3']],...
		'Sample time','T',...
		'position',[225,59,260,91])

add_block('built-in/Sum',[sys,'/',['Beispiel 2 // Abschnitt 3 // Buch',13,' - in MATLAB vorgeben:',13,'T=1; T1=10; T2=4; VS=1/St//PID/Sum3']])
set_param([sys,'/',['Beispiel 2 // Abschnitt 3 // Buch',13,' - in MATLAB vorgeben:',13,'T=1; T1=10; T2=4; VS=1/St//PID/Sum3']],...
		'inputs','+-',...
		'position',[190,65,210,85])

add_block('built-in/Transfer Fcn',[sys,'/',['Beispiel 2 // Abschnitt 3 // Buch',13,' - in MATLAB vorgeben:',13,'T=1; T1=10; T2=4; VS=1/St//PID/PT2.3']])
set_param([sys,'/',['Beispiel 2 // Abschnitt 3 // Buch',13,' - in MATLAB vorgeben:',13,'T=1; T1=10; T2=4; VS=1/St//PID/PT2.3']],...
		'Denominator','[T2 1]',...
		'position',[510,56,555,94])

add_block('built-in/Transfer Fcn',[sys,'/',['Beispiel 2 // Abschnitt 3 // Buch',13,' - in MATLAB vorgeben:',13,'T=1; T1=10; T2=4; VS=1/St//PID/PT1.3']])
set_param([sys,'/',['Beispiel 2 // Abschnitt 3 // Buch',13,' - in MATLAB vorgeben:',13,'T=1; T1=10; T2=4; VS=1/St//PID/PT1.3']],...
		'Numerator','[VS]',...
		'Denominator','[T1 1]',...
		'position',[450,55,495,95])

add_block('built-in/Filter',[sys,'/',['Beispiel 2 // Abschnitt 3 // Buch',13,' - in MATLAB vorgeben:',13,'T=1; T1=10; T2=4; VS=1/St//PID/Regler2: Formel 3.25//27']])
set_param([sys,'/',['Beispiel 2 // Abschnitt 3 // Buch',13,' - in MATLAB vorgeben:',13,'T=1; T1=10; T2=4; VS=1/St//PID/Regler2: Formel 3.25//27']],...
		'Numerator','[34.53 -47.9932 17.4515]',...
		'Denominator','[1 -1]',...
		'Sample time','T')
set_param([sys,'/',['Beispiel 2 // Abschnitt 3 // Buch',13,' - in MATLAB vorgeben:',13,'T=1; T1=10; T2=4; VS=1/St//PID/Regler2: Formel 3.25//27']],...
		'position',[280,54,430,96])
add_line([sys,'/',['Beispiel 2 // Abschnitt 3 // Buch',13,' - in MATLAB vorgeben:',13,'T=1; T1=10; T2=4; VS=1/St//PID']],[500,75;505,75])
add_line([sys,'/',['Beispiel 2 // Abschnitt 3 // Buch',13,' - in MATLAB vorgeben:',13,'T=1; T1=10; T2=4; VS=1/St//PID']],[165,70;185,70])
add_line([sys,'/',['Beispiel 2 // Abschnitt 3 // Buch',13,' - in MATLAB vorgeben:',13,'T=1; T1=10; T2=4; VS=1/St//PID']],[435,75;445,75])
add_line([sys,'/',['Beispiel 2 // Abschnitt 3 // Buch',13,' - in MATLAB vorgeben:',13,'T=1; T1=10; T2=4; VS=1/St//PID']],[265,75;275,75])
add_line([sys,'/',['Beispiel 2 // Abschnitt 3 // Buch',13,' - in MATLAB vorgeben:',13,'T=1; T1=10; T2=4; VS=1/St//PID']],[215,75;220,75])
add_line([sys,'/',['Beispiel 2 // Abschnitt 3 // Buch',13,' - in MATLAB vorgeben:',13,'T=1; T1=10; T2=4; VS=1/St//PID']],[35,70;35,70])
add_line([sys,'/',['Beispiel 2 // Abschnitt 3 // Buch',13,' - in MATLAB vorgeben:',13,'T=1; T1=10; T2=4; VS=1/St//PID']],[560,75;585,75])
add_line([sys,'/',['Beispiel 2 // Abschnitt 3 // Buch',13,' - in MATLAB vorgeben:',13,'T=1; T1=10; T2=4; VS=1/St//PID']],[565,75;565,120;175,120;185,80])


%     Finished composite block ['Beispiel 2 // Abschnitt 3 // Buch',13,' - in MATLAB vorgeben:',13,'T=1; T1=10; T2=4; VS=1/St//PID'].

set_param([sys,'/',['Beispiel 2 // Abschnitt 3 // Buch',13,' - in MATLAB vorgeben:',13,'T=1; T1=10; T2=4; VS=1/St//PID']],...
		'position',[170,270,200,320])

add_block('built-in/Mux',[sys,'/',['Beispiel 2 // Abschnitt 3 // Buch',13,' - in MATLAB vorgeben:',13,'T=1; T1=10; T2=4; VS=1/Multiplexer']])
set_param([sys,'/',['Beispiel 2 // Abschnitt 3 // Buch',13,' - in MATLAB vorgeben:',13,'T=1; T1=10; T2=4; VS=1/Multiplexer']],...
		'inputs','5',...
		'position',[535,61,595,149])

add_block('built-in/Transfer Fcn',[sys,'/',['Beispiel 2 // Abschnitt 3 // Buch',13,' - in MATLAB vorgeben:',13,'T=1; T1=10; T2=4; VS=1/PT1_2']])
set_param([sys,'/',['Beispiel 2 // Abschnitt 3 // Buch',13,' - in MATLAB vorgeben:',13,'T=1; T1=10; T2=4; VS=1/PT1_2']],...
		'Denominator','[T2 1]',...
		'position',[350,10,395,50])

add_block('built-in/Transfer Fcn',[sys,'/',['Beispiel 2 // Abschnitt 3 // Buch',13,' - in MATLAB vorgeben:',13,'T=1; T1=10; T2=4; VS=1/PT1_1']])
set_param([sys,'/',['Beispiel 2 // Abschnitt 3 // Buch',13,' - in MATLAB vorgeben:',13,'T=1; T1=10; T2=4; VS=1/PT1_1']],...
		'Denominator','[T1 1]',...
		'position',[265,9,315,51])
add_line([sys,'/',['Beispiel 2 // Abschnitt 3 // Buch',13,' - in MATLAB vorgeben:',13,'T=1; T1=10; T2=4; VS=1']],[600,105;610,105;610,50;535,50;535,20;550,20])
add_line([sys,'/',['Beispiel 2 // Abschnitt 3 // Buch',13,' - in MATLAB vorgeben:',13,'T=1; T1=10; T2=4; VS=1']],[65,30;75,30])
add_line([sys,'/',['Beispiel 2 // Abschnitt 3 // Buch',13,' - in MATLAB vorgeben:',13,'T=1; T1=10; T2=4; VS=1']],[400,30;500,30;500,75;530,75])
add_line([sys,'/',['Beispiel 2 // Abschnitt 3 // Buch',13,' - in MATLAB vorgeben:',13,'T=1; T1=10; T2=4; VS=1']],[320,30;345,30])
add_line([sys,'/',['Beispiel 2 // Abschnitt 3 // Buch',13,' - in MATLAB vorgeben:',13,'T=1; T1=10; T2=4; VS=1']],[115,30;260,30])
add_line([sys,'/',['Beispiel 2 // Abschnitt 3 // Buch',13,' - in MATLAB vorgeben:',13,'T=1; T1=10; T2=4; VS=1']],[130,30;130,90;165,90])
add_line([sys,'/',['Beispiel 2 // Abschnitt 3 // Buch',13,' - in MATLAB vorgeben:',13,'T=1; T1=10; T2=4; VS=1']],[205,90;530,90])
add_line([sys,'/',['Beispiel 2 // Abschnitt 3 // Buch',13,' - in MATLAB vorgeben:',13,'T=1; T1=10; T2=4; VS=1']],[205,155;270,155;270,105;530,105])
add_line([sys,'/',['Beispiel 2 // Abschnitt 3 // Buch',13,' - in MATLAB vorgeben:',13,'T=1; T1=10; T2=4; VS=1']],[205,225;295,225;295,120;530,120])
add_line([sys,'/',['Beispiel 2 // Abschnitt 3 // Buch',13,' - in MATLAB vorgeben:',13,'T=1; T1=10; T2=4; VS=1']],[205,295;320,295;320,135;530,135])
add_line([sys,'/',['Beispiel 2 // Abschnitt 3 // Buch',13,' - in MATLAB vorgeben:',13,'T=1; T1=10; T2=4; VS=1']],[130,90;130,155;165,155])
add_line([sys,'/',['Beispiel 2 // Abschnitt 3 // Buch',13,' - in MATLAB vorgeben:',13,'T=1; T1=10; T2=4; VS=1']],[130,155;130,225;165,225])
add_line([sys,'/',['Beispiel 2 // Abschnitt 3 // Buch',13,' - in MATLAB vorgeben:',13,'T=1; T1=10; T2=4; VS=1']],[130,225;130,295;165,295])


%     Finished composite block ['Beispiel 2 // Abschnitt 3 // Buch',13,' - in MATLAB vorgeben:',13,'T=1; T1=10; T2=4; VS=1'].

set_param([sys,'/',['Beispiel 2 // Abschnitt 3 // Buch',13,' - in MATLAB vorgeben:',13,'T=1; T1=10; T2=4; VS=1']],...
		'position',[255,125,285,175])


%     Subsystem  'Oszi'.

new_system([sys,'/','Oszi'])
set_param([sys,'/','Oszi'],'Location',[0,59,274,252])

add_block('built-in/Inport',[sys,'/','Oszi/x'])
set_param([sys,'/','Oszi/x'],...
		'position',[65,55,85,75])

add_block('built-in/S-Function',[sys,'/',['Oszi/S-function',13,'M-file which plots',13,'lines',13,'']])
set_param([sys,'/',['Oszi/S-function',13,'M-file which plots',13,'lines',13,'']],...
		'function name','sfuny',...
		'parameters','ax, color,dt',...
		'position',[130,55,180,75])
add_line([sys,'/','Oszi'],[90,65;125,65])
set_param([sys,'/','Oszi'],...
		'Mask Display','plot(0,0,100,100,[90,10,10,10,90,90,10],[65,65,90,40,40,90,90],[90,78,69,54,40,31,25,10],[77,60,48,46,56,75,81,84])',...
		'Mask Type','Graph scope.')
set_param([sys,'/','Oszi'],...
		'Mask Dialogue','Graph scope using MATLAB graph window.\nEnter plotting ranges and line type.|Time range:|y-min:|y-max:|Line type (rgbw-:*). Seperate each plot by ''/'':')
set_param([sys,'/','Oszi'],...
		'Mask Translate','color = @4; ax = [0, @1, @2, @3]; dt = -1;')
set_param([sys,'/','Oszi'],...
		'Mask Help','This block plots to the MATLAB graph window and can be used as an improved version of the Scope block. Look at the m-file sfuny.m to see how it works. This block can take scalar or vector input signal.')
set_param([sys,'/','Oszi'],...
		'Mask Entries','50\/-0.2\/1.2\/''k/b/r/m/g''\/')


%     Finished composite block 'Oszi'.

set_param([sys,'/','Oszi'],...
		'position',[485,131,515,169])


%     Subsystem  ['Beispiel 3 // Abschnitt 3 // Buch',13,' - inMATLAB vorgeben:',13,'T=1; T1=10; T2=4VS=1'].

new_system([sys,'/',['Beispiel 3 // Abschnitt 3 // Buch',13,' - inMATLAB vorgeben:',13,'T=1; T1=10; T2=4VS=1']])
set_param([sys,'/',['Beispiel 3 // Abschnitt 3 // Buch',13,' - inMATLAB vorgeben:',13,'T=1; T1=10; T2=4VS=1']],'Location',[4,42,628,468])

add_block('built-in/Outport',[sys,'/',['Beispiel 3 // Abschnitt 3 // Buch',13,' - inMATLAB vorgeben:',13,'T=1; T1=10; T2=4VS=1/out_1']])
set_param([sys,'/',['Beispiel 3 // Abschnitt 3 // Buch',13,' - inMATLAB vorgeben:',13,'T=1; T1=10; T2=4VS=1/out_1']],...
		'position',[555,10,575,30])

add_block('built-in/Inport',[sys,'/',['Beispiel 3 // Abschnitt 3 // Buch',13,' - inMATLAB vorgeben:',13,'T=1; T1=10; T2=4VS=1/in_1']])
set_param([sys,'/',['Beispiel 3 // Abschnitt 3 // Buch',13,' - inMATLAB vorgeben:',13,'T=1; T1=10; T2=4VS=1/in_1']],...
		'position',[40,20,60,40])

add_block('built-in/Gain',[sys,'/',['Beispiel 3 // Abschnitt 3 // Buch',13,' - inMATLAB vorgeben:',13,'T=1; T1=10; T2=4VS=1/Gain']])
set_param([sys,'/',['Beispiel 3 // Abschnitt 3 // Buch',13,' - inMATLAB vorgeben:',13,'T=1; T1=10; T2=4VS=1/Gain']],...
		'position',[80,15,110,45])


%     Subsystem  ['Beispiel 3 // Abschnitt 3 // Buch',13,' - inMATLAB vorgeben:',13,'T=1; T1=10; T2=4VS=1/Fh//PI'].

new_system([sys,'/',['Beispiel 3 // Abschnitt 3 // Buch',13,' - inMATLAB vorgeben:',13,'T=1; T1=10; T2=4VS=1/Fh//PI']])
set_param([sys,'/',['Beispiel 3 // Abschnitt 3 // Buch',13,' - inMATLAB vorgeben:',13,'T=1; T1=10; T2=4VS=1/Fh//PI']],'Location',[4,87,604,332])

add_block('built-in/Transfer Fcn',[sys,'/',['Beispiel 3 // Abschnitt 3 // Buch',13,' - inMATLAB vorgeben:',13,'T=1; T1=10; T2=4VS=1/Fh//PI/Int']])
set_param([sys,'/',['Beispiel 3 // Abschnitt 3 // Buch',13,' - inMATLAB vorgeben:',13,'T=1; T1=10; T2=4VS=1/Fh//PI/Int']],...
		'Denominator','[T 0]',...
		'position',[365,42,400,78])

add_block('built-in/Zero-Order Hold',[sys,'/',['Beispiel 3 // Abschnitt 3 // Buch',13,' - inMATLAB vorgeben:',13,'T=1; T1=10; T2=4VS=1/Fh//PI/ABT']])
set_param([sys,'/',['Beispiel 3 // Abschnitt 3 // Buch',13,' - inMATLAB vorgeben:',13,'T=1; T1=10; T2=4VS=1/Fh//PI/ABT']],...
		'Sample time','T',...
		'position',[415,44,450,76])

add_block('built-in/Filter',[sys,'/',['Beispiel 3 // Abschnitt 3 // Buch',13,' - inMATLAB vorgeben:',13,'T=1; T1=10; T2=4VS=1/Fh//PI/Diff.']])
set_param([sys,'/',['Beispiel 3 // Abschnitt 3 // Buch',13,' - inMATLAB vorgeben:',13,'T=1; T1=10; T2=4VS=1/Fh//PI/Diff.']],...
		'Numerator','[1 -1]',...
		'Denominator','[1]',...
		'Sample time','T',...
		'position',[465,41,525,79])

add_block('built-in/Outport',[sys,'/',['Beispiel 3 // Abschnitt 3 // Buch',13,' - inMATLAB vorgeben:',13,'T=1; T1=10; T2=4VS=1/Fh//PI/out_1']])
set_param([sys,'/',['Beispiel 3 // Abschnitt 3 // Buch',13,' - inMATLAB vorgeben:',13,'T=1; T1=10; T2=4VS=1/Fh//PI/out_1']],...
		'position',[550,50,570,70])

add_block('built-in/Sum',[sys,'/',['Beispiel 3 // Abschnitt 3 // Buch',13,' - inMATLAB vorgeben:',13,'T=1; T1=10; T2=4VS=1/Fh//PI/Sum']])
set_param([sys,'/',['Beispiel 3 // Abschnitt 3 // Buch',13,' - inMATLAB vorgeben:',13,'T=1; T1=10; T2=4VS=1/Fh//PI/Sum']],...
		'inputs','+-',...
		'position',[55,50,75,70])

add_block('built-in/Inport',[sys,'/',['Beispiel 3 // Abschnitt 3 // Buch',13,' - inMATLAB vorgeben:',13,'T=1; T1=10; T2=4VS=1/Fh//PI/in_1']])
set_param([sys,'/',['Beispiel 3 // Abschnitt 3 // Buch',13,' - inMATLAB vorgeben:',13,'T=1; T1=10; T2=4VS=1/Fh//PI/in_1']],...
		'position',[10,45,25,65])

add_block('built-in/Zero-Order Hold',[sys,'/',['Beispiel 3 // Abschnitt 3 // Buch',13,' - inMATLAB vorgeben:',13,'T=1; T1=10; T2=4VS=1/Fh//PI/Zero-Order',13,'Hold']])
set_param([sys,'/',['Beispiel 3 // Abschnitt 3 // Buch',13,' - inMATLAB vorgeben:',13,'T=1; T1=10; T2=4VS=1/Fh//PI/Zero-Order',13,'Hold']],...
		'Sample time','T',...
		'position',[95,44,130,76])

add_block('built-in/Filter',[sys,'/',['Beispiel 3 // Abschnitt 3 // Buch',13,' - inMATLAB vorgeben:',13,'T=1; T1=10; T2=4VS=1/Fh//PI/Regler: Formel 3.20']])
set_param([sys,'/',['Beispiel 3 // Abschnitt 3 // Buch',13,' - inMATLAB vorgeben:',13,'T=1; T1=10; T2=4VS=1/Fh//PI/Regler: Formel 3.20']],...
		'Numerator','[1.22 -1.1090]',...
		'Denominator','[1 -1]',...
		'Sample time','T')
set_param([sys,'/',['Beispiel 3 // Abschnitt 3 // Buch',13,' - inMATLAB vorgeben:',13,'T=1; T1=10; T2=4VS=1/Fh//PI/Regler: Formel 3.20']],...
		'position',[145,39,235,81])

add_block('built-in/Transfer Fcn',[sys,'/',['Beispiel 3 // Abschnitt 3 // Buch',13,' - inMATLAB vorgeben:',13,'T=1; T1=10; T2=4VS=1/Fh//PI/PT1_1']])
set_param([sys,'/',['Beispiel 3 // Abschnitt 3 // Buch',13,' - inMATLAB vorgeben:',13,'T=1; T1=10; T2=4VS=1/Fh//PI/PT1_1']],...
		'Numerator','[VS]',...
		'Denominator','[T1 1]',...
		'position',[250,40,290,80])

add_block('built-in/Transfer Fcn',[sys,'/',['Beispiel 3 // Abschnitt 3 // Buch',13,' - inMATLAB vorgeben:',13,'T=1; T1=10; T2=4VS=1/Fh//PI/PT1_2']])
set_param([sys,'/',['Beispiel 3 // Abschnitt 3 // Buch',13,' - inMATLAB vorgeben:',13,'T=1; T1=10; T2=4VS=1/Fh//PI/PT1_2']],...
		'Denominator','[T2 1]',...
		'position',[310,40,350,80])
add_line([sys,'/',['Beispiel 3 // Abschnitt 3 // Buch',13,' - inMATLAB vorgeben:',13,'T=1; T1=10; T2=4VS=1/Fh//PI']],[530,60;545,60])
add_line([sys,'/',['Beispiel 3 // Abschnitt 3 // Buch',13,' - inMATLAB vorgeben:',13,'T=1; T1=10; T2=4VS=1/Fh//PI']],[530,60;530,110;40,110;50,65])
add_line([sys,'/',['Beispiel 3 // Abschnitt 3 // Buch',13,' - inMATLAB vorgeben:',13,'T=1; T1=10; T2=4VS=1/Fh//PI']],[240,60;245,60])
add_line([sys,'/',['Beispiel 3 // Abschnitt 3 // Buch',13,' - inMATLAB vorgeben:',13,'T=1; T1=10; T2=4VS=1/Fh//PI']],[405,60;410,60])
add_line([sys,'/',['Beispiel 3 // Abschnitt 3 // Buch',13,' - inMATLAB vorgeben:',13,'T=1; T1=10; T2=4VS=1/Fh//PI']],[455,60;460,60])
add_line([sys,'/',['Beispiel 3 // Abschnitt 3 // Buch',13,' - inMATLAB vorgeben:',13,'T=1; T1=10; T2=4VS=1/Fh//PI']],[295,60;305,60])
add_line([sys,'/',['Beispiel 3 // Abschnitt 3 // Buch',13,' - inMATLAB vorgeben:',13,'T=1; T1=10; T2=4VS=1/Fh//PI']],[355,60;360,60])
add_line([sys,'/',['Beispiel 3 // Abschnitt 3 // Buch',13,' - inMATLAB vorgeben:',13,'T=1; T1=10; T2=4VS=1/Fh//PI']],[135,60;140,60])
add_line([sys,'/',['Beispiel 3 // Abschnitt 3 // Buch',13,' - inMATLAB vorgeben:',13,'T=1; T1=10; T2=4VS=1/Fh//PI']],[80,60;90,60])
add_line([sys,'/',['Beispiel 3 // Abschnitt 3 // Buch',13,' - inMATLAB vorgeben:',13,'T=1; T1=10; T2=4VS=1/Fh//PI']],[30,55;50,55])


%     Finished composite block ['Beispiel 3 // Abschnitt 3 // Buch',13,' - inMATLAB vorgeben:',13,'T=1; T1=10; T2=4VS=1/Fh//PI'].

set_param([sys,'/',['Beispiel 3 // Abschnitt 3 // Buch',13,' - inMATLAB vorgeben:',13,'T=1; T1=10; T2=4VS=1/Fh//PI']],...
		'position',[245,70,275,120])


%     Subsystem  ['Beispiel 3 // Abschnitt 3 // Buch',13,' - inMATLAB vorgeben:',13,'T=1; T1=10; T2=4VS=1/Fh//PID'].

new_system([sys,'/',['Beispiel 3 // Abschnitt 3 // Buch',13,' - inMATLAB vorgeben:',13,'T=1; T1=10; T2=4VS=1/Fh//PID']])
set_param([sys,'/',['Beispiel 3 // Abschnitt 3 // Buch',13,' - inMATLAB vorgeben:',13,'T=1; T1=10; T2=4VS=1/Fh//PID']],'Location',[4,167,604,340])

add_block('built-in/Filter',[sys,'/',['Beispiel 3 // Abschnitt 3 // Buch',13,' - inMATLAB vorgeben:',13,'T=1; T1=10; T2=4VS=1/Fh//PID/Regler: Formel 3.20']])
set_param([sys,'/',['Beispiel 3 // Abschnitt 3 // Buch',13,' - inMATLAB vorgeben:',13,'T=1; T1=10; T2=4VS=1/Fh//PID/Regler: Formel 3.20']],...
		'Numerator','[16.68 -28.1125 11.7811]',...
		'Denominator','[1 -1]',...
		'Sample time','T')
set_param([sys,'/',['Beispiel 3 // Abschnitt 3 // Buch',13,' - inMATLAB vorgeben:',13,'T=1; T1=10; T2=4VS=1/Fh//PID/Regler: Formel 3.20']],...
		'position',[130,45,280,85])

add_block('built-in/Inport',[sys,'/',['Beispiel 3 // Abschnitt 3 // Buch',13,' - inMATLAB vorgeben:',13,'T=1; T1=10; T2=4VS=1/Fh//PID/in_1']])
set_param([sys,'/',['Beispiel 3 // Abschnitt 3 // Buch',13,' - inMATLAB vorgeben:',13,'T=1; T1=10; T2=4VS=1/Fh//PID/in_1']],...
		'orientation',2,...
		'position',[15,15,30,35])

add_block('built-in/Sum',[sys,'/',['Beispiel 3 // Abschnitt 3 // Buch',13,' - inMATLAB vorgeben:',13,'T=1; T1=10; T2=4VS=1/Fh//PID/Sum1']])
set_param([sys,'/',['Beispiel 3 // Abschnitt 3 // Buch',13,' - inMATLAB vorgeben:',13,'T=1; T1=10; T2=4VS=1/Fh//PID/Sum1']],...
		'inputs','+-',...
		'position',[25,55,45,75])

add_block('built-in/Filter',[sys,'/',['Beispiel 3 // Abschnitt 3 // Buch',13,' - inMATLAB vorgeben:',13,'T=1; T1=10; T2=4VS=1/Fh//PID/Diff.1']])
set_param([sys,'/',['Beispiel 3 // Abschnitt 3 // Buch',13,' - inMATLAB vorgeben:',13,'T=1; T1=10; T2=4VS=1/Fh//PID/Diff.1']],...
		'Numerator','[1 -1]',...
		'Denominator','[1]',...
		'Sample time','T',...
		'position',[515,46,575,84])

add_block('built-in/Outport',[sys,'/',['Beispiel 3 // Abschnitt 3 // Buch',13,' - inMATLAB vorgeben:',13,'T=1; T1=10; T2=4VS=1/Fh//PID/out_1']])
set_param([sys,'/',['Beispiel 3 // Abschnitt 3 // Buch',13,' - inMATLAB vorgeben:',13,'T=1; T1=10; T2=4VS=1/Fh//PID/out_1']],...
		'orientation',2,...
		'position',[540,5,560,25])

add_block('built-in/Zero-Order Hold',[sys,'/',['Beispiel 3 // Abschnitt 3 // Buch',13,' - inMATLAB vorgeben:',13,'T=1; T1=10; T2=4VS=1/Fh//PID/Zero-Order',13,'Hold1']])
set_param([sys,'/',['Beispiel 3 // Abschnitt 3 // Buch',13,' - inMATLAB vorgeben:',13,'T=1; T1=10; T2=4VS=1/Fh//PID/Zero-Order',13,'Hold1']],...
		'Sample time','T',...
		'position',[65,49,100,81])

add_block('built-in/Zero-Order Hold',[sys,'/',['Beispiel 3 // Abschnitt 3 // Buch',13,' - inMATLAB vorgeben:',13,'T=1; T1=10; T2=4VS=1/Fh//PID/ABT1']])
set_param([sys,'/',['Beispiel 3 // Abschnitt 3 // Buch',13,' - inMATLAB vorgeben:',13,'T=1; T1=10; T2=4VS=1/Fh//PID/ABT1']],...
		'Sample time','T',...
		'position',[465,49,500,81])

add_block('built-in/Transfer Fcn',[sys,'/',['Beispiel 3 // Abschnitt 3 // Buch',13,' - inMATLAB vorgeben:',13,'T=1; T1=10; T2=4VS=1/Fh//PID/Int1']])
set_param([sys,'/',['Beispiel 3 // Abschnitt 3 // Buch',13,' - inMATLAB vorgeben:',13,'T=1; T1=10; T2=4VS=1/Fh//PID/Int1']],...
		'Denominator','[T 0]',...
		'position',[415,47,450,83])

add_block('built-in/Transfer Fcn',[sys,'/',['Beispiel 3 // Abschnitt 3 // Buch',13,' - inMATLAB vorgeben:',13,'T=1; T1=10; T2=4VS=1/Fh//PID/PT1_2']])
set_param([sys,'/',['Beispiel 3 // Abschnitt 3 // Buch',13,' - inMATLAB vorgeben:',13,'T=1; T1=10; T2=4VS=1/Fh//PID/PT1_2']],...
		'Denominator','[T2 1]',...
		'position',[360,45,400,85])

add_block('built-in/Transfer Fcn',[sys,'/',['Beispiel 3 // Abschnitt 3 // Buch',13,' - inMATLAB vorgeben:',13,'T=1; T1=10; T2=4VS=1/Fh//PID/PT1_1']])
set_param([sys,'/',['Beispiel 3 // Abschnitt 3 // Buch',13,' - inMATLAB vorgeben:',13,'T=1; T1=10; T2=4VS=1/Fh//PID/PT1_1']],...
		'Numerator','[VS]',...
		'Denominator','[T1 1]',...
		'position',[305,45,345,85])
add_line([sys,'/',['Beispiel 3 // Abschnitt 3 // Buch',13,' - inMATLAB vorgeben:',13,'T=1; T1=10; T2=4VS=1/Fh//PID']],[455,65;460,65])
add_line([sys,'/',['Beispiel 3 // Abschnitt 3 // Buch',13,' - inMATLAB vorgeben:',13,'T=1; T1=10; T2=4VS=1/Fh//PID']],[505,65;510,65])
add_line([sys,'/',['Beispiel 3 // Abschnitt 3 // Buch',13,' - inMATLAB vorgeben:',13,'T=1; T1=10; T2=4VS=1/Fh//PID']],[350,65;355,65])
add_line([sys,'/',['Beispiel 3 // Abschnitt 3 // Buch',13,' - inMATLAB vorgeben:',13,'T=1; T1=10; T2=4VS=1/Fh//PID']],[405,65;410,65])
add_line([sys,'/',['Beispiel 3 // Abschnitt 3 // Buch',13,' - inMATLAB vorgeben:',13,'T=1; T1=10; T2=4VS=1/Fh//PID']],[285,65;300,65])
add_line([sys,'/',['Beispiel 3 // Abschnitt 3 // Buch',13,' - inMATLAB vorgeben:',13,'T=1; T1=10; T2=4VS=1/Fh//PID']],[105,65;125,65])
add_line([sys,'/',['Beispiel 3 // Abschnitt 3 // Buch',13,' - inMATLAB vorgeben:',13,'T=1; T1=10; T2=4VS=1/Fh//PID']],[50,65;60,65])
add_line([sys,'/',['Beispiel 3 // Abschnitt 3 // Buch',13,' - inMATLAB vorgeben:',13,'T=1; T1=10; T2=4VS=1/Fh//PID']],[10,25;20,60])
add_line([sys,'/',['Beispiel 3 // Abschnitt 3 // Buch',13,' - inMATLAB vorgeben:',13,'T=1; T1=10; T2=4VS=1/Fh//PID']],[580,65;590,65;590,15;565,15])
add_line([sys,'/',['Beispiel 3 // Abschnitt 3 // Buch',13,' - inMATLAB vorgeben:',13,'T=1; T1=10; T2=4VS=1/Fh//PID']],[590,65;590,105;10,105;20,70])


%     Finished composite block ['Beispiel 3 // Abschnitt 3 // Buch',13,' - inMATLAB vorgeben:',13,'T=1; T1=10; T2=4VS=1/Fh//PID'].

set_param([sys,'/',['Beispiel 3 // Abschnitt 3 // Buch',13,' - inMATLAB vorgeben:',13,'T=1; T1=10; T2=4VS=1/Fh//PID']],...
		'position',[245,140,275,190])


%     Subsystem  ['Beispiel 3 // Abschnitt 3 // Buch',13,' - inMATLAB vorgeben:',13,'T=1; T1=10; T2=4VS=1/St//PI'].

new_system([sys,'/',['Beispiel 3 // Abschnitt 3 // Buch',13,' - inMATLAB vorgeben:',13,'T=1; T1=10; T2=4VS=1/St//PI']])
set_param([sys,'/',['Beispiel 3 // Abschnitt 3 // Buch',13,' - inMATLAB vorgeben:',13,'T=1; T1=10; T2=4VS=1/St//PI']],'Location',[4,90,628,292])

add_block('built-in/Outport',[sys,'/',['Beispiel 3 // Abschnitt 3 // Buch',13,' - inMATLAB vorgeben:',13,'T=1; T1=10; T2=4VS=1/St//PI/out_1']])
set_param([sys,'/',['Beispiel 3 // Abschnitt 3 // Buch',13,' - inMATLAB vorgeben:',13,'T=1; T1=10; T2=4VS=1/St//PI/out_1']],...
		'position',[600,30,620,50])

add_block('built-in/Filter',[sys,'/',['Beispiel 3 // Abschnitt 3 // Buch',13,' - inMATLAB vorgeben:',13,'T=1; T1=10; T2=4VS=1/St//PI/Filter4']])
set_param([sys,'/',['Beispiel 3 // Abschnitt 3 // Buch',13,' - inMATLAB vorgeben:',13,'T=1; T1=10; T2=4VS=1/St//PI/Filter4']],...
		'Numerator','0.1259',...
		'Denominator','[1 -0.8741]',...
		'position',[50,7,115,43])

add_block('built-in/Sum',[sys,'/',['Beispiel 3 // Abschnitt 3 // Buch',13,' - inMATLAB vorgeben:',13,'T=1; T1=10; T2=4VS=1/St//PI/Sum2']])
set_param([sys,'/',['Beispiel 3 // Abschnitt 3 // Buch',13,' - inMATLAB vorgeben:',13,'T=1; T1=10; T2=4VS=1/St//PI/Sum2']],...
		'inputs','+-',...
		'position',[30,95,50,115])

add_block('built-in/Inport',[sys,'/',['Beispiel 3 // Abschnitt 3 // Buch',13,' - inMATLAB vorgeben:',13,'T=1; T1=10; T2=4VS=1/St//PI/in_1']])
set_param([sys,'/',['Beispiel 3 // Abschnitt 3 // Buch',13,' - inMATLAB vorgeben:',13,'T=1; T1=10; T2=4VS=1/St//PI/in_1']],...
		'position',[15,15,30,35])

add_block('built-in/Filter',[sys,'/',['Beispiel 3 // Abschnitt 3 // Buch',13,' - inMATLAB vorgeben:',13,'T=1; T1=10; T2=4VS=1/St//PI/Diff.2']])
set_param([sys,'/',['Beispiel 3 // Abschnitt 3 // Buch',13,' - inMATLAB vorgeben:',13,'T=1; T1=10; T2=4VS=1/St//PI/Diff.2']],...
		'Numerator','[1 -1]',...
		'Denominator','[1]',...
		'Sample time','T',...
		'position',[495,86,555,124])

add_block('built-in/Zero-Order Hold',[sys,'/',['Beispiel 3 // Abschnitt 3 // Buch',13,' - inMATLAB vorgeben:',13,'T=1; T1=10; T2=4VS=1/St//PI/ABT2']])
set_param([sys,'/',['Beispiel 3 // Abschnitt 3 // Buch',13,' - inMATLAB vorgeben:',13,'T=1; T1=10; T2=4VS=1/St//PI/ABT2']],...
		'Sample time','T',...
		'position',[445,89,480,121])

add_block('built-in/Zero-Order Hold',[sys,'/',['Beispiel 3 // Abschnitt 3 // Buch',13,' - inMATLAB vorgeben:',13,'T=1; T1=10; T2=4VS=1/St//PI/Zero-Order',13,'Hold2']])
set_param([sys,'/',['Beispiel 3 // Abschnitt 3 // Buch',13,' - inMATLAB vorgeben:',13,'T=1; T1=10; T2=4VS=1/St//PI/Zero-Order',13,'Hold2']],...
		'Sample time','T',...
		'position',[75,89,110,121])

add_block('built-in/Filter',[sys,'/',['Beispiel 3 // Abschnitt 3 // Buch',13,' - inMATLAB vorgeben:',13,'T=1; T1=10; T2=4VS=1/St//PI/Regler: Formel 3.25727']])
set_param([sys,'/',['Beispiel 3 // Abschnitt 3 // Buch',13,' - inMATLAB vorgeben:',13,'T=1; T1=10; T2=4VS=1/St//PI/Regler: Formel 3.25727']],...
		'Numerator','[1.29 -1.1276]',...
		'Denominator','[1 -1]',...
		'Sample time','T')
set_param([sys,'/',['Beispiel 3 // Abschnitt 3 // Buch',13,' - inMATLAB vorgeben:',13,'T=1; T1=10; T2=4VS=1/St//PI/Regler: Formel 3.25727']],...
		'position',[145,85,235,125])

add_block('built-in/Transfer Fcn',[sys,'/',['Beispiel 3 // Abschnitt 3 // Buch',13,' - inMATLAB vorgeben:',13,'T=1; T1=10; T2=4VS=1/St//PI/PT1_1']])
set_param([sys,'/',['Beispiel 3 // Abschnitt 3 // Buch',13,' - inMATLAB vorgeben:',13,'T=1; T1=10; T2=4VS=1/St//PI/PT1_1']],...
		'Numerator','[VS]',...
		'Denominator','[T1 1]',...
		'position',[255,87,300,123])

add_block('built-in/Transfer Fcn',[sys,'/',['Beispiel 3 // Abschnitt 3 // Buch',13,' - inMATLAB vorgeben:',13,'T=1; T1=10; T2=4VS=1/St//PI/PT1_2']])
set_param([sys,'/',['Beispiel 3 // Abschnitt 3 // Buch',13,' - inMATLAB vorgeben:',13,'T=1; T1=10; T2=4VS=1/St//PI/PT1_2']],...
		'Denominator','[T2 1]',...
		'position',[325,88,370,122])

add_block('built-in/Transfer Fcn',[sys,'/',['Beispiel 3 // Abschnitt 3 // Buch',13,' - inMATLAB vorgeben:',13,'T=1; T1=10; T2=4VS=1/St//PI/Int2']])
set_param([sys,'/',['Beispiel 3 // Abschnitt 3 // Buch',13,' - inMATLAB vorgeben:',13,'T=1; T1=10; T2=4VS=1/St//PI/Int2']],...
		'Denominator','[T 0]',...
		'position',[390,87,425,123])
add_line([sys,'/',['Beispiel 3 // Abschnitt 3 // Buch',13,' - inMATLAB vorgeben:',13,'T=1; T1=10; T2=4VS=1/St//PI']],[560,105;570,105;570,150;15,150;25,110])
add_line([sys,'/',['Beispiel 3 // Abschnitt 3 // Buch',13,' - inMATLAB vorgeben:',13,'T=1; T1=10; T2=4VS=1/St//PI']],[430,105;440,105])
add_line([sys,'/',['Beispiel 3 // Abschnitt 3 // Buch',13,' - inMATLAB vorgeben:',13,'T=1; T1=10; T2=4VS=1/St//PI']],[485,105;490,105])
add_line([sys,'/',['Beispiel 3 // Abschnitt 3 // Buch',13,' - inMATLAB vorgeben:',13,'T=1; T1=10; T2=4VS=1/St//PI']],[305,105;320,105])
add_line([sys,'/',['Beispiel 3 // Abschnitt 3 // Buch',13,' - inMATLAB vorgeben:',13,'T=1; T1=10; T2=4VS=1/St//PI']],[375,105;385,105])
add_line([sys,'/',['Beispiel 3 // Abschnitt 3 // Buch',13,' - inMATLAB vorgeben:',13,'T=1; T1=10; T2=4VS=1/St//PI']],[240,105;250,105])
add_line([sys,'/',['Beispiel 3 // Abschnitt 3 // Buch',13,' - inMATLAB vorgeben:',13,'T=1; T1=10; T2=4VS=1/St//PI']],[115,105;140,105])
add_line([sys,'/',['Beispiel 3 // Abschnitt 3 // Buch',13,' - inMATLAB vorgeben:',13,'T=1; T1=10; T2=4VS=1/St//PI']],[55,105;70,105])
add_line([sys,'/',['Beispiel 3 // Abschnitt 3 // Buch',13,' - inMATLAB vorgeben:',13,'T=1; T1=10; T2=4VS=1/St//PI']],[35,25;45,25])
add_line([sys,'/',['Beispiel 3 // Abschnitt 3 // Buch',13,' - inMATLAB vorgeben:',13,'T=1; T1=10; T2=4VS=1/St//PI']],[120,25;175,25;175,65;15,65;25,100])
add_line([sys,'/',['Beispiel 3 // Abschnitt 3 // Buch',13,' - inMATLAB vorgeben:',13,'T=1; T1=10; T2=4VS=1/St//PI']],[570,105;570,40;595,40])


%     Finished composite block ['Beispiel 3 // Abschnitt 3 // Buch',13,' - inMATLAB vorgeben:',13,'T=1; T1=10; T2=4VS=1/St//PI'].

set_param([sys,'/',['Beispiel 3 // Abschnitt 3 // Buch',13,' - inMATLAB vorgeben:',13,'T=1; T1=10; T2=4VS=1/St//PI']],...
		'position',[245,210,275,260])


%     Subsystem  ['Beispiel 3 // Abschnitt 3 // Buch',13,' - inMATLAB vorgeben:',13,'T=1; T1=10; T2=4VS=1/St//PID'].

new_system([sys,'/',['Beispiel 3 // Abschnitt 3 // Buch',13,' - inMATLAB vorgeben:',13,'T=1; T1=10; T2=4VS=1/St//PID']])
set_param([sys,'/',['Beispiel 3 // Abschnitt 3 // Buch',13,' - inMATLAB vorgeben:',13,'T=1; T1=10; T2=4VS=1/St//PID']],'Location',[4,194,628,404])

add_block('built-in/Transfer Fcn',[sys,'/',['Beispiel 3 // Abschnitt 3 // Buch',13,' - inMATLAB vorgeben:',13,'T=1; T1=10; T2=4VS=1/St//PID/PT1_1']])
set_param([sys,'/',['Beispiel 3 // Abschnitt 3 // Buch',13,' - inMATLAB vorgeben:',13,'T=1; T1=10; T2=4VS=1/St//PID/PT1_1']],...
		'Numerator','[VS]',...
		'Denominator','[T1 1]',...
		'position',[295,93,340,127])

add_block('built-in/Transfer Fcn',[sys,'/',['Beispiel 3 // Abschnitt 3 // Buch',13,' - inMATLAB vorgeben:',13,'T=1; T1=10; T2=4VS=1/St//PID/PT1_2']])
set_param([sys,'/',['Beispiel 3 // Abschnitt 3 // Buch',13,' - inMATLAB vorgeben:',13,'T=1; T1=10; T2=4VS=1/St//PID/PT1_2']],...
		'Denominator','[T2 1]',...
		'position',[355,93,400,127])

add_block('built-in/Sum',[sys,'/',['Beispiel 3 // Abschnitt 3 // Buch',13,' - inMATLAB vorgeben:',13,'T=1; T1=10; T2=4VS=1/St//PID/Sum3']])
set_param([sys,'/',['Beispiel 3 // Abschnitt 3 // Buch',13,' - inMATLAB vorgeben:',13,'T=1; T1=10; T2=4VS=1/St//PID/Sum3']],...
		'inputs','+-',...
		'position',[35,100,55,120])

add_block('built-in/Filter',[sys,'/',['Beispiel 3 // Abschnitt 3 // Buch',13,' - inMATLAB vorgeben:',13,'T=1; T1=10; T2=4VS=1/St//PID/Filter5']])
set_param([sys,'/',['Beispiel 3 // Abschnitt 3 // Buch',13,' - inMATLAB vorgeben:',13,'T=1; T1=10; T2=4VS=1/St//PID/Filter5']],...
		'Numerator','0.0751',...
		'Denominator','[1 -1.4964 0.5715]',...
		'Sample time','T')
set_param([sys,'/',['Beispiel 3 // Abschnitt 3 // Buch',13,' - inMATLAB vorgeben:',13,'T=1; T1=10; T2=4VS=1/St//PID/Filter5']],...
		'position',[85,4,205,46])

add_block('built-in/Inport',[sys,'/',['Beispiel 3 // Abschnitt 3 // Buch',13,' - inMATLAB vorgeben:',13,'T=1; T1=10; T2=4VS=1/St//PID/in_1']])
set_param([sys,'/',['Beispiel 3 // Abschnitt 3 // Buch',13,' - inMATLAB vorgeben:',13,'T=1; T1=10; T2=4VS=1/St//PID/in_1']],...
		'position',[35,15,55,35])

add_block('built-in/Zero-Order Hold',[sys,'/',['Beispiel 3 // Abschnitt 3 // Buch',13,' - inMATLAB vorgeben:',13,'T=1; T1=10; T2=4VS=1/St//PID/Zero-Order',13,'Hold3']])
set_param([sys,'/',['Beispiel 3 // Abschnitt 3 // Buch',13,' - inMATLAB vorgeben:',13,'T=1; T1=10; T2=4VS=1/St//PID/Zero-Order',13,'Hold3']],...
		'Sample time','T',...
		'position',[75,94,110,126])

add_block('built-in/Outport',[sys,'/',['Beispiel 3 // Abschnitt 3 // Buch',13,' - inMATLAB vorgeben:',13,'T=1; T1=10; T2=4VS=1/St//PID/out_1']])
set_param([sys,'/',['Beispiel 3 // Abschnitt 3 // Buch',13,' - inMATLAB vorgeben:',13,'T=1; T1=10; T2=4VS=1/St//PID/out_1']],...
		'orientation',2,...
		'position',[545,30,565,50])

add_block('built-in/Filter',[sys,'/',['Beispiel 3 // Abschnitt 3 // Buch',13,' - inMATLAB vorgeben:',13,'T=1; T1=10; T2=4VS=1/St//PID/Filter3']])
set_param([sys,'/',['Beispiel 3 // Abschnitt 3 // Buch',13,' - inMATLAB vorgeben:',13,'T=1; T1=10; T2=4VS=1/St//PID/Filter3']],...
		'Numerator','[21.69 -32.4569 12.3985]',...
		'Denominator','[1 -1]',...
		'Sample time','T')
set_param([sys,'/',['Beispiel 3 // Abschnitt 3 // Buch',13,' - inMATLAB vorgeben:',13,'T=1; T1=10; T2=4VS=1/St//PID/Filter3']],...
		'position',[125,89,280,131])

add_block('built-in/Filter',[sys,'/',['Beispiel 3 // Abschnitt 3 // Buch',13,' - inMATLAB vorgeben:',13,'T=1; T1=10; T2=4VS=1/St//PID/Diff.3']])
set_param([sys,'/',['Beispiel 3 // Abschnitt 3 // Buch',13,' - inMATLAB vorgeben:',13,'T=1; T1=10; T2=4VS=1/St//PID/Diff.3']],...
		'Numerator','[1 -1]',...
		'Denominator','[1]',...
		'Sample time','T',...
		'position',[515,91,575,129])

add_block('built-in/Zero-Order Hold',[sys,'/',['Beispiel 3 // Abschnitt 3 // Buch',13,' - inMATLAB vorgeben:',13,'T=1; T1=10; T2=4VS=1/St//PID/ABT3']])
set_param([sys,'/',['Beispiel 3 // Abschnitt 3 // Buch',13,' - inMATLAB vorgeben:',13,'T=1; T1=10; T2=4VS=1/St//PID/ABT3']],...
		'Sample time','T',...
		'position',[465,94,500,126])

add_block('built-in/Transfer Fcn',[sys,'/',['Beispiel 3 // Abschnitt 3 // Buch',13,' - inMATLAB vorgeben:',13,'T=1; T1=10; T2=4VS=1/St//PID/Int3']])
set_param([sys,'/',['Beispiel 3 // Abschnitt 3 // Buch',13,' - inMATLAB vorgeben:',13,'T=1; T1=10; T2=4VS=1/St//PID/Int3']],...
		'Denominator','[T 0]',...
		'position',[415,92,450,128])
add_line([sys,'/',['Beispiel 3 // Abschnitt 3 // Buch',13,' - inMATLAB vorgeben:',13,'T=1; T1=10; T2=4VS=1/St//PID']],[455,110;460,110])
add_line([sys,'/',['Beispiel 3 // Abschnitt 3 // Buch',13,' - inMATLAB vorgeben:',13,'T=1; T1=10; T2=4VS=1/St//PID']],[505,110;510,110])
add_line([sys,'/',['Beispiel 3 // Abschnitt 3 // Buch',13,' - inMATLAB vorgeben:',13,'T=1; T1=10; T2=4VS=1/St//PID']],[345,110;350,110])
add_line([sys,'/',['Beispiel 3 // Abschnitt 3 // Buch',13,' - inMATLAB vorgeben:',13,'T=1; T1=10; T2=4VS=1/St//PID']],[405,110;410,110])
add_line([sys,'/',['Beispiel 3 // Abschnitt 3 // Buch',13,' - inMATLAB vorgeben:',13,'T=1; T1=10; T2=4VS=1/St//PID']],[285,110;290,110])
add_line([sys,'/',['Beispiel 3 // Abschnitt 3 // Buch',13,' - inMATLAB vorgeben:',13,'T=1; T1=10; T2=4VS=1/St//PID']],[115,110;120,110])
add_line([sys,'/',['Beispiel 3 // Abschnitt 3 // Buch',13,' - inMATLAB vorgeben:',13,'T=1; T1=10; T2=4VS=1/St//PID']],[60,110;70,110])
add_line([sys,'/',['Beispiel 3 // Abschnitt 3 // Buch',13,' - inMATLAB vorgeben:',13,'T=1; T1=10; T2=4VS=1/St//PID']],[60,25;80,25])
add_line([sys,'/',['Beispiel 3 // Abschnitt 3 // Buch',13,' - inMATLAB vorgeben:',13,'T=1; T1=10; T2=4VS=1/St//PID']],[210,25;230,25;230,75;20,75;30,105])
add_line([sys,'/',['Beispiel 3 // Abschnitt 3 // Buch',13,' - inMATLAB vorgeben:',13,'T=1; T1=10; T2=4VS=1/St//PID']],[580,110;590,110;590,155;20,155;30,115])
add_line([sys,'/',['Beispiel 3 // Abschnitt 3 // Buch',13,' - inMATLAB vorgeben:',13,'T=1; T1=10; T2=4VS=1/St//PID']],[590,110;590,40;570,40])


%     Finished composite block ['Beispiel 3 // Abschnitt 3 // Buch',13,' - inMATLAB vorgeben:',13,'T=1; T1=10; T2=4VS=1/St//PID'].

set_param([sys,'/',['Beispiel 3 // Abschnitt 3 // Buch',13,' - inMATLAB vorgeben:',13,'T=1; T1=10; T2=4VS=1/St//PID']],...
		'position',[245,285,275,335])

add_block('built-in/Mux',[sys,'/',['Beispiel 3 // Abschnitt 3 // Buch',13,' - inMATLAB vorgeben:',13,'T=1; T1=10; T2=4VS=1/Mux']])
set_param([sys,'/',['Beispiel 3 // Abschnitt 3 // Buch',13,' - inMATLAB vorgeben:',13,'T=1; T1=10; T2=4VS=1/Mux']],...
		'inputs','5',...
		'position',[520,68,555,162])

add_block('built-in/Transfer Fcn',[sys,'/',['Beispiel 3 // Abschnitt 3 // Buch',13,' - inMATLAB vorgeben:',13,'T=1; T1=10; T2=4VS=1/PT2.0']])
set_param([sys,'/',['Beispiel 3 // Abschnitt 3 // Buch',13,' - inMATLAB vorgeben:',13,'T=1; T1=10; T2=4VS=1/PT2.0']],...
		'Denominator','[T2 1]',...
		'position',[315,10,360,50])

add_block('built-in/Transfer Fcn',[sys,'/',['Beispiel 3 // Abschnitt 3 // Buch',13,' - inMATLAB vorgeben:',13,'T=1; T1=10; T2=4VS=1/PT1.0']])
set_param([sys,'/',['Beispiel 3 // Abschnitt 3 // Buch',13,' - inMATLAB vorgeben:',13,'T=1; T1=10; T2=4VS=1/PT1.0']],...
		'Numerator','[VS]',...
		'Denominator','[T1 1]',...
		'position',[240,10,285,50])
add_line([sys,'/',['Beispiel 3 // Abschnitt 3 // Buch',13,' - inMATLAB vorgeben:',13,'T=1; T1=10; T2=4VS=1']],[560,115;580,115;580,50;535,50;535,20;550,20])
add_line([sys,'/',['Beispiel 3 // Abschnitt 3 // Buch',13,' - inMATLAB vorgeben:',13,'T=1; T1=10; T2=4VS=1']],[65,30;75,30])
add_line([sys,'/',['Beispiel 3 // Abschnitt 3 // Buch',13,' - inMATLAB vorgeben:',13,'T=1; T1=10; T2=4VS=1']],[365,30;500,30;500,75;515,75])
add_line([sys,'/',['Beispiel 3 // Abschnitt 3 // Buch',13,' - inMATLAB vorgeben:',13,'T=1; T1=10; T2=4VS=1']],[290,30;310,30])
add_line([sys,'/',['Beispiel 3 // Abschnitt 3 // Buch',13,' - inMATLAB vorgeben:',13,'T=1; T1=10; T2=4VS=1']],[115,30;235,30])
add_line([sys,'/',['Beispiel 3 // Abschnitt 3 // Buch',13,' - inMATLAB vorgeben:',13,'T=1; T1=10; T2=4VS=1']],[130,30;130,95;240,95])
add_line([sys,'/',['Beispiel 3 // Abschnitt 3 // Buch',13,' - inMATLAB vorgeben:',13,'T=1; T1=10; T2=4VS=1']],[280,95;515,95])
add_line([sys,'/',['Beispiel 3 // Abschnitt 3 // Buch',13,' - inMATLAB vorgeben:',13,'T=1; T1=10; T2=4VS=1']],[280,165;315,165;315,115;515,115])
add_line([sys,'/',['Beispiel 3 // Abschnitt 3 // Buch',13,' - inMATLAB vorgeben:',13,'T=1; T1=10; T2=4VS=1']],[280,235;335,235;335,135;515,135])
add_line([sys,'/',['Beispiel 3 // Abschnitt 3 // Buch',13,' - inMATLAB vorgeben:',13,'T=1; T1=10; T2=4VS=1']],[280,310;365,310;365,155;515,155])
add_line([sys,'/',['Beispiel 3 // Abschnitt 3 // Buch',13,' - inMATLAB vorgeben:',13,'T=1; T1=10; T2=4VS=1']],[130,95;130,165;240,165])
add_line([sys,'/',['Beispiel 3 // Abschnitt 3 // Buch',13,' - inMATLAB vorgeben:',13,'T=1; T1=10; T2=4VS=1']],[130,165;130,235;240,235])
add_line([sys,'/',['Beispiel 3 // Abschnitt 3 // Buch',13,' - inMATLAB vorgeben:',13,'T=1; T1=10; T2=4VS=1']],[130,235;130,310;240,310])


%     Finished composite block ['Beispiel 3 // Abschnitt 3 // Buch',13,' - inMATLAB vorgeben:',13,'T=1; T1=10; T2=4VS=1'].

set_param([sys,'/',['Beispiel 3 // Abschnitt 3 // Buch',13,' - inMATLAB vorgeben:',13,'T=1; T1=10; T2=4VS=1']],...
		'position',[255,215,285,265])

add_block('built-in/To Workspace',[sys,'/','Speicherung in MATLAB'])
set_param([sys,'/','Speicherung in MATLAB'],...
		'mat-name','MessMatr',...
		'position',[460,47,510,63])
add_line(sys,[50,310;50,55;250,55])
add_line(sys,[50,150;240,150;250,150])
add_line(sys,[50,240;240,240;250,240])
add_line(sys,[290,240;395,240;395,150;480,150])
add_line(sys,[395,150;395,55;455,55])

drawnow

% Return any arguments.
if (nargin | nargout)
	% Must use feval here to access system in memory
	if (nargin > 3)
		if (flag == 0)
			eval(['[ret,x0,str,ts,xts]=',sys,'(t,x,u,flag);'])
		else
			eval(['ret =', sys,'(t,x,u,flag);'])
		end
	else
		[ret,x0,str,ts,xts] = feval(sys);
	end
else
	drawnow % Flash up the model and execute load callback
end
