function [ret,x0,str,ts,xts]=sist021(t,x,u,flag);
%SIST021	is the M-file description of the SIMULINK system named SIST021.
%	The block-diagram can be displayed by typing: SIST021.
%
%	SYS=SIST021(T,X,U,FLAG) returns depending on FLAG certain
%	system values given time point, T, current state vector, X,
%	and input vector, U.
%	FLAG is used to indicate the type of output to be returned in SYS.
%
%	Setting FLAG=1 causes SIST021 to return state derivatives, FLAG=2
%	discrete states, FLAG=3 system outputs and FLAG=4 next sample
%	time. For more information and other options see SFUNC.
%
%	Calling SIST021 with a FLAG of zero:
%	[SIZES]=SIST021([],[],[],0),  returns a vector, SIZES, which
%	contains the sizes of the state vector and other parameters.
%		SIZES(1) number of states
%		SIZES(2) number of discrete states
%		SIZES(3) number of outputs
%		SIZES(4) number of inputs
%		SIZES(5) number of roots (currently unsupported)
%		SIZES(6) direct feedthrough flag
%		SIZES(7) number of sample times
%
%	For the definition of other parameters in SIZES, see SFUNC.
%	See also, TRIM, LINMOD, LINSIM, EULER, RK23, RK45, ADAMS, GEAR.

% Note: This M-file is only used for saving graphical information;
%       after the model is loaded into memory an internal model
%       representation is used.

% the system will take on the name of this mfile:
sys = mfilename;
new_system(sys)
simver(1.3)
if (0 == (nargin + nargout))
     set_param(sys,'Location',[4,42,628,468])
     open_system(sys)
end;
set_param(sys,'algorithm',     'RK-45')
set_param(sys,'Start time',    '0.0')
set_param(sys,'Stop time',     '200')
set_param(sys,'Min step size', '0.000001')
set_param(sys,'Max step size', '1')
set_param(sys,'Relative error','1e-3')
set_param(sys,'Return vars',   '')

add_block('built-in/Zero-Order Hold',[sys,'/','S//H_1'])
set_param([sys,'/','S//H_1'],...
		'orientation',2,...
		'Sample time','T',...
		'position',[310,237,345,263])

add_block('built-in/Gain',[sys,'/','rz5//rn5'])
set_param([sys,'/','rz5//rn5'],...
		'orientation',2,...
		'Gain','K1',...
		'position',[255,237,280,263])

add_block('built-in/Zero-Order Hold',[sys,'/','S//H_2'])
set_param([sys,'/','S//H_2'],...
		'orientation',2,...
		'Sample time','T',...
		'position',[310,197,345,223])

add_block('built-in/Gain',[sys,'/','rz6//rn6'])
set_param([sys,'/','rz6//rn6'],...
		'orientation',2,...
		'Gain','K2',...
		'position',[255,197,280,223])

add_block('built-in/Gain',[sys,'/','rz7//rn7'])
set_param([sys,'/','rz7//rn7'],...
		'orientation',2,...
		'Gain','K3',...
		'position',[255,157,280,183])

add_block('built-in/Sum',[sys,'/','Sum3'])
set_param([sys,'/','Sum3'],...
		'inputs','+-',...
		'position',[430,315,450,335])

add_block('built-in/Transfer Fcn',[sys,'/','sz2//sn2'])
set_param([sys,'/','sz2//sn2'],...
		'Denominator','[TM 0]',...
		'position',[185,297,220,333])

add_block('built-in/Sum',[sys,'/','Sum1'])
set_param([sys,'/','Sum1'],...
		'inputs','+-',...
		'position',[145,305,165,325])

add_block('built-in/Transfer Fcn',[sys,'/','sz1//sn1'])
set_param([sys,'/','sz1//sn1'],...
		'Denominator','[Tel 1]',...
		'position',[70,293,115,327])

add_block('built-in/Transfer Fcn',[sys,'/','sz4//sn4'])
set_param([sys,'/','sz4//sn4'],...
		'Denominator','[TL 0]',...
		'position',[465,307,500,343])

add_block('built-in/Sum',[sys,'/','sum2'])
set_param([sys,'/','sum2'],...
		'inputs','+-',...
		'position',[260,310,280,330])


%     Subsystem  'Oszi'.

new_system([sys,'/','Oszi'])
set_param([sys,'/','Oszi'],'Location',[0,59,274,252])

add_block('built-in/Inport',[sys,'/','Oszi/x'])
set_param([sys,'/','Oszi/x'],...
		'position',[65,55,85,75])

add_block('built-in/S-Function',[sys,'/',['Oszi/S-function',13,'M-file which plots',13,'lines',13,'']])
set_param([sys,'/',['Oszi/S-function',13,'M-file which plots',13,'lines',13,'']],...
		'function name','sfuny',...
		'parameters','ax, color,dt',...
		'position',[130,55,180,75])
add_line([sys,'/','Oszi'],[90,65;125,65])
set_param([sys,'/','Oszi'],...
		'Mask Display','plot(0,0,100,100,[90,10,10,10,90,90,10],[65,65,90,40,40,90,90],[90,78,69,54,40,31,25,10],[77,60,48,46,56,75,81,84])',...
		'Mask Type','Graph scope.')
set_param([sys,'/','Oszi'],...
		'Mask Dialogue','Graph scope using MATLAB graph window.\nEnter plotting ranges and line type.|Time range:|y-min:|y-max:|Line type (rgbw-:*). Seperate each plot by ''/'':')
set_param([sys,'/','Oszi'],...
		'Mask Translate','color = @4; ax = [0, @1, @2, @3]; dt = -1;')
set_param([sys,'/','Oszi'],...
		'Mask Help','This block plots to the MATLAB graph window and can be used as an improved version of the Scope block. Look at the m-file sfuny.m to see how it works. This block can take scalar or vector input signal.')
set_param([sys,'/','Oszi'],...
		'Mask Entries','200\/-0.1\/1.2\/''k/b/r''\/')


%     Finished composite block 'Oszi'.

set_param([sys,'/','Oszi'],...
		'position',[475,35,495,55])

add_block('built-in/Mux',[sys,'/','Multiplexer'])
set_param([sys,'/','Multiplexer'],...
		'inputs','3',...
		'position',[425,36,455,54])

add_block('built-in/Zero-Order Hold',[sys,'/','S//H_4'])
set_param([sys,'/','S//H_4'],...
		'orientation',2,...
		'Sample time','T',...
		'position',[310,117,345,143])

add_block('built-in/Zero-Order Hold',[sys,'/','S//H_5'])
set_param([sys,'/','S//H_5'],...
		'orientation',2,...
		'Sample time','T',...
		'position',[310,77,345,103])

add_block('built-in/Gain',[sys,'/','rz8//rn8'])
set_param([sys,'/','rz8//rn8'],...
		'orientation',2,...
		'Gain','K4',...
		'position',[255,117,280,143])

add_block('built-in/Gain',[sys,'/','Beobachter'])
set_param([sys,'/','Beobachter'],...
		'orientation',2,...
		'Gain','VZ',...
		'position',[255,77,280,103])

add_block('built-in/Zero-Order Hold',[sys,'/','S//H_3'])
set_param([sys,'/','S//H_3'],...
		'orientation',2,...
		'Sample time','T',...
		'position',[310,157,345,183])

add_block('built-in/Sum',[sys,'/','Sum5'])
set_param([sys,'/','Sum5'],...
		'orientation',2,...
		'inputs','+++++',...
		'position',[170,142,190,198])

add_block('built-in/Sum',[sys,'/','Sum4'])
set_param([sys,'/','Sum4'],...
		'inputs','+-',...
		'position',[265,35,285,55])

add_block('built-in/Step Fcn',[sys,'/','Last'])
set_param([sys,'/','Last'],...
		'Time','T',...
		'After','0',...
		'position',[95,60,115,80])

add_block('built-in/Step Fcn',[sys,'/','Sollwert'])
set_param([sys,'/','Sollwert'],...
		'Time','T',...
		'position',[135,30,155,50])

add_block('built-in/Gain',[sys,'/','Wichtung'])
set_param([sys,'/','Wichtung'],...
		'Gain','VF',...
		'position',[185,28,210,52])

add_block('built-in/To Workspace',[sys,'/','"rz3//rn3"'])
set_param([sys,'/','"rz3//rn3"'],...
		'mat-name','OU_3',...
		'position',[450,162,500,178])

add_block('built-in/To Workspace',[sys,'/','"rz1//rn1"'])
set_param([sys,'/','"rz1//rn1"'],...
		'mat-name','OU_1',...
		'position',[450,242,500,258])

add_block('built-in/To Workspace',[sys,'/','"rz2//rn2"'])
set_param([sys,'/','"rz2//rn2"'],...
		'mat-name','OU_2',...
		'position',[450,202,500,218])

add_block('built-in/Transfer Fcn',[sys,'/','sz3//sn3'])
set_param([sys,'/','sz3//sn3'],...
		'Denominator','[TF 0]',...
		'position',[355,302,390,338])

add_block('built-in/To Workspace',[sys,'/','"rz4//rn4"'])
set_param([sys,'/','"rz4//rn4"'],...
		'mat-name','OU_4',...
		'position',[450,122,500,138])

add_block('built-in/To Workspace',[sys,'/','"Eingang"'])
set_param([sys,'/','"Eingang"'],...
		'mat-name','IN',...
		'position',[445,82,495,98])
add_line(sys,[170,315;180,315])
add_line(sys,[455,325;460,325])
add_line(sys,[225,315;255,315])
add_line(sys,[460,45;470,45])
add_line(sys,[305,250;285,250])
add_line(sys,[305,210;285,210])
add_line(sys,[285,320;295,320;330,320;350,320])
add_line(sys,[305,170;285,170])
add_line(sys,[120,310;140,310])
add_line(sys,[235,315;235,285;385,285;385,45;420,45])
add_line(sys,[290,45;300,45;300,280;55,280;65,310])
add_line(sys,[395,320;425,320])
add_line(sys,[505,325;515,325;515,360;235,360;235,325;255,325])
add_line(sys,[515,325;515,290;390,290;390,50;420,50])
add_line(sys,[405,320;405,355;130,355;140,320])
add_line(sys,[250,170;195,170])
add_line(sys,[250,210;240,210;240,180;195,180])
add_line(sys,[250,130;240,130;240,160;195,160])
add_line(sys,[250,250;230,250;230,190;195,190])
add_line(sys,[250,90;230,90;230,150;195,150])
add_line(sys,[120,70;360,70;350,90])
add_line(sys,[130,70;130,260;40,260;40,380;415,380;425,330])
add_line(sys,[160,40;180,40])
add_line(sys,[215,40;260,40])
add_line(sys,[165,170;155,170;155,135;220,135;220,50;260,50])
add_line(sys,[130,310;130,290;365,290;365,250;350,250])
add_line(sys,[365,250;365,250;445,250])
add_line(sys,[340,320;340,295;380,295;380,40;420,40])
add_line(sys,[385,210;360,210;350,210])
add_line(sys,[385,210;435,210;445,210])
add_line(sys,[405,320;405,170;350,170])
add_line(sys,[405,170;445,170])
add_line(sys,[390,130;350,130])
add_line(sys,[390,130;435,130;445,130])
add_line(sys,[360,90;430,90;440,90])
add_line(sys,[305,130;285,130])
add_line(sys,[305,90;285,90])

drawnow

% Return any arguments.
if (nargin | nargout)
	% Must use feval here to access system in memory
	if (nargin > 3)
		if (flag == 0)
			eval(['[ret,x0,str,ts,xts]=',sys,'(t,x,u,flag);'])
		else
			eval(['ret =', sys,'(t,x,u,flag);'])
		end
	else
		[ret,x0,str,ts,xts] = feval(sys);
	end
else
	drawnow % Flash up the model and execute load callback
end
