function [ret,x0,str,ts,xts]=sist030(t,x,u,flag);
%SIST030	is the M-file description of the SIMULINK system named SIST030.
%	The block-diagram can be displayed by typing: SIST030.
%
%	SYS=SIST030(T,X,U,FLAG) returns depending on FLAG certain
%	system values given time point, T, current state vector, X,
%	and input vector, U.
%	FLAG is used to indicate the type of output to be returned in SYS.
%
%	Setting FLAG=1 causes SIST030 to return state derivatives, FLAG=2
%	discrete states, FLAG=3 system outputs and FLAG=4 next sample
%	time. For more information and other options see SFUNC.
%
%	Calling SIST030 with a FLAG of zero:
%	[SIZES]=SIST030([],[],[],0),  returns a vector, SIZES, which
%	contains the sizes of the state vector and other parameters.
%		SIZES(1) number of states
%		SIZES(2) number of discrete states
%		SIZES(3) number of outputs
%		SIZES(4) number of inputs
%		SIZES(5) number of roots (currently unsupported)
%		SIZES(6) direct feedthrough flag
%		SIZES(7) number of sample times
%
%	For the definition of other parameters in SIZES, see SFUNC.
%	See also, TRIM, LINMOD, LINSIM, EULER, RK23, RK45, ADAMS, GEAR.

% Note: This M-file is only used for saving graphical information;
%       after the model is loaded into memory an internal model
%       representation is used.

% the system will take on the name of this mfile:
sys = mfilename;
new_system(sys)
simver(1.3)
if (0 == (nargin + nargout))
     set_param(sys,'Location',[4,42,628,468])
     open_system(sys)
end;
set_param(sys,'algorithm',     'RK-45')
set_param(sys,'Start time',    '0.0')
set_param(sys,'Stop time',     '110')
set_param(sys,'Min step size', '0.0001')
set_param(sys,'Max step size', '1')
set_param(sys,'Relative error','1e-3')
set_param(sys,'Return vars',   '')


%     Subsystem  'Totzeiten (0 bis 9)T'.

new_system([sys,'/','Totzeiten (0 bis 9)T'])
set_param([sys,'/','Totzeiten (0 bis 9)T'],'Location',[4,42,628,468])

add_block('built-in/Mux',[sys,'/','Totzeiten (0 bis 9)T/Mux'])
set_param([sys,'/','Totzeiten (0 bis 9)T/Mux'],...
		'inputs','10',...
		'position',[535,135,570,225])

add_block('built-in/Filter',[sys,'/','Totzeiten (0 bis 9)T/Filter8'])
set_param([sys,'/','Totzeiten (0 bis 9)T/Filter8'],...
		'Numerator','[0 0 0 0 0 0 1]',...
		'Denominator','[1]',...
		'position',[345,106,405,144])

add_block('built-in/Filter',[sys,'/','Totzeiten (0 bis 9)T/Filter7'])
set_param([sys,'/','Totzeiten (0 bis 9)T/Filter7'],...
		'Numerator','[0 0 0 0 0 0 0 1]',...
		'Denominator','[1]',...
		'position',[345,186,405,224])


%     Subsystem  'Totzeiten (0 bis 9)T/Subsystem7'.

new_system([sys,'/','Totzeiten (0 bis 9)T/Subsystem7'])
set_param([sys,'/','Totzeiten (0 bis 9)T/Subsystem7'],'Location',[45,42,596,276])

add_block('built-in/Transfer Fcn',[sys,'/','Totzeiten (0 bis 9)T/Subsystem7/Transfer Fcn1'])
set_param([sys,'/','Totzeiten (0 bis 9)T/Subsystem7/Transfer Fcn1'],...
		'Denominator','[4 1]',...
		'position',[150,132,185,168])

add_block('built-in/Transfer Fcn',[sys,'/','Totzeiten (0 bis 9)T/Subsystem7/Transfer Fcn'])
set_param([sys,'/','Totzeiten (0 bis 9)T/Subsystem7/Transfer Fcn'],...
		'Denominator','[10 1]',...
		'position',[80,132,115,168])

add_block('built-in/Zero-Order Hold',[sys,'/',['Totzeiten (0 bis 9)T/Subsystem7/Zero-Order',13,'Hold']])
set_param([sys,'/',['Totzeiten (0 bis 9)T/Subsystem7/Zero-Order',13,'Hold']],...
		'position',[110,49,145,81])

add_block('built-in/Sum',[sys,'/','Totzeiten (0 bis 9)T/Subsystem7/Sum'])
set_param([sys,'/','Totzeiten (0 bis 9)T/Subsystem7/Sum'],...
		'inputs','+-',...
		'position',[60,55,80,75])

add_block('built-in/Inport',[sys,'/','Totzeiten (0 bis 9)T/Subsystem7/in_1'])
set_param([sys,'/','Totzeiten (0 bis 9)T/Subsystem7/in_1'],...
		'position',[15,50,35,70])

add_block('built-in/Outport',[sys,'/','Totzeiten (0 bis 9)T/Subsystem7/out_2'])
set_param([sys,'/','Totzeiten (0 bis 9)T/Subsystem7/out_2'],...
		'Port','2',...
		'position',[240,140,260,160])

add_block('built-in/Inport',[sys,'/','Totzeiten (0 bis 9)T/Subsystem7/in_2'])
set_param([sys,'/','Totzeiten (0 bis 9)T/Subsystem7/in_2'],...
		'Port','2',...
		'position',[15,140,35,160])

add_block('built-in/Filter',[sys,'/','Totzeiten (0 bis 9)T/Subsystem7/Filter'])
set_param([sys,'/','Totzeiten (0 bis 9)T/Subsystem7/Filter'],...
		'Numerator','[REG(8,1) REG(8,1)*REG(8,2) REG(8,1)*REG(8,3)]',...
		'Denominator','[1 -1]',...
		'position',[165,44,455,86])

add_block('built-in/Outport',[sys,'/','Totzeiten (0 bis 9)T/Subsystem7/out_1'])
set_param([sys,'/','Totzeiten (0 bis 9)T/Subsystem7/out_1'],...
		'position',[495,55,515,75])
add_line([sys,'/','Totzeiten (0 bis 9)T/Subsystem7'],[190,150;190,115;45,115;55,70])
add_line([sys,'/','Totzeiten (0 bis 9)T/Subsystem7'],[120,150;145,150])
add_line([sys,'/','Totzeiten (0 bis 9)T/Subsystem7'],[85,65;105,65])
add_line([sys,'/','Totzeiten (0 bis 9)T/Subsystem7'],[150,65;160,65])
add_line([sys,'/','Totzeiten (0 bis 9)T/Subsystem7'],[40,60;55,60])
add_line([sys,'/','Totzeiten (0 bis 9)T/Subsystem7'],[460,65;490,65])
add_line([sys,'/','Totzeiten (0 bis 9)T/Subsystem7'],[190,150;235,150])
add_line([sys,'/','Totzeiten (0 bis 9)T/Subsystem7'],[40,150;75,150])


%     Finished composite block 'Totzeiten (0 bis 9)T/Subsystem7'.

set_param([sys,'/','Totzeiten (0 bis 9)T/Subsystem7'],...
		'position',[280,187,310,238])

add_block('built-in/Filter',[sys,'/','Totzeiten (0 bis 9)T/Filter6'])
set_param([sys,'/','Totzeiten (0 bis 9)T/Filter6'],...
		'Numerator','[0 0 0 0 0 0 0 0 1]',...
		'Denominator','[1]',...
		'position',[350,276,410,314])


%     Subsystem  'Totzeiten (0 bis 9)T/Subsystem6'.

new_system([sys,'/','Totzeiten (0 bis 9)T/Subsystem6'])
set_param([sys,'/','Totzeiten (0 bis 9)T/Subsystem6'],'Location',[45,42,588,276])

add_block('built-in/Transfer Fcn',[sys,'/','Totzeiten (0 bis 9)T/Subsystem6/Transfer Fcn1'])
set_param([sys,'/','Totzeiten (0 bis 9)T/Subsystem6/Transfer Fcn1'],...
		'Denominator','[4 1]',...
		'position',[150,132,185,168])

add_block('built-in/Transfer Fcn',[sys,'/','Totzeiten (0 bis 9)T/Subsystem6/Transfer Fcn'])
set_param([sys,'/','Totzeiten (0 bis 9)T/Subsystem6/Transfer Fcn'],...
		'Denominator','[10 1]',...
		'position',[80,132,115,168])

add_block('built-in/Zero-Order Hold',[sys,'/',['Totzeiten (0 bis 9)T/Subsystem6/Zero-Order',13,'Hold']])
set_param([sys,'/',['Totzeiten (0 bis 9)T/Subsystem6/Zero-Order',13,'Hold']],...
		'position',[110,49,145,81])

add_block('built-in/Sum',[sys,'/','Totzeiten (0 bis 9)T/Subsystem6/Sum'])
set_param([sys,'/','Totzeiten (0 bis 9)T/Subsystem6/Sum'],...
		'inputs','+-',...
		'position',[60,55,80,75])

add_block('built-in/Inport',[sys,'/','Totzeiten (0 bis 9)T/Subsystem6/in_1'])
set_param([sys,'/','Totzeiten (0 bis 9)T/Subsystem6/in_1'],...
		'position',[15,50,35,70])

add_block('built-in/Outport',[sys,'/','Totzeiten (0 bis 9)T/Subsystem6/out_2'])
set_param([sys,'/','Totzeiten (0 bis 9)T/Subsystem6/out_2'],...
		'Port','2',...
		'position',[240,140,260,160])

add_block('built-in/Inport',[sys,'/','Totzeiten (0 bis 9)T/Subsystem6/in_2'])
set_param([sys,'/','Totzeiten (0 bis 9)T/Subsystem6/in_2'],...
		'Port','2',...
		'position',[15,140,35,160])

add_block('built-in/Filter',[sys,'/','Totzeiten (0 bis 9)T/Subsystem6/Filter'])
set_param([sys,'/','Totzeiten (0 bis 9)T/Subsystem6/Filter'],...
		'Numerator','[REG(9,1) REG(9,1)*REG(9,2) REG(9,1)*REG(9,3)]',...
		'Denominator','[1 -1]',...
		'position',[165,45,460,85])

add_block('built-in/Outport',[sys,'/','Totzeiten (0 bis 9)T/Subsystem6/out_1'])
set_param([sys,'/','Totzeiten (0 bis 9)T/Subsystem6/out_1'],...
		'position',[500,55,520,75])
add_line([sys,'/','Totzeiten (0 bis 9)T/Subsystem6'],[190,150;190,115;45,115;55,70])
add_line([sys,'/','Totzeiten (0 bis 9)T/Subsystem6'],[120,150;145,150])
add_line([sys,'/','Totzeiten (0 bis 9)T/Subsystem6'],[85,65;105,65])
add_line([sys,'/','Totzeiten (0 bis 9)T/Subsystem6'],[150,65;160,65])
add_line([sys,'/','Totzeiten (0 bis 9)T/Subsystem6'],[40,60;55,60])
add_line([sys,'/','Totzeiten (0 bis 9)T/Subsystem6'],[465,65;495,65])
add_line([sys,'/','Totzeiten (0 bis 9)T/Subsystem6'],[190,150;235,150])
add_line([sys,'/','Totzeiten (0 bis 9)T/Subsystem6'],[40,150;75,150])


%     Finished composite block 'Totzeiten (0 bis 9)T/Subsystem6'.

set_param([sys,'/','Totzeiten (0 bis 9)T/Subsystem6'],...
		'position',[285,277,315,328])


%     Subsystem  'Totzeiten (0 bis 9)T/Subsystem5'.

new_system([sys,'/','Totzeiten (0 bis 9)T/Subsystem5'])
set_param([sys,'/','Totzeiten (0 bis 9)T/Subsystem5'],'Location',[45,42,604,276])

add_block('built-in/Transfer Fcn',[sys,'/','Totzeiten (0 bis 9)T/Subsystem5/Transfer Fcn1'])
set_param([sys,'/','Totzeiten (0 bis 9)T/Subsystem5/Transfer Fcn1'],...
		'Denominator','[4 1]',...
		'position',[150,132,185,168])

add_block('built-in/Transfer Fcn',[sys,'/','Totzeiten (0 bis 9)T/Subsystem5/Transfer Fcn'])
set_param([sys,'/','Totzeiten (0 bis 9)T/Subsystem5/Transfer Fcn'],...
		'Denominator','[10 1]',...
		'position',[80,132,115,168])

add_block('built-in/Zero-Order Hold',[sys,'/',['Totzeiten (0 bis 9)T/Subsystem5/Zero-Order',13,'Hold']])
set_param([sys,'/',['Totzeiten (0 bis 9)T/Subsystem5/Zero-Order',13,'Hold']],...
		'position',[110,49,145,81])

add_block('built-in/Sum',[sys,'/','Totzeiten (0 bis 9)T/Subsystem5/Sum'])
set_param([sys,'/','Totzeiten (0 bis 9)T/Subsystem5/Sum'],...
		'inputs','+-',...
		'position',[60,55,80,75])

add_block('built-in/Inport',[sys,'/','Totzeiten (0 bis 9)T/Subsystem5/in_1'])
set_param([sys,'/','Totzeiten (0 bis 9)T/Subsystem5/in_1'],...
		'position',[15,50,35,70])

add_block('built-in/Outport',[sys,'/','Totzeiten (0 bis 9)T/Subsystem5/out_2'])
set_param([sys,'/','Totzeiten (0 bis 9)T/Subsystem5/out_2'],...
		'Port','2',...
		'position',[240,140,260,160])

add_block('built-in/Inport',[sys,'/','Totzeiten (0 bis 9)T/Subsystem5/in_2'])
set_param([sys,'/','Totzeiten (0 bis 9)T/Subsystem5/in_2'],...
		'Port','2',...
		'position',[15,140,35,160])

add_block('built-in/Filter',[sys,'/','Totzeiten (0 bis 9)T/Subsystem5/Filter'])
set_param([sys,'/','Totzeiten (0 bis 9)T/Subsystem5/Filter'],...
		'Numerator','[REG(10,1) REG(10,1)*REG(10,2) REG(10,1)*REG(10,3)]',...
		'Denominator','[1 -1]',...
		'position',[165,44,500,86])

add_block('built-in/Outport',[sys,'/','Totzeiten (0 bis 9)T/Subsystem5/out_1'])
set_param([sys,'/','Totzeiten (0 bis 9)T/Subsystem5/out_1'],...
		'position',[525,55,545,75])
add_line([sys,'/','Totzeiten (0 bis 9)T/Subsystem5'],[190,150;190,115;45,115;55,70])
add_line([sys,'/','Totzeiten (0 bis 9)T/Subsystem5'],[120,150;145,150])
add_line([sys,'/','Totzeiten (0 bis 9)T/Subsystem5'],[85,65;105,65])
add_line([sys,'/','Totzeiten (0 bis 9)T/Subsystem5'],[150,65;160,65])
add_line([sys,'/','Totzeiten (0 bis 9)T/Subsystem5'],[40,60;55,60])
add_line([sys,'/','Totzeiten (0 bis 9)T/Subsystem5'],[505,65;520,65])
add_line([sys,'/','Totzeiten (0 bis 9)T/Subsystem5'],[190,150;235,150])
add_line([sys,'/','Totzeiten (0 bis 9)T/Subsystem5'],[40,150;75,150])


%     Finished composite block 'Totzeiten (0 bis 9)T/Subsystem5'.

set_param([sys,'/','Totzeiten (0 bis 9)T/Subsystem5'],...
		'position',[290,357,320,408])

add_block('built-in/Filter',[sys,'/','Totzeiten (0 bis 9)T/Filter5'])
set_param([sys,'/','Totzeiten (0 bis 9)T/Filter5'],...
		'Numerator','[0 0 0 0 0 0 0 0 0 1]',...
		'Denominator','[1]',...
		'position',[355,356,415,394])

add_block('built-in/Filter',[sys,'/','Totzeiten (0 bis 9)T/Filter4'])
set_param([sys,'/','Totzeiten (0 bis 9)T/Filter4'],...
		'Numerator','[0 0 0 0 1]',...
		'Denominator','[1]',...
		'position',[155,341,215,379])


%     Subsystem  'Totzeiten (0 bis 9)T/Subsystem4'.

new_system([sys,'/','Totzeiten (0 bis 9)T/Subsystem4'])
set_param([sys,'/','Totzeiten (0 bis 9)T/Subsystem4'],'Location',[45,42,588,276])

add_block('built-in/Transfer Fcn',[sys,'/','Totzeiten (0 bis 9)T/Subsystem4/Transfer Fcn1'])
set_param([sys,'/','Totzeiten (0 bis 9)T/Subsystem4/Transfer Fcn1'],...
		'Denominator','[4 1]',...
		'position',[150,132,185,168])

add_block('built-in/Transfer Fcn',[sys,'/','Totzeiten (0 bis 9)T/Subsystem4/Transfer Fcn'])
set_param([sys,'/','Totzeiten (0 bis 9)T/Subsystem4/Transfer Fcn'],...
		'Denominator','[10 1]',...
		'position',[80,132,115,168])

add_block('built-in/Zero-Order Hold',[sys,'/',['Totzeiten (0 bis 9)T/Subsystem4/Zero-Order',13,'Hold']])
set_param([sys,'/',['Totzeiten (0 bis 9)T/Subsystem4/Zero-Order',13,'Hold']],...
		'position',[110,49,145,81])

add_block('built-in/Sum',[sys,'/','Totzeiten (0 bis 9)T/Subsystem4/Sum'])
set_param([sys,'/','Totzeiten (0 bis 9)T/Subsystem4/Sum'],...
		'inputs','+-',...
		'position',[60,55,80,75])

add_block('built-in/Inport',[sys,'/','Totzeiten (0 bis 9)T/Subsystem4/in_1'])
set_param([sys,'/','Totzeiten (0 bis 9)T/Subsystem4/in_1'],...
		'position',[15,50,35,70])

add_block('built-in/Outport',[sys,'/','Totzeiten (0 bis 9)T/Subsystem4/out_2'])
set_param([sys,'/','Totzeiten (0 bis 9)T/Subsystem4/out_2'],...
		'Port','2',...
		'position',[240,140,260,160])

add_block('built-in/Inport',[sys,'/','Totzeiten (0 bis 9)T/Subsystem4/in_2'])
set_param([sys,'/','Totzeiten (0 bis 9)T/Subsystem4/in_2'],...
		'Port','2',...
		'position',[15,140,35,160])

add_block('built-in/Filter',[sys,'/','Totzeiten (0 bis 9)T/Subsystem4/Filter'])
set_param([sys,'/','Totzeiten (0 bis 9)T/Subsystem4/Filter'],...
		'Numerator','[REG(5,1) REG(5,1)*REG(5,2) REG(5,1)*REG(5,3)]',...
		'Denominator','[1 -1]',...
		'position',[165,45,485,85])

add_block('built-in/Outport',[sys,'/','Totzeiten (0 bis 9)T/Subsystem4/out_1'])
set_param([sys,'/','Totzeiten (0 bis 9)T/Subsystem4/out_1'],...
		'position',[505,55,525,75])
add_line([sys,'/','Totzeiten (0 bis 9)T/Subsystem4'],[190,150;190,115;45,115;55,70])
add_line([sys,'/','Totzeiten (0 bis 9)T/Subsystem4'],[120,150;145,150])
add_line([sys,'/','Totzeiten (0 bis 9)T/Subsystem4'],[85,65;105,65])
add_line([sys,'/','Totzeiten (0 bis 9)T/Subsystem4'],[150,65;160,65])
add_line([sys,'/','Totzeiten (0 bis 9)T/Subsystem4'],[40,60;55,60])
add_line([sys,'/','Totzeiten (0 bis 9)T/Subsystem4'],[490,65;500,65])
add_line([sys,'/','Totzeiten (0 bis 9)T/Subsystem4'],[190,150;235,150])
add_line([sys,'/','Totzeiten (0 bis 9)T/Subsystem4'],[40,150;75,150])


%     Finished composite block 'Totzeiten (0 bis 9)T/Subsystem4'.

set_param([sys,'/','Totzeiten (0 bis 9)T/Subsystem4'],...
		'position',[95,342,125,393])

add_block('built-in/Filter',[sys,'/','Totzeiten (0 bis 9)T/Filter3'])
set_param([sys,'/','Totzeiten (0 bis 9)T/Filter3'],...
		'Numerator','[0 0 0 1]',...
		'Denominator','[1]',...
		'position',[160,261,220,299])


%     Subsystem  'Totzeiten (0 bis 9)T/Subsystem3'.

new_system([sys,'/','Totzeiten (0 bis 9)T/Subsystem3'])
set_param([sys,'/','Totzeiten (0 bis 9)T/Subsystem3'],'Location',[45,42,604,276])

add_block('built-in/Transfer Fcn',[sys,'/','Totzeiten (0 bis 9)T/Subsystem3/Transfer Fcn1'])
set_param([sys,'/','Totzeiten (0 bis 9)T/Subsystem3/Transfer Fcn1'],...
		'Denominator','[4 1]',...
		'position',[150,132,185,168])

add_block('built-in/Transfer Fcn',[sys,'/','Totzeiten (0 bis 9)T/Subsystem3/Transfer Fcn'])
set_param([sys,'/','Totzeiten (0 bis 9)T/Subsystem3/Transfer Fcn'],...
		'Denominator','[10 1]',...
		'position',[80,132,115,168])

add_block('built-in/Zero-Order Hold',[sys,'/',['Totzeiten (0 bis 9)T/Subsystem3/Zero-Order',13,'Hold']])
set_param([sys,'/',['Totzeiten (0 bis 9)T/Subsystem3/Zero-Order',13,'Hold']],...
		'position',[110,49,145,81])

add_block('built-in/Sum',[sys,'/','Totzeiten (0 bis 9)T/Subsystem3/Sum'])
set_param([sys,'/','Totzeiten (0 bis 9)T/Subsystem3/Sum'],...
		'inputs','+-',...
		'position',[60,55,80,75])

add_block('built-in/Inport',[sys,'/','Totzeiten (0 bis 9)T/Subsystem3/in_1'])
set_param([sys,'/','Totzeiten (0 bis 9)T/Subsystem3/in_1'],...
		'position',[15,50,35,70])

add_block('built-in/Outport',[sys,'/','Totzeiten (0 bis 9)T/Subsystem3/out_2'])
set_param([sys,'/','Totzeiten (0 bis 9)T/Subsystem3/out_2'],...
		'Port','2',...
		'position',[240,140,260,160])

add_block('built-in/Inport',[sys,'/','Totzeiten (0 bis 9)T/Subsystem3/in_2'])
set_param([sys,'/','Totzeiten (0 bis 9)T/Subsystem3/in_2'],...
		'Port','2',...
		'position',[15,140,35,160])

add_block('built-in/Filter',[sys,'/','Totzeiten (0 bis 9)T/Subsystem3/Filter'])
set_param([sys,'/','Totzeiten (0 bis 9)T/Subsystem3/Filter'],...
		'Numerator','[REG(4,1) REG(4,1)*REG(4,2) REG(4,1)*REG(4,3)]',...
		'Denominator','[1 -1]',...
		'position',[165,47,465,83])

add_block('built-in/Outport',[sys,'/','Totzeiten (0 bis 9)T/Subsystem3/out_1'])
set_param([sys,'/','Totzeiten (0 bis 9)T/Subsystem3/out_1'],...
		'position',[500,55,520,75])
add_line([sys,'/','Totzeiten (0 bis 9)T/Subsystem3'],[190,150;190,115;45,115;55,70])
add_line([sys,'/','Totzeiten (0 bis 9)T/Subsystem3'],[120,150;145,150])
add_line([sys,'/','Totzeiten (0 bis 9)T/Subsystem3'],[85,65;105,65])
add_line([sys,'/','Totzeiten (0 bis 9)T/Subsystem3'],[150,65;160,65])
add_line([sys,'/','Totzeiten (0 bis 9)T/Subsystem3'],[40,60;55,60])
add_line([sys,'/','Totzeiten (0 bis 9)T/Subsystem3'],[470,65;495,65])
add_line([sys,'/','Totzeiten (0 bis 9)T/Subsystem3'],[190,150;235,150])
add_line([sys,'/','Totzeiten (0 bis 9)T/Subsystem3'],[40,150;75,150])


%     Finished composite block 'Totzeiten (0 bis 9)T/Subsystem3'.

set_param([sys,'/','Totzeiten (0 bis 9)T/Subsystem3'],...
		'position',[100,262,130,313])


%     Subsystem  'Totzeiten (0 bis 9)T/Subsystem2'.

new_system([sys,'/','Totzeiten (0 bis 9)T/Subsystem2'])
set_param([sys,'/','Totzeiten (0 bis 9)T/Subsystem2'],'Location',[45,42,596,276])

add_block('built-in/Transfer Fcn',[sys,'/','Totzeiten (0 bis 9)T/Subsystem2/Transfer Fcn1'])
set_param([sys,'/','Totzeiten (0 bis 9)T/Subsystem2/Transfer Fcn1'],...
		'Denominator','[4 1]',...
		'position',[150,132,185,168])

add_block('built-in/Transfer Fcn',[sys,'/','Totzeiten (0 bis 9)T/Subsystem2/Transfer Fcn'])
set_param([sys,'/','Totzeiten (0 bis 9)T/Subsystem2/Transfer Fcn'],...
		'Denominator','[10 1]',...
		'position',[80,132,115,168])

add_block('built-in/Zero-Order Hold',[sys,'/',['Totzeiten (0 bis 9)T/Subsystem2/Zero-Order',13,'Hold']])
set_param([sys,'/',['Totzeiten (0 bis 9)T/Subsystem2/Zero-Order',13,'Hold']],...
		'position',[110,49,145,81])

add_block('built-in/Sum',[sys,'/','Totzeiten (0 bis 9)T/Subsystem2/Sum'])
set_param([sys,'/','Totzeiten (0 bis 9)T/Subsystem2/Sum'],...
		'inputs','+-',...
		'position',[60,55,80,75])

add_block('built-in/Inport',[sys,'/','Totzeiten (0 bis 9)T/Subsystem2/in_1'])
set_param([sys,'/','Totzeiten (0 bis 9)T/Subsystem2/in_1'],...
		'position',[15,50,35,70])

add_block('built-in/Outport',[sys,'/','Totzeiten (0 bis 9)T/Subsystem2/out_2'])
set_param([sys,'/','Totzeiten (0 bis 9)T/Subsystem2/out_2'],...
		'Port','2',...
		'position',[240,140,260,160])

add_block('built-in/Inport',[sys,'/','Totzeiten (0 bis 9)T/Subsystem2/in_2'])
set_param([sys,'/','Totzeiten (0 bis 9)T/Subsystem2/in_2'],...
		'Port','2',...
		'position',[15,140,35,160])

add_block('built-in/Filter',[sys,'/','Totzeiten (0 bis 9)T/Subsystem2/Filter'])
set_param([sys,'/','Totzeiten (0 bis 9)T/Subsystem2/Filter'],...
		'Numerator','[REG(3,1) REG(3,1)*REG(3,2) REG(3,1)*REG(3,3)]',...
		'Denominator','[1 -1]',...
		'position',[165,45,490,85])

add_block('built-in/Outport',[sys,'/','Totzeiten (0 bis 9)T/Subsystem2/out_1'])
set_param([sys,'/','Totzeiten (0 bis 9)T/Subsystem2/out_1'],...
		'position',[520,55,540,75])
add_line([sys,'/','Totzeiten (0 bis 9)T/Subsystem2'],[190,150;190,115;45,115;55,70])
add_line([sys,'/','Totzeiten (0 bis 9)T/Subsystem2'],[120,150;145,150])
add_line([sys,'/','Totzeiten (0 bis 9)T/Subsystem2'],[85,65;105,65])
add_line([sys,'/','Totzeiten (0 bis 9)T/Subsystem2'],[150,65;160,65])
add_line([sys,'/','Totzeiten (0 bis 9)T/Subsystem2'],[40,60;55,60])
add_line([sys,'/','Totzeiten (0 bis 9)T/Subsystem2'],[495,65;515,65])
add_line([sys,'/','Totzeiten (0 bis 9)T/Subsystem2'],[190,150;235,150])
add_line([sys,'/','Totzeiten (0 bis 9)T/Subsystem2'],[40,150;75,150])


%     Finished composite block 'Totzeiten (0 bis 9)T/Subsystem2'.

set_param([sys,'/','Totzeiten (0 bis 9)T/Subsystem2'],...
		'position',[100,177,130,228])

add_block('built-in/Filter',[sys,'/','Totzeiten (0 bis 9)T/Filter'])
set_param([sys,'/','Totzeiten (0 bis 9)T/Filter'],...
		'Denominator','[1]',...
		'position',[160,11,220,49])


%     Subsystem  'Totzeiten (0 bis 9)T/Subsystem'.

new_system([sys,'/','Totzeiten (0 bis 9)T/Subsystem'])
set_param([sys,'/','Totzeiten (0 bis 9)T/Subsystem'],'Location',[45,42,588,276])

add_block('built-in/Transfer Fcn',[sys,'/','Totzeiten (0 bis 9)T/Subsystem/Transfer Fcn1'])
set_param([sys,'/','Totzeiten (0 bis 9)T/Subsystem/Transfer Fcn1'],...
		'Denominator','[4 1]',...
		'position',[150,132,185,168])

add_block('built-in/Transfer Fcn',[sys,'/','Totzeiten (0 bis 9)T/Subsystem/Transfer Fcn'])
set_param([sys,'/','Totzeiten (0 bis 9)T/Subsystem/Transfer Fcn'],...
		'Denominator','[10 1]',...
		'position',[80,132,115,168])

add_block('built-in/Zero-Order Hold',[sys,'/',['Totzeiten (0 bis 9)T/Subsystem/Zero-Order',13,'Hold']])
set_param([sys,'/',['Totzeiten (0 bis 9)T/Subsystem/Zero-Order',13,'Hold']],...
		'position',[110,49,145,81])

add_block('built-in/Sum',[sys,'/','Totzeiten (0 bis 9)T/Subsystem/Sum'])
set_param([sys,'/','Totzeiten (0 bis 9)T/Subsystem/Sum'],...
		'inputs','+-',...
		'position',[60,55,80,75])

add_block('built-in/Inport',[sys,'/','Totzeiten (0 bis 9)T/Subsystem/in_1'])
set_param([sys,'/','Totzeiten (0 bis 9)T/Subsystem/in_1'],...
		'position',[15,50,35,70])

add_block('built-in/Outport',[sys,'/','Totzeiten (0 bis 9)T/Subsystem/out_2'])
set_param([sys,'/','Totzeiten (0 bis 9)T/Subsystem/out_2'],...
		'Port','2',...
		'position',[240,140,260,160])

add_block('built-in/Inport',[sys,'/','Totzeiten (0 bis 9)T/Subsystem/in_2'])
set_param([sys,'/','Totzeiten (0 bis 9)T/Subsystem/in_2'],...
		'Port','2',...
		'position',[15,140,35,160])

add_block('built-in/Filter',[sys,'/','Totzeiten (0 bis 9)T/Subsystem/Filter'])
set_param([sys,'/','Totzeiten (0 bis 9)T/Subsystem/Filter'],...
		'Numerator','[REG(1,1) REG(1,1)*REG(1,2) REG(1,1)*REG(1,3)]',...
		'Denominator','[1 -1]',...
		'position',[165,45,475,85])

add_block('built-in/Outport',[sys,'/','Totzeiten (0 bis 9)T/Subsystem/out_1'])
set_param([sys,'/','Totzeiten (0 bis 9)T/Subsystem/out_1'],...
		'position',[495,55,515,75])
add_line([sys,'/','Totzeiten (0 bis 9)T/Subsystem'],[190,150;190,115;45,115;55,70])
add_line([sys,'/','Totzeiten (0 bis 9)T/Subsystem'],[120,150;145,150])
add_line([sys,'/','Totzeiten (0 bis 9)T/Subsystem'],[85,65;105,65])
add_line([sys,'/','Totzeiten (0 bis 9)T/Subsystem'],[150,65;160,65])
add_line([sys,'/','Totzeiten (0 bis 9)T/Subsystem'],[40,60;55,60])
add_line([sys,'/','Totzeiten (0 bis 9)T/Subsystem'],[480,65;490,65])
add_line([sys,'/','Totzeiten (0 bis 9)T/Subsystem'],[190,150;235,150])
add_line([sys,'/','Totzeiten (0 bis 9)T/Subsystem'],[40,150;75,150])


%     Finished composite block 'Totzeiten (0 bis 9)T/Subsystem'.

set_param([sys,'/','Totzeiten (0 bis 9)T/Subsystem'],...
		'position',[100,17,130,68])

add_block('built-in/Filter',[sys,'/','Totzeiten (0 bis 9)T/Filter2'])
set_param([sys,'/','Totzeiten (0 bis 9)T/Filter2'],...
		'Numerator','[0 0 1]',...
		'Denominator','[1]',...
		'position',[160,176,220,214])


%     Subsystem  'Totzeiten (0 bis 9)T/Subsystem1'.

new_system([sys,'/','Totzeiten (0 bis 9)T/Subsystem1'])
set_param([sys,'/','Totzeiten (0 bis 9)T/Subsystem1'],'Location',[45,42,596,276])

add_block('built-in/Transfer Fcn',[sys,'/','Totzeiten (0 bis 9)T/Subsystem1/Transfer Fcn1'])
set_param([sys,'/','Totzeiten (0 bis 9)T/Subsystem1/Transfer Fcn1'],...
		'Denominator','[4 1]',...
		'position',[150,132,185,168])

add_block('built-in/Transfer Fcn',[sys,'/','Totzeiten (0 bis 9)T/Subsystem1/Transfer Fcn'])
set_param([sys,'/','Totzeiten (0 bis 9)T/Subsystem1/Transfer Fcn'],...
		'Denominator','[10 1]',...
		'position',[80,132,115,168])

add_block('built-in/Zero-Order Hold',[sys,'/',['Totzeiten (0 bis 9)T/Subsystem1/Zero-Order',13,'Hold']])
set_param([sys,'/',['Totzeiten (0 bis 9)T/Subsystem1/Zero-Order',13,'Hold']],...
		'position',[110,49,145,81])

add_block('built-in/Sum',[sys,'/','Totzeiten (0 bis 9)T/Subsystem1/Sum'])
set_param([sys,'/','Totzeiten (0 bis 9)T/Subsystem1/Sum'],...
		'inputs','+-',...
		'position',[60,55,80,75])

add_block('built-in/Inport',[sys,'/','Totzeiten (0 bis 9)T/Subsystem1/in_1'])
set_param([sys,'/','Totzeiten (0 bis 9)T/Subsystem1/in_1'],...
		'position',[15,50,35,70])

add_block('built-in/Outport',[sys,'/','Totzeiten (0 bis 9)T/Subsystem1/out_2'])
set_param([sys,'/','Totzeiten (0 bis 9)T/Subsystem1/out_2'],...
		'Port','2',...
		'position',[240,140,260,160])

add_block('built-in/Inport',[sys,'/','Totzeiten (0 bis 9)T/Subsystem1/in_2'])
set_param([sys,'/','Totzeiten (0 bis 9)T/Subsystem1/in_2'],...
		'Port','2',...
		'position',[15,140,35,160])

add_block('built-in/Filter',[sys,'/','Totzeiten (0 bis 9)T/Subsystem1/Filter'])
set_param([sys,'/','Totzeiten (0 bis 9)T/Subsystem1/Filter'],...
		'Numerator','[REG(2,1) REG(2,1)*REG(2,2) REG(2,1)*REG(2,3)]',...
		'Denominator','[1 -1]',...
		'position',[165,45,470,85])

add_block('built-in/Outport',[sys,'/','Totzeiten (0 bis 9)T/Subsystem1/out_1'])
set_param([sys,'/','Totzeiten (0 bis 9)T/Subsystem1/out_1'],...
		'position',[500,55,520,75])
add_line([sys,'/','Totzeiten (0 bis 9)T/Subsystem1'],[190,150;190,115;45,115;55,70])
add_line([sys,'/','Totzeiten (0 bis 9)T/Subsystem1'],[120,150;145,150])
add_line([sys,'/','Totzeiten (0 bis 9)T/Subsystem1'],[85,65;105,65])
add_line([sys,'/','Totzeiten (0 bis 9)T/Subsystem1'],[150,65;160,65])
add_line([sys,'/','Totzeiten (0 bis 9)T/Subsystem1'],[40,60;55,60])
add_line([sys,'/','Totzeiten (0 bis 9)T/Subsystem1'],[475,65;495,65])
add_line([sys,'/','Totzeiten (0 bis 9)T/Subsystem1'],[190,150;235,150])
add_line([sys,'/','Totzeiten (0 bis 9)T/Subsystem1'],[40,150;75,150])


%     Finished composite block 'Totzeiten (0 bis 9)T/Subsystem1'.

set_param([sys,'/','Totzeiten (0 bis 9)T/Subsystem1'],...
		'position',[95,97,125,148])

add_block('built-in/Filter',[sys,'/','Totzeiten (0 bis 9)T/Filter1'])
set_param([sys,'/','Totzeiten (0 bis 9)T/Filter1'],...
		'Numerator','[0 1]',...
		'Denominator','[1]',...
		'position',[155,96,215,134])

add_block('built-in/Outport',[sys,'/','Totzeiten (0 bis 9)T/out_1'])
set_param([sys,'/','Totzeiten (0 bis 9)T/out_1'],...
		'position',[585,170,605,190])

add_block('built-in/Inport',[sys,'/','Totzeiten (0 bis 9)T/in_1'])
set_param([sys,'/','Totzeiten (0 bis 9)T/in_1'],...
		'position',[5,316,25,344])


%     Subsystem  'Totzeiten (0 bis 9)T/Subsystem8'.

new_system([sys,'/','Totzeiten (0 bis 9)T/Subsystem8'])
set_param([sys,'/','Totzeiten (0 bis 9)T/Subsystem8'],'Location',[45,42,596,276])

add_block('built-in/Transfer Fcn',[sys,'/','Totzeiten (0 bis 9)T/Subsystem8/Transfer Fcn1'])
set_param([sys,'/','Totzeiten (0 bis 9)T/Subsystem8/Transfer Fcn1'],...
		'Denominator','[4 1]',...
		'position',[150,132,185,168])

add_block('built-in/Transfer Fcn',[sys,'/','Totzeiten (0 bis 9)T/Subsystem8/Transfer Fcn'])
set_param([sys,'/','Totzeiten (0 bis 9)T/Subsystem8/Transfer Fcn'],...
		'Denominator','[10 1]',...
		'position',[80,132,115,168])

add_block('built-in/Zero-Order Hold',[sys,'/',['Totzeiten (0 bis 9)T/Subsystem8/Zero-Order',13,'Hold']])
set_param([sys,'/',['Totzeiten (0 bis 9)T/Subsystem8/Zero-Order',13,'Hold']],...
		'position',[110,49,145,81])

add_block('built-in/Sum',[sys,'/','Totzeiten (0 bis 9)T/Subsystem8/Sum'])
set_param([sys,'/','Totzeiten (0 bis 9)T/Subsystem8/Sum'],...
		'inputs','+-',...
		'position',[60,55,80,75])

add_block('built-in/Inport',[sys,'/','Totzeiten (0 bis 9)T/Subsystem8/in_1'])
set_param([sys,'/','Totzeiten (0 bis 9)T/Subsystem8/in_1'],...
		'position',[15,50,35,70])

add_block('built-in/Outport',[sys,'/','Totzeiten (0 bis 9)T/Subsystem8/out_2'])
set_param([sys,'/','Totzeiten (0 bis 9)T/Subsystem8/out_2'],...
		'Port','2',...
		'position',[240,140,260,160])

add_block('built-in/Inport',[sys,'/','Totzeiten (0 bis 9)T/Subsystem8/in_2'])
set_param([sys,'/','Totzeiten (0 bis 9)T/Subsystem8/in_2'],...
		'Port','2',...
		'position',[15,140,35,160])

add_block('built-in/Filter',[sys,'/','Totzeiten (0 bis 9)T/Subsystem8/Filter'])
set_param([sys,'/','Totzeiten (0 bis 9)T/Subsystem8/Filter'],...
		'Numerator','[REG(7,1) REG(7,1)*REG(7,2) REG(7,1)*REG(7,3)]',...
		'Denominator','[1 -1]',...
		'position',[165,45,480,85])

add_block('built-in/Outport',[sys,'/','Totzeiten (0 bis 9)T/Subsystem8/out_1'])
set_param([sys,'/','Totzeiten (0 bis 9)T/Subsystem8/out_1'],...
		'position',[510,55,530,75])
add_line([sys,'/','Totzeiten (0 bis 9)T/Subsystem8'],[190,150;190,115;45,115;55,70])
add_line([sys,'/','Totzeiten (0 bis 9)T/Subsystem8'],[120,150;145,150])
add_line([sys,'/','Totzeiten (0 bis 9)T/Subsystem8'],[85,65;105,65])
add_line([sys,'/','Totzeiten (0 bis 9)T/Subsystem8'],[150,65;160,65])
add_line([sys,'/','Totzeiten (0 bis 9)T/Subsystem8'],[40,60;55,60])
add_line([sys,'/','Totzeiten (0 bis 9)T/Subsystem8'],[485,65;505,65])
add_line([sys,'/','Totzeiten (0 bis 9)T/Subsystem8'],[190,150;235,150])
add_line([sys,'/','Totzeiten (0 bis 9)T/Subsystem8'],[40,150;75,150])


%     Finished composite block 'Totzeiten (0 bis 9)T/Subsystem8'.

set_param([sys,'/','Totzeiten (0 bis 9)T/Subsystem8'],...
		'position',[280,102,310,153])

add_block('built-in/Filter',[sys,'/','Totzeiten (0 bis 9)T/Filter9'])
set_param([sys,'/','Totzeiten (0 bis 9)T/Filter9'],...
		'Numerator','[0 0 0 0 0 1]',...
		'Denominator','[1]',...
		'position',[355,21,415,59])


%     Subsystem  'Totzeiten (0 bis 9)T/Subsystem9'.

new_system([sys,'/','Totzeiten (0 bis 9)T/Subsystem9'])
set_param([sys,'/','Totzeiten (0 bis 9)T/Subsystem9'],'Location',[45,42,604,276])

add_block('built-in/Transfer Fcn',[sys,'/','Totzeiten (0 bis 9)T/Subsystem9/Transfer Fcn1'])
set_param([sys,'/','Totzeiten (0 bis 9)T/Subsystem9/Transfer Fcn1'],...
		'Denominator','[4 1]',...
		'position',[150,132,185,168])

add_block('built-in/Transfer Fcn',[sys,'/','Totzeiten (0 bis 9)T/Subsystem9/Transfer Fcn'])
set_param([sys,'/','Totzeiten (0 bis 9)T/Subsystem9/Transfer Fcn'],...
		'Denominator','[10 1]',...
		'position',[80,132,115,168])

add_block('built-in/Zero-Order Hold',[sys,'/',['Totzeiten (0 bis 9)T/Subsystem9/Zero-Order',13,'Hold']])
set_param([sys,'/',['Totzeiten (0 bis 9)T/Subsystem9/Zero-Order',13,'Hold']],...
		'position',[110,49,145,81])

add_block('built-in/Sum',[sys,'/','Totzeiten (0 bis 9)T/Subsystem9/Sum'])
set_param([sys,'/','Totzeiten (0 bis 9)T/Subsystem9/Sum'],...
		'inputs','+-',...
		'position',[60,55,80,75])

add_block('built-in/Inport',[sys,'/','Totzeiten (0 bis 9)T/Subsystem9/in_1'])
set_param([sys,'/','Totzeiten (0 bis 9)T/Subsystem9/in_1'],...
		'position',[15,50,35,70])

add_block('built-in/Outport',[sys,'/','Totzeiten (0 bis 9)T/Subsystem9/out_2'])
set_param([sys,'/','Totzeiten (0 bis 9)T/Subsystem9/out_2'],...
		'Port','2',...
		'position',[240,140,260,160])

add_block('built-in/Inport',[sys,'/','Totzeiten (0 bis 9)T/Subsystem9/in_2'])
set_param([sys,'/','Totzeiten (0 bis 9)T/Subsystem9/in_2'],...
		'Port','2',...
		'position',[15,140,35,160])

add_block('built-in/Filter',[sys,'/','Totzeiten (0 bis 9)T/Subsystem9/Filter'])
set_param([sys,'/','Totzeiten (0 bis 9)T/Subsystem9/Filter'],...
		'Numerator','[REG(6,1) REG(6,1)*REG(6,2) REG(6,1)*REG(6,3)]',...
		'Denominator','[1 -1]',...
		'position',[165,45,490,85])

add_block('built-in/Outport',[sys,'/','Totzeiten (0 bis 9)T/Subsystem9/out_1'])
set_param([sys,'/','Totzeiten (0 bis 9)T/Subsystem9/out_1'],...
		'position',[520,55,540,75])
add_line([sys,'/','Totzeiten (0 bis 9)T/Subsystem9'],[190,150;190,115;45,115;55,70])
add_line([sys,'/','Totzeiten (0 bis 9)T/Subsystem9'],[120,150;145,150])
add_line([sys,'/','Totzeiten (0 bis 9)T/Subsystem9'],[85,65;105,65])
add_line([sys,'/','Totzeiten (0 bis 9)T/Subsystem9'],[150,65;160,65])
add_line([sys,'/','Totzeiten (0 bis 9)T/Subsystem9'],[40,60;55,60])
add_line([sys,'/','Totzeiten (0 bis 9)T/Subsystem9'],[495,65;515,65])
add_line([sys,'/','Totzeiten (0 bis 9)T/Subsystem9'],[190,150;235,150])
add_line([sys,'/','Totzeiten (0 bis 9)T/Subsystem9'],[40,150;75,150])


%     Finished composite block 'Totzeiten (0 bis 9)T/Subsystem9'.

set_param([sys,'/','Totzeiten (0 bis 9)T/Subsystem9'],...
		'position',[295,17,325,68])
add_line([sys,'/','Totzeiten (0 bis 9)T'],[130,380;145,380;145,420;500,420;500,225;530,225])
add_line([sys,'/','Totzeiten (0 bis 9)T'],[325,395;340,395;340,405;485,405;485,215;530,215])
add_line([sys,'/','Totzeiten (0 bis 9)T'],[135,300;150,300;150,315;255,315;255,340;470,340;470,205;530,205])
add_line([sys,'/','Totzeiten (0 bis 9)T'],[320,315;340,315;340,335;460,335;460,195;530,195])
add_line([sys,'/','Totzeiten (0 bis 9)T'],[135,215;150,215;150,240;260,240;260,260;450,260;450,185;530,185])
add_line([sys,'/','Totzeiten (0 bis 9)T'],[315,225;330,225;330,240;440,240;440,175;530,175])
add_line([sys,'/','Totzeiten (0 bis 9)T'],[130,135;140,135;140,150;255,150;255,165;530,165])
add_line([sys,'/','Totzeiten (0 bis 9)T'],[315,140;330,140;330,155;530,155])
add_line([sys,'/','Totzeiten (0 bis 9)T'],[135,55;150,55;150,70;245,70;245,90;500,90;500,145;530,145])
add_line([sys,'/','Totzeiten (0 bis 9)T'],[330,55;340,55;340,70;515,70;515,135;530,135])
add_line([sys,'/','Totzeiten (0 bis 9)T'],[30,330;30,410;245,410;245,370;285,370])
add_line([sys,'/','Totzeiten (0 bis 9)T'],[30,330;245,330;245,290;280,290])
add_line([sys,'/','Totzeiten (0 bis 9)T'],[30,330;30,190;95,190])
add_line([sys,'/','Totzeiten (0 bis 9)T'],[30,330;30,250;245,250;245,200;275,200])
add_line([sys,'/','Totzeiten (0 bis 9)T'],[30,330;30,160;245,160;245,115;275,115])
add_line([sys,'/','Totzeiten (0 bis 9)T'],[30,330;30,80;260,80;260,30;290,30])
add_line([sys,'/','Totzeiten (0 bis 9)T'],[30,330;30,110;90,110])
add_line([sys,'/','Totzeiten (0 bis 9)T'],[30,330;30,30;95,30])
add_line([sys,'/','Totzeiten (0 bis 9)T'],[420,40;420,10;270,10;270,55;290,55])
add_line([sys,'/','Totzeiten (0 bis 9)T'],[330,30;340,30;350,40])
add_line([sys,'/','Totzeiten (0 bis 9)T'],[410,125;420,125;420,100;260,100;260,140;275,140])
add_line([sys,'/','Totzeiten (0 bis 9)T'],[315,115;330,115;340,125])
add_line([sys,'/','Totzeiten (0 bis 9)T'],[410,205;420,205;420,180;260,180;260,225;275,225])
add_line([sys,'/','Totzeiten (0 bis 9)T'],[315,200;320,200;320,205;340,205])
add_line([sys,'/','Totzeiten (0 bis 9)T'],[415,295;425,295;425,270;265,270;265,315;280,315])
add_line([sys,'/','Totzeiten (0 bis 9)T'],[320,290;335,290;345,295])
add_line([sys,'/','Totzeiten (0 bis 9)T'],[420,375;430,375;430,350;270,350;270,395;285,395])
add_line([sys,'/','Totzeiten (0 bis 9)T'],[325,370;340,370;350,375])
add_line([sys,'/','Totzeiten (0 bis 9)T'],[220,360;225,360;225,335;70,335;70,380;90,380])
add_line([sys,'/','Totzeiten (0 bis 9)T'],[130,355;130,360;150,360])
add_line([sys,'/','Totzeiten (0 bis 9)T'],[225,280;230,280;230,255;75,255;75,300;95,300])
add_line([sys,'/','Totzeiten (0 bis 9)T'],[135,275;135,280;155,280])
add_line([sys,'/','Totzeiten (0 bis 9)T'],[225,195;230,195;230,170;75,170;75,215;95,215])
add_line([sys,'/','Totzeiten (0 bis 9)T'],[135,190;135,195;155,195])
add_line([sys,'/','Totzeiten (0 bis 9)T'],[220,115;230,115;230,90;75,90;75,135;90,135])
add_line([sys,'/','Totzeiten (0 bis 9)T'],[130,110;135,110;135,115;150,115])
add_line([sys,'/','Totzeiten (0 bis 9)T'],[225,30;235,30;235,5;80,5;80,55;95,55])
add_line([sys,'/','Totzeiten (0 bis 9)T'],[135,30;155,30])
add_line([sys,'/','Totzeiten (0 bis 9)T'],[575,180;580,180])
add_line([sys,'/','Totzeiten (0 bis 9)T'],[30,355;90,355])
add_line([sys,'/','Totzeiten (0 bis 9)T'],[30,275;95,275])


%     Finished composite block 'Totzeiten (0 bis 9)T'.

set_param([sys,'/','Totzeiten (0 bis 9)T'],...
		'position',[190,15,220,65])


%     Subsystem  'Totzeiten (10 bis 19)T'.

new_system([sys,'/','Totzeiten (10 bis 19)T'])
set_param([sys,'/','Totzeiten (10 bis 19)T'],'Location',[4,42,628,468])

add_block('built-in/Outport',[sys,'/','Totzeiten (10 bis 19)T/out_1'])
set_param([sys,'/','Totzeiten (10 bis 19)T/out_1'],...
		'orientation',2,...
		'position',[575,85,595,105])

add_block('built-in/Mux',[sys,'/','Totzeiten (10 bis 19)T/Mux'])
set_param([sys,'/','Totzeiten (10 bis 19)T/Mux'],...
		'inputs','10',...
		'position',[570,131,600,249])


%     Subsystem  'Totzeiten (10 bis 19)T/Subsystem9'.

new_system([sys,'/','Totzeiten (10 bis 19)T/Subsystem9'])
set_param([sys,'/','Totzeiten (10 bis 19)T/Subsystem9'],'Location',[45,42,620,276])

add_block('built-in/Transfer Fcn',[sys,'/','Totzeiten (10 bis 19)T/Subsystem9/Transfer Fcn1'])
set_param([sys,'/','Totzeiten (10 bis 19)T/Subsystem9/Transfer Fcn1'],...
		'Denominator','[4 1]',...
		'position',[150,132,185,168])

add_block('built-in/Transfer Fcn',[sys,'/','Totzeiten (10 bis 19)T/Subsystem9/Transfer Fcn'])
set_param([sys,'/','Totzeiten (10 bis 19)T/Subsystem9/Transfer Fcn'],...
		'Denominator','[10 1]',...
		'position',[80,132,115,168])

add_block('built-in/Zero-Order Hold',[sys,'/',['Totzeiten (10 bis 19)T/Subsystem9/Zero-Order',13,'Hold']])
set_param([sys,'/',['Totzeiten (10 bis 19)T/Subsystem9/Zero-Order',13,'Hold']],...
		'position',[110,49,145,81])

add_block('built-in/Sum',[sys,'/','Totzeiten (10 bis 19)T/Subsystem9/Sum'])
set_param([sys,'/','Totzeiten (10 bis 19)T/Subsystem9/Sum'],...
		'inputs','+-',...
		'position',[60,55,80,75])

add_block('built-in/Inport',[sys,'/','Totzeiten (10 bis 19)T/Subsystem9/in_1'])
set_param([sys,'/','Totzeiten (10 bis 19)T/Subsystem9/in_1'],...
		'position',[15,50,35,70])

add_block('built-in/Outport',[sys,'/','Totzeiten (10 bis 19)T/Subsystem9/out_2'])
set_param([sys,'/','Totzeiten (10 bis 19)T/Subsystem9/out_2'],...
		'Port','2',...
		'position',[240,140,260,160])

add_block('built-in/Inport',[sys,'/','Totzeiten (10 bis 19)T/Subsystem9/in_2'])
set_param([sys,'/','Totzeiten (10 bis 19)T/Subsystem9/in_2'],...
		'Port','2',...
		'position',[15,140,35,160])

add_block('built-in/Filter',[sys,'/','Totzeiten (10 bis 19)T/Subsystem9/Filter'])
set_param([sys,'/','Totzeiten (10 bis 19)T/Subsystem9/Filter'],...
		'Numerator','[REG(16,1) REG(16,1)*REG(16,2) REG(16,1)*REG(16,3)]',...
		'Denominator','[1 -1]',...
		'position',[165,45,510,85])

add_block('built-in/Outport',[sys,'/','Totzeiten (10 bis 19)T/Subsystem9/out_1'])
set_param([sys,'/','Totzeiten (10 bis 19)T/Subsystem9/out_1'],...
		'position',[530,55,550,75])
add_line([sys,'/','Totzeiten (10 bis 19)T/Subsystem9'],[190,150;190,115;45,115;55,70])
add_line([sys,'/','Totzeiten (10 bis 19)T/Subsystem9'],[120,150;145,150])
add_line([sys,'/','Totzeiten (10 bis 19)T/Subsystem9'],[85,65;105,65])
add_line([sys,'/','Totzeiten (10 bis 19)T/Subsystem9'],[150,65;160,65])
add_line([sys,'/','Totzeiten (10 bis 19)T/Subsystem9'],[40,60;55,60])
add_line([sys,'/','Totzeiten (10 bis 19)T/Subsystem9'],[515,65;525,65])
add_line([sys,'/','Totzeiten (10 bis 19)T/Subsystem9'],[190,150;235,150])
add_line([sys,'/','Totzeiten (10 bis 19)T/Subsystem9'],[40,150;75,150])


%     Finished composite block 'Totzeiten (10 bis 19)T/Subsystem9'.

set_param([sys,'/','Totzeiten (10 bis 19)T/Subsystem9'],...
		'position',[340,12,370,63])

add_block('built-in/Filter',[sys,'/','Totzeiten (10 bis 19)T/Filter9'])
set_param([sys,'/','Totzeiten (10 bis 19)T/Filter9'],...
		'Numerator','[0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 1]',...
		'Denominator','[1]',...
		'position',[405,11,465,49])


%     Subsystem  'Totzeiten (10 bis 19)T/Subsystem8'.

new_system([sys,'/','Totzeiten (10 bis 19)T/Subsystem8'])
set_param([sys,'/','Totzeiten (10 bis 19)T/Subsystem8'],'Location',[45,42,620,276])

add_block('built-in/Transfer Fcn',[sys,'/','Totzeiten (10 bis 19)T/Subsystem8/Transfer Fcn1'])
set_param([sys,'/','Totzeiten (10 bis 19)T/Subsystem8/Transfer Fcn1'],...
		'Denominator','[4 1]',...
		'position',[150,132,185,168])

add_block('built-in/Transfer Fcn',[sys,'/','Totzeiten (10 bis 19)T/Subsystem8/Transfer Fcn'])
set_param([sys,'/','Totzeiten (10 bis 19)T/Subsystem8/Transfer Fcn'],...
		'Denominator','[10 1]',...
		'position',[80,132,115,168])

add_block('built-in/Zero-Order Hold',[sys,'/',['Totzeiten (10 bis 19)T/Subsystem8/Zero-Order',13,'Hold']])
set_param([sys,'/',['Totzeiten (10 bis 19)T/Subsystem8/Zero-Order',13,'Hold']],...
		'position',[110,49,145,81])

add_block('built-in/Sum',[sys,'/','Totzeiten (10 bis 19)T/Subsystem8/Sum'])
set_param([sys,'/','Totzeiten (10 bis 19)T/Subsystem8/Sum'],...
		'inputs','+-',...
		'position',[60,55,80,75])

add_block('built-in/Inport',[sys,'/','Totzeiten (10 bis 19)T/Subsystem8/in_1'])
set_param([sys,'/','Totzeiten (10 bis 19)T/Subsystem8/in_1'],...
		'position',[15,50,35,70])

add_block('built-in/Outport',[sys,'/','Totzeiten (10 bis 19)T/Subsystem8/out_2'])
set_param([sys,'/','Totzeiten (10 bis 19)T/Subsystem8/out_2'],...
		'Port','2',...
		'position',[240,140,260,160])

add_block('built-in/Inport',[sys,'/','Totzeiten (10 bis 19)T/Subsystem8/in_2'])
set_param([sys,'/','Totzeiten (10 bis 19)T/Subsystem8/in_2'],...
		'Port','2',...
		'position',[15,140,35,160])

add_block('built-in/Filter',[sys,'/','Totzeiten (10 bis 19)T/Subsystem8/Filter'])
set_param([sys,'/','Totzeiten (10 bis 19)T/Subsystem8/Filter'],...
		'Numerator','[REG(17,1) REG(17,1)*REG(17,2) REG(17,1)*REG(17,3)]',...
		'Denominator','[1 -1]',...
		'position',[165,45,510,85])

add_block('built-in/Outport',[sys,'/','Totzeiten (10 bis 19)T/Subsystem8/out_1'])
set_param([sys,'/','Totzeiten (10 bis 19)T/Subsystem8/out_1'],...
		'position',[540,55,560,75])
add_line([sys,'/','Totzeiten (10 bis 19)T/Subsystem8'],[190,150;190,115;45,115;55,70])
add_line([sys,'/','Totzeiten (10 bis 19)T/Subsystem8'],[120,150;145,150])
add_line([sys,'/','Totzeiten (10 bis 19)T/Subsystem8'],[85,65;105,65])
add_line([sys,'/','Totzeiten (10 bis 19)T/Subsystem8'],[150,65;160,65])
add_line([sys,'/','Totzeiten (10 bis 19)T/Subsystem8'],[40,60;55,60])
add_line([sys,'/','Totzeiten (10 bis 19)T/Subsystem8'],[515,65;535,65])
add_line([sys,'/','Totzeiten (10 bis 19)T/Subsystem8'],[190,150;235,150])
add_line([sys,'/','Totzeiten (10 bis 19)T/Subsystem8'],[40,150;75,150])


%     Finished composite block 'Totzeiten (10 bis 19)T/Subsystem8'.

set_param([sys,'/','Totzeiten (10 bis 19)T/Subsystem8'],...
		'position',[315,102,345,153])

add_block('built-in/Filter',[sys,'/','Totzeiten (10 bis 19)T/Filter8'])
set_param([sys,'/','Totzeiten (10 bis 19)T/Filter8'],...
		'Numerator','[0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 1]',...
		'Denominator','[1]',...
		'position',[380,101,440,139])

add_block('built-in/Filter',[sys,'/','Totzeiten (10 bis 19)T/Filter7'])
set_param([sys,'/','Totzeiten (10 bis 19)T/Filter7'],...
		'Numerator','[0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 1]',...
		'Denominator','[1]',...
		'position',[380,181,440,219])


%     Subsystem  'Totzeiten (10 bis 19)T/Subsystem7'.

new_system([sys,'/','Totzeiten (10 bis 19)T/Subsystem7'])
set_param([sys,'/','Totzeiten (10 bis 19)T/Subsystem7'],'Location',[45,42,620,276])

add_block('built-in/Transfer Fcn',[sys,'/','Totzeiten (10 bis 19)T/Subsystem7/Transfer Fcn1'])
set_param([sys,'/','Totzeiten (10 bis 19)T/Subsystem7/Transfer Fcn1'],...
		'Denominator','[4 1]',...
		'position',[150,132,185,168])

add_block('built-in/Transfer Fcn',[sys,'/','Totzeiten (10 bis 19)T/Subsystem7/Transfer Fcn'])
set_param([sys,'/','Totzeiten (10 bis 19)T/Subsystem7/Transfer Fcn'],...
		'Denominator','[10 1]',...
		'position',[80,132,115,168])

add_block('built-in/Zero-Order Hold',[sys,'/',['Totzeiten (10 bis 19)T/Subsystem7/Zero-Order',13,'Hold']])
set_param([sys,'/',['Totzeiten (10 bis 19)T/Subsystem7/Zero-Order',13,'Hold']],...
		'position',[110,49,145,81])

add_block('built-in/Sum',[sys,'/','Totzeiten (10 bis 19)T/Subsystem7/Sum'])
set_param([sys,'/','Totzeiten (10 bis 19)T/Subsystem7/Sum'],...
		'inputs','+-',...
		'position',[60,55,80,75])

add_block('built-in/Inport',[sys,'/','Totzeiten (10 bis 19)T/Subsystem7/in_1'])
set_param([sys,'/','Totzeiten (10 bis 19)T/Subsystem7/in_1'],...
		'position',[15,50,35,70])

add_block('built-in/Outport',[sys,'/','Totzeiten (10 bis 19)T/Subsystem7/out_2'])
set_param([sys,'/','Totzeiten (10 bis 19)T/Subsystem7/out_2'],...
		'Port','2',...
		'position',[240,140,260,160])

add_block('built-in/Inport',[sys,'/','Totzeiten (10 bis 19)T/Subsystem7/in_2'])
set_param([sys,'/','Totzeiten (10 bis 19)T/Subsystem7/in_2'],...
		'Port','2',...
		'position',[15,140,35,160])

add_block('built-in/Filter',[sys,'/','Totzeiten (10 bis 19)T/Subsystem7/Filter'])
set_param([sys,'/','Totzeiten (10 bis 19)T/Subsystem7/Filter'],...
		'Numerator','[REG(18,1) REG(18,1)*REG(18,2) REG(18,1)*REG(18,3)]',...
		'Denominator','[1 -1]',...
		'position',[165,45,510,85])

add_block('built-in/Outport',[sys,'/','Totzeiten (10 bis 19)T/Subsystem7/out_1'])
set_param([sys,'/','Totzeiten (10 bis 19)T/Subsystem7/out_1'],...
		'position',[535,55,555,75])
add_line([sys,'/','Totzeiten (10 bis 19)T/Subsystem7'],[190,150;190,115;45,115;55,70])
add_line([sys,'/','Totzeiten (10 bis 19)T/Subsystem7'],[120,150;145,150])
add_line([sys,'/','Totzeiten (10 bis 19)T/Subsystem7'],[85,65;105,65])
add_line([sys,'/','Totzeiten (10 bis 19)T/Subsystem7'],[150,65;160,65])
add_line([sys,'/','Totzeiten (10 bis 19)T/Subsystem7'],[40,60;55,60])
add_line([sys,'/','Totzeiten (10 bis 19)T/Subsystem7'],[515,65;530,65])
add_line([sys,'/','Totzeiten (10 bis 19)T/Subsystem7'],[190,150;235,150])
add_line([sys,'/','Totzeiten (10 bis 19)T/Subsystem7'],[40,150;75,150])


%     Finished composite block 'Totzeiten (10 bis 19)T/Subsystem7'.

set_param([sys,'/','Totzeiten (10 bis 19)T/Subsystem7'],...
		'position',[315,182,345,233])

add_block('built-in/Filter',[sys,'/','Totzeiten (10 bis 19)T/Filter6'])
set_param([sys,'/','Totzeiten (10 bis 19)T/Filter6'],...
		'Numerator','[0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 1]',...
		'Denominator','[1]',...
		'position',[385,271,445,309])


%     Subsystem  'Totzeiten (10 bis 19)T/Subsystem6'.

new_system([sys,'/','Totzeiten (10 bis 19)T/Subsystem6'])
set_param([sys,'/','Totzeiten (10 bis 19)T/Subsystem6'],'Location',[45,42,604,276])

add_block('built-in/Transfer Fcn',[sys,'/','Totzeiten (10 bis 19)T/Subsystem6/Transfer Fcn1'])
set_param([sys,'/','Totzeiten (10 bis 19)T/Subsystem6/Transfer Fcn1'],...
		'Denominator','[4 1]',...
		'position',[150,132,185,168])

add_block('built-in/Transfer Fcn',[sys,'/','Totzeiten (10 bis 19)T/Subsystem6/Transfer Fcn'])
set_param([sys,'/','Totzeiten (10 bis 19)T/Subsystem6/Transfer Fcn'],...
		'Denominator','[10 1]',...
		'position',[80,132,115,168])

add_block('built-in/Zero-Order Hold',[sys,'/',['Totzeiten (10 bis 19)T/Subsystem6/Zero-Order',13,'Hold']])
set_param([sys,'/',['Totzeiten (10 bis 19)T/Subsystem6/Zero-Order',13,'Hold']],...
		'position',[110,49,145,81])

add_block('built-in/Sum',[sys,'/','Totzeiten (10 bis 19)T/Subsystem6/Sum'])
set_param([sys,'/','Totzeiten (10 bis 19)T/Subsystem6/Sum'],...
		'inputs','+-',...
		'position',[60,55,80,75])

add_block('built-in/Inport',[sys,'/','Totzeiten (10 bis 19)T/Subsystem6/in_1'])
set_param([sys,'/','Totzeiten (10 bis 19)T/Subsystem6/in_1'],...
		'position',[15,50,35,70])

add_block('built-in/Outport',[sys,'/','Totzeiten (10 bis 19)T/Subsystem6/out_2'])
set_param([sys,'/','Totzeiten (10 bis 19)T/Subsystem6/out_2'],...
		'Port','2',...
		'position',[240,140,260,160])

add_block('built-in/Inport',[sys,'/','Totzeiten (10 bis 19)T/Subsystem6/in_2'])
set_param([sys,'/','Totzeiten (10 bis 19)T/Subsystem6/in_2'],...
		'Port','2',...
		'position',[15,140,35,160])

add_block('built-in/Filter',[sys,'/','Totzeiten (10 bis 19)T/Subsystem6/Filter'])
set_param([sys,'/','Totzeiten (10 bis 19)T/Subsystem6/Filter'],...
		'Numerator','[REG(19,1) REG(19,1)*REG(19,2) REG(19,1)*REG(19,3)]',...
		'Denominator','[1 -1]',...
		'position',[165,45,505,85])

add_block('built-in/Outport',[sys,'/','Totzeiten (10 bis 19)T/Subsystem6/out_1'])
set_param([sys,'/','Totzeiten (10 bis 19)T/Subsystem6/out_1'],...
		'position',[520,55,540,75])
add_line([sys,'/','Totzeiten (10 bis 19)T/Subsystem6'],[190,150;190,115;45,115;55,70])
add_line([sys,'/','Totzeiten (10 bis 19)T/Subsystem6'],[120,150;145,150])
add_line([sys,'/','Totzeiten (10 bis 19)T/Subsystem6'],[85,65;105,65])
add_line([sys,'/','Totzeiten (10 bis 19)T/Subsystem6'],[150,65;160,65])
add_line([sys,'/','Totzeiten (10 bis 19)T/Subsystem6'],[40,60;55,60])
add_line([sys,'/','Totzeiten (10 bis 19)T/Subsystem6'],[510,65;515,65])
add_line([sys,'/','Totzeiten (10 bis 19)T/Subsystem6'],[190,150;235,150])
add_line([sys,'/','Totzeiten (10 bis 19)T/Subsystem6'],[40,150;75,150])


%     Finished composite block 'Totzeiten (10 bis 19)T/Subsystem6'.

set_param([sys,'/','Totzeiten (10 bis 19)T/Subsystem6'],...
		'position',[320,272,350,323])


%     Subsystem  'Totzeiten (10 bis 19)T/Subsystem5'.

new_system([sys,'/','Totzeiten (10 bis 19)T/Subsystem5'])
set_param([sys,'/','Totzeiten (10 bis 19)T/Subsystem5'],'Location',[45,42,612,276])

add_block('built-in/Transfer Fcn',[sys,'/','Totzeiten (10 bis 19)T/Subsystem5/Transfer Fcn1'])
set_param([sys,'/','Totzeiten (10 bis 19)T/Subsystem5/Transfer Fcn1'],...
		'Denominator','[4 1]',...
		'position',[150,132,185,168])

add_block('built-in/Transfer Fcn',[sys,'/','Totzeiten (10 bis 19)T/Subsystem5/Transfer Fcn'])
set_param([sys,'/','Totzeiten (10 bis 19)T/Subsystem5/Transfer Fcn'],...
		'Denominator','[10 1]',...
		'position',[80,132,115,168])

add_block('built-in/Zero-Order Hold',[sys,'/',['Totzeiten (10 bis 19)T/Subsystem5/Zero-Order',13,'Hold']])
set_param([sys,'/',['Totzeiten (10 bis 19)T/Subsystem5/Zero-Order',13,'Hold']],...
		'position',[110,49,145,81])

add_block('built-in/Sum',[sys,'/','Totzeiten (10 bis 19)T/Subsystem5/Sum'])
set_param([sys,'/','Totzeiten (10 bis 19)T/Subsystem5/Sum'],...
		'inputs','+-',...
		'position',[60,55,80,75])

add_block('built-in/Inport',[sys,'/','Totzeiten (10 bis 19)T/Subsystem5/in_1'])
set_param([sys,'/','Totzeiten (10 bis 19)T/Subsystem5/in_1'],...
		'position',[15,50,35,70])

add_block('built-in/Outport',[sys,'/','Totzeiten (10 bis 19)T/Subsystem5/out_2'])
set_param([sys,'/','Totzeiten (10 bis 19)T/Subsystem5/out_2'],...
		'Port','2',...
		'position',[240,140,260,160])

add_block('built-in/Inport',[sys,'/','Totzeiten (10 bis 19)T/Subsystem5/in_2'])
set_param([sys,'/','Totzeiten (10 bis 19)T/Subsystem5/in_2'],...
		'Port','2',...
		'position',[15,140,35,160])

add_block('built-in/Filter',[sys,'/','Totzeiten (10 bis 19)T/Subsystem5/Filter'])
set_param([sys,'/','Totzeiten (10 bis 19)T/Subsystem5/Filter'],...
		'Numerator','[REG(20,1) REG(20,1)*REG(20,2) REG(20,1)*REG(20,3)]',...
		'Denominator','[1 -1]',...
		'position',[165,45,515,85])

add_block('built-in/Outport',[sys,'/','Totzeiten (10 bis 19)T/Subsystem5/out_1'])
set_param([sys,'/','Totzeiten (10 bis 19)T/Subsystem5/out_1'],...
		'position',[540,55,560,75])
add_line([sys,'/','Totzeiten (10 bis 19)T/Subsystem5'],[190,150;190,115;45,115;55,70])
add_line([sys,'/','Totzeiten (10 bis 19)T/Subsystem5'],[120,150;145,150])
add_line([sys,'/','Totzeiten (10 bis 19)T/Subsystem5'],[85,65;105,65])
add_line([sys,'/','Totzeiten (10 bis 19)T/Subsystem5'],[150,65;160,65])
add_line([sys,'/','Totzeiten (10 bis 19)T/Subsystem5'],[40,60;55,60])
add_line([sys,'/','Totzeiten (10 bis 19)T/Subsystem5'],[520,65;535,65])
add_line([sys,'/','Totzeiten (10 bis 19)T/Subsystem5'],[190,150;235,150])
add_line([sys,'/','Totzeiten (10 bis 19)T/Subsystem5'],[40,150;75,150])


%     Finished composite block 'Totzeiten (10 bis 19)T/Subsystem5'.

set_param([sys,'/','Totzeiten (10 bis 19)T/Subsystem5'],...
		'position',[325,352,355,403])

add_block('built-in/Filter',[sys,'/','Totzeiten (10 bis 19)T/Filter5'])
set_param([sys,'/','Totzeiten (10 bis 19)T/Filter5'],...
		'Numerator','[0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 1]',...
		'Denominator','[1]',...
		'position',[390,351,450,389])

add_block('built-in/Filter',[sys,'/','Totzeiten (10 bis 19)T/Filter4'])
set_param([sys,'/','Totzeiten (10 bis 19)T/Filter4'],...
		'Numerator','[0 0 0 0 0 0 0 0 0 0 0 0 0 0 1]',...
		'Denominator','[1]',...
		'position',[190,336,250,374])


%     Subsystem  'Totzeiten (10 bis 19)T/Subsystem4'.

new_system([sys,'/','Totzeiten (10 bis 19)T/Subsystem4'])
set_param([sys,'/','Totzeiten (10 bis 19)T/Subsystem4'],'Location',[45,42,612,276])

add_block('built-in/Transfer Fcn',[sys,'/','Totzeiten (10 bis 19)T/Subsystem4/Transfer Fcn1'])
set_param([sys,'/','Totzeiten (10 bis 19)T/Subsystem4/Transfer Fcn1'],...
		'Denominator','[4 1]',...
		'position',[150,132,185,168])

add_block('built-in/Transfer Fcn',[sys,'/','Totzeiten (10 bis 19)T/Subsystem4/Transfer Fcn'])
set_param([sys,'/','Totzeiten (10 bis 19)T/Subsystem4/Transfer Fcn'],...
		'Denominator','[10 1]',...
		'position',[80,132,115,168])

add_block('built-in/Zero-Order Hold',[sys,'/',['Totzeiten (10 bis 19)T/Subsystem4/Zero-Order',13,'Hold']])
set_param([sys,'/',['Totzeiten (10 bis 19)T/Subsystem4/Zero-Order',13,'Hold']],...
		'position',[110,49,145,81])

add_block('built-in/Sum',[sys,'/','Totzeiten (10 bis 19)T/Subsystem4/Sum'])
set_param([sys,'/','Totzeiten (10 bis 19)T/Subsystem4/Sum'],...
		'inputs','+-',...
		'position',[60,55,80,75])

add_block('built-in/Inport',[sys,'/','Totzeiten (10 bis 19)T/Subsystem4/in_1'])
set_param([sys,'/','Totzeiten (10 bis 19)T/Subsystem4/in_1'],...
		'position',[15,50,35,70])

add_block('built-in/Outport',[sys,'/','Totzeiten (10 bis 19)T/Subsystem4/out_2'])
set_param([sys,'/','Totzeiten (10 bis 19)T/Subsystem4/out_2'],...
		'Port','2',...
		'position',[240,140,260,160])

add_block('built-in/Inport',[sys,'/','Totzeiten (10 bis 19)T/Subsystem4/in_2'])
set_param([sys,'/','Totzeiten (10 bis 19)T/Subsystem4/in_2'],...
		'Port','2',...
		'position',[15,140,35,160])

add_block('built-in/Filter',[sys,'/','Totzeiten (10 bis 19)T/Subsystem4/Filter'])
set_param([sys,'/','Totzeiten (10 bis 19)T/Subsystem4/Filter'],...
		'Numerator','[REG(15,1) REG(15,1)*REG(15,2) REG(15,1)*REG(15,3)]',...
		'Denominator','[1 -1]',...
		'position',[165,45,505,85])

add_block('built-in/Outport',[sys,'/','Totzeiten (10 bis 19)T/Subsystem4/out_1'])
set_param([sys,'/','Totzeiten (10 bis 19)T/Subsystem4/out_1'],...
		'position',[525,55,545,75])
add_line([sys,'/','Totzeiten (10 bis 19)T/Subsystem4'],[190,150;190,115;45,115;55,70])
add_line([sys,'/','Totzeiten (10 bis 19)T/Subsystem4'],[120,150;145,150])
add_line([sys,'/','Totzeiten (10 bis 19)T/Subsystem4'],[85,65;105,65])
add_line([sys,'/','Totzeiten (10 bis 19)T/Subsystem4'],[150,65;160,65])
add_line([sys,'/','Totzeiten (10 bis 19)T/Subsystem4'],[40,60;55,60])
add_line([sys,'/','Totzeiten (10 bis 19)T/Subsystem4'],[510,65;520,65])
add_line([sys,'/','Totzeiten (10 bis 19)T/Subsystem4'],[190,150;235,150])
add_line([sys,'/','Totzeiten (10 bis 19)T/Subsystem4'],[40,150;75,150])


%     Finished composite block 'Totzeiten (10 bis 19)T/Subsystem4'.

set_param([sys,'/','Totzeiten (10 bis 19)T/Subsystem4'],...
		'position',[130,337,160,388])

add_block('built-in/Filter',[sys,'/','Totzeiten (10 bis 19)T/Filter3'])
set_param([sys,'/','Totzeiten (10 bis 19)T/Filter3'],...
		'Numerator','[0 0 0 0 0 0 0 0 0 0 0 0 0 1]',...
		'Denominator','[1]',...
		'position',[195,256,255,294])


%     Subsystem  'Totzeiten (10 bis 19)T/Subsystem3'.

new_system([sys,'/','Totzeiten (10 bis 19)T/Subsystem3'])
set_param([sys,'/','Totzeiten (10 bis 19)T/Subsystem3'],'Location',[45,42,612,276])

add_block('built-in/Transfer Fcn',[sys,'/','Totzeiten (10 bis 19)T/Subsystem3/Transfer Fcn1'])
set_param([sys,'/','Totzeiten (10 bis 19)T/Subsystem3/Transfer Fcn1'],...
		'Denominator','[4 1]',...
		'position',[150,132,185,168])

add_block('built-in/Transfer Fcn',[sys,'/','Totzeiten (10 bis 19)T/Subsystem3/Transfer Fcn'])
set_param([sys,'/','Totzeiten (10 bis 19)T/Subsystem3/Transfer Fcn'],...
		'Denominator','[10 1]',...
		'position',[80,132,115,168])

add_block('built-in/Zero-Order Hold',[sys,'/',['Totzeiten (10 bis 19)T/Subsystem3/Zero-Order',13,'Hold']])
set_param([sys,'/',['Totzeiten (10 bis 19)T/Subsystem3/Zero-Order',13,'Hold']],...
		'position',[110,49,145,81])

add_block('built-in/Sum',[sys,'/','Totzeiten (10 bis 19)T/Subsystem3/Sum'])
set_param([sys,'/','Totzeiten (10 bis 19)T/Subsystem3/Sum'],...
		'inputs','+-',...
		'position',[60,55,80,75])

add_block('built-in/Inport',[sys,'/','Totzeiten (10 bis 19)T/Subsystem3/in_1'])
set_param([sys,'/','Totzeiten (10 bis 19)T/Subsystem3/in_1'],...
		'position',[15,50,35,70])

add_block('built-in/Outport',[sys,'/','Totzeiten (10 bis 19)T/Subsystem3/out_2'])
set_param([sys,'/','Totzeiten (10 bis 19)T/Subsystem3/out_2'],...
		'Port','2',...
		'position',[240,140,260,160])

add_block('built-in/Inport',[sys,'/','Totzeiten (10 bis 19)T/Subsystem3/in_2'])
set_param([sys,'/','Totzeiten (10 bis 19)T/Subsystem3/in_2'],...
		'Port','2',...
		'position',[15,140,35,160])

add_block('built-in/Filter',[sys,'/','Totzeiten (10 bis 19)T/Subsystem3/Filter'])
set_param([sys,'/','Totzeiten (10 bis 19)T/Subsystem3/Filter'],...
		'Numerator','[REG(14,1) REG(14,1)*REG(14,2) REG(14,1)*REG(14,3)]',...
		'Denominator','[1 -1]',...
		'position',[165,45,495,85])

add_block('built-in/Outport',[sys,'/','Totzeiten (10 bis 19)T/Subsystem3/out_1'])
set_param([sys,'/','Totzeiten (10 bis 19)T/Subsystem3/out_1'],...
		'position',[525,55,545,75])
add_line([sys,'/','Totzeiten (10 bis 19)T/Subsystem3'],[190,150;190,115;45,115;55,70])
add_line([sys,'/','Totzeiten (10 bis 19)T/Subsystem3'],[120,150;145,150])
add_line([sys,'/','Totzeiten (10 bis 19)T/Subsystem3'],[85,65;105,65])
add_line([sys,'/','Totzeiten (10 bis 19)T/Subsystem3'],[150,65;160,65])
add_line([sys,'/','Totzeiten (10 bis 19)T/Subsystem3'],[40,60;55,60])
add_line([sys,'/','Totzeiten (10 bis 19)T/Subsystem3'],[500,65;520,65])
add_line([sys,'/','Totzeiten (10 bis 19)T/Subsystem3'],[190,150;235,150])
add_line([sys,'/','Totzeiten (10 bis 19)T/Subsystem3'],[40,150;75,150])


%     Finished composite block 'Totzeiten (10 bis 19)T/Subsystem3'.

set_param([sys,'/','Totzeiten (10 bis 19)T/Subsystem3'],...
		'position',[135,257,165,308])

add_block('built-in/Filter',[sys,'/','Totzeiten (10 bis 19)T/Filter'])
set_param([sys,'/','Totzeiten (10 bis 19)T/Filter'],...
		'Numerator','[0 0 0 0 0 0 0 0 0 0 1]',...
		'Denominator','[1]',...
		'position',[195,6,255,44])


%     Subsystem  'Totzeiten (10 bis 19)T/Subsystem'.

new_system([sys,'/','Totzeiten (10 bis 19)T/Subsystem'])
set_param([sys,'/','Totzeiten (10 bis 19)T/Subsystem'],'Location',[45,42,588,276])

add_block('built-in/Transfer Fcn',[sys,'/','Totzeiten (10 bis 19)T/Subsystem/Transfer Fcn1'])
set_param([sys,'/','Totzeiten (10 bis 19)T/Subsystem/Transfer Fcn1'],...
		'Denominator','[4 1]',...
		'position',[150,132,185,168])

add_block('built-in/Transfer Fcn',[sys,'/','Totzeiten (10 bis 19)T/Subsystem/Transfer Fcn'])
set_param([sys,'/','Totzeiten (10 bis 19)T/Subsystem/Transfer Fcn'],...
		'Denominator','[10 1]',...
		'position',[80,132,115,168])

add_block('built-in/Zero-Order Hold',[sys,'/',['Totzeiten (10 bis 19)T/Subsystem/Zero-Order',13,'Hold']])
set_param([sys,'/',['Totzeiten (10 bis 19)T/Subsystem/Zero-Order',13,'Hold']],...
		'position',[110,49,145,81])

add_block('built-in/Sum',[sys,'/','Totzeiten (10 bis 19)T/Subsystem/Sum'])
set_param([sys,'/','Totzeiten (10 bis 19)T/Subsystem/Sum'],...
		'inputs','+-',...
		'position',[60,55,80,75])

add_block('built-in/Inport',[sys,'/','Totzeiten (10 bis 19)T/Subsystem/in_1'])
set_param([sys,'/','Totzeiten (10 bis 19)T/Subsystem/in_1'],...
		'position',[15,50,35,70])

add_block('built-in/Outport',[sys,'/','Totzeiten (10 bis 19)T/Subsystem/out_2'])
set_param([sys,'/','Totzeiten (10 bis 19)T/Subsystem/out_2'],...
		'Port','2',...
		'position',[240,140,260,160])

add_block('built-in/Inport',[sys,'/','Totzeiten (10 bis 19)T/Subsystem/in_2'])
set_param([sys,'/','Totzeiten (10 bis 19)T/Subsystem/in_2'],...
		'Port','2',...
		'position',[15,140,35,160])

add_block('built-in/Filter',[sys,'/','Totzeiten (10 bis 19)T/Subsystem/Filter'])
set_param([sys,'/','Totzeiten (10 bis 19)T/Subsystem/Filter'],...
		'Numerator','[REG(11,1) REG(11,1)*REG(11,2) REG(11,1)*REG(11,3)]',...
		'Denominator','[1 -1]',...
		'position',[165,44,485,86])

add_block('built-in/Outport',[sys,'/','Totzeiten (10 bis 19)T/Subsystem/out_1'])
set_param([sys,'/','Totzeiten (10 bis 19)T/Subsystem/out_1'],...
		'position',[500,55,520,75])
add_line([sys,'/','Totzeiten (10 bis 19)T/Subsystem'],[190,150;190,115;45,115;55,70])
add_line([sys,'/','Totzeiten (10 bis 19)T/Subsystem'],[120,150;145,150])
add_line([sys,'/','Totzeiten (10 bis 19)T/Subsystem'],[85,65;105,65])
add_line([sys,'/','Totzeiten (10 bis 19)T/Subsystem'],[150,65;160,65])
add_line([sys,'/','Totzeiten (10 bis 19)T/Subsystem'],[40,60;55,60])
add_line([sys,'/','Totzeiten (10 bis 19)T/Subsystem'],[490,65;495,65])
add_line([sys,'/','Totzeiten (10 bis 19)T/Subsystem'],[190,150;235,150])
add_line([sys,'/','Totzeiten (10 bis 19)T/Subsystem'],[40,150;75,150])


%     Finished composite block 'Totzeiten (10 bis 19)T/Subsystem'.

set_param([sys,'/','Totzeiten (10 bis 19)T/Subsystem'],...
		'position',[135,12,165,63])

add_block('built-in/Filter',[sys,'/','Totzeiten (10 bis 19)T/Filter2'])
set_param([sys,'/','Totzeiten (10 bis 19)T/Filter2'],...
		'Numerator','[0 0 0 0 0 0 0 0 0 0 0 0 1]',...
		'Denominator','[1]',...
		'position',[195,171,255,209])


%     Subsystem  'Totzeiten (10 bis 19)T/Subsystem2'.

new_system([sys,'/','Totzeiten (10 bis 19)T/Subsystem2'])
set_param([sys,'/','Totzeiten (10 bis 19)T/Subsystem2'],'Location',[45,42,620,276])

add_block('built-in/Transfer Fcn',[sys,'/','Totzeiten (10 bis 19)T/Subsystem2/Transfer Fcn1'])
set_param([sys,'/','Totzeiten (10 bis 19)T/Subsystem2/Transfer Fcn1'],...
		'Denominator','[4 1]',...
		'position',[150,132,185,168])

add_block('built-in/Transfer Fcn',[sys,'/','Totzeiten (10 bis 19)T/Subsystem2/Transfer Fcn'])
set_param([sys,'/','Totzeiten (10 bis 19)T/Subsystem2/Transfer Fcn'],...
		'Denominator','[10 1]',...
		'position',[80,132,115,168])

add_block('built-in/Zero-Order Hold',[sys,'/',['Totzeiten (10 bis 19)T/Subsystem2/Zero-Order',13,'Hold']])
set_param([sys,'/',['Totzeiten (10 bis 19)T/Subsystem2/Zero-Order',13,'Hold']],...
		'position',[110,49,145,81])

add_block('built-in/Sum',[sys,'/','Totzeiten (10 bis 19)T/Subsystem2/Sum'])
set_param([sys,'/','Totzeiten (10 bis 19)T/Subsystem2/Sum'],...
		'inputs','+-',...
		'position',[60,55,80,75])

add_block('built-in/Inport',[sys,'/','Totzeiten (10 bis 19)T/Subsystem2/in_1'])
set_param([sys,'/','Totzeiten (10 bis 19)T/Subsystem2/in_1'],...
		'position',[15,50,35,70])

add_block('built-in/Outport',[sys,'/','Totzeiten (10 bis 19)T/Subsystem2/out_2'])
set_param([sys,'/','Totzeiten (10 bis 19)T/Subsystem2/out_2'],...
		'Port','2',...
		'position',[240,140,260,160])

add_block('built-in/Inport',[sys,'/','Totzeiten (10 bis 19)T/Subsystem2/in_2'])
set_param([sys,'/','Totzeiten (10 bis 19)T/Subsystem2/in_2'],...
		'Port','2',...
		'position',[15,140,35,160])

add_block('built-in/Filter',[sys,'/','Totzeiten (10 bis 19)T/Subsystem2/Filter'])
set_param([sys,'/','Totzeiten (10 bis 19)T/Subsystem2/Filter'],...
		'Numerator','[REG(13,1) REG(13,1)*REG(13,2) REG(13,1)*REG(13,3)]',...
		'Denominator','[1 -1]',...
		'position',[165,45,520,85])

add_block('built-in/Outport',[sys,'/','Totzeiten (10 bis 19)T/Subsystem2/out_1'])
set_param([sys,'/','Totzeiten (10 bis 19)T/Subsystem2/out_1'],...
		'position',[540,55,560,75])
add_line([sys,'/','Totzeiten (10 bis 19)T/Subsystem2'],[190,150;190,115;45,115;55,70])
add_line([sys,'/','Totzeiten (10 bis 19)T/Subsystem2'],[120,150;145,150])
add_line([sys,'/','Totzeiten (10 bis 19)T/Subsystem2'],[85,65;105,65])
add_line([sys,'/','Totzeiten (10 bis 19)T/Subsystem2'],[150,65;160,65])
add_line([sys,'/','Totzeiten (10 bis 19)T/Subsystem2'],[40,60;55,60])
add_line([sys,'/','Totzeiten (10 bis 19)T/Subsystem2'],[525,65;535,65])
add_line([sys,'/','Totzeiten (10 bis 19)T/Subsystem2'],[190,150;235,150])
add_line([sys,'/','Totzeiten (10 bis 19)T/Subsystem2'],[40,150;75,150])


%     Finished composite block 'Totzeiten (10 bis 19)T/Subsystem2'.

set_param([sys,'/','Totzeiten (10 bis 19)T/Subsystem2'],...
		'position',[135,172,165,223])


%     Subsystem  'Totzeiten (10 bis 19)T/Subsystem1'.

new_system([sys,'/','Totzeiten (10 bis 19)T/Subsystem1'])
set_param([sys,'/','Totzeiten (10 bis 19)T/Subsystem1'],'Location',[45,42,596,276])

add_block('built-in/Transfer Fcn',[sys,'/','Totzeiten (10 bis 19)T/Subsystem1/Transfer Fcn1'])
set_param([sys,'/','Totzeiten (10 bis 19)T/Subsystem1/Transfer Fcn1'],...
		'Denominator','[4 1]',...
		'position',[150,132,185,168])

add_block('built-in/Transfer Fcn',[sys,'/','Totzeiten (10 bis 19)T/Subsystem1/Transfer Fcn'])
set_param([sys,'/','Totzeiten (10 bis 19)T/Subsystem1/Transfer Fcn'],...
		'Denominator','[10 1]',...
		'position',[80,132,115,168])

add_block('built-in/Zero-Order Hold',[sys,'/',['Totzeiten (10 bis 19)T/Subsystem1/Zero-Order',13,'Hold']])
set_param([sys,'/',['Totzeiten (10 bis 19)T/Subsystem1/Zero-Order',13,'Hold']],...
		'position',[110,49,145,81])

add_block('built-in/Sum',[sys,'/','Totzeiten (10 bis 19)T/Subsystem1/Sum'])
set_param([sys,'/','Totzeiten (10 bis 19)T/Subsystem1/Sum'],...
		'inputs','+-',...
		'position',[60,55,80,75])

add_block('built-in/Inport',[sys,'/','Totzeiten (10 bis 19)T/Subsystem1/in_1'])
set_param([sys,'/','Totzeiten (10 bis 19)T/Subsystem1/in_1'],...
		'position',[15,50,35,70])

add_block('built-in/Outport',[sys,'/','Totzeiten (10 bis 19)T/Subsystem1/out_2'])
set_param([sys,'/','Totzeiten (10 bis 19)T/Subsystem1/out_2'],...
		'Port','2',...
		'position',[240,140,260,160])

add_block('built-in/Inport',[sys,'/','Totzeiten (10 bis 19)T/Subsystem1/in_2'])
set_param([sys,'/','Totzeiten (10 bis 19)T/Subsystem1/in_2'],...
		'Port','2',...
		'position',[15,140,35,160])

add_block('built-in/Filter',[sys,'/','Totzeiten (10 bis 19)T/Subsystem1/Filter'])
set_param([sys,'/','Totzeiten (10 bis 19)T/Subsystem1/Filter'],...
		'Numerator','[REG(12,1) REG(12,1)*REG(12,2) REG(12,1)*REG(12,3)]',...
		'Denominator','[1 -1]',...
		'position',[165,45,500,85])

add_block('built-in/Outport',[sys,'/','Totzeiten (10 bis 19)T/Subsystem1/out_1'])
set_param([sys,'/','Totzeiten (10 bis 19)T/Subsystem1/out_1'],...
		'position',[520,55,540,75])
add_line([sys,'/','Totzeiten (10 bis 19)T/Subsystem1'],[190,150;190,115;45,115;55,70])
add_line([sys,'/','Totzeiten (10 bis 19)T/Subsystem1'],[120,150;145,150])
add_line([sys,'/','Totzeiten (10 bis 19)T/Subsystem1'],[85,65;105,65])
add_line([sys,'/','Totzeiten (10 bis 19)T/Subsystem1'],[150,65;160,65])
add_line([sys,'/','Totzeiten (10 bis 19)T/Subsystem1'],[40,60;55,60])
add_line([sys,'/','Totzeiten (10 bis 19)T/Subsystem1'],[505,65;515,65])
add_line([sys,'/','Totzeiten (10 bis 19)T/Subsystem1'],[190,150;235,150])
add_line([sys,'/','Totzeiten (10 bis 19)T/Subsystem1'],[40,150;75,150])


%     Finished composite block 'Totzeiten (10 bis 19)T/Subsystem1'.

set_param([sys,'/','Totzeiten (10 bis 19)T/Subsystem1'],...
		'position',[125,92,155,143])

add_block('built-in/Filter',[sys,'/','Totzeiten (10 bis 19)T/Filter1'])
set_param([sys,'/','Totzeiten (10 bis 19)T/Filter1'],...
		'Numerator','[0 0 0 0 0 0 0 0 0 0 0 1]',...
		'Denominator','[1]',...
		'position',[185,91,245,129])

add_block('built-in/Inport',[sys,'/','Totzeiten (10 bis 19)T/in_1'])
set_param([sys,'/','Totzeiten (10 bis 19)T/in_1'],...
		'position',[30,64,50,86])
add_line([sys,'/','Totzeiten (10 bis 19)T'],[165,375;180,375;180,415;535,415;535,235;565,235])
add_line([sys,'/','Totzeiten (10 bis 19)T'],[360,390;375,390;375,400;520,400;520,225;565,225])
add_line([sys,'/','Totzeiten (10 bis 19)T'],[170,295;185,295;185,310;290,310;290,335;505,335;505,215;565,215])
add_line([sys,'/','Totzeiten (10 bis 19)T'],[355,310;375,310;375,330;495,330;495,205;565,205])
add_line([sys,'/','Totzeiten (10 bis 19)T'],[170,210;185,210;185,225;295,225;295,255;485,255;485,195;565,195])
add_line([sys,'/','Totzeiten (10 bis 19)T'],[350,220;365,220;365,235;475,235;475,185;565,185])
add_line([sys,'/','Totzeiten (10 bis 19)T'],[350,140;365,140;365,165;565,165])
add_line([sys,'/','Totzeiten (10 bis 19)T'],[170,50;185,50;185,65;280,65;280,85;535,85;535,155;565,155])
add_line([sys,'/','Totzeiten (10 bis 19)T'],[375,50;395,50;395,65;550,65;550,145;565,145])
add_line([sys,'/','Totzeiten (10 bis 19)T'],[55,75;65,75;65,400;280,400;280,365;320,365])
add_line([sys,'/','Totzeiten (10 bis 19)T'],[55,75;285,75;285,285;315,285])
add_line([sys,'/','Totzeiten (10 bis 19)T'],[55,75;295,75;295,25;335,25])
add_line([sys,'/','Totzeiten (10 bis 19)T'],[470,30;480,30;480,5;320,5;320,50;335,50])
add_line([sys,'/','Totzeiten (10 bis 19)T'],[375,25;390,25;400,30])
add_line([sys,'/','Totzeiten (10 bis 19)T'],[445,120;455,120;455,95;300,95;310,140])
add_line([sys,'/','Totzeiten (10 bis 19)T'],[350,115;365,115;375,120])
add_line([sys,'/','Totzeiten (10 bis 19)T'],[445,200;455,200;455,175;295,175;295,220;310,220])
add_line([sys,'/','Totzeiten (10 bis 19)T'],[350,195;355,195;355,200;375,200])
add_line([sys,'/','Totzeiten (10 bis 19)T'],[450,290;460,290;460,265;300,265;300,310;315,310])
add_line([sys,'/','Totzeiten (10 bis 19)T'],[355,285;370,285;380,290])
add_line([sys,'/','Totzeiten (10 bis 19)T'],[455,370;465,370;465,345;305,345;305,390;320,390])
add_line([sys,'/','Totzeiten (10 bis 19)T'],[360,365;375,365;385,370])
add_line([sys,'/','Totzeiten (10 bis 19)T'],[255,355;260,355;260,330;105,330;105,375;125,375])
add_line([sys,'/','Totzeiten (10 bis 19)T'],[165,350;165,355;185,355])
add_line([sys,'/','Totzeiten (10 bis 19)T'],[260,275;265,275;265,250;110,250;110,295;130,295])
add_line([sys,'/','Totzeiten (10 bis 19)T'],[170,270;170,275;190,275])
add_line([sys,'/','Totzeiten (10 bis 19)T'],[260,190;265,190;265,165;110,165;110,210;130,210])
add_line([sys,'/','Totzeiten (10 bis 19)T'],[170,185;170,190;190,190])
add_line([sys,'/','Totzeiten (10 bis 19)T'],[250,110;250,85;110,85;120,130])
add_line([sys,'/','Totzeiten (10 bis 19)T'],[260,25;270,25;270,0;115,0;115,50;130,50])
add_line([sys,'/','Totzeiten (10 bis 19)T'],[170,25;190,25])
add_line([sys,'/','Totzeiten (10 bis 19)T'],[605,190;615,190;615,95;600,95])
add_line([sys,'/','Totzeiten (10 bis 19)T'],[65,350;125,350])
add_line([sys,'/','Totzeiten (10 bis 19)T'],[65,270;130,270])
add_line([sys,'/','Totzeiten (10 bis 19)T'],[65,240;270,240;270,195;310,195])
add_line([sys,'/','Totzeiten (10 bis 19)T'],[65,75;65,25;130,25])
add_line([sys,'/','Totzeiten (10 bis 19)T'],[65,105;120,105])
add_line([sys,'/','Totzeiten (10 bis 19)T'],[65,185;130,185])
add_line([sys,'/','Totzeiten (10 bis 19)T'],[65,160;270,160;270,115;310,115])
add_line([sys,'/','Totzeiten (10 bis 19)T'],[160,130;180,130;180,145;295,145;295,175;565,175])
add_line([sys,'/','Totzeiten (10 bis 19)T'],[160,105;170,105;180,110])


%     Finished composite block 'Totzeiten (10 bis 19)T'.

set_param([sys,'/','Totzeiten (10 bis 19)T'],...
		'position',[190,90,220,140])


%     Subsystem  'Totzeiten (20 bis 29)T'.

new_system([sys,'/','Totzeiten (20 bis 29)T'])
set_param([sys,'/','Totzeiten (20 bis 29)T'],'Location',[4,42,628,468])

add_block('built-in/Filter',[sys,'/','Totzeiten (20 bis 29)T/Filter1'])
set_param([sys,'/','Totzeiten (20 bis 29)T/Filter1'],...
		'Numerator','[0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 1]',...
		'Denominator','[1]',...
		'position',[200,96,260,134])


%     Subsystem  'Totzeiten (20 bis 29)T/Subsystem1'.

new_system([sys,'/','Totzeiten (20 bis 29)T/Subsystem1'])
set_param([sys,'/','Totzeiten (20 bis 29)T/Subsystem1'],'Location',[45,42,620,276])

add_block('built-in/Transfer Fcn',[sys,'/','Totzeiten (20 bis 29)T/Subsystem1/Transfer Fcn1'])
set_param([sys,'/','Totzeiten (20 bis 29)T/Subsystem1/Transfer Fcn1'],...
		'Denominator','[4 1]',...
		'position',[150,132,185,168])

add_block('built-in/Transfer Fcn',[sys,'/','Totzeiten (20 bis 29)T/Subsystem1/Transfer Fcn'])
set_param([sys,'/','Totzeiten (20 bis 29)T/Subsystem1/Transfer Fcn'],...
		'Denominator','[10 1]',...
		'position',[80,132,115,168])

add_block('built-in/Zero-Order Hold',[sys,'/',['Totzeiten (20 bis 29)T/Subsystem1/Zero-Order',13,'Hold']])
set_param([sys,'/',['Totzeiten (20 bis 29)T/Subsystem1/Zero-Order',13,'Hold']],...
		'position',[110,49,145,81])

add_block('built-in/Sum',[sys,'/','Totzeiten (20 bis 29)T/Subsystem1/Sum'])
set_param([sys,'/','Totzeiten (20 bis 29)T/Subsystem1/Sum'],...
		'inputs','+-',...
		'position',[60,55,80,75])

add_block('built-in/Inport',[sys,'/','Totzeiten (20 bis 29)T/Subsystem1/in_1'])
set_param([sys,'/','Totzeiten (20 bis 29)T/Subsystem1/in_1'],...
		'position',[15,50,35,70])

add_block('built-in/Outport',[sys,'/','Totzeiten (20 bis 29)T/Subsystem1/out_2'])
set_param([sys,'/','Totzeiten (20 bis 29)T/Subsystem1/out_2'],...
		'Port','2',...
		'position',[240,140,260,160])

add_block('built-in/Inport',[sys,'/','Totzeiten (20 bis 29)T/Subsystem1/in_2'])
set_param([sys,'/','Totzeiten (20 bis 29)T/Subsystem1/in_2'],...
		'Port','2',...
		'position',[15,140,35,160])

add_block('built-in/Filter',[sys,'/','Totzeiten (20 bis 29)T/Subsystem1/Filter'])
set_param([sys,'/','Totzeiten (20 bis 29)T/Subsystem1/Filter'],...
		'Numerator','[REG(22,1) REG(22,1)*REG(22,2) REG(22,1)*REG(22,3)]',...
		'Denominator','[1 -1]',...
		'position',[165,45,480,85])

add_block('built-in/Outport',[sys,'/','Totzeiten (20 bis 29)T/Subsystem1/out_1'])
set_param([sys,'/','Totzeiten (20 bis 29)T/Subsystem1/out_1'],...
		'position',[510,55,530,75])
add_line([sys,'/','Totzeiten (20 bis 29)T/Subsystem1'],[190,150;190,115;45,115;55,70])
add_line([sys,'/','Totzeiten (20 bis 29)T/Subsystem1'],[120,150;145,150])
add_line([sys,'/','Totzeiten (20 bis 29)T/Subsystem1'],[85,65;105,65])
add_line([sys,'/','Totzeiten (20 bis 29)T/Subsystem1'],[150,65;160,65])
add_line([sys,'/','Totzeiten (20 bis 29)T/Subsystem1'],[40,60;55,60])
add_line([sys,'/','Totzeiten (20 bis 29)T/Subsystem1'],[485,65;505,65])
add_line([sys,'/','Totzeiten (20 bis 29)T/Subsystem1'],[190,150;235,150])
add_line([sys,'/','Totzeiten (20 bis 29)T/Subsystem1'],[40,150;75,150])


%     Finished composite block 'Totzeiten (20 bis 29)T/Subsystem1'.

set_param([sys,'/','Totzeiten (20 bis 29)T/Subsystem1'],...
		'position',[140,97,170,148])

add_block('built-in/Filter',[sys,'/','Totzeiten (20 bis 29)T/Filter2'])
set_param([sys,'/','Totzeiten (20 bis 29)T/Filter2'],...
		'Numerator','[0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 1]',...
		'Denominator','[1]',...
		'position',[205,176,265,214])


%     Subsystem  'Totzeiten (20 bis 29)T/Subsystem2'.

new_system([sys,'/','Totzeiten (20 bis 29)T/Subsystem2'])
set_param([sys,'/','Totzeiten (20 bis 29)T/Subsystem2'],'Location',[45,42,620,276])

add_block('built-in/Transfer Fcn',[sys,'/','Totzeiten (20 bis 29)T/Subsystem2/Transfer Fcn1'])
set_param([sys,'/','Totzeiten (20 bis 29)T/Subsystem2/Transfer Fcn1'],...
		'Denominator','[4 1]',...
		'position',[150,132,185,168])

add_block('built-in/Transfer Fcn',[sys,'/','Totzeiten (20 bis 29)T/Subsystem2/Transfer Fcn'])
set_param([sys,'/','Totzeiten (20 bis 29)T/Subsystem2/Transfer Fcn'],...
		'Denominator','[10 1]',...
		'position',[80,132,115,168])

add_block('built-in/Zero-Order Hold',[sys,'/',['Totzeiten (20 bis 29)T/Subsystem2/Zero-Order',13,'Hold']])
set_param([sys,'/',['Totzeiten (20 bis 29)T/Subsystem2/Zero-Order',13,'Hold']],...
		'position',[110,49,145,81])

add_block('built-in/Sum',[sys,'/','Totzeiten (20 bis 29)T/Subsystem2/Sum'])
set_param([sys,'/','Totzeiten (20 bis 29)T/Subsystem2/Sum'],...
		'inputs','+-',...
		'position',[60,55,80,75])

add_block('built-in/Inport',[sys,'/','Totzeiten (20 bis 29)T/Subsystem2/in_1'])
set_param([sys,'/','Totzeiten (20 bis 29)T/Subsystem2/in_1'],...
		'position',[15,50,35,70])

add_block('built-in/Outport',[sys,'/','Totzeiten (20 bis 29)T/Subsystem2/out_2'])
set_param([sys,'/','Totzeiten (20 bis 29)T/Subsystem2/out_2'],...
		'Port','2',...
		'position',[240,140,260,160])

add_block('built-in/Inport',[sys,'/','Totzeiten (20 bis 29)T/Subsystem2/in_2'])
set_param([sys,'/','Totzeiten (20 bis 29)T/Subsystem2/in_2'],...
		'Port','2',...
		'position',[15,140,35,160])

add_block('built-in/Filter',[sys,'/','Totzeiten (20 bis 29)T/Subsystem2/Filter'])
set_param([sys,'/','Totzeiten (20 bis 29)T/Subsystem2/Filter'],...
		'Numerator','[REG(23,1) REG(23,1)*REG(23,2) REG(23,1)*REG(23,3)]',...
		'Denominator','[1 -1]',...
		'position',[165,45,490,85])

add_block('built-in/Outport',[sys,'/','Totzeiten (20 bis 29)T/Subsystem2/out_1'])
set_param([sys,'/','Totzeiten (20 bis 29)T/Subsystem2/out_1'],...
		'position',[505,55,525,75])
add_line([sys,'/','Totzeiten (20 bis 29)T/Subsystem2'],[190,150;190,115;45,115;55,70])
add_line([sys,'/','Totzeiten (20 bis 29)T/Subsystem2'],[120,150;145,150])
add_line([sys,'/','Totzeiten (20 bis 29)T/Subsystem2'],[85,65;105,65])
add_line([sys,'/','Totzeiten (20 bis 29)T/Subsystem2'],[150,65;160,65])
add_line([sys,'/','Totzeiten (20 bis 29)T/Subsystem2'],[40,60;55,60])
add_line([sys,'/','Totzeiten (20 bis 29)T/Subsystem2'],[495,65;500,65])
add_line([sys,'/','Totzeiten (20 bis 29)T/Subsystem2'],[190,150;235,150])
add_line([sys,'/','Totzeiten (20 bis 29)T/Subsystem2'],[40,150;75,150])


%     Finished composite block 'Totzeiten (20 bis 29)T/Subsystem2'.

set_param([sys,'/','Totzeiten (20 bis 29)T/Subsystem2'],...
		'position',[145,177,175,228])


%     Subsystem  'Totzeiten (20 bis 29)T/Subsystem4'.

new_system([sys,'/','Totzeiten (20 bis 29)T/Subsystem4'])
set_param([sys,'/','Totzeiten (20 bis 29)T/Subsystem4'],'Location',[45,42,596,276])

add_block('built-in/Transfer Fcn',[sys,'/','Totzeiten (20 bis 29)T/Subsystem4/Transfer Fcn1'])
set_param([sys,'/','Totzeiten (20 bis 29)T/Subsystem4/Transfer Fcn1'],...
		'Denominator','[4 1]',...
		'position',[150,132,185,168])

add_block('built-in/Transfer Fcn',[sys,'/','Totzeiten (20 bis 29)T/Subsystem4/Transfer Fcn'])
set_param([sys,'/','Totzeiten (20 bis 29)T/Subsystem4/Transfer Fcn'],...
		'Denominator','[10 1]',...
		'position',[80,132,115,168])

add_block('built-in/Zero-Order Hold',[sys,'/',['Totzeiten (20 bis 29)T/Subsystem4/Zero-Order',13,'Hold']])
set_param([sys,'/',['Totzeiten (20 bis 29)T/Subsystem4/Zero-Order',13,'Hold']],...
		'position',[110,49,145,81])

add_block('built-in/Sum',[sys,'/','Totzeiten (20 bis 29)T/Subsystem4/Sum'])
set_param([sys,'/','Totzeiten (20 bis 29)T/Subsystem4/Sum'],...
		'inputs','+-',...
		'position',[60,55,80,75])

add_block('built-in/Inport',[sys,'/','Totzeiten (20 bis 29)T/Subsystem4/in_1'])
set_param([sys,'/','Totzeiten (20 bis 29)T/Subsystem4/in_1'],...
		'position',[15,50,35,70])

add_block('built-in/Outport',[sys,'/','Totzeiten (20 bis 29)T/Subsystem4/out_2'])
set_param([sys,'/','Totzeiten (20 bis 29)T/Subsystem4/out_2'],...
		'Port','2',...
		'position',[240,140,260,160])

add_block('built-in/Inport',[sys,'/','Totzeiten (20 bis 29)T/Subsystem4/in_2'])
set_param([sys,'/','Totzeiten (20 bis 29)T/Subsystem4/in_2'],...
		'Port','2',...
		'position',[15,140,35,160])

add_block('built-in/Filter',[sys,'/','Totzeiten (20 bis 29)T/Subsystem4/Filter'])
set_param([sys,'/','Totzeiten (20 bis 29)T/Subsystem4/Filter'],...
		'Numerator','[REG(25,1) REG(25,1)*REG(25,2) REG(25,1)*REG(25,3)]',...
		'Denominator','[1 -1]',...
		'position',[165,45,485,85])

add_block('built-in/Outport',[sys,'/','Totzeiten (20 bis 29)T/Subsystem4/out_1'])
set_param([sys,'/','Totzeiten (20 bis 29)T/Subsystem4/out_1'],...
		'position',[510,55,530,75])
add_line([sys,'/','Totzeiten (20 bis 29)T/Subsystem4'],[190,150;190,115;45,115;55,70])
add_line([sys,'/','Totzeiten (20 bis 29)T/Subsystem4'],[120,150;145,150])
add_line([sys,'/','Totzeiten (20 bis 29)T/Subsystem4'],[85,65;105,65])
add_line([sys,'/','Totzeiten (20 bis 29)T/Subsystem4'],[150,65;160,65])
add_line([sys,'/','Totzeiten (20 bis 29)T/Subsystem4'],[40,60;55,60])
add_line([sys,'/','Totzeiten (20 bis 29)T/Subsystem4'],[490,65;505,65])
add_line([sys,'/','Totzeiten (20 bis 29)T/Subsystem4'],[190,150;235,150])
add_line([sys,'/','Totzeiten (20 bis 29)T/Subsystem4'],[40,150;75,150])


%     Finished composite block 'Totzeiten (20 bis 29)T/Subsystem4'.

set_param([sys,'/','Totzeiten (20 bis 29)T/Subsystem4'],...
		'position',[140,342,170,393])

add_block('built-in/Filter',[sys,'/','Totzeiten (20 bis 29)T/Filter4'])
set_param([sys,'/','Totzeiten (20 bis 29)T/Filter4'],...
		'Numerator','[0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 1]',...
		'Denominator','[1]',...
		'position',[200,341,260,379])

add_block('built-in/Filter',[sys,'/','Totzeiten (20 bis 29)T/Filter5'])
set_param([sys,'/','Totzeiten (20 bis 29)T/Filter5'],...
		'Numerator','[0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 1]',...
		'Denominator','[1]',...
		'position',[400,356,460,394])


%     Subsystem  'Totzeiten (20 bis 29)T/Subsystem5'.

new_system([sys,'/','Totzeiten (20 bis 29)T/Subsystem5'])
set_param([sys,'/','Totzeiten (20 bis 29)T/Subsystem5'],'Location',[45,42,620,276])

add_block('built-in/Transfer Fcn',[sys,'/','Totzeiten (20 bis 29)T/Subsystem5/Transfer Fcn1'])
set_param([sys,'/','Totzeiten (20 bis 29)T/Subsystem5/Transfer Fcn1'],...
		'Denominator','[4 1]',...
		'position',[150,132,185,168])

add_block('built-in/Transfer Fcn',[sys,'/','Totzeiten (20 bis 29)T/Subsystem5/Transfer Fcn'])
set_param([sys,'/','Totzeiten (20 bis 29)T/Subsystem5/Transfer Fcn'],...
		'Denominator','[10 1]',...
		'position',[80,132,115,168])

add_block('built-in/Zero-Order Hold',[sys,'/',['Totzeiten (20 bis 29)T/Subsystem5/Zero-Order',13,'Hold']])
set_param([sys,'/',['Totzeiten (20 bis 29)T/Subsystem5/Zero-Order',13,'Hold']],...
		'position',[110,49,145,81])

add_block('built-in/Sum',[sys,'/','Totzeiten (20 bis 29)T/Subsystem5/Sum'])
set_param([sys,'/','Totzeiten (20 bis 29)T/Subsystem5/Sum'],...
		'inputs','+-',...
		'position',[60,55,80,75])

add_block('built-in/Inport',[sys,'/','Totzeiten (20 bis 29)T/Subsystem5/in_1'])
set_param([sys,'/','Totzeiten (20 bis 29)T/Subsystem5/in_1'],...
		'position',[15,50,35,70])

add_block('built-in/Outport',[sys,'/','Totzeiten (20 bis 29)T/Subsystem5/out_2'])
set_param([sys,'/','Totzeiten (20 bis 29)T/Subsystem5/out_2'],...
		'Port','2',...
		'position',[240,140,260,160])

add_block('built-in/Inport',[sys,'/','Totzeiten (20 bis 29)T/Subsystem5/in_2'])
set_param([sys,'/','Totzeiten (20 bis 29)T/Subsystem5/in_2'],...
		'Port','2',...
		'position',[15,140,35,160])

add_block('built-in/Filter',[sys,'/','Totzeiten (20 bis 29)T/Subsystem5/Filter'])
set_param([sys,'/','Totzeiten (20 bis 29)T/Subsystem5/Filter'],...
		'Numerator','[REG(30,1) REG(30,1)*REG(30,2) REG(30,1)*REG(30,3)]',...
		'Denominator','[1 -1]',...
		'position',[165,45,480,85])

add_block('built-in/Outport',[sys,'/','Totzeiten (20 bis 29)T/Subsystem5/out_1'])
set_param([sys,'/','Totzeiten (20 bis 29)T/Subsystem5/out_1'],...
		'position',[510,55,530,75])
add_line([sys,'/','Totzeiten (20 bis 29)T/Subsystem5'],[190,150;190,115;45,115;55,70])
add_line([sys,'/','Totzeiten (20 bis 29)T/Subsystem5'],[120,150;145,150])
add_line([sys,'/','Totzeiten (20 bis 29)T/Subsystem5'],[85,65;105,65])
add_line([sys,'/','Totzeiten (20 bis 29)T/Subsystem5'],[150,65;160,65])
add_line([sys,'/','Totzeiten (20 bis 29)T/Subsystem5'],[40,60;55,60])
add_line([sys,'/','Totzeiten (20 bis 29)T/Subsystem5'],[485,65;505,65])
add_line([sys,'/','Totzeiten (20 bis 29)T/Subsystem5'],[190,150;235,150])
add_line([sys,'/','Totzeiten (20 bis 29)T/Subsystem5'],[40,150;75,150])


%     Finished composite block 'Totzeiten (20 bis 29)T/Subsystem5'.

set_param([sys,'/','Totzeiten (20 bis 29)T/Subsystem5'],...
		'position',[335,357,365,408])


%     Subsystem  'Totzeiten (20 bis 29)T/Subsystem6'.

new_system([sys,'/','Totzeiten (20 bis 29)T/Subsystem6'])
set_param([sys,'/','Totzeiten (20 bis 29)T/Subsystem6'],'Location',[45,42,620,276])

add_block('built-in/Transfer Fcn',[sys,'/','Totzeiten (20 bis 29)T/Subsystem6/Transfer Fcn1'])
set_param([sys,'/','Totzeiten (20 bis 29)T/Subsystem6/Transfer Fcn1'],...
		'Denominator','[4 1]',...
		'position',[150,132,185,168])

add_block('built-in/Transfer Fcn',[sys,'/','Totzeiten (20 bis 29)T/Subsystem6/Transfer Fcn'])
set_param([sys,'/','Totzeiten (20 bis 29)T/Subsystem6/Transfer Fcn'],...
		'Denominator','[10 1]',...
		'position',[80,132,115,168])

add_block('built-in/Zero-Order Hold',[sys,'/',['Totzeiten (20 bis 29)T/Subsystem6/Zero-Order',13,'Hold']])
set_param([sys,'/',['Totzeiten (20 bis 29)T/Subsystem6/Zero-Order',13,'Hold']],...
		'position',[110,49,145,81])

add_block('built-in/Sum',[sys,'/','Totzeiten (20 bis 29)T/Subsystem6/Sum'])
set_param([sys,'/','Totzeiten (20 bis 29)T/Subsystem6/Sum'],...
		'inputs','+-',...
		'position',[60,55,80,75])

add_block('built-in/Inport',[sys,'/','Totzeiten (20 bis 29)T/Subsystem6/in_1'])
set_param([sys,'/','Totzeiten (20 bis 29)T/Subsystem6/in_1'],...
		'position',[15,50,35,70])

add_block('built-in/Outport',[sys,'/','Totzeiten (20 bis 29)T/Subsystem6/out_2'])
set_param([sys,'/','Totzeiten (20 bis 29)T/Subsystem6/out_2'],...
		'Port','2',...
		'position',[240,140,260,160])

add_block('built-in/Inport',[sys,'/','Totzeiten (20 bis 29)T/Subsystem6/in_2'])
set_param([sys,'/','Totzeiten (20 bis 29)T/Subsystem6/in_2'],...
		'Port','2',...
		'position',[15,140,35,160])

add_block('built-in/Filter',[sys,'/','Totzeiten (20 bis 29)T/Subsystem6/Filter'])
set_param([sys,'/','Totzeiten (20 bis 29)T/Subsystem6/Filter'],...
		'Numerator','[REG(29,1) REG(29,1)*REG(29,2) REG(29,1)*REG(29,3)]',...
		'Denominator','[1 -1]',...
		'position',[165,45,495,85])

add_block('built-in/Outport',[sys,'/','Totzeiten (20 bis 29)T/Subsystem6/out_1'])
set_param([sys,'/','Totzeiten (20 bis 29)T/Subsystem6/out_1'],...
		'position',[525,55,545,75])
add_line([sys,'/','Totzeiten (20 bis 29)T/Subsystem6'],[190,150;190,115;45,115;55,70])
add_line([sys,'/','Totzeiten (20 bis 29)T/Subsystem6'],[120,150;145,150])
add_line([sys,'/','Totzeiten (20 bis 29)T/Subsystem6'],[85,65;105,65])
add_line([sys,'/','Totzeiten (20 bis 29)T/Subsystem6'],[150,65;160,65])
add_line([sys,'/','Totzeiten (20 bis 29)T/Subsystem6'],[40,60;55,60])
add_line([sys,'/','Totzeiten (20 bis 29)T/Subsystem6'],[500,65;520,65])
add_line([sys,'/','Totzeiten (20 bis 29)T/Subsystem6'],[190,150;235,150])
add_line([sys,'/','Totzeiten (20 bis 29)T/Subsystem6'],[40,150;75,150])


%     Finished composite block 'Totzeiten (20 bis 29)T/Subsystem6'.

set_param([sys,'/','Totzeiten (20 bis 29)T/Subsystem6'],...
		'position',[330,277,360,328])

add_block('built-in/Filter',[sys,'/','Totzeiten (20 bis 29)T/Filter6'])
set_param([sys,'/','Totzeiten (20 bis 29)T/Filter6'],...
		'Numerator','[0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 1]',...
		'Denominator','[1]',...
		'position',[395,276,455,314])


%     Subsystem  'Totzeiten (20 bis 29)T/Subsystem7'.

new_system([sys,'/','Totzeiten (20 bis 29)T/Subsystem7'])
set_param([sys,'/','Totzeiten (20 bis 29)T/Subsystem7'],'Location',[45,42,620,276])

add_block('built-in/Transfer Fcn',[sys,'/','Totzeiten (20 bis 29)T/Subsystem7/Transfer Fcn1'])
set_param([sys,'/','Totzeiten (20 bis 29)T/Subsystem7/Transfer Fcn1'],...
		'Denominator','[4 1]',...
		'position',[150,132,185,168])

add_block('built-in/Transfer Fcn',[sys,'/','Totzeiten (20 bis 29)T/Subsystem7/Transfer Fcn'])
set_param([sys,'/','Totzeiten (20 bis 29)T/Subsystem7/Transfer Fcn'],...
		'Denominator','[10 1]',...
		'position',[80,132,115,168])

add_block('built-in/Zero-Order Hold',[sys,'/',['Totzeiten (20 bis 29)T/Subsystem7/Zero-Order',13,'Hold']])
set_param([sys,'/',['Totzeiten (20 bis 29)T/Subsystem7/Zero-Order',13,'Hold']],...
		'position',[110,49,145,81])

add_block('built-in/Sum',[sys,'/','Totzeiten (20 bis 29)T/Subsystem7/Sum'])
set_param([sys,'/','Totzeiten (20 bis 29)T/Subsystem7/Sum'],...
		'inputs','+-',...
		'position',[60,55,80,75])

add_block('built-in/Inport',[sys,'/','Totzeiten (20 bis 29)T/Subsystem7/in_1'])
set_param([sys,'/','Totzeiten (20 bis 29)T/Subsystem7/in_1'],...
		'position',[15,50,35,70])

add_block('built-in/Outport',[sys,'/','Totzeiten (20 bis 29)T/Subsystem7/out_2'])
set_param([sys,'/','Totzeiten (20 bis 29)T/Subsystem7/out_2'],...
		'Port','2',...
		'position',[240,140,260,160])

add_block('built-in/Inport',[sys,'/','Totzeiten (20 bis 29)T/Subsystem7/in_2'])
set_param([sys,'/','Totzeiten (20 bis 29)T/Subsystem7/in_2'],...
		'Port','2',...
		'position',[15,140,35,160])

add_block('built-in/Filter',[sys,'/','Totzeiten (20 bis 29)T/Subsystem7/Filter'])
set_param([sys,'/','Totzeiten (20 bis 29)T/Subsystem7/Filter'],...
		'Numerator','[REG(28,1) REG(28,1)*REG(28,2) REG(28,1)*REG(28,3)]',...
		'Denominator','[1 -1]',...
		'position',[165,47,495,83])

add_block('built-in/Outport',[sys,'/','Totzeiten (20 bis 29)T/Subsystem7/out_1'])
set_param([sys,'/','Totzeiten (20 bis 29)T/Subsystem7/out_1'],...
		'position',[510,55,530,75])
add_line([sys,'/','Totzeiten (20 bis 29)T/Subsystem7'],[190,150;190,115;45,115;55,70])
add_line([sys,'/','Totzeiten (20 bis 29)T/Subsystem7'],[120,150;145,150])
add_line([sys,'/','Totzeiten (20 bis 29)T/Subsystem7'],[85,65;105,65])
add_line([sys,'/','Totzeiten (20 bis 29)T/Subsystem7'],[150,65;160,65])
add_line([sys,'/','Totzeiten (20 bis 29)T/Subsystem7'],[40,60;55,60])
add_line([sys,'/','Totzeiten (20 bis 29)T/Subsystem7'],[500,65;505,65])
add_line([sys,'/','Totzeiten (20 bis 29)T/Subsystem7'],[190,150;235,150])
add_line([sys,'/','Totzeiten (20 bis 29)T/Subsystem7'],[40,150;75,150])


%     Finished composite block 'Totzeiten (20 bis 29)T/Subsystem7'.

set_param([sys,'/','Totzeiten (20 bis 29)T/Subsystem7'],...
		'position',[325,187,355,238])

add_block('built-in/Filter',[sys,'/','Totzeiten (20 bis 29)T/Filter7'])
set_param([sys,'/','Totzeiten (20 bis 29)T/Filter7'],...
		'Numerator','[0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 1]',...
		'Denominator','[1]',...
		'position',[390,186,450,224])

add_block('built-in/Filter',[sys,'/','Totzeiten (20 bis 29)T/Filter8'])
set_param([sys,'/','Totzeiten (20 bis 29)T/Filter8'],...
		'Numerator','[0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 1]',...
		'Denominator','[1]',...
		'position',[390,106,450,144])


%     Subsystem  'Totzeiten (20 bis 29)T/Subsystem8'.

new_system([sys,'/','Totzeiten (20 bis 29)T/Subsystem8'])
set_param([sys,'/','Totzeiten (20 bis 29)T/Subsystem8'],'Location',[45,42,620,276])

add_block('built-in/Transfer Fcn',[sys,'/','Totzeiten (20 bis 29)T/Subsystem8/Transfer Fcn1'])
set_param([sys,'/','Totzeiten (20 bis 29)T/Subsystem8/Transfer Fcn1'],...
		'Denominator','[4 1]',...
		'position',[150,132,185,168])

add_block('built-in/Transfer Fcn',[sys,'/','Totzeiten (20 bis 29)T/Subsystem8/Transfer Fcn'])
set_param([sys,'/','Totzeiten (20 bis 29)T/Subsystem8/Transfer Fcn'],...
		'Denominator','[10 1]',...
		'position',[80,132,115,168])

add_block('built-in/Zero-Order Hold',[sys,'/',['Totzeiten (20 bis 29)T/Subsystem8/Zero-Order',13,'Hold']])
set_param([sys,'/',['Totzeiten (20 bis 29)T/Subsystem8/Zero-Order',13,'Hold']],...
		'position',[110,49,145,81])

add_block('built-in/Sum',[sys,'/','Totzeiten (20 bis 29)T/Subsystem8/Sum'])
set_param([sys,'/','Totzeiten (20 bis 29)T/Subsystem8/Sum'],...
		'inputs','+-',...
		'position',[60,55,80,75])

add_block('built-in/Inport',[sys,'/','Totzeiten (20 bis 29)T/Subsystem8/in_1'])
set_param([sys,'/','Totzeiten (20 bis 29)T/Subsystem8/in_1'],...
		'position',[15,50,35,70])

add_block('built-in/Outport',[sys,'/','Totzeiten (20 bis 29)T/Subsystem8/out_2'])
set_param([sys,'/','Totzeiten (20 bis 29)T/Subsystem8/out_2'],...
		'Port','2',...
		'position',[240,140,260,160])

add_block('built-in/Inport',[sys,'/','Totzeiten (20 bis 29)T/Subsystem8/in_2'])
set_param([sys,'/','Totzeiten (20 bis 29)T/Subsystem8/in_2'],...
		'Port','2',...
		'position',[15,140,35,160])

add_block('built-in/Filter',[sys,'/','Totzeiten (20 bis 29)T/Subsystem8/Filter'])
set_param([sys,'/','Totzeiten (20 bis 29)T/Subsystem8/Filter'],...
		'Numerator','[REG(27,1) REG(27,1)*REG(27,2) REG(27,1)*REG(27,3)]',...
		'Denominator','[1 -1]',...
		'position',[165,45,500,85])

add_block('built-in/Outport',[sys,'/','Totzeiten (20 bis 29)T/Subsystem8/out_1'])
set_param([sys,'/','Totzeiten (20 bis 29)T/Subsystem8/out_1'],...
		'position',[530,55,550,75])
add_line([sys,'/','Totzeiten (20 bis 29)T/Subsystem8'],[190,150;190,115;45,115;55,70])
add_line([sys,'/','Totzeiten (20 bis 29)T/Subsystem8'],[120,150;145,150])
add_line([sys,'/','Totzeiten (20 bis 29)T/Subsystem8'],[85,65;105,65])
add_line([sys,'/','Totzeiten (20 bis 29)T/Subsystem8'],[150,65;160,65])
add_line([sys,'/','Totzeiten (20 bis 29)T/Subsystem8'],[40,60;55,60])
add_line([sys,'/','Totzeiten (20 bis 29)T/Subsystem8'],[505,65;525,65])
add_line([sys,'/','Totzeiten (20 bis 29)T/Subsystem8'],[190,150;235,150])
add_line([sys,'/','Totzeiten (20 bis 29)T/Subsystem8'],[40,150;75,150])


%     Finished composite block 'Totzeiten (20 bis 29)T/Subsystem8'.

set_param([sys,'/','Totzeiten (20 bis 29)T/Subsystem8'],...
		'position',[325,107,355,158])

add_block('built-in/Filter',[sys,'/','Totzeiten (20 bis 29)T/Filter9'])
set_param([sys,'/','Totzeiten (20 bis 29)T/Filter9'],...
		'Numerator','[0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 1]',...
		'Denominator','[1]',...
		'position',[415,16,475,54])


%     Subsystem  'Totzeiten (20 bis 29)T/Subsystem9'.

new_system([sys,'/','Totzeiten (20 bis 29)T/Subsystem9'])
set_param([sys,'/','Totzeiten (20 bis 29)T/Subsystem9'],'Location',[45,42,612,276])

add_block('built-in/Transfer Fcn',[sys,'/','Totzeiten (20 bis 29)T/Subsystem9/Transfer Fcn1'])
set_param([sys,'/','Totzeiten (20 bis 29)T/Subsystem9/Transfer Fcn1'],...
		'Denominator','[4 1]',...
		'position',[150,132,185,168])

add_block('built-in/Transfer Fcn',[sys,'/','Totzeiten (20 bis 29)T/Subsystem9/Transfer Fcn'])
set_param([sys,'/','Totzeiten (20 bis 29)T/Subsystem9/Transfer Fcn'],...
		'Denominator','[10 1]',...
		'position',[80,132,115,168])

add_block('built-in/Zero-Order Hold',[sys,'/',['Totzeiten (20 bis 29)T/Subsystem9/Zero-Order',13,'Hold']])
set_param([sys,'/',['Totzeiten (20 bis 29)T/Subsystem9/Zero-Order',13,'Hold']],...
		'position',[110,49,145,81])

add_block('built-in/Sum',[sys,'/','Totzeiten (20 bis 29)T/Subsystem9/Sum'])
set_param([sys,'/','Totzeiten (20 bis 29)T/Subsystem9/Sum'],...
		'inputs','+-',...
		'position',[60,55,80,75])

add_block('built-in/Inport',[sys,'/','Totzeiten (20 bis 29)T/Subsystem9/in_1'])
set_param([sys,'/','Totzeiten (20 bis 29)T/Subsystem9/in_1'],...
		'position',[15,50,35,70])

add_block('built-in/Outport',[sys,'/','Totzeiten (20 bis 29)T/Subsystem9/out_2'])
set_param([sys,'/','Totzeiten (20 bis 29)T/Subsystem9/out_2'],...
		'Port','2',...
		'position',[240,140,260,160])

add_block('built-in/Inport',[sys,'/','Totzeiten (20 bis 29)T/Subsystem9/in_2'])
set_param([sys,'/','Totzeiten (20 bis 29)T/Subsystem9/in_2'],...
		'Port','2',...
		'position',[15,140,35,160])

add_block('built-in/Filter',[sys,'/','Totzeiten (20 bis 29)T/Subsystem9/Filter'])
set_param([sys,'/','Totzeiten (20 bis 29)T/Subsystem9/Filter'],...
		'Numerator','[REG(26,1) REG(26,1)*REG(26,2) REG(26,1)*REG(26,3)]',...
		'Denominator','[1 -1]',...
		'position',[165,45,500,85])

add_block('built-in/Outport',[sys,'/','Totzeiten (20 bis 29)T/Subsystem9/out_1'])
set_param([sys,'/','Totzeiten (20 bis 29)T/Subsystem9/out_1'],...
		'position',[525,55,545,75])
add_line([sys,'/','Totzeiten (20 bis 29)T/Subsystem9'],[190,150;190,115;45,115;55,70])
add_line([sys,'/','Totzeiten (20 bis 29)T/Subsystem9'],[120,150;145,150])
add_line([sys,'/','Totzeiten (20 bis 29)T/Subsystem9'],[85,65;105,65])
add_line([sys,'/','Totzeiten (20 bis 29)T/Subsystem9'],[150,65;160,65])
add_line([sys,'/','Totzeiten (20 bis 29)T/Subsystem9'],[40,60;55,60])
add_line([sys,'/','Totzeiten (20 bis 29)T/Subsystem9'],[505,65;520,65])
add_line([sys,'/','Totzeiten (20 bis 29)T/Subsystem9'],[190,150;235,150])
add_line([sys,'/','Totzeiten (20 bis 29)T/Subsystem9'],[40,150;75,150])


%     Finished composite block 'Totzeiten (20 bis 29)T/Subsystem9'.

set_param([sys,'/','Totzeiten (20 bis 29)T/Subsystem9'],...
		'position',[350,17,380,68])

add_block('built-in/Inport',[sys,'/','Totzeiten (20 bis 29)T/in_1'])
set_param([sys,'/','Totzeiten (20 bis 29)T/in_1'],...
		'position',[20,65,40,85])

add_block('built-in/Filter',[sys,'/','Totzeiten (20 bis 29)T/Filter3'])
set_param([sys,'/','Totzeiten (20 bis 29)T/Filter3'],...
		'Numerator','[0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 1]',...
		'Denominator','[1]',...
		'position',[205,266,265,304])


%     Subsystem  'Totzeiten (20 bis 29)T/Subsystem3'.

new_system([sys,'/','Totzeiten (20 bis 29)T/Subsystem3'])
set_param([sys,'/','Totzeiten (20 bis 29)T/Subsystem3'],'Location',[45,42,604,276])

add_block('built-in/Transfer Fcn',[sys,'/','Totzeiten (20 bis 29)T/Subsystem3/Transfer Fcn1'])
set_param([sys,'/','Totzeiten (20 bis 29)T/Subsystem3/Transfer Fcn1'],...
		'Denominator','[4 1]',...
		'position',[150,132,185,168])

add_block('built-in/Transfer Fcn',[sys,'/','Totzeiten (20 bis 29)T/Subsystem3/Transfer Fcn'])
set_param([sys,'/','Totzeiten (20 bis 29)T/Subsystem3/Transfer Fcn'],...
		'Denominator','[10 1]',...
		'position',[80,132,115,168])

add_block('built-in/Zero-Order Hold',[sys,'/',['Totzeiten (20 bis 29)T/Subsystem3/Zero-Order',13,'Hold']])
set_param([sys,'/',['Totzeiten (20 bis 29)T/Subsystem3/Zero-Order',13,'Hold']],...
		'position',[110,49,145,81])

add_block('built-in/Sum',[sys,'/','Totzeiten (20 bis 29)T/Subsystem3/Sum'])
set_param([sys,'/','Totzeiten (20 bis 29)T/Subsystem3/Sum'],...
		'inputs','+-',...
		'position',[60,55,80,75])

add_block('built-in/Inport',[sys,'/','Totzeiten (20 bis 29)T/Subsystem3/in_1'])
set_param([sys,'/','Totzeiten (20 bis 29)T/Subsystem3/in_1'],...
		'position',[15,50,35,70])

add_block('built-in/Outport',[sys,'/','Totzeiten (20 bis 29)T/Subsystem3/out_2'])
set_param([sys,'/','Totzeiten (20 bis 29)T/Subsystem3/out_2'],...
		'Port','2',...
		'position',[240,140,260,160])

add_block('built-in/Inport',[sys,'/','Totzeiten (20 bis 29)T/Subsystem3/in_2'])
set_param([sys,'/','Totzeiten (20 bis 29)T/Subsystem3/in_2'],...
		'Port','2',...
		'position',[15,140,35,160])

add_block('built-in/Filter',[sys,'/','Totzeiten (20 bis 29)T/Subsystem3/Filter'])
set_param([sys,'/','Totzeiten (20 bis 29)T/Subsystem3/Filter'],...
		'Numerator','[REG(24,1) REG(24,1)*REG(24,2) REG(24,1)*REG(24,3)]',...
		'Denominator','[1 -1]',...
		'position',[165,45,500,85])

add_block('built-in/Outport',[sys,'/','Totzeiten (20 bis 29)T/Subsystem3/out_1'])
set_param([sys,'/','Totzeiten (20 bis 29)T/Subsystem3/out_1'],...
		'position',[520,55,540,75])
add_line([sys,'/','Totzeiten (20 bis 29)T/Subsystem3'],[190,150;190,115;45,115;55,70])
add_line([sys,'/','Totzeiten (20 bis 29)T/Subsystem3'],[120,150;145,150])
add_line([sys,'/','Totzeiten (20 bis 29)T/Subsystem3'],[85,65;105,65])
add_line([sys,'/','Totzeiten (20 bis 29)T/Subsystem3'],[150,65;160,65])
add_line([sys,'/','Totzeiten (20 bis 29)T/Subsystem3'],[40,60;55,60])
add_line([sys,'/','Totzeiten (20 bis 29)T/Subsystem3'],[505,65;515,65])
add_line([sys,'/','Totzeiten (20 bis 29)T/Subsystem3'],[190,150;235,150])
add_line([sys,'/','Totzeiten (20 bis 29)T/Subsystem3'],[40,150;75,150])


%     Finished composite block 'Totzeiten (20 bis 29)T/Subsystem3'.

set_param([sys,'/','Totzeiten (20 bis 29)T/Subsystem3'],...
		'position',[145,267,175,318])


%     Subsystem  'Totzeiten (20 bis 29)T/Subsystem'.

new_system([sys,'/','Totzeiten (20 bis 29)T/Subsystem'])
set_param([sys,'/','Totzeiten (20 bis 29)T/Subsystem'],'Location',[45,42,620,276])

add_block('built-in/Transfer Fcn',[sys,'/','Totzeiten (20 bis 29)T/Subsystem/Transfer Fcn1'])
set_param([sys,'/','Totzeiten (20 bis 29)T/Subsystem/Transfer Fcn1'],...
		'Denominator','[4 1]',...
		'position',[150,132,185,168])

add_block('built-in/Transfer Fcn',[sys,'/','Totzeiten (20 bis 29)T/Subsystem/Transfer Fcn'])
set_param([sys,'/','Totzeiten (20 bis 29)T/Subsystem/Transfer Fcn'],...
		'Denominator','[10 1]',...
		'position',[80,132,115,168])

add_block('built-in/Zero-Order Hold',[sys,'/',['Totzeiten (20 bis 29)T/Subsystem/Zero-Order',13,'Hold']])
set_param([sys,'/',['Totzeiten (20 bis 29)T/Subsystem/Zero-Order',13,'Hold']],...
		'position',[110,49,145,81])

add_block('built-in/Sum',[sys,'/','Totzeiten (20 bis 29)T/Subsystem/Sum'])
set_param([sys,'/','Totzeiten (20 bis 29)T/Subsystem/Sum'],...
		'inputs','+-',...
		'position',[60,55,80,75])

add_block('built-in/Inport',[sys,'/','Totzeiten (20 bis 29)T/Subsystem/in_1'])
set_param([sys,'/','Totzeiten (20 bis 29)T/Subsystem/in_1'],...
		'position',[15,50,35,70])

add_block('built-in/Outport',[sys,'/','Totzeiten (20 bis 29)T/Subsystem/out_2'])
set_param([sys,'/','Totzeiten (20 bis 29)T/Subsystem/out_2'],...
		'Port','2',...
		'position',[240,140,260,160])

add_block('built-in/Inport',[sys,'/','Totzeiten (20 bis 29)T/Subsystem/in_2'])
set_param([sys,'/','Totzeiten (20 bis 29)T/Subsystem/in_2'],...
		'Port','2',...
		'position',[15,140,35,160])

add_block('built-in/Filter',[sys,'/','Totzeiten (20 bis 29)T/Subsystem/Filter'])
set_param([sys,'/','Totzeiten (20 bis 29)T/Subsystem/Filter'],...
		'Numerator','[REG(21,1) REG(21,1)*REG(21,2) REG(21,1)*REG(21,3)]',...
		'Denominator','[1 -1]',...
		'position',[165,45,480,85])

add_block('built-in/Outport',[sys,'/','Totzeiten (20 bis 29)T/Subsystem/out_1'])
set_param([sys,'/','Totzeiten (20 bis 29)T/Subsystem/out_1'],...
		'position',[510,55,530,75])
add_line([sys,'/','Totzeiten (20 bis 29)T/Subsystem'],[190,150;190,115;45,115;55,70])
add_line([sys,'/','Totzeiten (20 bis 29)T/Subsystem'],[120,150;145,150])
add_line([sys,'/','Totzeiten (20 bis 29)T/Subsystem'],[85,65;105,65])
add_line([sys,'/','Totzeiten (20 bis 29)T/Subsystem'],[150,65;160,65])
add_line([sys,'/','Totzeiten (20 bis 29)T/Subsystem'],[40,60;55,60])
add_line([sys,'/','Totzeiten (20 bis 29)T/Subsystem'],[485,65;505,65])
add_line([sys,'/','Totzeiten (20 bis 29)T/Subsystem'],[190,150;235,150])
add_line([sys,'/','Totzeiten (20 bis 29)T/Subsystem'],[40,150;75,150])


%     Finished composite block 'Totzeiten (20 bis 29)T/Subsystem'.

set_param([sys,'/','Totzeiten (20 bis 29)T/Subsystem'],...
		'position',[145,12,175,63])

add_block('built-in/Filter',[sys,'/','Totzeiten (20 bis 29)T/Filter'])
set_param([sys,'/','Totzeiten (20 bis 29)T/Filter'],...
		'Numerator','[0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 1]',...
		'Denominator','[1]',...
		'position',[210,11,270,49])

add_block('built-in/Mux',[sys,'/','Totzeiten (20 bis 29)T/Mux'])
set_param([sys,'/','Totzeiten (20 bis 29)T/Mux'],...
		'inputs','10',...
		'position',[580,128,605,252])

add_block('built-in/Outport',[sys,'/','Totzeiten (20 bis 29)T/out_1'])
set_param([sys,'/','Totzeiten (20 bis 29)T/out_1'],...
		'orientation',2,...
		'position',[575,80,595,100])
add_line([sys,'/','Totzeiten (20 bis 29)T'],[175,380;190,380;190,420;545,420;545,235;575,235])
add_line([sys,'/','Totzeiten (20 bis 29)T'],[370,395;385,395;385,405;530,405;530,225;575,225])
add_line([sys,'/','Totzeiten (20 bis 29)T'],[180,305;195,305;195,320;300,320;300,340;515,340;515,215;575,215])
add_line([sys,'/','Totzeiten (20 bis 29)T'],[365,315;385,315;385,335;505,335;505,205;575,205])
add_line([sys,'/','Totzeiten (20 bis 29)T'],[180,215;195,215;195,240;305,240;305,260;495,260;495,195;575,195])
add_line([sys,'/','Totzeiten (20 bis 29)T'],[360,225;375,225;375,240;485,240;485,185;575,185])
add_line([sys,'/','Totzeiten (20 bis 29)T'],[175,135;185,135;185,150;300,150;300,175;575,175])
add_line([sys,'/','Totzeiten (20 bis 29)T'],[360,145;375,145;375,165;575,165])
add_line([sys,'/','Totzeiten (20 bis 29)T'],[180,50;195,50;195,70;290,70;290,90;545,90;545,155;575,155])
add_line([sys,'/','Totzeiten (20 bis 29)T'],[385,55;405,55;405,70;560,70;560,145;575,145])
add_line([sys,'/','Totzeiten (20 bis 29)T'],[45,75;75,75;75,410;290,410;290,370;330,370])
add_line([sys,'/','Totzeiten (20 bis 29)T'],[45,75;305,75;305,30;345,30])
add_line([sys,'/','Totzeiten (20 bis 29)T'],[480,35;490,35;490,10;330,10;330,55;345,55])
add_line([sys,'/','Totzeiten (20 bis 29)T'],[385,30;400,30;410,35])
add_line([sys,'/','Totzeiten (20 bis 29)T'],[455,125;465,125;465,100;305,100;305,145;320,145])
add_line([sys,'/','Totzeiten (20 bis 29)T'],[360,120;375,120;385,125])
add_line([sys,'/','Totzeiten (20 bis 29)T'],[455,205;465,205;465,180;305,180;305,225;320,225])
add_line([sys,'/','Totzeiten (20 bis 29)T'],[360,200;365,200;365,205;385,205])
add_line([sys,'/','Totzeiten (20 bis 29)T'],[460,295;470,295;470,270;310,270;310,315;325,315])
add_line([sys,'/','Totzeiten (20 bis 29)T'],[365,290;380,290;390,295])
add_line([sys,'/','Totzeiten (20 bis 29)T'],[465,375;475,375;475,350;315,350;315,395;330,395])
add_line([sys,'/','Totzeiten (20 bis 29)T'],[370,370;385,370;395,375])
add_line([sys,'/','Totzeiten (20 bis 29)T'],[265,360;270,360;270,335;115,335;115,380;135,380])
add_line([sys,'/','Totzeiten (20 bis 29)T'],[175,355;175,360;195,360])
add_line([sys,'/','Totzeiten (20 bis 29)T'],[270,285;275,285;275,260;120,260;120,305;140,305])
add_line([sys,'/','Totzeiten (20 bis 29)T'],[180,280;180,285;200,285])
add_line([sys,'/','Totzeiten (20 bis 29)T'],[270,195;275,195;275,170;120,170;120,215;140,215])
add_line([sys,'/','Totzeiten (20 bis 29)T'],[180,190;180,195;200,195])
add_line([sys,'/','Totzeiten (20 bis 29)T'],[265,115;275,115;275,90;120,90;120,135;135,135])
add_line([sys,'/','Totzeiten (20 bis 29)T'],[175,110;180,110;180,115;195,115])
add_line([sys,'/','Totzeiten (20 bis 29)T'],[275,30;280,30;280,5;125,5;125,50;140,50])
add_line([sys,'/','Totzeiten (20 bis 29)T'],[610,190;600,90])
add_line([sys,'/','Totzeiten (20 bis 29)T'],[75,355;135,355])
add_line([sys,'/','Totzeiten (20 bis 29)T'],[75,75;75,25;140,25])
add_line([sys,'/','Totzeiten (20 bis 29)T'],[75,110;135,110])
add_line([sys,'/','Totzeiten (20 bis 29)T'],[75,165;285,165;285,120;320,120])
add_line([sys,'/','Totzeiten (20 bis 29)T'],[75,190;140,190])
add_line([sys,'/','Totzeiten (20 bis 29)T'],[75,330;285,330;285,290;325,290])
add_line([sys,'/','Totzeiten (20 bis 29)T'],[75,255;290,255;290,200;320,200])
add_line([sys,'/','Totzeiten (20 bis 29)T'],[75,280;140,280])
add_line([sys,'/','Totzeiten (20 bis 29)T'],[180,25;190,25;190,30;205,30])


%     Finished composite block 'Totzeiten (20 bis 29)T'.

set_param([sys,'/','Totzeiten (20 bis 29)T'],...
		'position',[190,165,220,215])


%     Subsystem  'Totzeiten (30 bis 31)T'.

new_system([sys,'/','Totzeiten (30 bis 31)T'])
set_param([sys,'/','Totzeiten (30 bis 31)T'],'Location',[4,42,628,468])

add_block('built-in/Filter',[sys,'/','Totzeiten (30 bis 31)T/Filter'])
set_param([sys,'/','Totzeiten (30 bis 31)T/Filter'],...
		'Numerator','[0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 1]',...
		'Denominator','[1]',...
		'position',[185,46,245,84])

add_block('built-in/Inport',[sys,'/','Totzeiten (30 bis 31)T/in_1'])
set_param([sys,'/','Totzeiten (30 bis 31)T/in_1'],...
		'position',[25,95,45,115])

add_block('built-in/Filter',[sys,'/','Totzeiten (30 bis 31)T/Filter1'])
set_param([sys,'/','Totzeiten (30 bis 31)T/Filter1'],...
		'Numerator','[0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 1]',...
		'Denominator','[1]',...
		'position',[180,161,240,199])

add_block('built-in/Mux',[sys,'/','Totzeiten (30 bis 31)T/Mux'])
set_param([sys,'/','Totzeiten (30 bis 31)T/Mux'],...
		'inputs','2',...
		'position',[385,64,415,111])

add_block('built-in/Outport',[sys,'/','Totzeiten (30 bis 31)T/out_1'])
set_param([sys,'/','Totzeiten (30 bis 31)T/out_1'],...
		'position',[475,80,495,100])


%     Subsystem  'Totzeiten (30 bis 31)T/Subsystem1'.

new_system([sys,'/','Totzeiten (30 bis 31)T/Subsystem1'])
set_param([sys,'/','Totzeiten (30 bis 31)T/Subsystem1'],'Location',[45,42,604,276])

add_block('built-in/Transfer Fcn',[sys,'/','Totzeiten (30 bis 31)T/Subsystem1/Transfer Fcn1'])
set_param([sys,'/','Totzeiten (30 bis 31)T/Subsystem1/Transfer Fcn1'],...
		'Denominator','[4 1]',...
		'position',[150,132,185,168])

add_block('built-in/Transfer Fcn',[sys,'/','Totzeiten (30 bis 31)T/Subsystem1/Transfer Fcn'])
set_param([sys,'/','Totzeiten (30 bis 31)T/Subsystem1/Transfer Fcn'],...
		'Denominator','[10 1]',...
		'position',[80,132,115,168])

add_block('built-in/Zero-Order Hold',[sys,'/',['Totzeiten (30 bis 31)T/Subsystem1/Zero-Order',13,'Hold']])
set_param([sys,'/',['Totzeiten (30 bis 31)T/Subsystem1/Zero-Order',13,'Hold']],...
		'position',[110,49,145,81])

add_block('built-in/Sum',[sys,'/','Totzeiten (30 bis 31)T/Subsystem1/Sum'])
set_param([sys,'/','Totzeiten (30 bis 31)T/Subsystem1/Sum'],...
		'inputs','+-',...
		'position',[60,55,80,75])

add_block('built-in/Inport',[sys,'/','Totzeiten (30 bis 31)T/Subsystem1/in_1'])
set_param([sys,'/','Totzeiten (30 bis 31)T/Subsystem1/in_1'],...
		'position',[15,50,35,70])

add_block('built-in/Outport',[sys,'/','Totzeiten (30 bis 31)T/Subsystem1/out_2'])
set_param([sys,'/','Totzeiten (30 bis 31)T/Subsystem1/out_2'],...
		'Port','2',...
		'position',[240,140,260,160])

add_block('built-in/Inport',[sys,'/','Totzeiten (30 bis 31)T/Subsystem1/in_2'])
set_param([sys,'/','Totzeiten (30 bis 31)T/Subsystem1/in_2'],...
		'Port','2',...
		'position',[15,140,35,160])

add_block('built-in/Filter',[sys,'/','Totzeiten (30 bis 31)T/Subsystem1/Filter'])
set_param([sys,'/','Totzeiten (30 bis 31)T/Subsystem1/Filter'],...
		'Numerator','[REG(32,1) REG(32,1)*REG(32,2) REG(32,1)*REG(32,3)]',...
		'Denominator','[1 -1]',...
		'position',[165,45,480,85])

add_block('built-in/Outport',[sys,'/','Totzeiten (30 bis 31)T/Subsystem1/out_1'])
set_param([sys,'/','Totzeiten (30 bis 31)T/Subsystem1/out_1'],...
		'position',[510,55,530,75])
add_line([sys,'/','Totzeiten (30 bis 31)T/Subsystem1'],[190,150;190,115;45,115;55,70])
add_line([sys,'/','Totzeiten (30 bis 31)T/Subsystem1'],[120,150;145,150])
add_line([sys,'/','Totzeiten (30 bis 31)T/Subsystem1'],[85,65;105,65])
add_line([sys,'/','Totzeiten (30 bis 31)T/Subsystem1'],[150,65;160,65])
add_line([sys,'/','Totzeiten (30 bis 31)T/Subsystem1'],[40,60;55,60])
add_line([sys,'/','Totzeiten (30 bis 31)T/Subsystem1'],[485,65;505,65])
add_line([sys,'/','Totzeiten (30 bis 31)T/Subsystem1'],[190,150;235,150])
add_line([sys,'/','Totzeiten (30 bis 31)T/Subsystem1'],[40,150;75,150])


%     Finished composite block 'Totzeiten (30 bis 31)T/Subsystem1'.

set_param([sys,'/','Totzeiten (30 bis 31)T/Subsystem1'],...
		'position',[125,164,155,231])


%     Subsystem  'Totzeiten (30 bis 31)T/Subsystem'.

new_system([sys,'/','Totzeiten (30 bis 31)T/Subsystem'])
set_param([sys,'/','Totzeiten (30 bis 31)T/Subsystem'],'Location',[45,42,604,276])

add_block('built-in/Transfer Fcn',[sys,'/','Totzeiten (30 bis 31)T/Subsystem/Transfer Fcn1'])
set_param([sys,'/','Totzeiten (30 bis 31)T/Subsystem/Transfer Fcn1'],...
		'Denominator','[4 1]',...
		'position',[150,132,185,168])

add_block('built-in/Transfer Fcn',[sys,'/','Totzeiten (30 bis 31)T/Subsystem/Transfer Fcn'])
set_param([sys,'/','Totzeiten (30 bis 31)T/Subsystem/Transfer Fcn'],...
		'Denominator','[10 1]',...
		'position',[80,132,115,168])

add_block('built-in/Zero-Order Hold',[sys,'/',['Totzeiten (30 bis 31)T/Subsystem/Zero-Order',13,'Hold']])
set_param([sys,'/',['Totzeiten (30 bis 31)T/Subsystem/Zero-Order',13,'Hold']],...
		'position',[110,49,145,81])

add_block('built-in/Sum',[sys,'/','Totzeiten (30 bis 31)T/Subsystem/Sum'])
set_param([sys,'/','Totzeiten (30 bis 31)T/Subsystem/Sum'],...
		'inputs','+-',...
		'position',[60,55,80,75])

add_block('built-in/Inport',[sys,'/','Totzeiten (30 bis 31)T/Subsystem/in_1'])
set_param([sys,'/','Totzeiten (30 bis 31)T/Subsystem/in_1'],...
		'position',[15,50,35,70])

add_block('built-in/Outport',[sys,'/','Totzeiten (30 bis 31)T/Subsystem/out_2'])
set_param([sys,'/','Totzeiten (30 bis 31)T/Subsystem/out_2'],...
		'Port','2',...
		'position',[240,140,260,160])

add_block('built-in/Inport',[sys,'/','Totzeiten (30 bis 31)T/Subsystem/in_2'])
set_param([sys,'/','Totzeiten (30 bis 31)T/Subsystem/in_2'],...
		'Port','2',...
		'position',[15,140,35,160])

add_block('built-in/Filter',[sys,'/','Totzeiten (30 bis 31)T/Subsystem/Filter'])
set_param([sys,'/','Totzeiten (30 bis 31)T/Subsystem/Filter'],...
		'Numerator','[REG(31,1) REG(31,1)*REG(31,2) REG(31,1)*REG(31,3)]',...
		'Denominator','[1 -1]',...
		'position',[165,45,495,85])

add_block('built-in/Outport',[sys,'/','Totzeiten (30 bis 31)T/Subsystem/out_1'])
set_param([sys,'/','Totzeiten (30 bis 31)T/Subsystem/out_1'],...
		'position',[520,55,540,75])
add_line([sys,'/','Totzeiten (30 bis 31)T/Subsystem'],[190,150;190,115;45,115;55,70])
add_line([sys,'/','Totzeiten (30 bis 31)T/Subsystem'],[120,150;145,150])
add_line([sys,'/','Totzeiten (30 bis 31)T/Subsystem'],[85,65;105,65])
add_line([sys,'/','Totzeiten (30 bis 31)T/Subsystem'],[150,65;160,65])
add_line([sys,'/','Totzeiten (30 bis 31)T/Subsystem'],[40,60;55,60])
add_line([sys,'/','Totzeiten (30 bis 31)T/Subsystem'],[500,65;515,65])
add_line([sys,'/','Totzeiten (30 bis 31)T/Subsystem'],[190,150;235,150])
add_line([sys,'/','Totzeiten (30 bis 31)T/Subsystem'],[40,150;75,150])


%     Finished composite block 'Totzeiten (30 bis 31)T/Subsystem'.

set_param([sys,'/','Totzeiten (30 bis 31)T/Subsystem'],...
		'position',[125,49,155,116])
add_line([sys,'/','Totzeiten (30 bis 31)T'],[160,215;165,215;165,135;285,135;285,75;380,75])
add_line([sys,'/','Totzeiten (30 bis 31)T'],[160,100;380,100])
add_line([sys,'/','Totzeiten (30 bis 31)T'],[50,105;80,105;80,65;120,65])
add_line([sys,'/','Totzeiten (30 bis 31)T'],[245,180;255,180;255,265;100,265;100,215;120,215])
add_line([sys,'/','Totzeiten (30 bis 31)T'],[160,180;175,180])
add_line([sys,'/','Totzeiten (30 bis 31)T'],[250,65;265,65;265,25;105,25;105,100;120,100])
add_line([sys,'/','Totzeiten (30 bis 31)T'],[160,65;180,65])
add_line([sys,'/','Totzeiten (30 bis 31)T'],[420,90;470,90])
add_line([sys,'/','Totzeiten (30 bis 31)T'],[80,105;80,180;120,180])


%     Finished composite block 'Totzeiten (30 bis 31)T'.

set_param([sys,'/','Totzeiten (30 bis 31)T'],...
		'position',[190,235,220,285])

add_block('built-in/To File',[sys,'/','zu MATLAB'])
set_param([sys,'/','zu MATLAB'],...
		'File name','totzei32.mat',...
		'Matrix name','totzei32',...
		'position',[395,110,470,140])

add_block('built-in/Mux',[sys,'/','Mux'])
set_param([sys,'/','Mux'],...
		'position',[330,31,365,94])


%     Subsystem  'Oszi'.

new_system([sys,'/','Oszi'])
set_param([sys,'/','Oszi'],'Location',[0,59,274,252])

add_block('built-in/Inport',[sys,'/','Oszi/x'])
set_param([sys,'/','Oszi/x'],...
		'position',[65,55,85,75])

add_block('built-in/S-Function',[sys,'/',['Oszi/S-function',13,'M-file which plots',13,'lines',13,'']])
set_param([sys,'/',['Oszi/S-function',13,'M-file which plots',13,'lines',13,'']],...
		'function name','sfuny',...
		'parameters','ax, color,dt',...
		'position',[130,55,180,75])
add_line([sys,'/','Oszi'],[90,65;125,65])
set_param([sys,'/','Oszi'],...
		'Mask Display','plot(0,0,100,100,[90,10,10,10,90,90,10],[65,65,90,40,40,90,90],[90,78,69,54,40,31,25,10],[77,60,48,46,56,75,81,84])',...
		'Mask Type','Graph scope.')
set_param([sys,'/','Oszi'],...
		'Mask Dialogue','Graph scope using MATLAB graph window.\nEnter plotting ranges and line type.|Time range:|y-min:|y-max:|Line type (rgbw-:*). Seperate each plot by ''/'':')
set_param([sys,'/','Oszi'],...
		'Mask Translate','color = @4; ax = [0, @1, @2, @3]; dt = -1;')
set_param([sys,'/','Oszi'],...
		'Mask Help','This block plots to the MATLAB graph window and can be used as an improved version of the Scope block. Look at the m-file sfuny.m to see how it works. This block can take scalar or vector input signal.')
set_param([sys,'/','Oszi'],...
		'Mask Entries','110\/0\/1.2\/''b/b/b/b/b/b/b/b/b/b/b/b/b/b/b/b/b/b/b/b/b/b/b/b/b/b/b/b/b/b/b/b''\/')


%     Finished composite block 'Oszi'.

set_param([sys,'/','Oszi'],...
		'position',[425,46,455,84])

add_block('built-in/Step Fcn',[sys,'/','Sollwert'])
set_param([sys,'/','Sollwert'],...
		'position',[40,30,60,50])
add_line(sys,[65,40;185,40])
add_line(sys,[225,40;325,40])
add_line(sys,[225,115;260,115;260,55;325,55])
add_line(sys,[225,190;275,190;275,70;325,70])
add_line(sys,[225,260;290,260;290,85;325,85])
add_line(sys,[370,65;420,65])
add_line(sys,[380,65;390,125])
add_line(sys,[100,40;100,115;185,115])
add_line(sys,[100,115;100,190;185,190])
add_line(sys,[100,190;100,260;185,260])

drawnow

% Return any arguments.
if (nargin | nargout)
	% Must use feval here to access system in memory
	if (nargin > 3)
		if (flag == 0)
			eval(['[ret,x0,str,ts,xts]=',sys,'(t,x,u,flag);'])
		else
			eval(['ret =', sys,'(t,x,u,flag);'])
		end
	else
		[ret,x0,str,ts,xts] = feval(sys);
	end
else
	drawnow % Flash up the model and execute load callback
end
