function [ret,x0,str,ts,xts]=sist031(t,x,u,flag);
%SIST031	is the M-file description of the SIMULINK system named SIST031.
%	The block-diagram can be displayed by typing: SIST031.
%
%	SYS=SIST031(T,X,U,FLAG) returns depending on FLAG certain
%	system values given time point, T, current state vector, X,
%	and input vector, U.
%	FLAG is used to indicate the type of output to be returned in SYS.
%
%	Setting FLAG=1 causes SIST031 to return state derivatives, FLAG=2
%	discrete states, FLAG=3 system outputs and FLAG=4 next sample
%	time. For more information and other options see SFUNC.
%
%	Calling SIST031 with a FLAG of zero:
%	[SIZES]=SIST031([],[],[],0),  returns a vector, SIZES, which
%	contains the sizes of the state vector and other parameters.
%		SIZES(1) number of states
%		SIZES(2) number of discrete states
%		SIZES(3) number of outputs
%		SIZES(4) number of inputs
%		SIZES(5) number of roots (currently unsupported)
%		SIZES(6) direct feedthrough flag
%		SIZES(7) number of sample times
%
%	For the definition of other parameters in SIZES, see SFUNC.
%	See also, TRIM, LINMOD, LINSIM, EULER, RK23, RK45, ADAMS, GEAR.

% Note: This M-file is only used for saving graphical information;
%       after the model is loaded into memory an internal model
%       representation is used.

% the system will take on the name of this mfile:
sys = mfilename;
new_system(sys)
simver(1.3)
if (0 == (nargin + nargout))
     set_param(sys,'Location',[4,42,628,468])
     open_system(sys)
end;
set_param(sys,'algorithm',     'RK-45')
set_param(sys,'Start time',    '0.0')
set_param(sys,'Stop time',     '150')
set_param(sys,'Min step size', '0.00000001')
set_param(sys,'Max step size', '10')
set_param(sys,'Relative error','1e-3')
set_param(sys,'Return vars',   '')

add_block('built-in/Sum',[sys,'/','Sum'])
set_param([sys,'/','Sum'],...
		'inputs','+-',...
		'position',[50,100,70,120])

add_block('built-in/Filter',[sys,'/',['Regler-',13,'polynome']])
set_param([sys,'/',['Regler-',13,'polynome']],...
		'Numerator','[1 -0.9485]',...
		'Denominator','[1 -1]',...
		'Sample time','1.6',...
		'position',[190,92,255,128])

add_block('built-in/Zero-Order Hold',[sys,'/',['ABT1=1,5ms',13,'Bus-',13,'abtatszeit']])
set_param([sys,'/',['ABT1=1,5ms',13,'Bus-',13,'abtatszeit']],...
		'Sample time','1.5',...
		'position',[275,94,310,126])

add_block('built-in/Filter',[sys,'/',['Tt1=1,5ms',13,'Bustotzeit']])
set_param([sys,'/',['Tt1=1,5ms',13,'Bustotzeit']],...
		'Numerator','[0 1]',...
		'Denominator','[1]',...
		'Sample time','1.5',...
		'position',[335,91,395,129])

add_block('built-in/Zero-Order Hold',[sys,'/',['TSt=1,6ms',13,'Stromsollwert-',13,'abtastzeit']])
set_param([sys,'/',['TSt=1,6ms',13,'Stromsollwert-',13,'abtastzeit']],...
		'Sample time','1.6',...
		'position',[420,94,455,126])

add_block('built-in/Mux',[sys,'/','Multiplexer'])
set_param([sys,'/','Multiplexer'],...
		'inputs','3',...
		'position',[495,272,525,308])

add_block('built-in/Transfer Fcn',[sys,'/','VS u. TM'])
set_param([sys,'/','VS u. TM'],...
		'Numerator','[33]',...
		'Denominator','[4000 1]',...
		'position',[470,93,525,127])

add_block('built-in/Transfer Fcn',[sys,'/','TSu'])
set_param([sys,'/','TSu'],...
		'Denominator','[0.7 1]',...
		'position',[540,92,575,128])

add_block('built-in/Zero-Order Hold',[sys,'/',['ABT2=1,5ms',13,'Bus-',13,'abtastzeit']])
set_param([sys,'/',['ABT2=1,5ms',13,'Bus-',13,'abtastzeit']],...
		'orientation',2,...
		'Sample time','1.5',...
		'position',[135,179,170,211])

add_block('built-in/Filter',[sys,'/',['Tt2=1,5ms',13,'Bustotzeit']])
set_param([sys,'/',['Tt2=1,5ms',13,'Bustotzeit']],...
		'orientation',2,...
		'Numerator','[0 1]',...
		'Denominator','[1]',...
		'Sample time','1.5',...
		'position',[45,176,105,214])

add_block('built-in/Filter',[sys,'/',['Differenz-',13,'bildung']])
set_param([sys,'/',['Differenz-',13,'bildung']],...
		'orientation',2,...
		'Numerator','[1 -1]',...
		'Denominator','[1]',...
		'Sample time','1.6',...
		'position',[320,176,380,214])

add_block('built-in/Zero-Order Hold',[sys,'/',['T_MWM=1,6ms',13,'Messabtastzeit']])
set_param([sys,'/',['T_MWM=1,6ms',13,'Messabtastzeit']],...
		'orientation',2,...
		'Sample time','1.6',...
		'position',[405,179,440,211])

add_block('built-in/Integrator',[sys,'/','Integration'])
set_param([sys,'/','Integration'],...
		'orientation',2,...
		'position',[545,185,565,205])

add_block('built-in/Gain',[sys,'/',['TMess=1,6ms',13,'Integrations-',13,'zeitkonstante']])
set_param([sys,'/',['TMess=1,6ms',13,'Integrations-',13,'zeitkonstante']],...
		'orientation',2,...
		'Gain','(1/1.6)',...
		'position',[485,182,510,208])

add_block('built-in/Filter',[sys,'/',['Tt3=0,4ms',13,'Istwertber-',13,'gabetotzeit']])
set_param([sys,'/',['Tt3=0,4ms',13,'Istwertber-',13,'gabetotzeit']],...
		'orientation',2,...
		'Numerator','[0 1]',...
		'Denominator','[1]',...
		'Sample time','0.4',...
		'position',[205,176,265,214])

add_block('built-in/Filter',[sys,'/','Vorfilter'])
set_param([sys,'/','Vorfilter'],...
		'Numerator','[0.0515]',...
		'Denominator','[1 -0.9485]',...
		'Sample time','1.6',...
		'position',[80,6,140,44])

add_block('built-in/To Workspace',[sys,'/','To Workspace'])
set_param([sys,'/','To Workspace'],...
		'orientation',2,...
		'mat-name','Istwert',...
		'buffer','50000',...
		'position',[370,250,420,270])

add_block('built-in/Step Fcn',[sys,'/','Step Input'])
set_param([sys,'/','Step Input'],...
		'Time','0',...
		'position',[25,15,45,35])

add_block('built-in/Mux',[sys,'/','Mux1'])
set_param([sys,'/','Mux1'],...
		'orientation',1,...
		'position',[179,300,211,335])


%     Subsystem  'Clock'.

new_system([sys,'/','Clock'])
set_param([sys,'/','Clock'],'Location',[471,305,788,438])

add_block('built-in/Discrete Transfer Fcn',[sys,'/','Clock/Dis. Transfer Fcn1'])
set_param([sys,'/','Clock/Dis. Transfer Fcn1'],...
		'Denominator','[1 ]',...
		'Sample time','[duration, duration-duration/20]',...
		'position',[90,202,135,238])

add_block('built-in/Discrete Transfer Fcn',[sys,'/','Clock/Dis. Transfer Fcn'])
set_param([sys,'/','Clock/Dis. Transfer Fcn'],...
		'Denominator','[1 ]',...
		'Sample time','[duration, duration/20]',...
		'position',[210,202,255,238])

add_block('built-in/Constant',[sys,'/','Clock/Constant'])
set_param([sys,'/','Clock/Constant'],...
		'position',[25,25,45,45])

add_block('built-in/Outport',[sys,'/','Clock/out_1'])
set_param([sys,'/','Clock/out_1'],...
		'position',[240,30,260,50])

add_block('built-in/Unit Delay',[sys,'/','Clock/Unit Delay'])
set_param([sys,'/','Clock/Unit Delay'],...
		'orientation',2,...
		'Sample time','duration',...
		'position',[125,80,175,100])

add_block('built-in/Sum',[sys,'/','Clock/Sum'])
set_param([sys,'/','Clock/Sum'],...
		'inputs','+-',...
		'position',[115,30,135,50])
add_line([sys,'/','Clock'],[140,40;235,40])
add_line([sys,'/','Clock'],[120,90;85,90;85,45;110,45])
add_line([sys,'/','Clock'],[140,40;210,40;210,90;180,90])
add_line([sys,'/','Clock'],[50,35;110,35])
set_param([sys,'/','Clock'],...
		'Mask Display','plot(0,0,100,100,[90,75,75,60,60,35,35,20,20,10],[20,20,80,80,19,20,80,80,20,20])',...
		'Mask Type','Digital clock')
set_param([sys,'/','Clock'],...
		'Mask Dialogue','Digital clock.\nOutput is set to 1 for the first half of the period.|Period:',...
		'Mask Translate','duration = @1/2;',...
		'Mask Help','Digital clock for logic systems.')
set_param([sys,'/','Clock'],...
		'Mask Entries','1.6\/')


%     Finished composite block 'Clock'.

set_param([sys,'/','Clock'],...
		'orientation',2,...
		'position',[380,326,420,354])

add_block('built-in/Gain',[sys,'/',['VR',13,'Regler1']])
set_param([sys,'/',['VR',13,'Regler1']],...
		'orientation',2,...
		'Gain','0.05',...
		'position',[335,327,360,353])


%     Subsystem  'Oszi'.

new_system([sys,'/','Oszi'])
set_param([sys,'/','Oszi'],'Location',[0,59,274,252])

add_block('built-in/Inport',[sys,'/','Oszi/x'])
set_param([sys,'/','Oszi/x'],...
		'position',[65,55,85,75])

add_block('built-in/S-Function',[sys,'/',['Oszi/S-function',13,'M-file which plots',13,'lines',13,'']])
set_param([sys,'/',['Oszi/S-function',13,'M-file which plots',13,'lines',13,'']],...
		'function name','sfuny',...
		'parameters','ax, color,dt',...
		'position',[130,55,180,75])
add_line([sys,'/','Oszi'],[90,65;125,65])
set_param([sys,'/','Oszi'],...
		'Mask Display','plot(0,0,100,100,[90,10,10,10,90,90,10],[65,65,90,40,40,90,90],[90,78,69,54,40,31,25,10],[77,60,48,46,56,75,81,84])',...
		'Mask Type','Graph scope.')
set_param([sys,'/','Oszi'],...
		'Mask Dialogue','Graph scope using MATLAB graph window.\nEnter plotting ranges and line type.|Time range:|y-min:|y-max:|Line type (rgbw-:*). Seperate each plot by ''/'':')
set_param([sys,'/','Oszi'],...
		'Mask Translate','color = @4; ax = [0, @1, @2, @3]; dt = -1;')
set_param([sys,'/','Oszi'],...
		'Mask Help','This block plots to the MATLAB graph window and can be used as an improved version of the Scope block. Look at the m-file sfuny.m to see how it works. This block can take scalar or vector input signal.')
set_param([sys,'/','Oszi'],...
		'Mask Entries','150\/0\/1.15\/''b/k/m/r''\/')


%     Finished composite block 'Oszi'.

set_param([sys,'/','Oszi'],...
		'position',[545,270,575,310])

add_block('built-in/To Workspace',[sys,'/','To Workspace2'])
set_param([sys,'/','To Workspace2'],...
		'orientation',2,...
		'mat-name','Istwert',...
		'buffer','50000',...
		'position',[375,585,425,605])


%     Subsystem  'System ohne Bus'.

new_system([sys,'/','System ohne Bus'])
set_param([sys,'/','System ohne Bus'],'Location',[-4,210,620,361])

add_block('built-in/Integrator',[sys,'/','System ohne Bus/Integration1'])
set_param([sys,'/','System ohne Bus/Integration1'],...
		'position',[365,60,385,80])

add_block('built-in/Gain',[sys,'/',['System ohne Bus/TMess=1,6ms',13,'Integrations-',13,'zeitkonstante1']])
set_param([sys,'/',['System ohne Bus/TMess=1,6ms',13,'Integrations-',13,'zeitkonstante1']],...
		'Gain','(1/1.6)',...
		'position',[430,57,455,83])

add_block('built-in/Zero-Order Hold',[sys,'/',['System ohne Bus/T_MWM=1,6ms',13,'Messabtastzeit1']])
set_param([sys,'/',['System ohne Bus/T_MWM=1,6ms',13,'Messabtastzeit1']],...
		'Sample time','1.6',...
		'position',[500,54,535,86])

add_block('built-in/Filter',[sys,'/',['System ohne Bus/Differenz-',13,'bildung1']])
set_param([sys,'/',['System ohne Bus/Differenz-',13,'bildung1']],...
		'Numerator','[1 -1]',...
		'Denominator','[1]',...
		'Sample time','1.6',...
		'position',[560,51,620,89])

add_block('built-in/Transfer Fcn',[sys,'/','System ohne Bus/TSu1'])
set_param([sys,'/','System ohne Bus/TSu1'],...
		'Denominator','[0.7 1]',...
		'position',[310,52,345,88])

add_block('built-in/Transfer Fcn',[sys,'/','System ohne Bus/VS u. TM1'])
set_param([sys,'/','System ohne Bus/VS u. TM1'],...
		'Numerator','[33]',...
		'Denominator','[4000 1]',...
		'position',[260,52,295,88])

add_block('built-in/Filter',[sys,'/',['System ohne Bus/Regler-',13,'polynome1']])
set_param([sys,'/',['System ohne Bus/Regler-',13,'polynome1']],...
		'Numerator','[1 -0.8199]',...
		'Denominator','[1 -1]',...
		'Sample time','1.6',...
		'position',[185,51,245,89])

add_block('built-in/Gain',[sys,'/',['System ohne Bus/VR',13,'Regler2']])
set_param([sys,'/',['System ohne Bus/VR',13,'Regler2']],...
		'Gain','33.2440',...
		'position',[145,57,170,83])

add_block('built-in/Zero-Order Hold',[sys,'/',['System ohne Bus/TDr=1,6ms',13,'Drehzahlregler-',13,'abtastzeit1']])
set_param([sys,'/',['System ohne Bus/TDr=1,6ms',13,'Drehzahlregler-',13,'abtastzeit1']],...
		'Sample time','1.6',...
		'position',[90,54,125,86])

add_block('built-in/Sum',[sys,'/','System ohne Bus/Sum2'])
set_param([sys,'/','System ohne Bus/Sum2'],...
		'inputs','+-',...
		'position',[55,60,75,80])

add_block('built-in/Outport',[sys,'/','System ohne Bus/out_1'])
set_param([sys,'/','System ohne Bus/out_1'],...
		'position',[640,30,660,50])

add_block('built-in/Outport',[sys,'/','System ohne Bus/out_2'])
set_param([sys,'/','System ohne Bus/out_2'],...
		'Port','2',...
		'position',[485,10,505,30])

add_block('built-in/Filter',[sys,'/','System ohne Bus/Vorfilter1'])
set_param([sys,'/','System ohne Bus/Vorfilter1'],...
		'Numerator','[0.1801]',...
		'Denominator','[1 -0.8199]',...
		'Sample time','1.6',...
		'position',[95,1,155,39])

add_block('built-in/Inport',[sys,'/','System ohne Bus/in_1'])
set_param([sys,'/','System ohne Bus/in_1'],...
		'position',[35,10,50,30])
add_line([sys,'/','System ohne Bus'],[625,70;635,70;635,40])
add_line([sys,'/','System ohne Bus'],[635,70;635,120;40,120;50,75])
add_line([sys,'/','System ohne Bus'],[250,70;255,70])
add_line([sys,'/','System ohne Bus'],[540,70;555,70])
add_line([sys,'/','System ohne Bus'],[460,70;495,70])
add_line([sys,'/','System ohne Bus'],[390,70;425,70])
add_line([sys,'/','System ohne Bus'],[350,70;360,70])
add_line([sys,'/','System ohne Bus'],[300,70;305,70])
add_line([sys,'/','System ohne Bus'],[80,70;85,70])
add_line([sys,'/','System ohne Bus'],[130,70;140,70])
add_line([sys,'/','System ohne Bus'],[175,70;180,70])
add_line([sys,'/','System ohne Bus'],[350,70;350,20;480,20])
add_line([sys,'/','System ohne Bus'],[55,20;90,20])
add_line([sys,'/','System ohne Bus'],[160,20;170,20;170,45;35,45;35,65;50,65])


%     Finished composite block 'System ohne Bus'.

set_param([sys,'/','System ohne Bus'],...
		'position',[235,7,265,58])

add_block('built-in/Mux',[sys,'/','Mux2'])
set_param([sys,'/','Mux2'],...
		'inputs','2',...
		'position',[315,12,345,48])

add_block('built-in/Signal Generator',[sys,'/',['Signal',13,'Generator']])
set_param([sys,'/',['Signal',13,'Generator']],...
		'Peak','0.500000',...
		'Peak Range','1.000000',...
		'Freq','0.030000',...
		'Freq Range','0.250000',...
		'Wave','Sqr',...
		'Units','Rads',...
		'position',[20,288,65,322])

add_block('built-in/Sum',[sys,'/','Sum1'])
set_param([sys,'/','Sum1'],...
		'position',[125,300,145,320])

add_block('built-in/Constant',[sys,'/','Constant'])
set_param([sys,'/','Constant'],...
		'Value','0.5',...
		'position',[75,345,95,365])

add_block('built-in/To Workspace',[sys,'/','To Workspace1'])
set_param([sys,'/','To Workspace1'],...
		'mat-name','Messung',...
		'position',[385,50,435,70])

add_block('built-in/Zero-Order Hold',[sys,'/',['TDr=1,6ms',13,'Drehzahlregler-',13,'abtastzeit']])
set_param([sys,'/',['TDr=1,6ms',13,'Drehzahlregler-',13,'abtastzeit']],...
		'Sample time','1.6',...
		'position',[95,94,130,126])

add_block('built-in/Gain',[sys,'/',['VR',13,'Regler']])
set_param([sys,'/',['VR',13,'Regler']],...
		'Gain','8.1747',...
		'position',[150,97,175,123])
add_line(sys,[180,110;185,110])
add_line(sys,[135,110;145,110])
add_line(sys,[75,110;90,110])
add_line(sys,[315,110;330,110])
add_line(sys,[260,110;270,110])
add_line(sys,[400,110;415,110])
add_line(sys,[460,110;465,110])
add_line(sys,[530,110;535,110])
add_line(sys,[580,110;590,110;590,195;570,195])
add_line(sys,[540,195;515,195])
add_line(sys,[480,195;445,195])
add_line(sys,[400,195;385,195])
add_line(sys,[130,195;110,195])
add_line(sys,[200,195;175,195])
add_line(sys,[315,195;270,195])
add_line(sys,[585,195;585,255;475,255;475,280;490,280])
add_line(sys,[70,305;120,305])
add_line(sys,[100,355;110,355;120,315])
add_line(sys,[50,25;75,25])
add_line(sys,[305,195;305,290;490,290])
add_line(sys,[475,260;425,260])
add_line(sys,[75,110;75,150;25,150;25,265;180,265;180,295])
add_line(sys,[315,110;315,170;285,170;285,255;200,255;200,295])
add_line(sys,[260,110;260,160;190,160;190,295])
add_line(sys,[375,340;365,340])
add_line(sys,[330,340;325,340;325,325;280,325;280,285;210,295])
add_line(sys,[530,290;540,290])
add_line(sys,[40,195;15,195;15,115;45,115])
add_line(sys,[270,20;310,20])
add_line(sys,[270,45;285,45;285,40;310,40])
add_line(sys,[350,30;600,30;600,345;475,345;475,300;490,300])
add_line(sys,[60,25;60,70;180,70;180,35;230,35])
add_line(sys,[285,45;285,60;380,60])
add_line(sys,[145,25;160,25;160,55;25,55;25,105;45,105])

drawnow

% Return any arguments.
if (nargin | nargout)
	% Must use feval here to access system in memory
	if (nargin > 3)
		if (flag == 0)
			eval(['[ret,x0,str,ts,xts]=',sys,'(t,x,u,flag);'])
		else
			eval(['ret =', sys,'(t,x,u,flag);'])
		end
	else
		[ret,x0,str,ts,xts] = feval(sys);
	end
else
	drawnow % Flash up the model and execute load callback
end
