function [ret,x0,str,ts,xts]=sist041(t,x,u,flag);
%SIST041	is the M-file description of the SIMULINK system named SIST041.
%	The block-diagram can be displayed by typing: SIST041.
%
%	SYS=SIST041(T,X,U,FLAG) returns depending on FLAG certain
%	system values given time point, T, current state vector, X,
%	and input vector, U.
%	FLAG is used to indicate the type of output to be returned in SYS.
%
%	Setting FLAG=1 causes SIST041 to return state derivatives, FLAG=2
%	discrete states, FLAG=3 system outputs and FLAG=4 next sample
%	time. For more information and other options see SFUNC.
%
%	Calling SIST041 with a FLAG of zero:
%	[SIZES]=SIST041([],[],[],0),  returns a vector, SIZES, which
%	contains the sizes of the state vector and other parameters.
%		SIZES(1) number of states
%		SIZES(2) number of discrete states
%		SIZES(3) number of outputs
%		SIZES(4) number of inputs
%		SIZES(5) number of roots (currently unsupported)
%		SIZES(6) direct feedthrough flag
%		SIZES(7) number of sample times
%
%	For the definition of other parameters in SIZES, see SFUNC.
%	See also, TRIM, LINMOD, LINSIM, EULER, RK23, RK45, ADAMS, GEAR.

% Note: This M-file is only used for saving graphical information;
%       after the model is loaded into memory an internal model
%       representation is used.

% the system will take on the name of this mfile:
sys = mfilename;
new_system(sys)
simver(1.3)
if (0 == (nargin + nargout))
     set_param(sys,'Location',[4,42,628,468])
     open_system(sys)
end;
set_param(sys,'algorithm',     'RK-23')
set_param(sys,'Start time',    '0.0')
set_param(sys,'Stop time',     '200')
set_param(sys,'Min step size', '0.000001')
set_param(sys,'Max step size', '10')
set_param(sys,'Relative error','1e-3')
set_param(sys,'Return vars',   '')


%     Subsystem  '4 Varianten'.

new_system([sys,'/','4 Varianten'])
set_param([sys,'/','4 Varianten'],'Location',[4,42,628,468])
open_system([sys,'/','4 Varianten'])

add_block('built-in/Sum',[sys,'/','4 Varianten/Sum1'])
set_param([sys,'/','4 Varianten/Sum1'],...
		'inputs','+-',...
		'position',[55,190,75,210])

add_block('built-in/Sum',[sys,'/','4 Varianten/Sum'])
set_param([sys,'/','4 Varianten/Sum'],...
		'inputs','+-',...
		'position',[45,105,65,125])

add_block('built-in/Zero-Order Hold',[sys,'/',['4 Varianten/Zero-Order',13,'Hold1']])
set_param([sys,'/',['4 Varianten/Zero-Order',13,'Hold1']],...
		'position',[120,184,155,216])

add_block('built-in/Zero-Order Hold',[sys,'/',['4 Varianten/Zero-Order',13,'Hold']])
set_param([sys,'/',['4 Varianten/Zero-Order',13,'Hold']],...
		'position',[105,99,140,131])

add_block('built-in/Transfer Fcn',[sys,'/','4 Varianten/PT3'])
set_param([sys,'/','4 Varianten/PT3'],...
		'Denominator','[2 1]',...
		'position',[435,42,470,78])

add_block('built-in/Transfer Fcn',[sys,'/','4 Varianten/PT3_1'])
set_param([sys,'/','4 Varianten/PT3_1'],...
		'Denominator','[2 1]',...
		'position',[435,97,470,133])

add_block('built-in/Filter',[sys,'/','4 Varianten/Regler_2'])
set_param([sys,'/','4 Varianten/Regler_2'],...
		'Numerator','[31.49 -57.82 26.51]',...
		'Denominator','[1 -1]',...
		'position',[175,179,305,221])

add_block('built-in/Transfer Fcn',[sys,'/','4 Varianten/PT2'])
set_param([sys,'/','4 Varianten/PT2'],...
		'Denominator','[8 1]',...
		'position',[360,42,395,78])

add_block('built-in/Transfer Fcn',[sys,'/','4 Varianten/PT1'])
set_param([sys,'/','4 Varianten/PT1'],...
		'Denominator','[20 1]',...
		'position',[290,42,325,78])

add_block('built-in/Transfer Fcn',[sys,'/','4 Varianten/PT2_1'])
set_param([sys,'/','4 Varianten/PT2_1'],...
		'Denominator','[8 1]',...
		'position',[355,97,390,133])

add_block('built-in/Transfer Fcn',[sys,'/','4 Varianten/PT1_1'])
set_param([sys,'/','4 Varianten/PT1_1'],...
		'Denominator','[20 1]',...
		'position',[285,97,320,133])

add_block('built-in/Outport',[sys,'/','4 Varianten/out_1'])
set_param([sys,'/','4 Varianten/out_1'],...
		'position',[525,25,545,45])

add_block('built-in/Sum',[sys,'/','4 Varianten/Sum2'])
set_param([sys,'/','4 Varianten/Sum2'],...
		'inputs','+-',...
		'position',[125,275,145,295])

add_block('built-in/Zero-Order Hold',[sys,'/',['4 Varianten/Zero-Order',13,'Hold2']])
set_param([sys,'/',['4 Varianten/Zero-Order',13,'Hold2']],...
		'position',[185,269,220,301])

add_block('built-in/Transfer Fcn',[sys,'/','4 Varianten/PT3_3'])
set_param([sys,'/','4 Varianten/PT3_3'],...
		'Denominator','[2 1]',...
		'position',[515,267,550,303])

add_block('built-in/Transfer Fcn',[sys,'/','4 Varianten/PT2_3'])
set_param([sys,'/','4 Varianten/PT2_3'],...
		'Denominator','[8 1]',...
		'position',[435,267,470,303])

add_block('built-in/Transfer Fcn',[sys,'/','4 Varianten/PT1_3'])
set_param([sys,'/','4 Varianten/PT1_3'],...
		'Denominator','[20 1]',...
		'position',[365,267,400,303])

add_block('built-in/Filter',[sys,'/','4 Varianten/Regler_3'])
set_param([sys,'/','4 Varianten/Regler_3'],...
		'Numerator','[1.19 -1.12]',...
		'Denominator','[1 -1]',...
		'position',[235,264,320,306])

add_block('built-in/Filter',[sys,'/','4 Varianten/Filter_3'])
set_param([sys,'/','4 Varianten/Filter_3'],...
		'Numerator','0.06',...
		'Denominator','[1 -0.94]',...
		'position',[35,261,95,299])

add_block('built-in/Filter',[sys,'/','4 Varianten/Filter_4'])
set_param([sys,'/','4 Varianten/Filter_4'],...
		'Numerator','0.02',...
		'Denominator','[1 -1.74 0.76]',...
		'position',[35,345,135,385])

add_block('built-in/Mux',[sys,'/','4 Varianten/Multiplexer'])
set_param([sys,'/','4 Varianten/Multiplexer'],...
		'inputs','5',...
		'position',[545,94,570,156])

add_block('built-in/Filter',[sys,'/','4 Varianten/Regler_1'])
set_param([sys,'/','4 Varianten/Regler_1'],...
		'Numerator','[1.14 -1.09]',...
		'Denominator','[1 -1]',...
		'position',[170,95,255,135])

add_block('built-in/Transfer Fcn',[sys,'/','4 Varianten/PT3_4'])
set_param([sys,'/','4 Varianten/PT3_4'],...
		'Denominator','[2 1]',...
		'position',[545,352,580,388])

add_block('built-in/Transfer Fcn',[sys,'/','4 Varianten/PT2_4'])
set_param([sys,'/','4 Varianten/PT2_4'],...
		'Denominator','[8 1]',...
		'position',[485,352,520,388])

add_block('built-in/Transfer Fcn',[sys,'/','4 Varianten/PT1_4'])
set_param([sys,'/','4 Varianten/PT1_4'],...
		'Denominator','[20 1]',...
		'position',[425,352,460,388])

add_block('built-in/Filter',[sys,'/','4 Varianten/Regler_4'])
set_param([sys,'/','4 Varianten/Regler_4'],...
		'Numerator','[35.99 -62.69 27.43]',...
		'Denominator','[1 -1]',...
		'position',[280,348,410,392])

add_block('built-in/Zero-Order Hold',[sys,'/',['4 Varianten/Zero-Order',13,'Hold3']])
set_param([sys,'/',['4 Varianten/Zero-Order',13,'Hold3']],...
		'position',[215,354,250,386])

add_block('built-in/Sum',[sys,'/','4 Varianten/Sum3'])
set_param([sys,'/','4 Varianten/Sum3'],...
		'inputs','+-',...
		'position',[165,360,185,380])

add_block('built-in/Inport',[sys,'/','4 Varianten/in_1'])
set_param([sys,'/','4 Varianten/in_1'],...
		'orientation',2,...
		'position',[70,20,90,40])

add_block('built-in/Transfer Fcn',[sys,'/','4 Varianten/PT1_2'])
set_param([sys,'/','4 Varianten/PT1_2'],...
		'Denominator','[20 1]',...
		'position',[330,182,365,218])

add_block('built-in/Transfer Fcn',[sys,'/','4 Varianten/PT2_2'])
set_param([sys,'/','4 Varianten/PT2_2'],...
		'Denominator','[8 1]',...
		'position',[390,182,425,218])

add_block('built-in/Transfer Fcn',[sys,'/','4 Varianten/PT3_2'])
set_param([sys,'/','4 Varianten/PT3_2'],...
		'Denominator','[2 1]',...
		'position',[445,182,480,218])
add_line([sys,'/','4 Varianten'],[485,200;505,200;505,250;35,250;35,205;50,205])
add_line([sys,'/','4 Varianten'],[475,60;500,60;500,105;540,105])
add_line([sys,'/','4 Varianten'],[475,115;490,115;490,165;25,165;25,120;40,120])
add_line([sys,'/','4 Varianten'],[490,115;540,115])
add_line([sys,'/','4 Varianten'],[80,200;115,200])
add_line([sys,'/','4 Varianten'],[70,115;100,115])
add_line([sys,'/','4 Varianten'],[160,200;170,200])
add_line([sys,'/','4 Varianten'],[145,115;165,115])
add_line([sys,'/','4 Varianten'],[310,200;325,200])
add_line([sys,'/','4 Varianten'],[260,115;280,115])
add_line([sys,'/','4 Varianten'],[325,115;350,115])
add_line([sys,'/','4 Varianten'],[370,200;385,200])
add_line([sys,'/','4 Varianten'],[330,60;355,60])
add_line([sys,'/','4 Varianten'],[400,60;430,60])
add_line([sys,'/','4 Varianten'],[395,115;430,115])
add_line([sys,'/','4 Varianten'],[430,200;440,200])
add_line([sys,'/','4 Varianten'],[575,125;590,125;590,85;505,85;505,35;520,35])
add_line([sys,'/','4 Varianten'],[65,30;15,30;15,60;285,60])
add_line([sys,'/','4 Varianten'],[15,60;15,195;50,195])
add_line([sys,'/','4 Varianten'],[15,110;40,110])
add_line([sys,'/','4 Varianten'],[150,285;180,285])
add_line([sys,'/','4 Varianten'],[225,285;230,285])
add_line([sys,'/','4 Varianten'],[325,285;360,285])
add_line([sys,'/','4 Varianten'],[405,285;430,285])
add_line([sys,'/','4 Varianten'],[475,285;510,285])
add_line([sys,'/','4 Varianten'],[190,370;210,370])
add_line([sys,'/','4 Varianten'],[255,370;275,370])
add_line([sys,'/','4 Varianten'],[415,370;420,370])
add_line([sys,'/','4 Varianten'],[465,370;480,370])
add_line([sys,'/','4 Varianten'],[525,370;540,370])
add_line([sys,'/','4 Varianten'],[555,285;570,285;570,335;105,335;105,290;120,290])
add_line([sys,'/','4 Varianten'],[585,370;595,370;595,415;145,415;145,375;160,375])
add_line([sys,'/','4 Varianten'],[570,285;570,255;520,255;520,135;540,135])
add_line([sys,'/','4 Varianten'],[595,370;595,235;530,235;540,145])
add_line([sys,'/','4 Varianten'],[140,365;160,365])
add_line([sys,'/','4 Varianten'],[100,280;120,280])
add_line([sys,'/','4 Varianten'],[15,195;15,280;30,280])
add_line([sys,'/','4 Varianten'],[15,280;15,365;30,365])
add_line([sys,'/','4 Varianten'],[505,200;505,125;540,125])


%     Finished composite block '4 Varianten'.

set_param([sys,'/','4 Varianten'],...
		'position',[305,90,335,140])

add_block('built-in/Step Fcn',[sys,'/','Sollwert'])
set_param([sys,'/','Sollwert'],...
		'position',[215,105,235,125])


%     Subsystem  'Oszi'.

new_system([sys,'/','Oszi'])
set_param([sys,'/','Oszi'],'Location',[0,59,274,252])

add_block('built-in/Inport',[sys,'/','Oszi/x'])
set_param([sys,'/','Oszi/x'],...
		'position',[65,55,85,75])

add_block('built-in/S-Function',[sys,'/',['Oszi/S-function',13,'M-file which plots',13,'lines',13,'']])
set_param([sys,'/',['Oszi/S-function',13,'M-file which plots',13,'lines',13,'']],...
		'function name','sfuny',...
		'parameters','ax, color,dt',...
		'position',[130,55,180,75])
add_line([sys,'/','Oszi'],[90,65;125,65])
set_param([sys,'/','Oszi'],...
		'Mask Display','plot(0,0,100,100,[90,10,10,10,90,90,10],[65,65,90,40,40,90,90],[90,78,69,54,40,31,25,10],[77,60,48,46,56,75,81,84])',...
		'Mask Type','Graph scope.')
set_param([sys,'/','Oszi'],...
		'Mask Dialogue','Graph scope using MATLAB graph window.\nEnter plotting ranges and line type.|Time range:|y-min:|y-max:|Line type (rgbw-:*). Seperate each plot by ''/'':')
set_param([sys,'/','Oszi'],...
		'Mask Translate','color = @4; ax = [0, @1, @2, @3]; dt = -1;')
set_param([sys,'/','Oszi'],...
		'Mask Help','This block plots to the MATLAB graph window and can be used as an improved version of the Scope block. Look at the m-file sfuny.m to see how it works. This block can take scalar or vector input signal.')
set_param([sys,'/','Oszi'],...
		'Mask Entries','200\/-0.2\/1.2\/''r/k/b/k/b''\/')


%     Finished composite block 'Oszi'.

set_param([sys,'/','Oszi'],...
		'position',[415,96,445,134])

add_block('built-in/To Workspace',[sys,'/','zu MATLAB'])
set_param([sys,'/','zu MATLAB'],...
		'mat-name','MessMatr',...
		'position',[410,172,460,188])
add_line(sys,[240,115;300,115])
add_line(sys,[340,115;410,115])
add_line(sys,[375,115;375,180;405,180])

drawnow

% Return any arguments.
if (nargin | nargout)
	% Must use feval here to access system in memory
	if (nargin > 3)
		if (flag == 0)
			eval(['[ret,x0,str,ts,xts]=',sys,'(t,x,u,flag);'])
		else
			eval(['ret =', sys,'(t,x,u,flag);'])
		end
	else
		[ret,x0,str,ts,xts] = feval(sys);
	end
else
	drawnow % Flash up the model and execute load callback
end
