function [ac,bc,cc,p] = ctrlf(a,b,c)
%CTRLF    Conversion of state space models into canonical controller form.
%         [AC,BC,CC,P] = CTRLF(A,B,C)  converts the system:
%
%             px = Ax + Bu
%              y = Cx + Du
%
%         to the system:
%
%             px = ACx + BCu
%              y = CCx + Du
%
%         which is in controller form, using the transform matrix P.
%

%         P.Thind
%         7/89


    error(nargchk(3,3,nargin));
    error(abcdchk(a,b,c));

    char_poly = poly(a);             % Characteristic polynomial of a
    [ra,ca] = size(a);
    j = 0;
    for i = 1:ra                     % Form the M matrix.
        M(i,:) = [zeros(1,j),char_poly(1,1:(ca + 1 - i))];
        j = i;
    end
    p = ctrb(a,b);
    [rp,cp] = size(p);
    if rp == cp
        if det(p) == 0
            error('The system is not completely reachable');
        end
        p = p*M;
    else                            % find linerarly independent columns
                                    % of the controlabilty matrix
        rw_reduce_fm = rref(p);
        rw_ones = ones(1,cp);
        rw_zeros = zeros(1,cp);
        detect_mat = zeros(rp,cp);
        i = 1;
        for j = 1:rp
            detect_mat(i,:) = rw_zeros;
            i = j;
            detect_mat(j,:) = rw_ones;
            result = rw_reduce_fm - detect_mat;
            for k = 1:cp
                if ~any(result(:,k))
                    ctrl = [ctrl,p(:,k)];
                    break
                end
            end
        end
        [r_ctrl,c_ctrl] = size(ctrl);
        if r_ctrl ~= c_ctrl
            error('The system is not completely reachable');
        end
        p = ctrl*M;
    end
    ac = p\a*p;
    bc = p\b;
    cc = c*p;

