function [a,b,c,d] = del2c(a,b,c,d,delta);
%DEL2C  Conversion from discrete time delta domain to continuous domain.
%       [A,B,C,D] = DEL2C(DA,DB,DC,DD,delta)  
%  converts the discrete time system
%
%               px = DAx + DBu
%                y = DCx + DDu
%
%       to the continuous time system
%                .
%                x = Ax + Bu
%                y = Cx + Du
%
%       using delta as the sampling period.
%
%       [NUM,DEN] = DEL2C(DNUM,DDEN,delta)  converts the discrete time system
%       described by  y(d)/u(d) = DNUM(d)/DDEN(d) to the continuous time system
%       described by  y(s)/u(s) = NUM(s)/DEN(s) using delta as the sampling
%       period.


%       I.Kaspura
%       11/89


nargs = nargin;
if nargs == 3
    delta = c;
    [a,b,c,d] = tf2ss(a,b);
    nargs = 5;
end
error(nargchk(5,5,nargs));

if delta~=0
    [m,n] = size(a);
    [m,nb] = size(b);
    a = delta*a + eye(n);           % Convert the system from delta domain to
    b = delta*b;                    % z domain.

    if det(a)==0
        error('det(I+deltaA)=0. No solution possible. Execution aborted.');
    end

    if m==1
        if a==1
            a = 0;
            b = b/delta;
            return
        end
    end

    s = logm([[a,b];zeros(nb,n),eye(nb)])/delta;
    if norm(imag(s))/(norm(real(s))+eps) > 1e-09
        error('Bad Discrete to Continuous Conversion : Complex Result');
    end;
    s=real(s);
    a = s(1:n,1:n);
    b = s(1:n,n+1:n+nb);
end

if nargout == 2
    [a,b] = ss2tf(a,b,c,d,1);
end

