function [Ab,Bb,Cb,m,t] = delbalre(a,b,c,delta)
%DELBALRE    Balanced state-space realization and model reduction
%            in delta domain.
%            [AB,BB,CB,M,T] = DELBALRE(A,B,C,delta) returns a balanced
%            state-space realization of the system:
%
%                    px = Ax + Bx
%                     y = Cx + Dx
%
%            Upon exit returns a vector M containing the diagonal of the
%            gramian of the balanced realization, and a matrix T, the
%            similarity transformation used.
%

%            P.Thind
%            9/89

    error(nargchk(4,4,nargin));
    error(abcdchk(a,b,c));

    Gc = delgram(a,b,delta);
    Go = delgram(a',c',delta);
    R = chol(Gc);
    S = R*Go*R';
    S = tril(S) + tril(S,-1)';
    [v,d] = eig(S);
    t = R'*v*diag(diag(d).^(-.25));
    Ab = t\a*t;
    Bb = t\b;
    Cb = c*t;

    if nargout > 3
            m = diag(delgram(Ab,Bb,delta))';
    end


