function p = delgram(a,b,delta)
%DELGRAM     Controllability and observability gramians in delta domain.
%                P = DELGRAM(A,B,delta)  returns the controllability gramian
%            of the system:
%
%                    px = Ax + Bu
%                     y = Cx + Du
%
%                P = DELGRAM(A',C',delta)  returns the observability gramian
%            of the same system.
%
%            The routine uses the special form of the Lyapunov matrix equation:
%                           AP + PA' + (delta)APA' = -BB'
%            or
%                   A'P + PA + (delta)A'PA = -C'C
%

%  P.Thind
%  5/89.



    error(nargchk(3,3,nargin));
    error(abcdchk(a,b));



    [v,d]=eig(a);
    for i=1:length(d)
        if abs(d(i))^2*delta/2+real(d(i))<0
            error('A not asymptotically stable. Execution aborted');
        end;
    end;

    [ra,ca] = size(a);
    I = eye(ra,ca);
    Ac = I + (delta * a) / 2;
    if det(Ac) == 0
        error('No unique solution. Execution aborted');
    else
        b = b * b';
        b = Ac \ b / (I + (delta * a') / 2);
        a = Ac \ a;
        p = lyap(a,b);
    end

