function [y,x] = delimp(a,b,c,d,iu,t,delta)
%DELIMP   Impulse response of discrete time linear systems in delta domain.
%             [Y,X] = DELIMP(A,B,C,D,iu,T,delta)  
%         calculates the response of the
%         system.
%                        px = Ax + Bu
%                         y = Cx + Du
%
%         to an impulse applied to the iu'th input. Vector T must be the time
%         axis for the response, spaced by delta, the sampling period.
%         DELIMP returns a matrix Y with as many columns as there are outputs
%         and with LENGTH(T) rows. X contains the state time history upon exit.
%
%             [Y,X] = DELIMP(NUM,DEN,T,delta) 
%         calculates the impulse response from
%         the transfer function description  G(s) = NUM(s)/DEN(s)  
%         where NUM and
%         DEN contain the polynomial coefficients in descending powers.

%         I.Kaspura
%         11/89


nargs = nargin;
if (nargs == 4)
    t = c;
    delta = d;
    iu = 1;
    [a,b,c] = tf2ss(a,b);
    nargs = 7;
end

error(nargchk(7,7,nargs));
error(abcdchk(a,b,c));

x0 = b(:,iu);

for i=1:length(t)
    x(:,i) = x0;
    x0 = x0 + a*delta*x0;
end

y = c*x;

