function [h,p] = dellqe(a,c,q,r,delta,n)
%DELLQE    Delta domain linear quadratic estimator design.
%              [H,P] = DELLQE(A,C,Q,R,delta,N)  given the system:
%               px = Ax + v1
%                y = Cx + v2
%
%          where
%               Q=E{v1v1'}/delta, R=E{v2v2'}*delta, N=E{v1v2'}*delta
%
%          returns the gain matrix H such that the stationary Kalman filter:
%                       px = Ax + H(y - Cx))
%
%          produces an optimal filter in the LQG sense.
%
%          N is the cross weighting between q and r and is optional.


%          P. Thind
%          10/89.

    nargs = nargin;
    error(nargchk(5,6,nargin));

    % Calculate estimator gain using DELLQR and duality:

    if nargs == 5
        [l,s] = dellqr(a',c',q,r,delta);
    else
        [l,s] = dellqr(a',c',q,r,delta,n);
    end

    h = l';
    p = s';

