function [mag,pha,w] = delnic(a,b,c,d,iu,delta)
%DELNIC    Calculates the frequency response of a discrete time system
%          in delta domain and then plots the nichols diagram.
%          [MAG,PHA,W] = DELNIC(A,B,C,D,iu,delta)
%          This function finds the frequency response of the system:
%
%                    px = Ax + Bu
%                     y = Cx + Du
%
%          from the iu'th input using delta as the sampling period.
%          Upon exit the vectors MAG and PHA contain the magnitude and
%          phase of the frequency response. The frequency range required
%          for the plot is automatically calculated based upon the position
%          of the systems poles and the sampling frequency. The response is
%          calculated and plotted at the points returned in W.
%
%          [MAG,PHA,W] = DELNIC(NUM,DEN,delta)  calculates the frequency
%          response and plots the nicholas diagram using the discrete time
%          transfer function  y(d)/u(d) = NUM(d)/DEN(d).

%          I.Kaspura
%          11/89


nargs = nargin;
if nargs == 3
    delta = c;
    iu = 1;
    [a,b,c,d] = tf2ss(a,b);
    nargs = 6;
end
error(nargchk(6,6,nargs));


%   Determine the frequency range required.
%   This is done by ensuring that the frequency range extends from
%   0.2 times the frequency of the lowest pole in the system, up to
%   6 times the frequency of the largest pole in the system.

%   Find the poles.
[z,p,k] = ss2zp(a,b,c,d,1);
num_poles = length(p);

wmax = 0;
wmin = 1e10;
for i = 1:num_poles
    wn = sqrt( (real(p(i)))^2 + (imag(p(i)))^2 );
    if wn > wmax
        wmax = wn;
    end
    if wn < wmin
        wmin = wn;
    end
end

wmax = log10(6*wmax);
wmin = log10(0.2*wmin);

%   If the frequency range selected is greater than the sampling frequency
%   reduce the range.
if delta~=0
    if wmax > log10(pi/delta*0.9)
        wmax = log10(pi/delta*0.9);
    end
end

w=logspace(wmin,wmax,300);

h=delfreq(a,b,c,d,iu,w,delta);
mag = 20*log10(abs(h));
pha = 180/pi*unwrap(angle(h));


M=[12,6,4,3,2,1,0.5,0.25,0,-0.5,-1,-2,-3,-4,-5,-6,-9,-12,-18,-24];

    magn=31*ones(61,1)-[1:61]';
    t=magn/20;
    y=exp(t*log(10));
for i=1:20
    A=10^(M(i)/20);
%    x(i,:)=-(acos(((1-A*A)*y.*y-A*A*ones(y))./(2*A*A*y))*57.29577951)';
     x(i,:)=-(acos(((1-A*A)*y.*y-A*A*(y*0+1))./(2*A*A*y))*57.29577951)';%DT
%    for j=1:61
%        magn(j)=31-j;
%        t=magn(j)/20;
%        y(j)=10^t(j);
%        t=(1-A*A)*y(j)*y(j)-A*A;
%        x(i,j)=-acos(((1-A*A)*y(j)*y(j)-A*A)/(2*A*A*y(j)))*57.29577951;
%    end
end


theta1=-2;
theta2=-5;
theta3=-10;
theta4=-20;
theta5=-30;
theta6=-40;
theta7=-50;
theta8=-60;
theta9=-70;
theta10=-80;
theta11=-100;
theta12=-120;
theta13=-140;
theta14=-160;


for j=1:35
    xx=-5*j*0.017453293;
    ang1(j)=-5*j;
    t=sin(xx)-cos(xx)*tan(xx-theta1*0.017453293);
    t=tan(xx-theta1*0.017453293)/t;
    yy1(j)=20*log10(t);
end
for j=1:34
    xx=-5*(j+1)*0.017453293;
    ang2(j)=-5*(j+1);
    t=sin(xx)-cos(xx)*tan(xx-theta2*0.017453293);
    t=tan(xx-theta2*0.017453293)/t;
    yy2(j)=20*log10(t);
end
for j=1:33
    xx=-5*(j+2)*0.017453293;
    ang3(j)=-5*(j+2);
    t=sin(xx)-cos(xx)*tan(xx-theta3*0.017453293);
    t=tan(xx-theta3*0.017453293)/t;
    yy3(j)=20*log10(t);
end
for j=1:31
    xx=-5*(j+4)*0.017453293;
    ang4(j)=-5*(j+4);
    t=sin(xx)-cos(xx)*tan(xx-theta4*0.017453293);
    t=tan(xx-theta4*0.017453293)/t;
    yy4(j)=20*log10(t);
end
for j=1:29
    xx=-5*(j+6)*0.017453293;
    ang5(j)=-5*(j+6);
    t=sin(xx)-cos(xx)*tan(xx-theta5*0.017453293);
    t=tan(xx-theta5*0.017453293)/t;
    yy5(j)=20*log10(t);
end
for j=1:27
    xx=-5*(j+8)*0.017453293;
    ang6(j)=-5*(j+8);
    t=sin(xx)-cos(xx)*tan(xx-theta6*0.017453293);
    t=tan(xx-theta6*0.017453293)/t;
    yy6(j)=20*log10(t);
end
for j=1:25
    xx=-5*(j+10)*0.017453293;
    ang7(j)=-5*(j+10);
    t=sin(xx)-cos(xx)*tan(xx-theta7*0.017453293);
    t=tan(xx-theta7*0.017453293)/t;
    yy7(j)=20*log10(t);
end
for j=1:23
    xx=-5*(j+12)*0.017453293;
    ang8(j)=-5*(j+12);
    t=sin(xx)-cos(xx)*tan(xx-theta8*0.017453293);
    t=tan(xx-theta8*0.017453293)/t;
    yy8(j)=20*log10(t);
end
for j=1:21
    xx=-5*(j+14)*0.017453293;
    ang9(j)=-5*(j+14);
    t=sin(xx)-cos(xx)*tan(xx-theta9*0.017453293);
    t=tan(xx-theta9*0.017453293)/t;
    yy9(j)=20*log10(t);
end
for j=1:19
    xx=-5*(j+16)*0.017453293;
    ang10(j)=-5*(j+16);
    t=sin(xx)-cos(xx)*tan(xx-theta10*0.017453293);
    t=tan(xx-theta10*0.017453293)/t;
    yy10(j)=20*log10(t);
end
for j=1:15
    xx=-5*(j+20)*0.017453293;
    ang11(j)=-5*(j+20);
    t=sin(xx)-cos(xx)*tan(xx-theta11*0.017453293);
    t=tan(xx-theta11*0.017453293)/t;
    yy11(j)=20*log10(t);
end
for j=1:11
    xx=-5*(j+24)*0.017453293;
    ang12(j)=-5*(j+24);
    t=sin(xx)-cos(xx)*tan(xx-theta12*0.017453293);
    t=tan(xx-theta12*0.017453293)/t;
    yy12(j)=20*log10(t);
end
for j=1:7
    xx=-5*(j+28)*0.017453293;
    ang13(j)=-5*(j+28);
    t=sin(xx)-cos(xx)*tan(xx-theta13*0.017453293);
    t=tan(xx-theta13*0.017453293)/t;
    yy13(j)=20*log10(t);
end
for j=1:3
    xx=-5*(j+32)*0.017453293;
    ang14(j)=-5*(j+32);
    t=sin(xx)-cos(xx)*tan(xx-theta14*0.017453293);
    t=tan(xx-theta14*0.017453293)/t;
    yy14(j)=20*log10(t);
end
clg;
plot(x(20,:),magn,'--')
hold;
plot(x(19,:),magn,'--')
plot(x(18,:),magn,'--')
plot(x(17,:),magn,'--')
plot(x(16,:),magn,'--')
plot(x(15,:),magn,'--')
plot(x(14,:),magn,'--')
plot(x(13,:),magn,'--')
plot(x(12,:),magn,'--')
plot(x(11,:),magn,'--')
plot(x(10,:),magn,'--')
plot(x(9,:),magn,'--')
plot(x(8,:),magn,'--')
plot(x(7,:),magn,'--')
plot(x(6,:),magn,'--')
plot(x(5,:),magn,'--')
plot(x(4,:),magn,'--')
plot(x(3,:),magn,'--')
plot(x(2,:),magn,'--')
plot(x(1,:),magn,'--')

plot(ang1,yy1,'-.g')
plot(ang2,yy2,'-.g')
plot(ang3,yy3,'-.g')
plot(ang4,yy4,'-.g')
plot(ang5,yy5,'-.g')
plot(ang6,yy6,'-.g')
plot(ang7,yy7,'-.g')
plot(ang8,yy8,'-.g')
plot(ang9,yy9,'-.g')
plot(ang10,yy10,'-.g')
plot(ang11,yy11,'-.g')
plot(ang12,yy12,'-.g')
plot(ang13,yy13,'-.g')
plot(ang14,yy14,'-.g')

plot(pha,mag,'w')

grid;
title('Nichols Plot');
ylabel('Magnitude (db)');
xlabel('Phase (degrees)');

hold;
pause
