function [y,x] = delstep(a,b,c,d,iu,t,delta)
%DELSTEP  Step response of discrete time linear systems in delta domain.
%             [Y,X] = DELSTEP(A,B,C,D,iu,T,delta)  
%         calculates the response of the
%         system:
%                      px = Ax + Bu
%                       y = Cx + Du
%
%             to a step applied to the iu'th input.  
%         Vector T must be the time axis
%         for the response, spaced by delta, the sampling period.
%         DELSTEP returns a matrix Y with as many columns as there are outputs
%             and with LENGTH(T) rows. X contains the state time history.
%
%             [Y,X] = DELSTEP(NUM,DEN,T,delta) 
%         calculates the step response from
%             the transfer function description  G(s) = NUM(s)/DEN(s)  where NUM
%         and DEN contain the polynomial coefficients in descending powers.

%         I.Kaspura
%         11/89


nargs = nargin;
if (nargs == 4)
    t = c;
    iu = 1;
    delta = d;
    [a,b,c,d] = tf2ss(a,b);
    nargs = 7;
end
error(nargchk(7,7,nargs));
error(abcdchk(a,b,c,d));

% To get the step response put an integrator in series with the system
% and then find the impulse response.
% The state space model of an integrator in delta domain is
%       a1=0; b1=1; c1=1; d1=0;

[a2,b2,c2,d2] = series(0,1,1,0,a,b(:,iu),c,d(:,iu));

[y,x] = delimp(a2,b2,c2,d2,1,t,delta);

% Remove the integrator state introduced earlier.
sa = size(a2);
x = x(:,2:sa(1));
