function [ao,bo,co,p] = obsrf(a,b,c);
% OBSRF      Conversion of state space models into canonical observer form.
%            [AO,BO,CO,P] = OBSRF(A,B,C)  converts the system:
%
%                px = Ax + Bu
%                 y = Cx + Du
%
%            to the system:
%
%                px = AOx + BOu
%                 y = COx + DOu
%
%            which is in observer form, using the transform matrix P.

%            P.Thind
%            7/89

% Canonical observer form of a, b, c is equal to the canonical
% controller form of a', c', b', provided the solution matrix
% are transposed and the transformation matrix modified
% appropriatly.

[ac,bc,cc,pc] = ctrlf(a',c',b');
ao = ac';
bo = cc';
co = bc';
p = inv(pc');

