function y = s2del(s,delta)
%S2DEL   Maps from the continous s plane to the discrete delta plane.
%        Y = S2DEL(S,delta)
%        Given S, either a vector or a matrix, returns
%
%            Y = (exp(S*delta)-I)/delta
%
%        where delta is the sampling period.

%        I.Kaspura
%        11/89.

nargs = nargin;
error(nargchk(2,2,nargs));
if delta == 0
    y = s;
else
    [rs,cs] = size(s);
    if rs==cs                                       % square matrix form
        I=eye(rs,cs); O=zeros(rs,cs);
        A=[s*delta s; O O];
        y=[I O]*expm(A)*[O;I];
    else                                            % non-square
        y=(exp(s*delta)-ones(rs,cs))/delta;
    end
end
