%                        exereal
%
%    This script file computes a state-space realization
%    ( A , B , C , D ) of a given P x M proper real ra-
%    tional transfer matrix G. The file operates on the
%    following workspace variables:
%
%       P, M - number of outputs and inputs of G,
%              respectively.
%
%        Nij - row vector containing numerator co-
%              efficients of row i, column j of G
%              in descending order, for i = 1, 2,
%              ..., P and j = 1, 2, ..., M.
%
%        Dij - row vector containing denominator
%              coefficients of row i, column j of G
%              in descending order, for i = 1, 2,
%              ..., P and j = 1, 2, ..., M.
%
%    The file returns the matrices A , B , C , and D, cor-
%    responding to a state-space realization of G. This
%    realization is constructed on an element-by-element
%    ( e x e ) basis. In other words, each channel of G
%    is independently realized, and then the individual
%    realizations are appropriately interconnected.

%    ^^^^^^^^^^^^^^^^^^^^^^^^^^^*
%     Dr. C. N. Nett, GE CRD/CTB, (518) 387-5539, 5 July 87
%    ^^^^^^^^^^^^^^^^^^^^^^^^^^^*

                                      % PRESERVE WORKSPACE
save TMP1
                                             % ROW LOOP
for RIND = 1 : P
                                          % COLUMN LOOP
   for CIND = 1 : M

                                % COMPUTE CHANNEL REALIZATION

      RINDS = int2str( RIND ) ;
      CINDS = int2str( CIND ) ;
      STR = [ 'tf2ss( N' , RINDS , CINDS , ' , D' , RINDS , CINDS , ' )' ] ;
      [ACH , BCH , CCH , DCH ] = eval( STR ) ;

                       % APPEND CHANNEL REALIZATION TO ROW REALIZATION

      if CIND == 1

        AR = ACH ; BR = BCH ; CR = CCH ; DR = DCH ;

      else

        [ AR, BR, CR, DR ] = parallel( AR, BR, CR, DR, ACH, BCH, CCH, DCH ) ;

      end

   end

                        % APPEND ROW REALIZATION TO MATRIX REALIZATION

   if RIND == 1

      AT = AR' ; BT = BR' ; CT = CR' ; DT = DR' ;

   else

      [ AT, CT, BT, DT ] = parallel( AT, CT, BT, DT, AR', CR', BR', DR' ) ;

   end

end
                                      % MATRIX REALIZATION
A = AT' , B = BT' , C = CT' , D = DT'
                                          % SAVE RESULT
save TMP2 A B C D
                                  % OLD WORKSPACE WITH RESULT
clear
load TMP1
load TMP2
                                              % TIDY UP
!del TMP1.MAT
!del TMP2.MAT
