function [b,a]=fscale(num,den,w)
%
%  [B,A] = fscale(N,D,w)
%
%  frequency scale the transfer function H(s) by w
%
%                 B(s)   N(s)|
%                 ---- = ----|
%                 A(s)   D(s)|s = s/w
%
%  N,D = row vectors of numerator and denominator coefficients
%  w = scale factor
%  B,A = scaled numerator and denominator coefficients
%

%  Written by: Duane Hanselman, University of Maine, (207)-581-2246

errmsg = 'NUMERATOR order must be less than or equal to DENOMINATOR order';
nn = length(num);
nd = length(den);
if nn > nd,
        error('errmsg')
end
sf = w .^ (0:nd-1);
b = num .* sf(nd-nn+1:nd);
a = den .* sf;
