function [mx,n] = fsplot(X,point_type)
%
%  [mx,n] = fsplot(X,point_type)
%
%  plot the magnitude of the positive Fourier Series coefficients
%  given by X = fft(x)
%
%  point_type = optional argument, if it exists it defines the
%               point type to use for plotting:
%               '.'  '+'  '*'  'o'  'x'  (default is 'o')
%
%  [mx,n] are returned if they exist as output arguments
%         mx = magnitude of positive FS coefficients
%          n = index of harmonic numbers associated with mx
%
nx = max(size(X));
n2 = nx/2;
n = 0:n2;
mx = abs( X(1:n2+1) )/nx;
if nargin == 1, point_type = 'o';end
plot(n,mx,point_type)
xlabel('HARMONIC NO.'),ylabel('MAG'),title('FS COEFFICIENTS')
if nargout <= 1, mx=[] n=[]; end
