function [c,s] = cgivens(x,y)
%
% Complex Givens Rotation
%
% [C,S] = CGIVENS (X, Y) produces a Givens rotation of a vector
%          _  _
%         [x ,y ]' (complex or real), such that :
%                _
%           | c  s| |x| = |*|
%           |-s  c| |y|   |0|
%
% -------- Richard Y. Chiang (4/1/86, USC)
%-----------------------------------------------------------------
if abs(x) == 0., c = 0; s = 1; return, end
if abs(y) == 0., c = 1; s = 0; return, end
x1 = real(x); x2 = imag(x);
y1 = real(y); y2 = imag(y);
if abs(y2) < 1.e-6, y2 = 1.e-12; end
if abs(x2) >= abs(x1), t = x1/x2; a = (t*y2-y1)/(t*y1+y2);
   else t = x2/x1; a = (y2-t*y1)/(t*y2+y1); end
b = x2+a*x1;
d = b/y2;
s1 = 1/sqrt(1+d^2+a^2);
s2 = a*s1;
c = d*s1;
s = s1+sqrt(-1)*s2;
%
% ------ End of CGIVENS.M ---- RYC ---- %
