function [am,bm,cm,dm,totbnd] = hklmr(a,b,c,d,tol)
%
% [AM,BM,CM,DM,TOTBND] = HKLMR(A,B,C,D,TOL) produces a Hankel-norm MDA
%       model reduction of an given unstable plant G(s) such that the
%       inf-norm of the error (Ghed(s) - G(s)) = sum of the k+1 to n
%       Hankel singular value of G(s) + 2 * tol, where the tol is between
%       the kth and k+1th Hankel singular values.
%
%       No. of states removed is equal to the no. of Hankel singular
%       value which is less than the "tol".
%
%       Subroutines called : hkapp.m/ satsf.m/ rsasfac.m/ hqr5.m/
%                     cgivens.m/ less.m/ sizflg.m/
%                            (avaliable in RCLIB)
%
%  Author : R. Y. Chiang   ----   USC  2/86
% ------------------------------------------------------------------------
%
disp(' - - - - Working on Hankel Norm MDA Model Reduction - - - -');
[ra,ca] = size(a);
[ee,dd] = eig(a);
%
% ------ Find the no. of stable roots :
%
m = 0;
for k = 1 : ra
    if real(dd(k,k)) < 0.
        m = m + 1;
    end
end
%
% ------ If completely stable :
%
kk = -1;
if m == ra
   [alf,blf,clf,dlf,kl,bndl] = hkapp(a,b,c,d,tol);
   am = alf; bm = blf; cm = clf; dm = d;
   kk = 1;
   kr = 0.;
   totbnd = bndl;
end
%
% ------ If completely unstable :
%
if m == 0.
   [arf,brf,crf,drf,kr,bndr] = hkapp(-a,-b,c,d,tol);
   arf = -arf;
   brf = -brf;
   am = arf; bm = brf; cm = crf; dm = d;
   kk = 1;
   kl = 0.;
   totbnd = bndr;
end
%
% ------ If having both stable & unstable parts :
%
if kk < 0
   [al,bl,cl,dl,ar,br,cr,dr,msat] = satsf(a,b,c,d);
   [alf,blf,clf,dlf,kl,bndl] = hkapp(al,bl,cl,dl,tol);
   dlf = dl;
   [arf,brf,crf,drf,kr,bndr] = hkapp(-ar,-br,cr,dr,tol);
   drf = dr;
   arf = -arf;
   brf = -brf;
   totbnd = bndl + bndr;
   [am,bm,cm,dm] = add2(alf,blf,clf,dlf,arf,brf,crf,drf);
   [ral,cal] = size(al); [rar,car] = size(ar);
   if kl == ral
      am = arf; bm = brf; cm = crf; dm = d;
   end
   if kr == rar
      am = alf; bm = blf; cm = clf; dm = d;
   end
end
%
StateRem = kl + kr
%
% ----- End of HKLMR.M --- 2/13/86 RYC --- %
