function [qn,tn,m,swap] = hqr5(a)
%
% [QN,TN,M,SWAP] = HQR5(A) produces an ordered Complex Schur decom-
%          position such that the stable part is on the top of the
%          the diagonal of Tn, and the unstable part at the bottom,
%     where
%             Tn = Qn' * A * Qn
%              m = no. of stable poles.
%           swap = total no. of swaps.
%
%         The complex Givens rotation is used to swap the two adjacent
%    diagonal terms.
%
%         Similar Schur decompositions are also available :
%
%           HQR6 : ordering the complex Schur form according to the
%                      mag. of the eigenvalue real parts.
%               HQR7 : ordering the complex Schur form according to the
%                      modulus of the eigenvalues.
%
% Author : Richard Y. Chiang   (4/4/86, USC)
%----------------------------------------------------------------------
%
[ma,na] = size(a);
%
% -------- Regular Complex Schur Decomposition :
%
disp(' - - - - Working on the Complex Schur Decomposition - - - -');
[q,t] = schur(a);
[q,t] = rsf2csf(q,t);
%
[mt,nt] = size(t);
dt = diag(t);
%
% -------- Find the no. of stable roots :
%
idm = less(real(dt),zeros(mt,1));
m = sizflg(idm);
if (m==0) | (m==mt), qn = eye(mt); tn = t; swap = 0; return, end
%
% -------- Assign I.C. for the loop counter :
%
pcnt = 0.; kcnt = 0.; gcnt = 0.;
%
% -------- Begin major loop :
%
disp(' - - - - Working on the Complex Givens Rotation - - - -');
for p = 1 : (nt-m)*m
    pcnt = pcnt + 1;
    for k = 1 : (nt-1)
        kcnt = kcnt + 1;
        if (real(t(k,k))>0.) & (real(t(k+1,k+1))<0.)
           gcnt = gcnt + 1;
           [c,s] = cgivens(t(k,k+1),t(k,k)-t(k+1,k+1));
           jb = eye(nt);
           jb(k:k+1,k:k+1) = [c conj(s);-s c];
           t = jb' * t * jb;
           q = q*jb;
        end
    end
    dt = diag(t); ndt = dt(1:m,1);
    flag = less(real(ndt),zeros(m,1)); [fm] = sizflg(flag);
    if fm == m, qn = q; tn = t; swap = gcnt; break, end
end
%
% -------- End of HQR5.M ---- RYC ---- %
