function [qn,tn,swap] = hqr7(a)
%
% Ordered Complex Schur Decomposition
%
% [QN,TN,SWAP] = HQR7(A) produces an ordered complex Schur decomposition
%         according to the modulus of the eigenvalues, and puts them in
%         the acscending order, where
%
%                    Tn   = Qn' * A * Qn
%                    swap = total no. of swaps.
%
%         The complex Given rotation is used to swap the two adjacent
%         diagonal terms.
%
%         Similar Schur decompositions are also available :
%
%                 HQR5 : ordering the complex Schur form according to
%                        the stable/unstable eigenvalues.
%                 HQR6 : ordering the complex Schur form according to
%                        the mag. of the eigenvalue real parts.
%
% Author :  Richard Y. Chiang   (2/22/87, USC)
%
% --------------------------------------------------------------------
%
% ------ Regular Complex Schur Decomposition :
%
disp('- - - - Working on the Complex Schur Decomposition - - - -');
[q,t] = schur(a);
[q,t] = rsf2csf(q,t);
%
[mt,nt] = size(t);
dt = diag(t);
[sordt,idt] = sort(abs(dt));
%
% ------ Assign I.C for loop counter :
%
pcnt = 0.; kcnt = 0.; gcnt = 0.;
%
% ------ Begin Major Loop :
%
disp('- - - - Working on the Complex Givens Rotation - - - -');
for p = 1 : nt*nt
    pcnt = pcnt + 1;
    for k = 1 : (nt-1),
        kcnt = kcnt + 1;
        if (abs(t(k,k))-abs(t(k+1,k+1))) > 0.
           gcnt = gcnt + 1;
           [c,s] = cgivens(t(k,k+1),t(k,k)-t(k+1,k+1));
           jb = eye(nt);
           jb(k:k+1,k:k+1) = [c conj(s);-s c];
           t  = jb' * t * jb;
           q  = q * jb;
        end
     end
     stpflg = norm((abs(diag(t))-sordt),inf);
     if norm((abs(diag(t))-sordt),inf) < 1.e-4
         qn = q; tn = t; swap = gcnt;
         break
     end
end
%
%  ---- End of HQR7.M ---- RYC %
