function [u,u1,u1p,t,a11h,a12h,a22h,m] = rsasfac(a)
%
% Real Stable/Unstable Decomposition.
%
% [U,U1,U1P,T,A11H,A12H,A22H,M] = RSASFAC(A) produces a real
%         stabel/unstable decomposition with factored blocks
%         A11h(stable), A22h(unstable), and A12h of an ordered
%         complex Schur decomposition result.
%
% -------- Richard Y. Chiang (4/4/86, USC)
% ------------------------------------------------------------
[ra,ca] = size(a);
%
% ----- Ordered Complex Schur Decomposition :
%
[qn,tn,m,swap] = hqr5(a);
%
% ----- Find the Orthonomal basis :
%
kk = -1;
if m == ra
     u = eye(ra);
     t = a;
     u1 = eye(ra);
     u1p = zeros(ra,ca);
     a11h = a;
     a22h = zeros(ra,ca);
     a12h = zeros(ra,ca);
     kk = 1;
end
if m == 0.
     u = eye(ra);
     t = a;
     u1 = eye(ra);
     u1p = zeros(ra,ca);
     a22h = a;
     a11h = zeros(ra,ca);
     a12h = zeros(ra,ca);
     kk = 1;
end
if kk < 0
     qord = [real(qn(:,1:m)) imag(qn(:,1:m))];
     [u,r] = qr(qord);
     t = u' * a * u;
     [ru,cu] = size(u);
     u1 = u(:,1:m);
     u1p = u(:,m+1:cu);
     a11h = u1'  * a * u1;
     a12h = u1'  * a * u1p;
     a22h = u1p' * a * u1p;
end
%
% ----- End of RSASFAC.M ---- RYC ---- %
