function  [A,B,C,K]=allocrem(A,B,C,l);
%
%     function  [A,B,C,K]=allocrem(A,B,C,l);
%
%     Given  nxn, nxm, and pxm  matrices  A, B, and C  respectively,
%  with  p=m+1,  this function recursively allocates  r  eigenvalues
%  specified in  l. The function allocates two eigenvalues each time
%  is called, and returns the  K  that has accomplished the allocation
%  along with the deflated, by two states, subsystem  (A,B,C).
%  The function is called by function  MEVAO, and calls functions
%  MEVAOSTP, and  itself.
%
%      Written by  George S. Miminis
%                  Department of Computer Science
%                  Memorial University of Newfoundland
%                  St. John's, Newfoundland, CANADA,
%                  A1C 5S7.
%             tel: (709)737-8635
%          e-mail: george@garfield.cs.mun.ca
%                  na.miminis@na-net.ornl.gov
%
%
r=length(l);
if r>2,
   [A,B,C,k1,V1]=mevaostp(A,B,C,l(1));
   [A,B,C,k2,V2]=mevaostp(A,B,C,l(2));
   A=A.';
   AUX=C.';
   C=B.';
   B=AUX;
   [A,B,C,K]=allocrem(A,B,C,l(3:r));
   K=[k2,K.']*V2';
   K=[k1,K]*V1';
   return;
elseif r==2,
   [n,m]=size(B); [p,n]=size(C);
   [A,B,C,k1,V1]=mevaostp(A,B,C,l(1));
   [A,B,C,k2,V2]=mevaostp(A,B,C,l(2));
   K=zeros(m,p-2);
   K=[k2,K]*V2';
   K=[k1,K]*V1';
   return;
elseif r==1
   [n,m]=size(B); [p,n]=size(C);
   [A,B,C,k1,V1]=mevaostp(A,B,C,l(1));
   K=zeros(m,p-1);
   K=[k1,K]*V1';
   return;
else
   return;
end;
