function F=demesas(E,A,B,l,X);
%
%     function F=demesas(E,A,B,l,X);
%
%     This is the driver program that solves the Eigenstucture Assignment
%  problem for Multi-Input Descriptor systems using State Feedback, by
%  calling the functions  SREDUCE, and  EIGENSTR.
%     Given a system  (E,A,B),  a set  l  of desired eigenvalues, and a
%  matrix  X  with the corresponding desired and feasible eigenvectors,
%  the program constructs matrices  X  and  L  so that it may allocate two
%  eigenvalues at a time along with the corresponding eigenspace in a double
%  step. The algorithm reduces the system of equations by two at each double
%  step. This process  resembles deflation and we will in the sequel use the
%  term. The program is an implementation of an algorithm by George Miminis
%  submitted to the special issue of the journal,  Linear Algebra and its
%  Applications, on Systems, Signals and Control.
%
%  INPUT:  E,A,B    nxn, nxn, nxm  matrices respectively.
%          l        n-dimensional vector, contains the  n  eigenvalues to be
%                   allocated. Complex eigenvalues appear first and in
%                   conjugate pairs. Real eigenvalues follow.
%          X        nxn  matrix with the corresponding eigenvectors. Complex
%                   eigenvectors appear in conjugate pairs.
%
%  OUTPUT: F        The desired feedback matrix.
%
%
%  Note that for its proper execution it needs the  m.functions  ODD,
%  and  ROWS.
%
%
%      Written by  George S. Miminis
%                  Department of Computer Science
%                  Memorial University of Newfoundland
%                  St. John's, Newfoundland, CANADA,
%                  A1C 5S7.
%             tel: (709)737-8635
%          e-mail: george@garfield.cs.mun.ca
%                  na.miminis@na-net.ornl.gov
%
%
[n,m]=size(B);
l(n+1)=0;
%
% Prepare  X,  and  L  for  SREDUCE.
%
L=zeros(n,2);
nn=n-1;
if odd(n),
   nn=n-2;
   L(n,1)=l(n);
end;
for i=1:2:nn,
    if imag(l(i))==0,
       L(i,1)=l(i);
       L(i+1,1)=l(i+1);
    else
       L(i,1)=real(l(i));
       L(i,2)=imag(l(i));
       L(i+1,1)=-imag(l(i));
       L(i+1,2)=real(l(i));
       X(:,i)=real(X(:,i));
       X(:,i+1)=-imag(X(:,i+1));
    end;
end;
l(n+1)=[];
[E,A,B,L,X,V,W]=sreduce(E,A,B,L,X);
[nc,mc]=size(B);
Fhat=zeros(mc,n-nc);
Fdown=zeros(m-mc,n);
%
% Prepare  L  for  EIGENSTR.
%
nL=rows(L);
for i=1:2:nL-1,
    if L(i,2)==0,
       L(i+1,2)=L(i+1,1);
       L(i+1,1)=0;
    end;
end;
F1=eigenstr(E,A,B,L,X);
F=W*[ F1   Fhat; ...
        Fdown   ]*V';
