%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%                                                                           %
%                                   demo.m                                  %
%                                                                           %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
home, clc
echo on
%
%   This demonstration will remove from memory all items that have been
% created during the current matlab session.
%
pause  % Press any key to continue or  Ctrl c  to terminate  DEMO.
home, clc
%
%    In the sequel  MEVAS  will stand for  "Multi input EigenValue Allocation
% using State feedback", where the upper case letters compose the name  MEVAS.
% Similarly  MEVAO  stands for  "Multi input EigenValue Allocation using
% Output feedback",  SEVAS  stands for  "Single input EigenValue Allocation
% using State feedback", while  DEMEVAS  stands for the corresponding  MEVAS
% for  DEscriptor systems, and  DEMESAS  for the EigenStructure Allocation
% problem using State feedback for DEscriptor systems.
%
pause  % Press any key to continue.
home, clc
%
%    The first three examples in this demonstration, will present how  MEVAS
% may be used, the next two examples will be concerned with  MEVAO ,
% while the next example will present how  SEVAS  may be used. The five
% examples that will follow will demonstrate how  REDUCE  and  DEMEVAS  may
% be used. Finaly the last example will present  DEMESAS. Once you have
% mastered how to use  MEVAS,  MEVAO,  SEVAS,  REDUCE,  DEMEVAS,  and  DEMESAS
% you may delete  DEMO.m . You may also delete all the data files since they
% are only used by  DEMO.m . MEVAS.out is created by  DEMO.m , therefore it
% may be deleted as well.
%
pause  %  Press any key to start the first example for  MEVAS.
clear
echo off
inm1
echo on
home, clc
A, B
pause  %  Press any key to see the desired eigenvalues and  info.
home, clc
l, info
%
%  The above system is controllable thus all the eigenvalues may be
% allocated. Note that  info=[1 1 1],  meaning that we want the
% controllability form of the system to be computed and displayed.
% Furthermore during the computation of the controllability form,
% we want the  svd  to be used for the determination of ranks.
% See more about  info  by displaying the comments for  MEVAS.m .
%
       %  To allocate the eigenvalues type  F=mevas(A,B,l,info).
pause  %  Press any key to do the above.
home, clc
F=mevas(A,B,l,info);    % Working.
pause  %  Press any key to see  F.
F
       %  Press any key to check the allocated eigenvalues  eig(A-B*F)
pause  %  against the desired eigenvalues  l.
home, clc
[sort(eig(A-B*F)), sort(l)]
pause  %  Press any key to continue.
home, clc
%
%  Suppose in the above example you did not want the controllability form
% of the system displayed, then set  info(2)  equal to anything but  1
% for example
%
info(2)=0
F=mevas(A,B,l,info)    % Working.
pause  %  Press any key to see the second example.
clear
echo off
inm2
echo on
home, clc
A, B
pause  %  Press any key to see the desired eigenvalues and  info.
home, clc
l, info
%
%  The above system is uncontrollable thus appropriate messages will
% be displayed. Since they may disappear from your monitor, faster than
% you can read them, they will be saved in a file  MEVAS.out  in your
% current directory.
%
pause  %  Press any key to allocate the eigenvalues.
home, clc
diary MEVAS.out
F=mevas(A,B,l,info)  % Working.
diary  %  MEVAS.out  stops at this point.
       %  Press any key to check the  four  allocated eigenvalues
pause  %  against the desired eigenvalues  l.
home, clc
[sort(eig(A-B*F)), sort(l)]
pause  %  Press any key to see the third example.
clear
echo off
inm3
echo on
home, clc
A, B
pause  %  Press any key to see the desired eigenvalues  info  and  nn.
home,clc
l, info, nn
pause  %  Press any key to continue.
%
%  The above example is already in its controllability form thus  info is
% a scalar other than  1 . Note that this time  nn  should also be given.
% nn  is a vector containing the row rank of  B  and the row ranks of the
% subdiagonal blocks of  A. When the system is not in its controllability
% form,  nn  is created by  MEVAS. See more about  nn  by displaying the
% comments for  MEVAS.m .
%
pause  %  Press any key to allocate the eigenvalues.
home, clc
F=mevas(A,B,l,info,nn)   % Working.
       %  Press any key to check the allocated eigenvalues  eig(A-B*F)
pause  %  against the desired eigenvalues  l.
home, clc
[sort(eig(A-B*F)), sort(l)]
pause  %  Press any key to start the first example for  MEVAO.
clear
echo off
ino1
echo on
home, clc
A
pause  %  Press any key to see  B  and  C.
home, clc
B, C
pause  %  Press any key to see the desired eigenvalues.
home, clc
l
%
%   In the above example we have  m+p-1<n  hence only  m+p-1 = 4  eigenvalues
% will be allocated.
%
       %  To allocate the eigenvalues type  K=mevao(A,B,C,l).
pause  %  Press any key to do the above.
home, clc
K=mevao(A,B,C,l)    % Working.
       %  Press any key to check the allocated eigenvalues  eig(A-B*K*C)
pause  %  against the desired eigenvalues  l.
home, clc
sort(eig(A-B*K*C)), sort(l)
pause  %  Press any key to start the second example for  MEVAO.
clear
echo off
ino2
echo on
home, clc
A
pause  %  Press any key to see  B  and  C.
home, clc
B, C
pause  %  Press any key to see the desired eigenvalues.
home, clc
l
%
%   In the above example we have  m+p-1>=n  hence all  n  eigenvalues may be
% allocated.
%
pause  %  Press any key to allocate the eigenvalues.
home, clc
K=mevao(A,B,C,l)    % Working.
       %  Press any key to check the allocated eigenvalues  eig(A-B*K*C)
pause  %  against the desired eigenvalues  l.
home, clc
[sort(eig(A-B*K*C)), sort(l)]
pause  %  Press any key to see the example for  SEVAS.
clear
echo off
ins
echo on
home, clc
A, b
pause  %  Press any key to see the desired eigenvalues
home, clc
l
       %  To allocate the eigenvalues, compute the controllability form
       %  of the system, and display it, type  f=sevas(A,b,l,1,1).
pause  %  Press any key to do the above.
home, clc
f=sevas(A,b,l,1,1);  % Working.
pause  %  Press any key to see  f.
f
       %  Press any key to check the allocated eigenvalues  eig(A-b*f')
pause  %  against the desired eigenvalues  l.
home, clc
[sort(eig(A-b*f')), sort(l)]
pause  %  Press any key to see an example on how to use  REDUCE.
clear
echo off
inde111
echo on
home, clc
%
%   In this example  REDUCE  will detect three kinds of uncontrollability.
% The first will be due to a finite uncontrollable eigenvalue. The other two
% will be due to the uncontrollable nature of the infinite eigenvalues of
% (A,E). REDUCE  will detect an infinite eigenvalue of  (A,E)  that if it
% causes singularity of  (A,E),  it cannot be altered in  (A-B*F,E). It will
% also detect an infinite eigenvalue of  (A,E)  that if it causes singularity,
% it can be altered in  (A-B*F,E). This system has  7  states and  2  inputs.
%
pause  %  Press any key to run  REDUCE.
home, clc
[E,A,B,nn,U,V,W]=reduce(E,A,B);   %  Working.
pause  %  Press any key to see  E,  and  B.
home, clc
E, B
pause  %  Press any key to see  A,  and  nn.
home, clc
A, nn
pause  %  Press any key to see the first example for the  DEMEVAS.
clear
echo off
inde000
echo on
home, clc
%
%   This system has  7  states and  3  inputs, and it is completely
% controllable.
%
pause  %  Press any key to run  DEMEVAS.
home, clc
F=demevas(E,A,B,l,form,write)   %  Working.
       %  Press any key to check the allocated eigenvalues against the
pause  % the desired eigenvalues.
home, clc
[sort(eig(A-B*F,E)), sort(l)]
pause  %  Press any key to start the second example for  DEMEVAS.
clear
echo off
inde010
echo on
home, clc
%
%   This system has  7  states and  3  inputs. (A,E)  however has an infinite
% eigenvalue that if it causes singularity of  (A,E),  it may change in
% (A-B*F,E). This is a "CONTROLLABLE INFINITE EIGENVALUE". Appropriate
% messages will be produced by the program. Press any key to proceed with the
% allocation.
%
pause
home, clc
F=demevas(E,A,B,l,form,write)   %  Working.
%
%  Press any key to check the allocated eigenvalues. Since  E  is singular we
% will compute the eigenproblem of  (E,A-B*F)  instead, and then invert the
% nonzero eigenvalues. Press any key to do the above.
%
pause
home, clc
lcl=eig(E,A-B*F);
lcl=[ones(1,3)./lcl(1:3)' ones(1,3)./lcl(5:7)' inf]'
%  Press any key to check the allocated eigenvalues against the desired
% eigenvalues.
pause
home, clc
[sort(lcl), sort(l)]
pause  %  Press any key to see the third example for  DEMEVAS.
clear
echo off
inde0112
echo on
home, clc
%
%   This system has  7  states and  3  inputs. (A,E)  has three infinite
% eigenvalues. Two of them are such that if they cause singularity of  (A,E),
% F  is unable to change this in  (A-B*F,E), ("UNCONTROLLABLE INFINITE
% EIGENVALUES") thus they are deflated. The third is a controllable infinite
% eigenvalue. Appropriate messages will be produced by the program. The
% parameter  "write"  however is zero this time, hence the system will not be
% displayed as it changes form. Press any key to proceed with the allocation.
%
pause
home, clc
F=demevas(E,A,B,l,form,write)   %  Working.
%
%  Press any key to check the allocated eigenvalues. Note that since
% (A-B*F,E)  will have three infinite eigenvalues, here too we compute the
% eigenvalues of  (E,A-B*F)  and invert the nonzero ones. Press any key to do
% the above.
%
pause
home, clc
lcl=eig(E,A-B*F);
lcl=[ones(1,4)./lcl(1:4)' inf inf inf]'
%  Press any key to check the allocated eigenvalues against the desired
% eigenvalues.
pause
home, clc
[sort(lcl), sort(l)]
pause  %  Press any key to see the fourth example for  DEMEVAS.
clear
echo off
inde111
echo on
home, clc
%
%   This system has  7  states and  3  inputs. (A,E)  has two infinite
% eigenvalues, one controllable and one uncontrollable. The latter is
% deflated and appropriate messages are produced by the program.
% Press any key to proceed with the allocation.
%
pause
home, clc
F=demevas(E,A,B,l,form,write)   %  Working.
%
%  Press any key to check the allocated eigenvalues.
%
pause
home, clc
lcl=eig(E,A-B*F);
lcl=[ones(1,5)./lcl(1:5)' inf inf]'
%  Press any key to check the allocated eigenvalues against the desired
% eigenvalues.
pause
home, clc
[sort(lcl), sort(l)]
pause  %  Press any key to see an example for the  DEMESAS.
clear
echo off
indesas
echo on
home, clc
%
%   This system has  7  states and  2  inputs. (A,E)  has two infinite
% eigenvalues, one controllable and one uncontrollable. The latter is
% deflated and appropriate messages are produced by the program. The system
% has also a finite uncontrollable eigenvalue, which is deflated as well.
% Press any key to proceed with the allocation. Note that  l  includes the
% finite uncontrollable eigenvalue of (A,E), which is 1.1621. The program
% however, will detect this and will not include this eigenvalue among those
% to be allocated, thereby avoiding a double eigenvalue for the pencil
% (A-B*F,E).
%
pause
home, clc
F=demesas(E,A,B,l,X)   %  Working.
%
%  Press any key to check the results.
%
pause
home, clc
%
%  Since  E  is singular we will compute the eigenproblem of  (E,A-B*F)
% instead, and then invert the nonzero eigenvalues. Note that the eigenvectors
% of  (E,A-B*F)  are the same as those of  (A-B*F,E). Press any key to
% fist see the eigenvectors of  (A-B*F,E).
%
pause
home, clc
[Xcl,lcl]=eig(E,A-B*F);
Xcl
pause  % Press any key to see the eigenvalues.
home, clc
lcl=diag(lcl);
lcl=[ones(1,5)./lcl(1:5)' inf inf]'
pause
home, clc
%
%   Press any key to check the eigenvalues of  (A-B*F,E)  against  l. Note
% that only four out of seven eigenvalues have been allocated. Also recall
% the peculiarity of the eigenvalue  1.1621.
%
pause
home, clc
[sort(lcl) sort(l)]
pause
home, clc
%
%   Press any key to check the allocated eigenvectors. We will accomplish
% that by checking for linear dependency among the desired eigenvectors,
% stored in  X, and those of  (A-B*F,E),  stored in  Xcl. The  svd  will
% be used for the above.
%
pause
home, clc
format long
svd([X(:,[1,2]) Xcl(:,[2,4])])
pause
home, clc
%
%   Press any key to continue.
%
svd([X(:,[3,4]) Xcl(:,[1,3])])
pause
home, clc
%
%   The eigenvector of  (A-B*F,E)  that corresponds to the eigenvalue  1.1621
% does not necessarily have to be linearly dependent on the corresponding
% eigenvector of  (A,E). Press any key to see this.
%
pause
home, clc
svd([X(:,5) Xcl(:,5)])
pause
home, clc
pause  %  Press any key to finish  DEMO.
format short
clear
home, clc
