function  A=hohapl(A,u,pi);
%
%  function  A=hohapl(A,u,pi);
%
%       HOHAPL: applies a Householder transformation, defined by  u  and  pi,
%               to a matrix  A. The transformation eliminates elements
%               A(1,j), A(2,j),..., A(i-1,j), A(i+1,j),..., A(m,j) into
%               A(i,j)  where  A(i,j)  is some element of  A  determined by
%               The user and  m  is  the number of rows in  A. The function
%               also works for a complex  A.
%  Application: (I-(u*u')/pi)*A = A-u*(u'*A)/pi
%            A: is a matrix with  m  rows.
%            u: is an  m-dimensional  row or column vector that along with
%               pi  define the householder transformation.
%         NOTE: the number of rows in  A  must be the same as the number of
%               elements in  u.
%
%      Written by  George S. Miminis
%                  Department of Computer Science
%                  Memorial University of Newfoundland
%                  St. John's, Newfoundland, CANADA,
%                  A1C 5S7.
%             tel: (709)737-8635
%          e-mail: george@garfield.cs.mun.ca
%                  na.miminis@na-net.ornl.gov
%
[m,n]=size(A);
for j=1:n,
    A(:,j)=A(:,j)-((u'*A(:,j))/pi)*u;
end;
