function  H=hohleft(n,u,row);
%
%  function  H=hohleft(n,u,row);
%
%      HOHLEFT: creates a Householder transformation  H  that eliminates
%               u(2), u(3) ,..., u(m) into  u(1).
%               The function works for complex  u  as well.
%  Application: H*(column vector  or  matrix).
%            n: is an integer that represents the size of the column vector
%               or matrix in the calling program that  H  will be applied to.
%            u: is an  m-dimensional  row or column vector.
%          row: is an integer that represents the row of the column vector
%               or matrix in the calling program that  u(1)  corresponds to.
%
%      Written by  George S. Miminis
%                  Department of Computer Science
%                  Memorial University of Newfoundland
%                  St. John's, Newfoundland, CANADA,
%                  A1C 5S7.
%             tel: (709)737-8635
%          e-mail: george@garfield.cs.mun.ca
%                  na.miminis@na-net.ornl.gov
%
[m k]=size(u);
if m==1,
   u=u';
   m=k;
end;
H=eye(n);
eta=max(u);
u=u./eta;
si=norm(u);
tol=si*n*eps;
if norm(u(2:m))<=tol,
   return;
else
   theta=angle(u(1));
   if abs(theta)<tol | abs(theta-pi)<tol,
      si=si*cos(theta);
   else
      si=si*(cos(theta)+i*sin(theta));
   end;
   u(1)=u(1)+si;
   pi=si'*u(1);
   si=eta*si;
   sub=row:row+m-1;
   H(sub,sub')=eye(m)-u*u'/pi;
end;
