function  [u,xi]=hohvect(u,i);
%
%  function  [u,xi]=hohvect(u,i);
%
%      HOHVECT: computes the vector  u  that defines a Householder
%               transformation  H  along with the corresponding  pi(=xi).
%               H  eliminates  u(1),u(2),...,u(i-1),u(i+1),...,u(m)  into
%               u(i), where  m=length(u).
%               The function works for complex  u  as well.
%
%      Written by  George S. Miminis
%                  Department of Computer Science
%                  Memorial University of Newfoundland
%                  St. John's, Newfoundland, CANADA,
%                  A1C 5S7.
%             tel: (709)737-8635
%          e-mail: george@garfield.cs.mun.ca
%                  na.miminis@na-net.ornl.gov
%
[m k]=size(u);
if m==1,
   u=u';
   m=k;
end;
eta=max(abs(u));
u=u./eta;
si=norm(u);
tol=si*m*eps;
if norm([u(1:i-1)' u(i+1:m)'])<=tol,
   return;
else
   theta=angle(u(i));
   if abs(theta)<tol | abs(theta-pi)<tol,
      si=si*cos(theta);
   else
      si=si*(cos(theta)+j*sin(theta));
   end;
   u(i)=u(i)+si;
   xi=si'*u(i);
   si=eta*si;
end;
