function [A,B,C,k,V]=mevaostp(A,B,C,l);
%
%     function [A,B,C,k,V]=mevaostp(A,B,C,l);
%
%     Given  nxn, nxm, and pxn  matrices  A, B, C  respectively, this
%  function allocates eigenvalue  l  by computing an  m-dimensional
%  vector  k  . It also performs deflation and returns the deflated subsystem
%  (A,B,C). Finally it returns the unitary matrix  V  which is used to
%  compute the "original"  K.
%     The function is called by functions  MEVAO, and  ALLOCREM,  and calls
%  functions  BACKSB, and  HOHLEFT.
%
%      Written by  George S. Miminis
%                  Department of Computer Science
%                  Memorial University of Newfoundland
%                  St. John's, Newfoundland, CANADA,
%                  A1C 5S7.
%             tel: (709)737-8635
%          e-mail: george@garfield.cs.mun.ca
%                  na.miminis@na-net.ornl.gov
%
[n,m]=size(B);
[p,n]=size(C);
I=eye(n);
tol=sqrt(eps);
%
%  The allocation.
%
%  Compute that feasible eigenvector that forms the largest angle
%  with the null space of  C.
%
[H,Z,HH]=svd(C');
rankC=0;
for i=1:min(p,n),
    if Z(i,i)>tol,
       rankC=rankC+1;
    end;
end;
H0=H(:,1:rankC);
[U,R,UU]=svd(B);
rankB=0;
for i=1:min(m,n),
    if R(i,i)>tol,
       rankB=rankB+1;
    end;
end;
U0=U(:,1:rankB);
U1=U(:,rankB+1:n);
if rankB~=n,
   [W,T]=qr((U1'*(A-l*I))');
   W1=W(:,n-rankB+1:n);
   [Y,S,X]=svd(H0'*W1);
   x=X(:,1);
   x=W1*x;
else
   x=ones(rankC,1);
   x=H0*x;
end;
%
%   Allocate  (l,x)  by computing  K*V*I(:,1).
%
V=(hohleft(p,C*x,1))';
gamma=V'*C*x;
gamma=gamma(1);
R=diag(R(1:rankB,1:rankB));
UU=UU(1:rankB,1:rankB);
[P,D]=qr(UU');
k=backsb(D,P'*((U0'*((A-l*I)*x))./R)/gamma);
k=[k
   zeros(m-rankB,1)];
%
%   Compute unitary  Q  : Q'*x=||x||*I(:,1), and perform deflation
%   by applying a unitary similarity transformation based on  Q.
%
Q=hohleft(length(x),x,1)';
B=Q(:,2:n)'*B;
c=(V(:,1)'*C*Q(:,2:n))';
C=V(:,2:p)'*C*Q(:,2:n);
A=Q(:,2:n)'*A*Q(:,2:n)-B*k*c';
