function [Q,R,E]=qrtrans(A,piv);
%
% function [Q,R,E]=qrtrans(A,piv);
%
% QRTRANS computes the  QR  decomposition of  A  (with row pivoting
%          if  piv=1)  such that  A=E'*(0,T)*Q, where (0,T)=R  and
%          T  upper triangular.
%          For its execution it needs the  m.function  TRANS.
%
%      Written by  George S. Miminis
%                  Department of Computer Science
%                  Memorial University of Newfoundland
%                  St. John's, Newfoundland, CANADA,
%                  A1C 5S7.
%             tel: (709)737-8635
%          e-mail: george@garfield.cs.mun.ca
%                  na.miminis@na-net.ornl.gov
%
A=trans(A);
if ~exist('piv'), piv=0; end;
if piv,
   [Q,R,E]=qr(A);
else
   [Q,R]=qr(A);
end;
R=trans(R);
Q=trans(Q);
if piv,
   E=trans(E);
end;
