function A=rotapl(A,y,i);
%
%  function A=rotapl(A,y,i); with  y=[c,s].
%
%       ROTAPL:  Applies a rotation matrix, say  R, defined by  y=[c,s], to a
%                matrix  A  and eliminates some element  A(i(2),j)  into
%                another element  A(i(1),j). Index  j  is determined by the
%                user, and it appears implicitly in  y=[c,s].
%                It works for complex  A  as well.
%            i:  A 2-dimensional integer vector, where  i(1), i(2)  are two
%                integers that represent the rows of the vector or matrix in
%                the calling program, that  A(i(1),j), A(i(2),j)  correspond
%                to.
%
%  Application:  ROTAPL  may be used along with the m.function  ROT.
%                ROTAPL  normally applies  R  to the left of  A,  hence
%                if we access  A  by row we may use  ROTAPL  as:
%                         A=rotapl(A,rot(A(i,j)),i),
%                for some column  j;  if we access  A  by column then
%                         A=rotapl(A.',rot(A(j,i)),i).',
%                for some row  j. Note that  ().'  is the non-conjugate
%                transpose of a matrix.
%
%      Written by  George S. Miminis
%                  Department of Computer Science
%                  Memorial University of Newfoundland
%                  St. John's, Newfoundland, CANADA,
%                  A1C 5S7.
%             tel: (709)737-8635
%          e-mail: george@garfield.cs.mun.ca
%                  na.miminis@na-net.ornl.gov
%
c=y(1);
s=y(2);
A([i(1),i(2)],:)=[c' s'; -s  c]*A([i(1),i(2)],:);
