function u=laprec(f,g,p,q,a,b,x,y,ntrms)
% u=laprec(f,g,p,q,x,y)
% This function sums the series which solves Laplace's equation
% in a rectangle.
%  f,g,p,q - Fourier sine series coefficients for the boundary
%            conditions on the bottom, top, left, and right sides
%   a,b    - the horizontal and vertical side lengths
%   x,y    - vectors containing coordinates of points defining a
%            rectangular grid on which the solution is to be
%            evaluated.
%   ntrms  - number of series terms used (not exceeding length(f));

%   by Howard B. Wilson, U. of Alabama, Spring 1990

nt=length(f); if nargin==8, ntrms=nt; end; ntrms=min(nt,ntrms);
x=x(:); y=y(:)'; n=1:ntrms; nx=length(x); ny=length(y);
if nt>ntrms, f=f(n); g=g(n); p=p(n); q=q(n); end
a2=2*a; b2=2*b; na=(pi/a)*n; nb=(pi/b)*n;
denomx=1-exp(-b2*na(:));
f=f(:)./denomx; g=g(:)./denomx;
denomy=1-exp(-a2*nb(:)'); p=p(:)'./denomy; q=q(:)'./denomy;
u1_= (f*ones(1,ny)).*(  exp(-na'*y) - exp(-na'*(b2-y))  );
u2_= (g*ones(1,ny)).*(  exp(-na'*(b-y)) - exp(-na'*(b+y)) );
u=sin(x*na)*( u1_+u2_ );
u3_= ( exp(-x*nb) - exp(-(a2-x)*nb) ).*(ones(nx,1)*p);
u4_= ( exp(-(a-x)*nb) - exp(-(a+x)*nb) ).*(ones(nx,1)*q);
u=u+(u3_+u4_)*sin(nb'*y);
