function y=lintrp(x,xd,yd)
% y=lintrp(x,xd,yd)
% This function performs piecewise linear interpolation through
% data defined by vectors xd,yd. The components of xd are presumed
% to be in nondecreasing order. Any point where xd(i)==xd(i+1)
% generates a jump discontinuity. For points outside the data range,
% the interpolation gives yd(1) for x<xd(1), and gives yd(nd) for
% x>x(nd), where nd=length(xd).

% by Howard B. Wilson, U. of Alabama, Spring 1990

x=x(:); xd=xd(:); yd=yd(:); y=zeros(length(x),1); nd=length(xd);
y=y+yd(1)*(x<xd(1))+yd(nd)*(x>=xd(nd));
for i=1:nd-1
  xlft=xd(i); ylft=yd(i); xrht=xd(i+1); yrht=yd(i+1);
  dx=xrht-xlft;
  if dx~=0, s=(yrht-ylft)/dx;
    y=y+(x>=xlft).*(x<xrht).*(ylft+s*(x-xlft));
  end
end
