function sincof = sinfft(fun,hafper,powr2)
% sincof = sinfft(fun,halfper,powr2)
% This function determines coefficients in the Fourier sine
% series of a general real valued function.

%  by Howard B. Wilson, U. of Alabama, Spring 1990

%  hafper  - the half  period over which the expansion applies
%  fun     - the real valued function being expanded. This
%            function must be defined for vector arguments
%            with components between zero and hafper.
%  powr2   - the power of 2 determining the number of function
%            values used in the FFT (number of values = 2^powr2)
%            When powr2 is 9, then 512 function values are used
%            and 255 Fourier coefficients are conputed.

n=2^powr2; period=2*hafper; n2=n/2; x=(period/n)*(0:n2);
fval=feval(fun,x); fval=fval(:); fval=[fval;-fval(n2:-1:2)];
foucof=fft(fval); sincof=-(2/n)*imag(foucof(2:n2));

