% Driver program for solution of Laplace's equation
% in a rectangular domain
clear
global a_ b_ xbot_ ubot_ xtop_ utop_ ylft_ ulft_ yrht_ urht_
global sbot_ stop_ slft_ srht_ u1_ u2_
global c1 c2 c3 mat
% rectangle side lengths

a_=3; b_=2;

% Data for piecewise linear boundary conditions

xbot_=[0;3]; ubot_=[2;2]; nbot=length(xbot_);
xtop_=[0;1.5;3]; utop_=[1;3;-8]; ntop=length(xtop_);
ylft_=[0;1;1.05;2]; ulft_=[2;5;1;1]; nlft=length(ylft_);
yrht_=[0;.5;1.;1.5;2]; urht_=[2;1.9;1.3;.5;-8];
nrht=length(yrht_);

% Create the constants need in function ulbc

c_=setup;

% Adjust boundary data to give zero end conditions

for k=1:nbot, ubot_(k)=ubot_(k)-ulbc(c_,xbot_(k),0); end
for k=1:ntop, utop_(k)=utop_(k)-ulbc(c_,xtop_(k),b_); end
for k=1:nlft, ulft_(k)=ulft_(k)-ulbc(c_,0,ylft_(k)); end
for k=1:nrht, urht_(k)=urht_(k)-ulbc(c_,a_,yrht_(k)); end

% Generate Fourier coefficients for the modified boundary
% conditions

sbot_=sinfft('fbot',a_,9); stop_=sinfft('gtop',a_,9);
slft_=sinfft('plft',b_,9); srht_=sinfft('qrht',b_,9);

% Generate a grid of interior points for solution evaluation

nin=21; ntrms=200;
xin=a_/(nin-1)*(0:nin-1)'; yin=b_/(nin-1)*(0:nin-1)';

% Evaluate the solution having zero corner values

uin=laprec(sbot_,stop_,slft_,srht_,a_,b_,xin,yin,ntrms);

% Correct results for nonzero corner values

uin=uin+ulbc(c_,xin,yin);

% Display surfaces showing function values on the grid

mesh(uin,[10,40])
title('SURFACE PLOT (0,0 IS AT UPPER LEFT CORNER)'); pause
!del srfac.met
meta srfac.met
clg
contour(uin,20)
title('CONTOUR PLOT (0,0 IS AT UPPER LEFT CORNER)')
xlabel('y direction')
ylabel('x direction'); pause
!del contur.met
meta contur.met
