function [h] = helpshow(fname,dlgname)
%HELPSHOW Displays a help dialog box.
%       HANDLE = HELPSHOW(FILENAME,DLGNAME) displays the 
%       message contained the the text file FILENAME  in a dialog 
%       box with title DLGNAME.  
%       If a Help dialog with that name is already on the screen, 
%       it is brought to the front.  Otherwise it is created.
%
%       HANDLE = HELPSHOW(FILENAME) uses default title "Help Dialog"
%
%       See also: HELPDLG, DIALOG
%
%       [No Guarantees.  M. Lubinski]

% Check command call
if nargin<1
  errordlg('Function helpshow requires a filename input argument',...
      'HELPSHOW Error','on');
  return;
  error('');
end
if (~isstr('fname'))
  errordlg('Help file must be a string','HELPSHOW Error','on');
  return;
elseif (exist(fname) ~= 2)
  errordlg(['File ',fname,' cannot be found.'],'HELPSHOW Error','on');
  return;
end
if nargin<2,
   dlgname = 'Help Dialog';
end

% Open & read help file
fid = fopen(fname,'r');
if fid == -1
  errordlg(['Could not open file ',fname,'.'],'HELPSHOW Error','on');
  return;
end
F = fread(fid);
header=['The text in this help message may be longer than what appears' ...
	setstr(10) ...
	'on the screen. Use the arrow keys to scroll through the text.' ...
	setstr(10) ...
	'=======================================================' ...
	setstr(10) setstr(10)];
footer=[setstr(10) '======================================================='...
	 setstr(10) 'END of Help Text' setstr(10)];
F = setstr([header F' footer]);

% Put into dialog
h=helpdlg(F,dlgname);
