function tile_puzzle2(a, b)
% TILE_PUZZLE2(m, n) creates m x n tile puzzle with pushbuttons.
%
% The goal of this game is to arrange m x n numbered squares in the m x n
% field. The squares have to be moved in an increasing order from 1 to 
% m x n. To move the squares just click a square. The clicked square and the
% squares between the clicked one and the space will be moved towards the
% space. Here is an example:
%    -------  click '6' -> ------- *** Done ***
%    |1|2|*|               |1|2|3|
%    -------               -------
%    |4|5|3|               |4|5|6|
%    -------               -------
%    |7|8|6|               |7|8|*|
%    -------               -------
% Bugs: Doesn't work correctly with (m==1)|(n==1), sometimes ;-).

% (c) Daniel Scharstein  1/27/94   (schar@cs.cornell.edu)
% modified by Markus Matern 2/20/96   (Markus.Matern@student.uni-ulm.de)

global SIZE HOLE FINISHED b_m;
 
if nargin == 0,
   a = 3; b = 3;
elseif nargin == 1,
   b = a;
end;

if a > 0, 				% initialization
   clf; figure(gcf);
   SIZE = [a b a b];
   b_m = zeros(b,a);
   l = randperm(a*b-1); 		% create random permutation vector l
   ll = ones(size(l))'*l; 		% and make sure permutation is even
   if rem(sum(sum(triu(ll<ll'))), 2) 	% so that the puzzle is solvable
      l = [l(2) l(1) l(3:length(l))]; 
   end;
   l = [l 0]; FINISHED = []; k = 1;
   for j=b:-1:1;
      for i = 1:a;
	 if l(1) == 0;
	    HOLE = [i j k 0];
	 else
	    p = uicontrol('Style', 'Pushbutton', ...
		  'String', num2str(l(1)), ...
		  'UserData', [i j k l(1)], ...
		  'Units', 'Normalized', ...
		  'Position', [i j .9 .9]./(SIZE+2));
	    set(p, 'Callback', sprintf('tile_puzzle2(0, %.20g)', p));
	    b_m(j,i)=p;
	    FINISHED(l(1)) = (l(1) ~= k);
	 end;
	 l(1) = []; k = k+1;
      end;
   end;
else 					% button b pressed
   pos = get(b, 'UserData');
   h=HOLE;
   dx=pos(1)-h(1);
   if dx==0 ddx=1; else ddx=dx; end;
   dy=pos(2)-h(2);
   if dy==0 ddy=1; else ddy=dy; end;
   if (~dx|~dy)
      for j=h(2):sign(ddy):pos(2)
	 for i=h(1):sign(ddx):pos(1)
	    if dx==0
	       t=j+sign(dy);
	       if t-pos(2)~=sign(dy)
		  p=get(b_m(t,i),'UserData');
		  set(b_m(t,i),'UserData',[HOLE(1:3) p(4)]);
		  set(b_m(t,i), 'Position', [HOLE(1:2) .9 .9]./(SIZE+2));
		  b_m(j,i)=b_m(t,i);
		  b_m(t,i)=0;
		  FINISHED(p(4)) = (HOLE(3) ~= p(4));
		  HOLE(1:3) = p(1:3);
	       end
	    else
	       t=i+sign(dx);
	       if t-pos(1)~=sign(dx)
		  p=get(b_m(j,t),'UserData');
		  set(b_m(j,t),'UserData',[HOLE(1:3) p(4)]);
		  set(b_m(j,t), 'Position', [HOLE(1:2) .9 .9]./(SIZE+2));
		  b_m(j,i)=b_m(j,t);
		  b_m(j,t)=0;
		  FINISHED(p(4)) = (HOLE(3) ~= p(4));
		  HOLE(1:3) = p(1:3);
	       end
	    end
	 end;
      end;
      if sum(FINISHED) == 0
	 uicontrol('Style', 'Pushbutton', ...
	       'String', 'done', ...
	       'Units', 'Normalized', ...
	       'Position', [SIZE(1) 1 .9 .9]./(SIZE+2), ...
	       'Callback', 'clf');
	 HOLE = [0 0 0 0];
      end;
   end;
end;
