function o = findnew(x)
%
% FINDNEW returns the position of non-duplicate data in a vector, eg
%
%         x = [4 1 1 2]; i = findnew(x); 
% returns: i = [1 2 4], 
%
%              and
%
%         x = [4 1 1 2]; x = x(findnew(x)); 
% returns: x = [4 1 2].
%
% In the case of duplication, findnew will return the first occurance. 
% N.B.: Not robust with respect to NaN.
%
% usage:    i = findnew(x), or x = x(findnew(x)).

% Deirdre Byrne, L-DEO 5/12/95 
%
x = x(:); 
i = 1; l = length(x);
d = zeros(l,1);
while i < l
  n = (x(i+1:l) == x(i));  % identify duplicates in subsequent positions
  d(i+1:l) = d(i+1:l) | n; % keep track of dups
  i = i + 1;
end
o = find(~d);
clear d i n x
