% DEFAULT OPTIONS FILE FOR STAPLOT v2
% Deirdre Byrne, L-DEO 12/15/95
% 

% FILE: name of data file to load.  A fully qualifed pathname is preferable.
% Without path information, the data file must be IN THE CURRENT DIRECTORY.
file = '';

% How many stations?
nstn = [];

% How many sections, or cruises are there? Default is one.
sections = [1 nstn];

% what shall we call latitude, longitude, cast (station) number?
% N.B.: station number not to be confused with 'sta', the list of
% "active" stations (columns) ready to be plotted or otherwise 
% manipulated.  These are variables of type 1. 

lat_var = 'Lat';
lon_var = 'Lon';
sta_var = 'Sta_no';

% What are we going to call pressure and depth? These are variables
% of type 2 or type 3.

pr_var = 'PR';
de_var = 'DE';

% how about potential temperature, in situ temperature, and salinity?
% these are variables of type 3.
pt_var = 'PT';
te_var = 'TE';
sa_var = 'SA';
	 
% Should we reverse pressure and depth axes (ie treat them as 
% positive, increasing downwards)?  Boolean variables [0/1]
pr_reverse = 1;
de_reverse = 1;

% Shall we write the station numbers on cum. dist plots? Boolean.
sta_write = 1;

% PROPLIST: The default list of defined data properties recognized 
% and usable in Staplot.  Copy this file and customize as you wish,
% or use 'addprop' and 'saveopts' in staplot to create a customized
% version.

proplist = str2mat('Dist',lat_var,lon_var,sta_var,pr_var,pt_var, ...
    sa_var,de_var,te_var);

% TYPEVAR: variable type of proplist variables.  Options: one value per 
% station (1), a vector of unspecified length (2),  or a matrix with one 
% column per station (3)?
typevar = [1 1 1 1 3 3 3 3 3];

% MAPCOLORS: colors for coastline and isobaths 1000m to 6000m depth
% (in that order). May be a text matrix or numeric r-g-b (7 required)
%mapcolors = str2mat('w','c','g','m','b','r','y');
mapcolors = [1 1 1; 1 1 0; 1 0.3 0; 0.6 0 0; 1 0 1; 0.5 0 0.8; 0 0 1];

% PROJ: map projection to use.  Valid are 'rec' (rectilinear),
% 'north' (north polar) and 'south' (south polar)
proj = 'rec';

% ISOPYCNALS: which isopycnals to plot at the 'Sigma' command
% row 1 is for Sigma_0, row 2 for Sigma_1, to Sigma_4. Every
% row must have the same number of entries, but NaNs are acceptable.
isopycnals = [24.4:0.6:28.6 NaN; % Sigma_0
             28.6:0.6:32.8 NaN; % Sigma_1
             32.8:0.6:37.6; % Sigma_2
             37:0.6:41.8; % Sigma_3
	     41.2:0.6:46]; % Sigma_4

% NUMBER of CONTOUR lines.  Sets number of levels for 'contfill'.
contno = 10;

% PLOTCOLORS: an RGB row matrix.  Valid values are between 0 and 1.
% Maximum number of colors allowable is 64.

plotcolors = [1 0 0;  0.15 0.73 0.15; 0 0 1; % red green blue
              1 1 0;     1 0 1;       0 1 1; % yellow magenta cyan
        0.75 0.45 0; 0.8 0 0.5;     0.6 1 0; % brown pink grass
        0.55 0.55 1;   1 0.7 0;   0.3 0.5 0; % sky orange olive
          0.6 0 0.6;     1 1 1; 0.6 0.6 0.6; % purple white grey
             0 0 0];                       % black
	 
% COLORNAMES: The names your colors will be called on the selection menu.
colornames = str2mat(str2mat('Red    ','Green','Blue   ','Yellow ','Magenta','Cyan   ','Brown    ','Pink   ','Grass  '),str2mat('Sky  ','Orange ','Olive  ','Purple ','White  ','Grey   ','Black  '));

% PLOTSTYLE: the order of (extremely limited) Matlab plot symbols.
% Why anyone would want to change this I cannot fathom.
plotstyle = str2mat('+','o','x','*','-');

% MARKSIZE: how big the symbols will appear on all your staplot plots
marksize = 7;

% STATION_STYLE: the default color and style for plotting stations.
% Digit in tens column is color, digit in ones column is style.
station_style = 12*ones(1,nstn);
