% DEFAULT OPTIONS FILE FOR STAPLOT v2
% Deirdre Byrne, L-DEO 12/15/95
% 

% FILE: name of data file to load
% THIS SHOULD BE A FULLY DEFINED PATHNAME AFTER INSTALLATION
file = 'samp2dat';

% How many stations?
nstn = 10;

% How many sections, or cruises are there? 2 sections here.
sections = [1 7;
    8 10];

% What are we going to call pressure and depth?
pr_var = 'PR';
de_var = '';

% how about potential temperature, in situ temperature, and salinity?
pt_var = '';
te_var = 'TE';
sa_var = 'SA';
	 
% Should we reverse pressure and depth axes (ie treat them as 
% positive, increasing downwards)?  Boolean variables [0/1]
pr_reverse = 1;
de_reverse = 1;

% what shall we call latitude, longitude, cast (station) number?
% N.B.: station number not to be confused with 'sta', the list of
% "active" stations ready to be plotted or otherwise manipulated.
lat_var = 'Lat';
lon_var = 'Lon';
sta_var = 'Sta_no';

% Shall we write the station numbers on cum. dist plots? Boolean.
sta_write = 1;

% PROPLIST: The all-important list of defined data properties recognized 
% and usable in Staplot.  The variables named by these tags (e.g. lon_var),
% must exist in the main workspace to be used successfully
% here. Choose one of the following two lists, or CUSTOMIZE by using "addprop"
% and saving, or by copying this file, editing it and restarting 'staplot'.

%proplist = str2mat(lat_var,lon_var,sta_var,de_var,te_var,sa_var);
proplist = str2mat(str2mat(lat_var,lon_var,sta_var,pr_var,te_var, ...
    sa_var,'R'), str2mat('C10_isotherm','maxpr','R1','T1','S1'));

% TYPEVAR: variable type of proplist variables.  Options: one value per 
% station (1), a vector of unspecified length (2),  or a matrix with one 
% column per station (3)?
typevar = [1 1 1 3 3 3 3 1 1 1 1 1];

% MAPCOLORS: colors for coastline and isobaths 1000m to 6000m depth
% (in that order). May be a text matrix or numeric r-g-b (7 required)
%mapcolors = str2mat('w','c','g','m','b','r','y');
mapcolors = [1 1 1; 1 1 0; 1 0.3 0; 0.6 0 0; 1 0 1; 0.5 0 0.8; 0 0 1];

% PROJ: map projection to use.  Valid are 'rec' (rectilinear), 'north' 
% (north polar) and 'south' (south polar). PROJLIM: equatormost latitude
% for polar projections, in degrees.  Not used for rectilinear projection.
proj = 'north'; projlim = 20;

% ISOPYCNALS: which isopycnals to plot at the 'Sigma' command
% row 1 is for Sigma_0, row 2 for Sigma_1, to Sigma_4. NaNs
% are acceptable.
isopycnals = [24.4:0.6:28.6 NaN; % Sigma_0
             28.6:0.6:32.8 NaN; % Sigma_1
             32.8:0.6:37.6; % Sigma_2
             37:0.6:41.8; % Sigma_3
	     41.2:0.6:46]; % Sigma_4

% NUMBER of CONTOUR lines.  Sets number of levels for 'contfill'.
contno = 10;

% PLOTCOLORS: an RGB row matrix.  Valid values are between 0 and 1.
% Maximum number of colors allowable is 64.

plotcolors = [1 0 0;  0.15 0.73 0.15; 0 0 1; % red green blue
              1 1 0;     1 0 1;       0 1 1; % yellow magenta cyan
        0.75 0.45 0; 0.8 0 0.5;     0.6 1 0; % brown pink grass
        0.55 0.55 1;   1 0.7 0;   0.3 0.5 0; % sky orange olive
          0.6 0 0.6;     1 1 1; 0.6 0.6 0.6; % purple white grey
             0 0 0];                       % black
	 
% COLORNAMES: The names your colors will be called on the selection menu.
colornames = str2mat(str2mat('Red    ','Green','Blue   ','Yellow ','Magenta','Cyan   ','Brown    ','Pink   ','Grass  '),str2mat('Sky  ','Orange ','Olive  ','Purple ','White  ','Grey   ','Black  '));

% PLOTSTYLE: the order of (extremely limited) Matlab plot symbols.
% Why anyone would want to change this I cannot fathom.
plotstyle = str2mat('+','o','x','*','-');

% MARKSIZE: how big the symbols will appear on all your staplot plots
marksize = 7;

% STATION_STYLE: the default color and style for plotting stations.
% Value of tens+hundreds columns is color, value of ones column is style.
station_style = [];
station_style = [station_style 113 123 133  53 63 73  83 93 103 13];
