% Filename: axesmenu.m
% Rev.Date: 8/12/95
% Class: 	function
%
% USAGE: type "axesmenu" to put this amazing menu 
% 		 on the current figure window. Allows the
%        detailed manipulation of axes properties
%        as well as copy/paste, alignment/spacing,
%        and movability of axes with the mouse.
%        Features applied only to axes in the current
%        window being marked with the object property
%        'Selected' being 'on' (see addHamlet.m)
%		
%        If you get a message about being able to copy 
%        only one axes at a time, deselect all axes in
%        the figure, then specifically reselect only 
%        one of them.
%
% Subroutines required:
%   moveobj
%   cpaxes (which calls cplines, cpsurfs, & cplabels)
%   alignme 
%   changeme

% Written By: Kevin G. Kohrt, kkohrt@engr.iupui.edu
% Written On: 3/31/95 - 7/10/95
%			  (* parts pulled from addHamlet, first written 8/11/94)
%
% Permission granted to include AXESMENU or some variation of it
% with any other script(s), as long no part of this comment section 
% is deleted or changed (excluding the Rev.Date, Filename, & Class). -KGK
%
% Adapted By: 
% Adapted On: 
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

	function axesmenu
	%
	% Enable  line, axes and text selection if req'd
	% (WBDF ==> "Window Button Down Fcn")
	% ------------------------------------
	  if strcmp( get(gcf,'WindowButtonDownFcn'), '' )
	 	WBDF = [	'if exist(''ClickPoint'');',...
					'DoubleClick = ',...
						'( ClickPoint == get( gcf,''CurrentPoint'') );',...
				'end;',...
				'temp = get( gco,''Type'');',...
				'if DoubleClick;',...
					'if ( strcmp( temp,''line'') );',...
						'set( gco,''Color'', abs(1-get(gco,''Color'')) ),',...
						'if strcmp( get( gco,''Selected''),''on''); ',...
							 'set( gco,''Selected'',''off'');',...
						'else,'...
							 'set( gco,''Selected'',''on'');',...
						'end;',...
					'elseif(  ( strcmp( temp,''text'') ) ',...
							'| ( strcmp( temp,''axes'') ) );',...
						'if strcmp( get( gco,''Selected''),''on'');',...
							'set( gco,''Selected'',''off'');',...
						'else;',...
							'set( gco,''Selected'',''on'');',...
						'end;',...
					'end;',...
				'end; clear temp;',...
				'ClickPoint = get( gcf,''CurrentPoint'');'];
		set(gcf,'WindowButtonDownFcn', WBDF);
	  end

	% ========================================================================
	% MENU: 'Axes ': Adjust Axes Properties
	% ========================================================================
	%
	  AxesMenu = uimenu( gcf, 'Label', 'Axes ' );
	%
	% SUBMENU: Axes Selection
	% ----------------------------------------------------------------
	  axselmenu = uimenu( AxesMenu,  'Label',	'Select...');

	  uimenu( axselmenu, ...
			  'Label', 		'All',...
			  'callback', 	[...
							'set( findobj( gcf,''type'',''axes''),',...
							' ''Select'',''on'');',...
							'ans = findobj(gcf,''UserData'',''dateaxes'');',...
							'if ~isempty(ans);set(ans,''Sel'',''off'');end;'] );
	  uimenu( axselmenu	,...
			  'Label', 		'None (deselect)',...
			  'callback', 	'changeme(''axes'',''Select'',''off'');' );	
	%
	% SUBMENU: Grid Line Style 
	% ----------------------------------------------------------------
	  GridStyle = uimenu( AxesMenu,...
						  'Separator',	'on',...
						  'Label',		'Grid Lines');
	
	  GridStyleData = [ '- '; '--'; ': '; '-.' ];
	  GridStyleText = [ ' line   ';'dash    ';' dots   ';'dash-dot' ];
	  for idx = 1 : size( GridStyleData, 1 )
		AxType = GridStyleData( idx, GridStyleData( idx, : ) ~= ' ' );
	  	uimenu( GridStyle			,...
				'Label', 		[ AxType, ' ', GridStyleText(idx,:) ],...
				'UserData', 	[ AxType ],...
				'ForeGround',	[ strcmp( AxType, ':' ), 0, 0 ],...
				'BackGround', 	[ 0.7 0.7 0.7 ],... 
	       		'Callback',		[ 'changeme(''axes'',''GridLineStyle'', ',...
								  'get(gcmenu,''UserData'') );']);
	  end;
	  uimenu( GridStyle			,...
			  	'Label',		'Grid On',...
			  	'Separator',	'on' ,...
		      	'Callback',		[ ...
								'changeme(''axes'',''Xgrid'',''on'');',...
								'changeme(''axes'',''Ygrid'',''on'');',...
								'changeme(''axes'',''Zgrid'',''on'');' ] );
	  uimenu( GridStyle			,...
				'Label',		'Grid Off',...
		      	'Callback',		[ ...
								'changeme(''axes'',''Xgrid'',''off'');',...
								'changeme(''axes'',''Ygrid'',''off'');',...
								'changeme(''axes'',''Zgrid'',''off'');' ]);
	%
	% SUBMENU: Box Line Thickness:	
	% ----------------------------------------------------------------
	  Lnthick = uimenu( AxesMenu, 'Label', 		'Box Line Width' );

	  default = get( 0, 'DefaultAxesLineWidth' );
	  for idx = [ 0.5, 1, 2, 3, 4 ]
	   	uimenu(  Lnthick		,... 
				'Label',		num2str(idx),...
				'ForeGround',	[ idx == default, 0, 0 ],...
				'BackGround', 	[ 0.7 0.7 0.7 ],... 
	       		'Callback',		[ 'changeme(''axes'',''LineWidth'', ',...
								  'str2num( get(gcmenu,''Label'') ) ); ' ] );
	  end;
	  uimenu( 	Lnthick			,...
			  	'Label',		'Specify...',...
			  	'Separator',	'on' ,...
		      	'Callback',		[...
						'value = input(''Enter desired line width: '');',...
				  		'changeme(''axes'',''LineWidth'', value );' ] );

	  uimenu( 	Lnthick			,...
			  	'Label',		'Box On',...
				'Separator',	'on',...
		      	'Callback',		'changeme(''axes'',''Box'',''on'');' );
	  uimenu( 	Lnthick			,...
			  	'Label',		'Box Off',...
		      	'Callback',		'changeme(''axes'',''Box'',''off'');' );
	%
	% SUBMENU: Axes Font
	% ----------------------------------------------------------------
	  AFontMenu = uimenu( AxesMenu,  'Label',		'Label Font',...
									 'Separator',	'on' );
	
	  fontlabel = str2mat( 'Courier', 'Helvetica', 'Lucida-Bright',...
							'Palatino', 'Times', 'Symbol' );
	  default = get( 0, 'DefaultAxesFontName' );
	  for idx = 1 : size( fontlabel, 1 )
		uimenu( AFontMenu,...
				'Label',		fontlabel( idx, fontlabel(idx,:) ~= ' ' ),...
				'ForeGround',	[ strcmp( fontlabel(idx,2:5), default(2:5) ),...
								  0, 0 ],...
				'BackGround', 	[ 0.7 0.7 0.7 ],... 
					'Callback', [...
						 			'changeme(''axes'',''FontName'',',...
								  	'get( gcmenu,''Label'') );' ] );
	  end;
	%
	% SUBMENU: Font Size
	% ----------------------------------------------------------------
	  tsizemenu = uimenu( AxesMenu,  'Label',	'Label Size');
	
	  default = get( 0, 'DefaultAxesFontSize' );
	  for idx = [ 6 8 10 12 14 ]
	     uimenu( tsizemenu,...
			 	'Label',		num2str(idx),...
				'ForeGround',	[ idx == default, 0, 0 ],...
				'BackGround', 	[ 0.7 0.7 0.7 ],... 
				'Callback', 	[ ' changeme(''axes'',''FontSize'',',...
						 		  ' str2num( get( gcmenu,''Label'') ) );' ] );
	  end;
	  uimenu( tsizemenu,...
			  'Label',		'Specify...',...
			  'Separator',	'on' ,...
		      'Callback',	[...
							' value = input(''Enter desired font size: '');',...
							' changeme(''axes'',''FontSize'', value );' ] );
	%
	% SUBMENU: Font Style
	% ----------------------------------------------------------------
	  tstylemenu = uimenu( AxesMenu,  'Label',	'Label Style');
	
	  stylable = str2mat('light', 'normal', 'light', 'bold' );
	  default = get( 0, 'DefaultAxesFontWeight' );
	  for idx = 1 : size( stylable, 1 )
		styletext = stylable( idx, stylable( idx, : ) ~= ' ' );
		uimenu( tstylemenu		,...
				'Label',		styletext,...
				'ForeGround',	[ strcmp( styletext, default ), 0, 0 ],...
				'BackGround', 	[ 0.7 0.7 0.7 ],... 
				'Callback', 	[ ' changeme(''axes'',''FontWeight'', ',...
								  ' get( gcmenu,''Label'') );' ] );
	  end;

	  anglelabel = str2mat('italic', 'oblique' );
	  for idx = 1 : size( anglelabel, 1 )
		uimenu( tstylemenu	,...
				'Label',	anglelabel( idx, anglelabel( idx, : ) ~= ' ' ),...
		    	'Callback',	[ ' value = ( get( gcmenu,''Label'') ); ',...
							  ' changeme(''axes'',''FontAngle'', value );' ] );
	  end;
	% ----------------------------------------------------------------
	% ----------------------------------------------------------------
	% AXES SUBMENUS: 
	% ----------------------------------------------------------------
	  AX = uimenu( AxesMenu,  'Label', 'Axes', 'Separator', 'on'  );

	%
	% SUBMENU: Xaxis 
	% ----------------------------------------------------------------
	  Xmenu = uimenu( AX,  'Label', 'Xaxis', 'Separator', 'on'  );

	  	XSmenu = uimenu(  Xmenu, 'Label', 'Show' );
		uimenu( XSmenu			,...
				'Label',		'Hide',...
		    	'Callback',		' changeme(''axes'',''XTickLabels'', [] );' );
	  	uimenu( XSmenu			,...
			  	'Label',		'Show',...
		      	'Callback',		[ ...
					'changeme(''axes'',''XTickLabelMode'',''auto'');' ] );

	  	XLmenu = uimenu(  Xmenu, 'Label', 'Limits' );
	  	uimenu( XLmenu			,...
			  	'Label',		'Specify...',...
		      	'Callback',		[...
					' value = input(''Enter desired Limit(s): '');',...
					' if length( value ) == 1; value = [ 0 value ]; end;',... 
					' changeme(''axes'',''XLim'', value );' ] );	
	  	uimenu( XLmenu			,...
			  	'Label',		'Auto',...
		      	'Callback',		'changeme(''axes'',''XLimMode'',''auto'');' );	

	  	XGmenu = uimenu(  Xmenu, 'Label', 'Grid' );
	  	uimenu( XGmenu			,...
			  	'Label',		'Grid On',...
		      	'Callback',		' changeme(''axes'',''Xgrid'',''on'');' );
		uimenu( XGmenu			,...
				'Label',		'Grid Off',...
		    	'Callback',		' changeme(''axes'',''Xgrid'',''off'');' );
	%
	% SUBMENU: Yaxis 
	% ----------------------------------------------------------------
	  Ymenu = uimenu( AX,  'Label',  'Yaxis' );

	  	YSmenu = uimenu(  Ymenu, 'Label', 'Show' );
		uimenu( YSmenu			,...
				'Label',		'Hide',...
		    	'Callback',		' changeme(''axes'',''YTickLabels'', [] );' );
	  	uimenu( YSmenu			,...
			  	'Label',		'Show',...
		      	'Callback',		[ ...
					'changeme(''axes'',''YTickLabelMode'',''auto'');' ] );

	  	YLmenu = uimenu(  Ymenu, 'Label', 'Limits' );
	  	uimenu( YLmenu			,...
			  	'Label',		'Specify...',...
		      	'Callback',		[...
					' value = input(''Enter desired Limit(s): '');',...
					' if length( value ) == 1; value = [ 0 value ]; end;',... 
					' changeme(''axes'',''YLim'', value );' ] );	
	  	uimenu( YLmenu			,...
			  	'Label',		'Auto',...
		      	'Callback',		'changeme(''axes'',''YLimMode'',''auto'');' );	

	  	YGmenu = uimenu(  Ymenu, 'Label', 'Grid' );
	  	uimenu( YGmenu			,...
			  	'Label',		'Grid On',...
		      	'Callback',		' changeme(''axes'',''Ygrid'',''on'');' );
		uimenu( YGmenu			,...
				'Label',		'Grid Off',...
		    	'Callback',		' changeme(''axes'',''Ygrid'',''off'');' );
	%
	% SUBMENU: Zaxis 
	% ----------------------------------------------------------------
	  Zmenu = uimenu( AX,  'Label',  'Zaxis' );

	  	ZSmenu = uimenu(  Zmenu, 'Label', 'Show' );
		uimenu( ZSmenu			,...
				'Label',		'Hide',...
		    	'Callback',		' changeme(''axes'',''ZTickLabels'', [] );' );
	  	uimenu( ZSmenu			,...
			  	'Label',		'Show',...
		      	'Callback',		[ ...
					'changeme(''axes'',''ZTickLabelMode'',''auto'');' ] );

	  	ZLmenu = uimenu(  Zmenu, 'Label', 'Limits' );
	  	uimenu( ZLmenu			,...
			  	'Label',		'Specify...',...
		      	'Callback',		[...
					' value = input(''Enter desired Limit(s): '');',...
					' if length( value ) == 1; value = [ 0 value ]; end;',... 
					' changeme(''axes'',''ZLim'', value );' ] );	
	  	uimenu( ZLmenu			,...
			  	'Label',		'Auto',...
		      	'Callback',		'changeme(''axes'',''ZLimMode'',''auto'');' );	

	  	ZGmenu = uimenu(  Zmenu, 'Label', 'Grid' );
	  	uimenu( ZGmenu			,...
			  	'Label',		'Grid On',...
		      	'Callback',		' changeme(''axes'',''Zgrid'',''on'');' );
		uimenu( ZGmenu			,...
				'Label',		'Grid Off',...
		    	'Callback',		' changeme(''axes'',''Zgrid'',''off'');' );

	% ----------------------------------------------------------------
	% ----------------------------------------------------------------
	% SPECIAL SUBMENUS
	% ----------------------------------------------------------------
	  SP = uimenu(   AxesMenu		,...
			 		'Label',		'Special...',...
			 		'Separator',	'on' );
	%
	% SUBSUBMENU: Copy/Paste Selection
	% ----------------------------------------------------------------
	  axselmenu = uimenu( SP, ...
				  'Label',		'Copy', ...
				  'Separator',	'on',...
				  'Callback', 	[...
 				    'axh = findobj( findobj( gca,''Type'',''axes''),',... 
					' ''Select'',''on'');',...
					'if length( axh ) ~= 1;',...
					'  disp(''Error: Can copy only one axis at a time.'');',...
					'  disp(''Please deselect all & reselect only one.'');',...
				   	'else; cpaxes(''copy'',axh); end;'] );
	  axselmenu = uimenu( SP,...
				  'Label',		'Paste', ...
				  'Callback', 	[...
 				    'axh = findobj( findobj( gca,''Type'',''axes''),',... 
					' ''Select'',''on'');',...
					'if length(axh) ~= 1;',...
					'  disp(''Error: Can paste only one axis at a time'');',...
				   	'else; cpaxes(''paste'', axh ); end;'] );
	%
	% SUBSUBMENU: Move/Park Axes
	% ----------------------------------------------------------------
	 uimenu( SP		,...
			 'Label',		'Move',...
			 'Separator',	'on' ,...
		     'Callback',	'changeme(''axes'',''buttondown'',''moveobj'');' );
	 uimenu( SP		,...
			 'Label',		'Park',...
		     'Callback',	'changeme(''axes'',''buttondown'','''');' );
	%
	% SUBSUBMENU: Move/Park Axes
	% ----------------------------------------------------------------
	 uimenu( SP		,...
			 'Label',		'Align',...
			 'Separator',	'on' ,...
		     'Callback',	'alignme(0)' );
	 uimenu( SP		,...
			 'Label',		'Space',...
		     'Callback',	'alignme(1)' );
	% ----------------------------------------------------------------
	% ----------------------------------------------------------------
	%
	% SUBMENU: Delete Axes
	% ----------------------------------------------------------------
	 uimenu( AxesMenu		,...
			 'Label',		'Delete',...
			 'Separator',	'on' ,...
		     'Callback',	[...
					' delete( findobj( findobj( gcf,''Type'',''axes''),',...
					' 			''flat'',''Select'',''on'') );' ] );


%
% 3/11/95	Last known revisions
% 7/10/95	Working copy/paste axes functions added
% 			move/park axes added
%			Align/Space axes added
% 08/12/95  Object selection capability automatically added to window 
%			if no other WindowButtonDownFcn currently exists
