% Filename: changeme.m
% Rev.Date: 3/31/95
% Class: 	function
%
% USAGE: changeme( type, property, value )    {all strings}
%        sets the property "property" of all objects in the 
%        current figure window having type "type" and that 
%        have the property 'selected', 'on' already to the
%        value "value". 

% Written By: Kevin G. Kohrt
% Written On: 3/30/95 
%
% Adapted By: 
% Adapted On:  
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

	function changeme( type, property, value )

	% A quick check to be sure enough inputs are entered
	%-------------------------------------------------------------------------
	  if nargin < 3
			error('type, property, and value must be entered')
	  end;

	% A special case must be made for empty matrices
	%-------------------------------------------------------------------------
  	  if isempty( value )
		targets = findobj( findobj( gcf,'Type',type ),'flat','Selected','on' );
		set( targets, property, value );
		return
  	  end

	% A quick check to be sure inputs are correct
	%-------------------------------------------------------------------------
	  pnum = size( property, 1 );
	  if pnum ~= size( value, 1 )
			error('Number of properties must equal number of values')
	  end;

	% Initialize internal variables
	%-------------------------------------------------------------------------
	  targets = findobj( findobj( gcf, 'Type', type ),...
											'flat', 'Selected', 'on' );
	  Text = strcmp( type, 'text' );
	  Line = strcmp( type, 'line' );

	% A loop for multiple input properties
	%-------------------------------------------------------------------------
		for idx = 1 : pnum

		% A special case for text being set to "normal"
		%---------------------------------------------------------------------
		if strcmp( value( idx, : ), 'normal' )
			set( targets,  	'FontAngle', 'normal',...
							'FontWeight', 'normal' );

		% A special case for Lines being selected (it normally doesn't show)
		%---------------------------------------------------------------------
		elseif Line & strcmp( lower( property( idx, : ) ), 'selected' )
			for idx2 = targets'
				set( idx2, 	property( idx, : ), value( idx, : ),...
					 'color', abs( get( idx2, 'color' ) - 1 ) );
			end

		% All other cases
		%---------------------------------------------------------------------
		else
			set( targets, property( idx, : ), value( idx, : ) )
	
		end
	end

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%% END OF PROGRAM %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
