% Filename: cpaxes.m
% Rev.Date: 7/10/95
% Class: 	function
%
% USAGE: cpaxes( command, axes );
%        command = 'copy' to copy axes ( default )
%                  'paste' to paste axes
%        axes = axes to copy/paste (default: current axes)
%
%        CPAXES copies or pastes surface objects for an 
%        axes to/from a special .mat file.
%
% Subroutines required:
%   cplines
%   cpsurfs 
%   cplabels 

% Written By: Kevin G. Kohrt, kkohrt@engr.iupui.edu
% Written On: 7/6/95 - 7/10/95
%
% Permission granted to include CPAXES or some variation of it
% with any other script(s), as long no part of this comment section 
% is deleted or changed (excluding the Rev.Date, Filename, & Class). -KGK
%
% Adapted By: 
% Adapted On:  
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

	function cpaxes( cmd, axh )
	
  %---------------------------------------------------------------------------%
  % Verify input arguments
  %---------------------------------------------------------------------------%
	if nargin < 2; axh = gca; end	% default: use current axes
	if nargin < 1; cmd = 'c'; end	% default: copy axes
  %---------------------------------------------------------------------------%
  % Initialize parameters used for both copy and paste commands
  % NOTE: Some properties have been combined into matrices to reduce the total
  % the number of variable names saved (the SAVE command has a limit of ~40).
  % ALSO: An effort has been made to store limits and values (such as YLim)
  % _before_ storing the associated mode (i.e. YLimMode) so that the mode is
  % applied _after_ the values are applied. This prevents having all 'manual'
  % modes, which will overload the Save As M-File command. { Print -dmfile
  % saves parameters marked 'manual', but not those marked 'auto'. If all
  % parameters are manual, it crashes when rebuilding the figure window because 
  % the set( 'prop', 'param', ... ) command also has a limit on how many
  % properties may be set at once. }
  %---------------------------------------------------------------------------%
	pointer = get( get( axh, 'Parent' ), 'Pointer' );
	set( get( axh, 'Parent' ), 'Pointer', 'watch' );
	%-------------------  
	% Generic properties
	%-------------------  
	props = [	'Aspect'	
				'Box   '
				'CLim  '
				'Color '
				'ColorO'
				'FontNa'
				'FontSi'
				'GridLi'
				'LineSt'
				'LineWi'
				'Positi'
				'Select'
				'Tag   '
				'TickLe'
				'Units '
				'View  '
				'Xform '
				'Button' 
				'Clippi'
				'Interr'
				'UserDa'
				'Visibl' ];
	%-------------------------------------------------  
	% Properties that can be specified by one variable
	%-------------------------------------------------  
	prop1 = [	'DrawMode   '
				'NextPlot   '
				'FontAngle  '
				'FontWeight '
				'TickDir    '
				'CLimMode   ' ];
	%----------------------------------------------------
	% Properties that have similar names for X,Y,& Z axes
	%----------------------------------------------------
	for axdir = [ 'X', 'Y', 'Z' ]
		props = [ 	axdir,'Grid '
					axdir,'Scale'
					axdir,'Tick '
					props ];
  		prop1 = [ 	prop1
					axdir,'Dir       '
					axdir,'LimMode   '
					axdir,'TickMode  '
					axdir,'TickLabelM' ];

	end
	prop1sz = size( prop1, 1 );
	prop1list = [];
  %===========================================================================%
  % START  CMD#1 : COPY AXES FROM A FIGURE
  %---------------------------------------------------------------------------%
    if strcmp( lower( cmd(1) ), 'c' )
  %---------------------------------------------------------------------------%
  % Start building the string used to save all data in file 'tempaxes.mat'
  %---------------------------------------------------------------------------%
	savetxt = 'save tempaxes';
  	%-------------------------------------------------------------------------%
	% Loop to store all object properties in a uniquely named variable
  	%-------------------------------------------------------------------------%
	  for idx = 1 : length( props )
	  	%---------------------------------------------------------------------%
		% Create variable name...
	  	%---------------------------------------------------------------------%
		  property = props( idx, : );
		  property = property( property ~= ' ' );
		  varname = [ property '_prop' ];
	  	%---------------------------------------------------------------------%
		% assign it the appropriate object property value(s)...
	  	%---------------------------------------------------------------------%
		  eval( [ varname ' = get( axh, ''' property ''' );' ] );
	  	%---------------------------------------------------------------------%
		% add it to the list of variables to be saved
	  	%---------------------------------------------------------------------%
		  savetxt = [ savetxt, ' ', varname ];
	  	%---------------------------------------------------------------------%
		  if idx <= prop1sz 
		  	%-----------------------------------------------------------------%
			% Create the property name...
		  	%-----------------------------------------------------------------%
		  	  property = prop1( idx, : );
			  property = property( property ~= ' ' );
		  	%-----------------------------------------------------------------%
			% Get the object property string...
		  	%-----------------------------------------------------------------%
			  eval( [ 'temp = get( axh, ''' property ''' );' ] );
		  	%-----------------------------------------------------------------%
			% Append the first letter to the one-letter properties list
		  	%-----------------------------------------------------------------%
			  prop1list = [ prop1list, temp( 1 ) ];
		  	%-----------------------------------------------------------------%
		end % one letter properties loop
	  end % properties loop
  %	Record properties that are too big to go in the props matrix
	XTLabels = get( axh, 'XTickLabels' );
	YTLabels = get( axh, 'YTickLabels' );
	ZTLabels = get( axh, 'ZTickLabels' );
  %	Record properties that can be grouped into one matrix in order
  % to avoid maxing out the number of properties in the save command
	Axdat 	 = zeros( 7, 3 );
	Axdat( 1,  :  ) = get( axh, 'Xcolor' );
	Axdat( 2,  :  ) = get( axh, 'Ycolor' );
	Axdat( 3,  :  ) = get( axh, 'Zcolor' );
	Axdat( 4, 1:2 ) = get( axh, 'XLim' );
	Axdat( 5, 1:2 ) = get( axh, 'YLim' );
	Axdat( 6, 1:2 ) = get( axh, 'ZLim' );

  %---------------------------------------------------------------------------%
  % Save the data into a file 
  %---------------------------------------------------------------------------%
	eval( [ savetxt, ' XTLabels YTLabels ZTLabels Axdat prop1list' ])
	cplabels( cmd, axh )
	cpline2( cmd, axh )
	cpsurfs( cmd, axh )
	cptxts( cmd, axh )
	disp( 'Axes Copied ')
  %---------------------------------------------------------------------------%
  % END OF CMD#1 : COPY AXES FROM A FIGURE                                  
  %===========================================================================%
  % START  CMD#2 : PASTE AXES TO A FIGURE
  %---------------------------------------------------------------------------%
    elseif strcmp( lower( cmd(1) ), 'p' )
	axes( axh ); cla
	pos(1, :) = get( axh, 'Position' );
	uniax     = get( axh, 'Units' );
	
  %---------------------------------------------------------------------------%
  % Load axes data if the data file exists
  %---------------------------------------------------------------------------%
	if exist( 'tempaxes.mat' ) == 2
		load tempaxes
	else
		disp( 'Error: Cannot paste axes because the' )
		disp( 'file ''tempaxes.mat'' is not in the search path' )
		set( get( axh, 'Parent' ), 'Pointer', pointer );
		return
	end
  	%-------------------------------------------------------------------------%
    % Set properties that were grouped into special matrices 
  	%-------------------------------------------------------------------------%
	  set( axh, 'Xcolor', Axdat( 1,  :  ) );
	  set( axh, 'Ycolor', Axdat( 2,  :  ) );
	  set( axh, 'Zcolor', Axdat( 3,  :  ) );
	  set( axh, 'XLim', Axdat( 4, 1:2 ) );
	  set( axh, 'YLim', Axdat( 5, 1:2 ) );
	  set( axh, 'ZLim', Axdat( 6, 1:2 ) );
	  set( axh, 'XTickLabels', XTLabels );
	  set( axh, 'YTickLabels', YTLabels );
	  set( axh, 'ZTickLabels', ZTLabels );
  	%-------------------------------------------------------------------------%
	% Loop to set all remaining object properties of the axes 
  	%-------------------------------------------------------------------------%
	  for idx = 1 : length( props )
	  	%---------------------------------------------------------------------%
		% Create variable name...
	  	%---------------------------------------------------------------------%
		  property = props( idx, : );
		  property = property( property ~= ' ' );
		  varname = [ property '_prop' ];
	  	%---------------------------------------------------------------------%
		% assign it's value(s) to the appropriate object property
	  	%---------------------------------------------------------------------%
		  eval( [ 'set( axh, ''' property ''', ' varname ' )' ] );
	  	%---------------------------------------------------------------------%
		  if idx <= prop1sz 
		  	%-----------------------------------------------------------------%
			% Create the property name...
		  	%-----------------------------------------------------------------%
		  	  property = prop1( idx, : );
			  property = property( property ~= ' ' );
		  	%-----------------------------------------------------------------%
			% Set the object property 
		  	%-----------------------------------------------------------------%
			  eval( [ 'set( axh, ''' property ''', prop1list( idx ) );' ] );
		  	%-----------------------------------------------------------------%
		end % one letter properties loop
	  end % properties loop
	cptxts( 'paste', axh )
	cpline2( 'paste', axh )
	cpsurfs( 'paste', axh )

	set( axh, 'Units', uniax, 'Position', pos(1, :) )
	[ Title, XLab, YLab, ZLab ] = cplabels( 'paste', axh );
	set( axh, 'Title',  Title )
	set( axh, 'XLabel', XLab )
	set( axh, 'YLabel', YLab )
	set( axh, 'ZLabel', ZLab )
	changeme( 'axes', 'selected', 'off' )
	disp( 'Paste complete')
  %---------------------------------------------------------------------------%
  % END OF CMD#2 : PASTE AXES TO A FIGURE                                  
  %===========================================================================%

	else
		disp(' Error in cpaxes: bad command. ''copy'',or ''paste'' expected.')
	end

	set( get( axh, 'Parent' ), 'Pointer', pointer );




%	AspectRatio = [NaN NaN]					%%%   A MESH PLOT   %%%
%	Box = off
%	CLim = [0.00769819 0.991037]
%	CLimMode = auto
%	Color = none
%	CurrentPoint = [ (2 by 3) ]
%	ColorOrder = [ (6 by 3) ]
%	DrawMode = normal
%	FontAngle = normal
%	FontName = times
%	FontSize = [12]
%	FontWeight = normal
%	GridLineStyle = :
%	LineStyleOrder = -
%	LineWidth = [0.5]
%	NextPlot = replace
%	Position = [0.13 0.11 0.775 0.815]
%	TickLength = [0.01 0.025]
%	TickDir = out
%	Title = [72.0001]
%	Units = normalized
%	View = [322.5 30]
%	XColor = [1 1 1]
%	XDir = normal
%	Xform = [ (4 by 4) ]
%	XGrid = off
%	XLabel = [69.0001]
%	XLim = [0 8]
%	XLimMode = auto
%	XScale = linear
%	XTick = [0 2 4 6 8]
%	XTickLabels = 0;		2;		4;		6;		8
%	XTickLabelMode = auto
%	XTickMode = auto
%	YColor = [1 1 1]
%	YDir = normal
%	YGrid = off
%	YLabel = [70.0001]
%	YLim = [0 6]
%	YLimMode = auto
%	YScale = linear
%	YTick = [0 2 4 6]
%	YTickLabels = 0;		2;		4;		6
%	YTickLabelMode = auto
%	YTickMode = auto
%	ZColor = [1 1 1]
%	ZDir = normal
%	ZGrid = off
%	ZLabel = [71.0001]
%	ZLim = [0 1]
%	ZLimMode = auto
%	ZScale = linear
%	ZTick = [0 0.2 0.4 0.6 0.8 1]
%	ZTickLabels = 0;		0.2;		0.4;		0.6;		0.8;		1
%	ZTickLabelMode = auto
%	ZTickMode = auto
%
%	ButtonDownFcn = 				Parent = [1]	
%	Children = [68.0002]			Type = axes
%	Clipping = on					UserData = []
%	Interruptible = no				Visible = on
%
