% Filename: cplabels.m
% Rev.Date: 7/10/95
% Class: 	function
%
% USAGE: cplabels( command, axes );
%        command = 'copy' to copy axes ( default )
%                  'paste' to paste axes
%        axes = axes to copy/paste (default: current axes)
%
%        CPLABELS copies or pastes the title and x-, y-, and z-axis  
%        labels from the current axes to/from special .mat files
%   
% Written By: Kevin G. Kohrt
% Written On: 7/6/95 - 7/10/95

% Permission granted to include CPLABELS or some variation of it
% with any other script(s), as long no part of this comment section 
% is deleted or changed (excluding the Rev.Date, Filename, & Class). -KGK
%
% Adapted By: 
% Adapted On:  
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% Properties of a sample text object:
% 
%	Color = [1 1 1]
%	EraseMode = normal
%	Extent = [160 -20 0 0]
%	FontAngle = normal
%	FontName = times
%	FontSize = [12]
%	FontWeight = bold
%	HorizontalAlignment = center
%	Position = [160 -20.1955]
%	Rotation = [0]
%	String = 
%	Units = pixels
%	VerticalAlignment = cap
%
%	ButtonDownFcn = 
%	Children = []
%	Clipping = off
%	Interruptible = no
%	Parent = [56.0001]
%	Type = text
%	UserData = []
%	Visible = on

	function [ Ti, XL, YL, ZL ] = cplabels( cmd, axh )
	
  %---------------------------------------------------------------------------%
  % Verify input arguments
  %---------------------------------------------------------------------------%
	if nargin < 2; axh = gca; end	% default: use current axes
	if nargin < 1; cmd = 'c'; end	% default: copy labels
  %---------------------------------------------------------------------------%
  % Initialize parameters used for both commands
  %---------------------------------------------------------------------------%
	props = [	'Color   '
				'EraseMod'
				'FontAngl'
				'FontName'
				'FontSize'
				'FontStri'
				'FontWeig'
				'Horizont'
				'Position'
				'Rotation'
				'Selected'
				'String  ' 
				'Units   '
				'Vertical'
				'ButtonDo' 
				'Clipping'
				'Interrup'
				'UserData'
				'Visible ' ];
%				'Extent  '
  %---------------------------------------------------------------------------%
  % Initialize parameters for filenames
  %---------------------------------------------------------------------------%
	kids = [ 'titl' 
			 'xlab'
			 'ylab'
			 'zlab' ];

  %===========================================================================%
  % START  CMD#1 : COPY LABELS FROM AN AXES
  %---------------------------------------------------------------------------%
    if strcmp( lower( cmd(1) ), 'c' )
  %---------------------------------------------------------------------------%
  % Loop to memorize the object properties for each label on the axes
  %---------------------------------------------------------------------------%
	for num = 1 : 4
    %-------------------------------------------------------------------------%
    % Start building the string used to save all data in file 'templabels.mat'
    %-------------------------------------------------------------------------%
	  savetxt = [ 'save temp' kids( num, : ) ' kids' ];
  	%-------------------------------------------------------------------------%
	% Loop to store all object properties in a uniquely named variable
  	%-------------------------------------------------------------------------%
	  for idx = 1 : length( props )
	  	%---------------------------------------------------------------------%
		% Create variable name...
	  	%---------------------------------------------------------------------%
		  property = props( idx, : );
		  property = property( property ~= ' ' );
		  varname = [ property '_' kids( num, : ) ];
	  	%---------------------------------------------------------------------%
		% assign it the appropriate object property value(s)...
	  	%---------------------------------------------------------------------%
%		  disp( [ varname ' = get( get( axh, ''' kids(num, :) ''' ),',...
%				' ''' property ''' );' ] );
		  eval( [ varname ' = get( get( axh, ''' kids(num, :) ''' ),',...
				' ''' property ''' );' ] );
	  	%---------------------------------------------------------------------%
		% add it to the list of variables to be saved
	  	%---------------------------------------------------------------------%
		  savetxt = [ savetxt, ' ', varname ];
	  	%---------------------------------------------------------------------%
	  end % properties loop
    %-------------------------------------------------------------------------%
    % Save the data into a file 
    %-------------------------------------------------------------------------%
	  eval( savetxt )
  	%-------------------------------------------------------------------------%
	end % labels loop
  %---------------------------------------------------------------------------%
  % END OF CMD#1 : COPY LABELS FROM AN AXES                                  
  %===========================================================================%
  % START  CMD#2 : PASTE LABELS TO AN AXES
  %---------------------------------------------------------------------------%
    elseif strcmp( lower( cmd(1) ), 'p' )
	axes( axh );
  %---------------------------------------------------------------------------%
  % Loop to recall the object properties for each label on the axes
  %---------------------------------------------------------------------------%
	for num = 1 : 4
  %---------------------------------------------------------------------------%
  % Load label data if the data files exist
  %---------------------------------------------------------------------------%
	if exist( [ 'temp' kids( num, : ) '.mat' ] ) == 2
		eval( [ 'load temp' kids( num, : ) ] )
	else
		disp( 'Error: Cannot paste labels because the' )
		disp( 'file ''temp____.mat'' is not in the search path' )
		return
	end
  	%-------------------------------------------------------------------------%
	% Identify object handles
  	%-------------------------------------------------------------------------%
	  hand( num ) = text( 0, 0, kids( num ) );
  	%-------------------------------------------------------------------------%
	% Loop to regenerate each uniquely named variable
  	%-------------------------------------------------------------------------%
	  for idx = 1 : length( props )
	  	%---------------------------------------------------------------------%
		% Create variable name...
	  	%---------------------------------------------------------------------%
		  property = props( idx, : );
		  property = property( property ~= ' ' );
		  varname = [ property '_' kids( num, : ) ];
	  	%---------------------------------------------------------------------%
		% assign the value(s) to the appropriate object property
	  	%---------------------------------------------------------------------%
%		  disp( [ 'set( hand(num), ''' property ''', ' varname ' );' ] );
		  eval( [ 'set( hand(num), ''' property ''', ' varname ' );' ] );
	  	%---------------------------------------------------------------------%
	  end % properties loop
  	%-------------------------------------------------------------------------%
	end % labels loop
	Ti = hand(1);
	XL = hand(2);
	YL = hand(3);
	ZL = hand(4);
  %---------------------------------------------------------------------------%
  % END OF CMD#2 : PASTE LABELS TO AN AXES                                  
  %===========================================================================%

	else
		disp(' Error in cplabels: bad command. ''copy'',or ''paste'' expected.')
	end

