% Filename: cpline2.m
% Rev.Date: 7/10/95
% Class: 	function
%
% USAGE: cpline2( command, axes );
%        command = 'copy' to copy lines ( default )
%                  'paste' to paste lines
%        axes = axes to copy/paste to (default: current axes)
%
%        CPLINE2 copies or pastes lines for an axes 
%        to/from one or more special .mat files (MATLAB
%        limits the Save command to ~40 variables, so
%        if there are many lines on a plot...)
%
% Written By: Kevin G. Kohrt, kkohrt@engr.iupui.edu
% Written On: 7/6/95 - 7/10/95

% Permission granted to include CPLINE2 or some variation of it
% with any other script(s), as long no part of this comment section 
% is deleted or changed (excluding the Rev.Date, Filename, & Class). -KGK
%
% Adapted By: 
% Adapted On:  
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% Properties of a sample line object:
% 
%	Color = [1 0 1]
%	EraseMode = normal      EraseMode: [ {normal} | background | xor | none ]
%	LineStyle = -        	LineStyle: [ {-} | -- | : | -. | + | o | * | . | x ]
%	LineWidth = [0.5]
%	MarkerSize = [6]
%	XData = [ (1 by 11) ]
%	YData = [ (1 by 11) ]
%	ZData = []
%
%	ButtonDownFcn = 
%%%	Children = []
%	Clipping = on        	Clipping: [ {on} | off ]
%xx	Interruptible = no      Interruptible: [ {no} | yes ]
%%%	Parent = [56.0001]
%%%	Type = line
%	UserData = []
%	Visible = on        	Visible: [ {on} | off ]

	function cplines( cmd, axh )

  %---------------------------------------------------------------------------%
  % Verify input arguments
  %---------------------------------------------------------------------------%
	if nargin < 2; axh = gca; end	% default: use current axes
	if nargin < 1; cmd = 'c'; end	% default: copy lines

  %===========================================================================%
  % START  CMD#1 : COPY LINES FROM AN AXES
  %---------------------------------------------------------------------------%
    if strcmp( lower( cmd(1) ), 'c' )
  %---------------------------------------------------------------------------%
  % Initialize parameters for line search
  %---------------------------------------------------------------------------%
	theline = [];
	kids = get( axh, 'children' );
  %---------------------------------------------------------------------------%
  % Search children of axes to find any line objects
  %---------------------------------------------------------------------------%
	for idx = 1 : length( kids )
		if strcmp( get( kids( idx ), 'Type' ), 'line' ) 
			theline = [ theline; kids( idx ) ];
		end
	end
  %---------------------------------------------------------------------------%
  % Return to calling program if there are no lines in the axes
  %---------------------------------------------------------------------------%
	if isempty( theline ), 
		Nums1 = 0;
		save templn Nums1
		return 
	end
  %---------------------------------------------------------------------------%
  % Start building the string used to save all Data in file 'templn.mat'
  %---------------------------------------------------------------------------%
	numlines = length( theline );
	savetxt = 'save templn';
  %---------------------------------------------------------------------------%
  % Loop to memorize the object properties for each line in the axes
  %---------------------------------------------------------------------------%
	for num = 1 : numlines
	  nextset = ceil( num / 8 );
	  if nextset == num / 8;
		eval( savetxt );
		savetxt = [ 'save templn' num2str( nextset ) ];
	  end
	%-------------------------------------------------------------------------%
    % Get parameters and combine into fewer variables
    %-------------------------------------------------------------------------%
				Color = get( theline( num ), 'Color' );
				LineW = get( theline( num ), 'LineW' );
				Marke = get( theline( num ), 'Marke' );
	  eval( [ 'Nums' num2str( num ) ' = [ numlines, Color, LineW, Marke ];' ] )
				XData = get( theline( num ), 'XData' );
				YData = get( theline( num ), 'YData' );
				ZData = get( theline( num ), 'ZData' );
	  eval( [ 'Data' num2str( num ) ' = [ XData(:), YData(:), ZData(:) ];' ] )

				Erase = get( theline( num ), 'Erase' );
				LineS = get( theline( num ), 'LineS' );
					if length( LineS ) ~= 2, LineS = [ LineS, ' ' ]; end
				Clipp = get( theline( num ), 'Clipp' );
				Inter = get( theline( num ), 'Inter' );
				Visib = get( theline( num ), 'Visib' ); 
	  eval( [ 'Info' num2str( num ) ' = [ Erase(1:2); [ Erase(3) '' '' ]; ',...
				' LineS; Clipp(1:2); Inter(1:2); Visib(1:2) ];' ] )
	  eval( [ 'Btdwn' num2str( num ) ' = get( theline( num ), ''Butto'' );' ] )
	  eval( [ 'UserD' num2str( num ) ' = get( theline( num ), ''UserD'' );' ] )
	  savetxt = [ savetxt, ' Nums' num2str( num ) ' Data' num2str( num )...
		' Info' num2str( num ) ' Btdwn' num2str( num ) ' UserD' num2str( num ) ];
  	%-------------------------------------------------------------------------%
	end % lines loop
  %---------------------------------------------------------------------------%
  % Save the Data into a file 
  %---------------------------------------------------------------------------%
	eval( savetxt );
  %---------------------------------------------------------------------------%
  % END OF CMD#1 : COPY LINES FROM AN AXES                                  
  %===========================================================================%
  % START  CMD#2 : PASTE LINES TO AN AXES
  %---------------------------------------------------------------------------%
    elseif strcmp( lower( cmd(1) ), 'p' )
	axes( axh ); 
  %---------------------------------------------------------------------------%
  % Load lineData if the Data file exists
  %---------------------------------------------------------------------------%
	if exist( 'templn.mat' ) == 2
		load templn
	else
		disp( 'Error: Cannot paste lines because the' )
		disp( 'file ''templn.mat'' is not in the search path' )
		return
	end
  %---------------------------------------------------------------------------%
  % Loop to rewrite each line onto the axes
  %---------------------------------------------------------------------------%
	numlines = Nums1(1);
	if numlines > 0
	for num = 1 : numlines
	  nextset = ceil( num / 8 );
	  if nextset == num / 8;
%		fprintf( '\nnum = %3.0f; Loading next set of Data. \n', num )
	  	filename = [ 'templn' num2str( nextset ) ];
		if exist( [ filename '.mat' ] ) == 2
		  eval( [ 'load ' filename ] )
		else
		  disp( 'Error: Cannot paste lines because the file:' )
		  fprintf( '''templn%1.0f.mat'' isn''t in the search path', nextset )
		  return
	  	end
	  end
  	%-------------------------------------------------------------------------%
	% Create a basic line
  	%-------------------------------------------------------------------------%
%	  theline = line( [0,1], [0,1] );
	%-------------------------------------------------------------------------%
    % Set parameters for the line
    %-------------------------------------------------------------------------%
		eval( [ 'Nums = Nums' num2str( num ) ';' ] );
		eval( [ 'Data = Data' num2str( num ) ';' ] );
		eval( [ 'Info = Info' num2str( num ) ';' ] )
		linestyle = Info(3,:);
		linestyle = linestyle( linestyle ~= ' ' );

		theline = line( 'Color', Nums(2:4), 'LineWidth', Nums( 5 ), ...
			'MarkerSize', Nums( 6 ), 'XData', Data(:,1), 'YData', Data(:,2),...
			'EraseMode', [ Info(1,:) Info(2,1) ], 'LineStyle', linestyle );
		set( theline, 'Clipp', Info(4,:) );
		set( theline, 'Inter', Info(5,:) );
		set( theline, 'Visib', Info(6,:) );

		if size( Data, 2 ) == 3,
		  set( theline, 'ZData', Data(:,3) );
		end

		eval( [ 'set( theline, ''Butto'', Btdwn' num2str( num ) ');' ] );
		eval( [ 'set( theline, ''UserD'', UserD' num2str( num ) ');' ] );
  	%-------------------------------------------------------------------------%
	end % lines loop
	end % if lines
  %---------------------------------------------------------------------------%
  % END OF CMD#2 : PASTE LINES TO AN AXES                                  
  %===========================================================================%

	else
		disp(' Error in cplines: bad command. ''copy'',or ''paste'' expected.')
	end
