% Filename: cpsurfs.m
% Rev.Date: 7/10/95
% Class: 	function
%
% USAGE: cpsurfs( command, axes );
%        command = 'copy' to copy surfaces ( default )
%                  'paste' to paste surfaces
%        axes = axes to copy/paste to (default: current axes)
%
%        CPSURFS copies or pastes surface objects for an 
%        axes to/from a more special .mat file
%
% Written By: Kevin G. Kohrt, kkohrt@engr.iupui.edu
% Written On: 7/6/95 - 7/10/95

% Permission granted to include CPSURFS or some variation of it
% with any other script(s), as long no part of this comment section 
% is deleted or changed (excluding the Rev.Date, Filename, & Class). -KGK
%
% Adapted By: 
% Adapted On:  
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% Properties of a sample surface object:
% 
%	CData = [ (5 by 7) ]
%	EdgeColor = flat
%	EraseMode = normal
%	FaceColor = [0 0 0]
%	LineStyle = -
%	LineWidth = [0.5]
%	MarkerSize = [6]
%	MeshStyle = both
%	XData = [ (1 by 7) ]
%	YData = [ (5 by 1) ]
%	ZData = [ (5 by 7) ]
%
%	ButtonDownFcn = 
%	Children = []
%	Clipping = on
%	Interruptible = no
%	Parent = [56.0001]
%	Type = surface
%	UserData = []
%	Visible = on


    function cpsurfs( cmd, axh )
	
  %---------------------------------------------------------------------------%
  % Verify input arguments
  %---------------------------------------------------------------------------%
	if nargin < 2; axh = gca; end	% default: use current axes
	if nargin < 1; cmd = 'c'; end	% default: copy surfs
  %---------------------------------------------------------------------------%
  % Initialize parameters used for both commands
  %---------------------------------------------------------------------------%
	props =	[	'CData'
				'EdgeC'
				'Erase'
				'FaceC'
				'LineS'
				'LineW'
				'Marke'
				'MeshS'
				'Selec'
				'XData'
				'YData'
				'ZData'
				'Butto'
				'Clipp'
				'Inter'
				'UserD'
				'Visib' ];
  %===========================================================================%
  % START  CMD#1 : COPY SURFACES FROM AN AXES
  %---------------------------------------------------------------------------%
   if strcmp( lower( cmd(1) ), 'c' )
  %---------------------------------------------------------------------------%
  % Initialize parameters for line search
  %---------------------------------------------------------------------------%
	thesurf = [];
	kids = get( axh, 'children' );
  %---------------------------------------------------------------------------%
  % Search children of axes to find any line objects
  %---------------------------------------------------------------------------%
	for idx = 1 : length( kids )
		if strcmp( get( kids( idx ), 'Type' ), 'surface' ) 
			thesurf = [ thesurf; kids( idx ) ];
		end
	end
  %---------------------------------------------------------------------------%
  % Return to calling program if there are no surfs in the axes
  %---------------------------------------------------------------------------%

	if isempty( thesurf ), 
		numsurfs = 0;
		save tempsurf numsurfs
		return 
	end
  %---------------------------------------------------------------------------%
  % Start building the string used to save all data in file 'tempsurf.mat'
  %---------------------------------------------------------------------------%
	numsurfs = length( thesurf );
	savetxt = 'save tempsurf numsurfs';
  %---------------------------------------------------------------------------%
  % Loop to memorize the object properties for each surf in the axes
  %---------------------------------------------------------------------------%
	for num = 1 : numsurfs
  	%-------------------------------------------------------------------------%
	% Loop to store all object properties in a uniquely named variable
  	%-------------------------------------------------------------------------%
	  for idx = 1 : length( props )
	  	%---------------------------------------------------------------------%
		% Create variable name...
	  	%---------------------------------------------------------------------%
		  varname = [ props( idx, : ) '_prop' num2str( num ) ];
	  	%---------------------------------------------------------------------%
		% assign it the appropriate object property value(s)...
	  	%---------------------------------------------------------------------%
		  eval( [ varname ' = get( thesurf(num), ''' props(idx,:) ''' );' ] );
	  	%---------------------------------------------------------------------%
		% add it to the list of variables to be saved
	  	%---------------------------------------------------------------------%
		  savetxt = [ savetxt, ' ', varname ];
	  	%---------------------------------------------------------------------%
	  end % properties loop
  	%-------------------------------------------------------------------------%
	end % surfs loop
  %---------------------------------------------------------------------------%
  % Save the data into a file 
  %---------------------------------------------------------------------------%
	eval( savetxt )
  %---------------------------------------------------------------------------%
  % END OF CMD#1 : COPY SURFACES FROM AN AXES                                  
  %===========================================================================%
  % START  CMD#2 : PASTE SURFACES TO AN AXES
  %---------------------------------------------------------------------------%
    elseif strcmp( lower( cmd(1) ), 'p' )
	axes( axh ); 
  %---------------------------------------------------------------------------%
  % Load surf data if the data file exists
  %---------------------------------------------------------------------------%
	if exist( 'tempsurf.mat' ) == 2
		load tempsurf
	else
		disp( 'Error: Cannot paste surfaces because the' )
		disp( 'file ''tempsurf.mat'' is not in the search path' )
		return
	end
  %---------------------------------------------------------------------------%
  % Loop to rewrite each line onto the axes
  %---------------------------------------------------------------------------%
	for num = 1 : numsurfs
  	%-------------------------------------------------------------------------%
	% Start building the string used to insert all data into 'line' command
  	%-------------------------------------------------------------------------%
	  thesurf = surf( zeros( size( CData_prop1 ) ) );
  	%-------------------------------------------------------------------------%
	% Loop to set all object properties of the line 
  	%-------------------------------------------------------------------------%
	  for idx = 1 : length( props )
	  	%---------------------------------------------------------------------%
		% Create variable name...
	  	%---------------------------------------------------------------------%
		  varname = [ props( idx, : ) '_prop' num2str( num ) ];
	  	%---------------------------------------------------------------------%
		% assign it the appropriate object property value(s)...
	  	%---------------------------------------------------------------------%
		  eval( [ 'set( thesurf, ''' props( idx, : ) ''', ' varname ' )' ] );
	  	%---------------------------------------------------------------------%
	  end % properties loop
  	%-------------------------------------------------------------------------%
	end % surfs loop
  %---------------------------------------------------------------------------%
  % END OF CMD#2 : PASTE SURFACES TO AN AXES                                  
  %===========================================================================%

	else
		disp(' Error in cpsurfs: bad command. ''copy'',or ''paste'' expected.')
	end
