% Filename: cptxts.m
% Rev.Date: 7/10/95
% Class: 	function
%
% USAGE: cpline2( command, axes );
%        command = 'copy' to copy text ( default )
%                  'paste' to paste text
%        axes = axes to copy/paste to (default: current axes)
%
%        CPTXTS copies or pastes text for an axes 
%        to/from one or more special .mat files (MATLAB
%        limits the Save command to ~40 variables, so
%        if there are many text objects on a plot...)
%
% Written By: Kevin G. Kohrt, kkohrt@engr.iupui.edu
% Written On: 7/10/95

% Permission granted to include CPLINE2 or some variation of it
% with any other script(s), as long no part of this comment section 
% is deleted or changed (excluding the Rev.Date, Filename, & Class). -KGK
%
% Adapted By: 
% Adapted On:  
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

	function cptxts( cmd, axh )

  %---------------------------------------------------------------------------%
  % Verify input arguments
  %---------------------------------------------------------------------------%
	if nargin < 2; axh = gca; end	% default: use current axes
	if nargin < 1; cmd = 'c'; end	% default: copy lines

  %===========================================================================%
  % START  CMD#1 : COPY TEXT FROM AN AXES
  %---------------------------------------------------------------------------%
    if strcmp( lower( cmd(1) ), 'c' )
  %---------------------------------------------------------------------------%
  % Initialize parameters for line search
  %---------------------------------------------------------------------------%
	thetext = [];
	kids = get( axh, 'children' );
  %---------------------------------------------------------------------------%
  % Search children of axes to find any text objects
  %---------------------------------------------------------------------------%
	for idx = 1 : length( kids )
		if strcmp( get( kids( idx ), 'Type' ), 'text' ) 
			thetext = [ thetext; kids( idx ) ];
		end
	end
  %---------------------------------------------------------------------------%
  % Return to calling program if there are no text objects in the axes
  %---------------------------------------------------------------------------%
	if isempty( thetext ), 
		Nums1 = 0;
		save temptext Nums1
		return 
	end
  %---------------------------------------------------------------------------%
  % Start building the string used to save all Data in file 'temptext.mat'
  %---------------------------------------------------------------------------%
	numtxts = length( thetext );
	savetxt = 'save temptext';
  %---------------------------------------------------------------------------%
  % Loop to memorize the object properties for all text in the axes
  %---------------------------------------------------------------------------%
	for num = 1 : numtxts
	  nextset = ceil( num / 6 );
	  if nextset == num / 6;
		eval( savetxt );
		savetxt = [ 'save temptext' num2str( nextset ) ];
	  end
	%-------------------------------------------------------------------------%
    % Get parameters and combine into fewer variables
    %-------------------------------------------------------------------------%
				Color = get( thetext( num ), 'Color' );
				FontSize = get( thetext( num ), 'FontSize' );
				Rotat = get( thetext( num ), 'Rotat' );
				Posit = get( thetext( num ), 'Position' );
	  eval( [ 'Nums' num2str( num ),...
			 ' = [ numtxts, Color, FontSize, Rotat, Posit ];' ] )
				Erase = get( thetext( num ), 'Erase' );
				FontA = get( thetext( num ), 'FontA' );
				FontW = get( thetext( num ), 'FontW' );
				Horiz = get( thetext( num ), 'Horiz' );
				Selec = get( thetext( num ), 'Selec' );
				Units = get( thetext( num ), 'Units' );
				Verti = get( thetext( num ), 'Verti' );
				Clipp = get( thetext( num ), 'Clipp' );
				Inter = get( thetext( num ), 'Inter' );
				Visib = get( thetext( num ), 'Visib' ); 
	  eval( [ 'Info' num2str( num ) ' = [ Erase(1:2); [ Erase(3) '' '' ]; ',...
			' FontA(1:2); FontW(1:2); Horiz(1:2); Units(1:2); Selec(1:2);',...
			' Verti(1:2); Clipp(1:2); Inter(1:2); Visib(1:2) ];' ] )
	  eval( [ 'Btdwn' num2str( num ) ' = get( thetext( num ), ''Butto'' );' ] )
	  eval( [ 'UserD' num2str( num ) ' = get( thetext( num ), ''UserD'' );' ] )
	  eval( [ 'FontN' num2str( num ) ' = get( thetext( num ), ''FontN'' );' ] )
	  eval( [ 'Strin' num2str( num ) ' = get( thetext( num ), ''Strin'' );' ] )
	  savetxt = [ savetxt, ' Nums' num2str( num ) ' FontN' num2str( num )...
		' Info' num2str( num ) ' Btdwn' num2str( num )...
		' UserD' num2str( num ) ' Strin' num2str( num )];
  	%-------------------------------------------------------------------------%
	end % lines loop
  %---------------------------------------------------------------------------%
  % Save the Data into a file 
  %---------------------------------------------------------------------------%
	eval( savetxt );
  %---------------------------------------------------------------------------%
  % END OF CMD#1 : COPY LINES FROM AN AXES                                  
  %===========================================================================%
  % START  CMD#2 : PASTE LINES TO AN AXES
  %---------------------------------------------------------------------------%
    elseif strcmp( lower( cmd(1) ), 'p' )
	axes( axh ); 
  %---------------------------------------------------------------------------%
  % Load lineData if the Data file exists
  %---------------------------------------------------------------------------%
	if exist( 'temptext.mat' ) == 2
		load temptext
	else
		disp( 'Error: Cannot paste lines because the' )
		disp( 'file ''temptext.mat'' is not in the search path' )
		return
	end
  %---------------------------------------------------------------------------%
  % Loop to rewrite each line onto the axes
  %---------------------------------------------------------------------------%
	numtxts = Nums1(1);
	if numtxts > 0
	for num = 1 : numtxts
	  nextset = ceil( num / 6 );
	  if nextset == num / 6;
%		fprintf( '\nnum = %3.0f; Loading next set of Data. \n', num )
	  	filename = [ 'temptext' num2str( nextset ) ];
		if exist( [ filename '.mat' ] ) == 2
		  eval( [ 'load ' filename ] )
		else
		  disp( 'Error: Cannot paste lines because the file:' )
		  fprintf( '''temptext%1.0f.mat'' isn''t in the search path', nextset )
		  return
	  	end
	  end
  	%-------------------------------------------------------------------------%
	% Create a basic line
  	%-------------------------------------------------------------------------%
%	  thetext = line( [0,1], [0,1] );
	%-------------------------------------------------------------------------%
    % Set parameters for the line
    %-------------------------------------------------------------------------%
		eval( [ 'Nums = Nums' num2str( num ) ';' ] );
		eval( [ 'Info = Info' num2str( num ) ';' ] )
		eval( [ 'String = Strin' num2str( num ) ';' ] )

		thetext = text( 'String', String,...
			'Color', Nums(2:4), 'FontSize', Nums( 5 ), ...
			'Rotation', Nums( 6 ), 'Units', Info(6,:),...
			'Position', Nums( 7:length(Nums) ) );
		set( thetext, 'Erase', [ Info(1,:), Info(2,1) ] );
		set( thetext, 'FontA', Info(3,:) );
		set( thetext, 'FontW', Info(4,:) );
		set( thetext, 'Horiz', Info(5,:) );
		set( thetext, 'Selec', Info(7,:) );
		set( thetext, 'Verti', Info(8,:) );
		set( thetext, 'Clipp', Info(9,:) );
		set( thetext, 'Inter', Info(10,:) );
		set( thetext, 'Visib', Info(11,:) );

		eval( [ 'set( thetext, ''Butto'', Btdwn' num2str( num ) ');' ] );
		eval( [ 'set( thetext, ''FontN'', FontN' num2str( num ) ');' ] );
		eval( [ 'set( thetext, ''UserD'', UserD' num2str( num ) ');' ] );
  	%-------------------------------------------------------------------------%
	end % lines loop
	end % if lines
  %---------------------------------------------------------------------------%
  % END OF CMD#2 : PASTE LINES TO AN AXES                                  
  %===========================================================================%

	else
		disp(' Error in cplines: bad command. ''copy'',or ''paste'' expected.')
	end
