% Filename: linemenu.m
% Rev.Date: 8/12/95
% Class: 	function
%
% USAGE: type "linemenu" to put this amazing menu 
% 		 on the current figure window. Allows the
%        detailed manipulation of line properties.
%
% Subroutines required:
%   changeme

%
% Written By: Kevin G. Kohrt, kkohrt@engr.iupui.edu
% Written On: 3/31/95* - 7/10/95
%             (* pulled from addHamlet, first written 8/11/94)
%
% Permission granted to include LINEMENU or some variation of it
% with any other script(s), as long no part of this comment section 
% is deleted or changed (excluding the Rev.Date, Filename, & Class). -KGK
%
% Adapted By: 
% Adapted On:  
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

	function linemenu

	%
	% Enable  line, axes and text selection if req'd
	% (WBDF ==> "Window Button Down Fcn")
	% ------------------------------------
	  if strcmp( get(gcf,'WindowButtonDownFcn'), '' )
	 	WBDF = [	'if exist(''ClickPoint'');',...
					'DoubleClick = ',...
						'( ClickPoint == get( gcf,''CurrentPoint'') );',...
				'end;',...
				'temp = get( gco,''Type'');',...
				'if DoubleClick;',...
					'if ( strcmp( temp,''line'') );',...
						'set( gco,''Color'', abs(1-get(gco,''Color'')) ),',...
						'if strcmp( get( gco,''Selected''),''on''); ',...
							 'set( gco,''Selected'',''off'');',...
						'else,'...
							 'set( gco,''Selected'',''on'');',...
						'end;',...
					'elseif(  ( strcmp( temp,''text'') ) ',...
							'| ( strcmp( temp,''axes'') ) );',...
						'if strcmp( get( gco,''Selected''),''on'');',...
							'set( gco,''Selected'',''off'');',...
						'else;',...
							'set( gco,''Selected'',''on'');',...
						'end;',...
					'end;',...
				'end; clear temp;',...
				'ClickPoint = get( gcf,''CurrentPoint'');'];
		set(gcf,'WindowButtonDownFcn', WBDF);
	  end
	% ========================================================================
	% MENU: 'Line  ': Adjust line properties
	% ========================================================================
	%
	  LineMenu = uimenu( gcf, 'Label', 'Lines ' );

	%
	% SUBMENU: Line Selection
	% ----------------------------------------------------------------
	  lineselmenu = uimenu( LineMenu,  'Label',	'Select...');

	  uimenu( lineselmenu, ...
			  'Label', 		'All in figure',...
			  'callback', 	[...
							'All = findobj(gcf,''Type'',''line'');',...
							'All = findobj(All,''Selected'',''off'');',...
							'for idx = 1:length(All);',...
							  'tc = get(All(idx),''color'');',...
							  'set( All(idx),''Selected'',''on'', '...
							  ' ''color'', abs(tc-1)  );'...
							'end; clear tc All;' ] );

	  uimenu( lineselmenu, ...
			  'Label', 		'All in selected axes',...
			  'callback', 	[...
							's = findobj(gcf,''Type'',''axes'');',...
							's = findobj(s,''Selected'',''on'');',...
							'All = findobj(s,''Type'',''line'');',...
							'All = findobj(All,''Selected'',''off'');',...
							'for idx = 1:length(All);',...
							  'tc = get(All(idx),''color'');',...
							  'set( All(idx),''Selected'',''on'', '...
							  ' ''color'', abs(tc-1) );'...
							'end; clear s tc All;' ] );
	  uimenu( lineselmenu	,...
			  'Label', 		'None (deselect all)',...
			  'callback', 	'changeme(''line'',''Selected'',''off'');' );	
	%
	% SUBMENU: Line Style 
	% ----------------------------------------------------------------
	  Lnstyle = uimenu( LineMenu,  'Label',	'Line Style', 'Separator', 'on' );
	
	  LnStyleData = [ '- '; '--'; ': '; '-.'; 'x '; '+ '; 'o '; '* '; '. ' ];
	  LnStyleText = [ ' line   ';'dash    ';' dots   ';'dash-dot';...
				      'data pt.';'data pt.';'data pt.';'data pt.';'data pt.'];
	  default = get( 0, 'DefaultLineLineStyle' );
	  for idx = 1 : size( LnStyleData, 1 )
		LnType = LnStyleData( idx, LnStyleData( idx, : ) ~= ' ' );
	  	uimenu( Lnstyle			,...
				'Label', 		[ LnType, ' ', LnStyleText(idx,:) ],...
				'UserData', 	[ LnType ],...
				'ForeGround',	[ strcmp( LnType, default ), 0, 0 ],...
				'BackGround', 	[ 0.7 0.7 0.7 ],... 
	       		'Callback',		[ ' changeme(''line'',''LineStyle'', ',...
								  ' get( gcmenu,''UserData'') );']);
	  end;
	%
	% SUBMENU: Line Thickness:	
	% ----------------------------------------------------------------
	  Lnthick = uimenu( LineMenu, 'Label', 'Line Width' );

	  default = get( 0, 'DefaultLineLineWidth' );
	  for idx = [ 0.5, 1, 2:2:10]
	   	uimenu(  Lnthick		,... 
				'Label',		num2str(idx),...
				'ForeGround',	[ idx == default, 0, 0 ],...
				'BackGround', 	[ 0.7 0.7 0.7 ],... 
	       		'Callback',		[ 'changeme(''line'',''LineWidth'', ',...
								  'str2num( get( gcmenu,''Label'') ) ); ' ] );
	  end;
	  uimenu( 	Lnthick			,...
			  	'Label',		'Specify...',...
			  	'Separator',	'on' ,...
		      	'Callback',		[...
						'value = input(''Enter desired line width: '');',...
				  		'changeme(''line'',''LineWidth'', value );' ] );
	%
	% SUBMENU: Marker Size 
	% ----------------------------------------------------------------
	  marker = uimenu( LineMenu,  'Label',  'Marker Size' );
	  default = get( 0, 'DefaultAxesLineWidth' );
	  for idx = [ 2:4:18]
	  	uimenu(  marker,...
				'Label',		num2str(idx),...
				'ForeGround',	[ idx == default, 0, 0 ],...
				'BackGround', 	[ 0.7 0.7 0.7 ],... 
	       		'Callback',		[ ' changeme(''line'',''MarkerSize'', ',...
								  ' str2num( get( gcmenu,''Label'') ) ); ' ] );
	  end;
	  uimenu( 	marker			,...
			  	'Label',		'Specify...',...
			  	'Separator',	'on' ,...
		      	'Callback',		[...
					'value = input(''Enter desired marker size: '');',...
					'changeme(''line'',''MarkerSize'', value );' ] );	
	%
	% SUBMENU: Line Color
	% ----------------------------------------------------------------
	 lcolormenu = uimenu( LineMenu,  'Label',	'Color  ');
	
	 colorlabel = str2mat( 'black','white','yellow','magenta','red',...
							 'green','cyan','blue');
	 for idx = 1 : size( colorlabel, 1 )
		tempcolor = colorlabel( idx, colorlabel( idx, : ) ~= ' ' );
		uimenu( lcolormenu,...
				'Label',			tempcolor,...
				'ForeGroundColor',	tempcolor,...
				'BackGroundColor', 	[ 0.7 0.7 0.7 ],... 
				'Callback', 		['changeme(''line'',''Color'', ',...
								  	 'get( gcmenu,''Label'') );',...
									 'changeme(''line'',''Selected'',''on'')']);
	 end;
	 uimenu( lcolormenu,...
			 'Label',		'Specify [R,G,B]...',...
			 'Separator',	'on' ,...
		     'Callback',	[...
					' value = input(''Enter [ R, G, B ] triplet: '');',...
					' changeme(''text'',''Color'', value );',...
					' changeme(''line'',''Selected'',''on'');' ]);
	%
	% SUBMENU: Hide/Delete Lines
	% ----------------------------------------------------------------
	 uimenu( LineMenu		,...
			 'Label',		'Hide',...
			 'Separator',	'on' ,...
			 'Callback', 	[ 'changeme(''line'',''Visible'',''off'');',...
							  'changeme(''line'',''Selected'',''off'');' ]);
	 uimenu( LineMenu		,...
			 'Label',		'Show Hidden',...
			 'Callback', 	[ ...
							'changeme(''line'',''Selected'',''off'');',...
							'set( findobj( findobj(''Visible'',''off''),',...
							' ''Type'',''line''),''Visible'',''on'',',...
							' ''Selected'',''on'');',...
							'changeme(''line'',''Selected'',''on'');' ]);
	 uimenu( LineMenu		,...
			 'Label',		'Delete',...
		     'Callback',	[...
					'delete( findobj( findobj( gcf,''Type'',''line''),',...
					' ''flat'',''Selected'',''on'') );' ] );

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%                               REVISION HISTORY
%
% 03/31/95	Breaks off from addHamlet to become independent function.
%			Hide and Show Hidden added.
% 07/10/95  Callbacks compressed to (hopefully) save on memory & improve speed
% 08/12/95  Object selection capability automatically added to window 
%			if no other WindowButtonDownFcn currently exists
