% Filename: textmenu.m
% Rev.Date: 8/12/95
% Class: 	function
%
% USAGE: type "textmenu" to put this amazing menu 
% 		 on the current figure window. Allows the
%        detailed manipulation of text properties.
%
% Subroutines required:
%   moveobj.m
%   changeme.m
%
% WARNING: 	Axes titles and legends do not work well 
%			with move/park: they sometimes disappear 
%			off the screen depending on the axes limits. 
%			When you resize the window, though, MATLAB 
%			puts them back where they belong.
%			Orientation of Axes legends are also reset 
%			to default values by MATLAB when windows are 
%			resized (but the title will remain at an angle).
%
% Written By: Kevin G. Kohrt, kkohrt@engr.iupui.edu
% Written On: 3/31/95 - 7/10/95
%			  (* parts pulled from addHamlet, first written 8/11/94)

% Permission granted to include TEXTMENU or some variation of it
% with any other script(s), as long no part of this comment section 
% is deleted or changed (excluding the Rev.Date, Filename, & Class). -KGK
%
% Adapted By: 
% Adapted On: 
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

	function textmenu

	%
	% Enable  line, axes and text selection if req'd
	% (WBDF ==> "Window Button Down Fcn")
	% ------------------------------------
	  if strcmp( get(gcf,'WindowButtonDownFcn'), '' )
	 	WBDF = [	'if exist(''ClickPoint'');',...
					'DoubleClick = ',...
						'( ClickPoint == get( gcf,''CurrentPoint'') );',...
				'end;',...
				'temp = get( gco,''Type'');',...
				'if DoubleClick;',...
					'if ( strcmp( temp,''line'') );',...
						'set( gco,''Color'', abs(1-get(gco,''Color'')) ),',...
						'if strcmp( get( gco,''Selected''),''on''); ',...
							 'set( gco,''Selected'',''off'');',...
						'else,'...
							 'set( gco,''Selected'',''on'');',...
						'end;',...
					'elseif(  ( strcmp( temp,''text'') ) ',...
							'| ( strcmp( temp,''axes'') ) );',...
						'if strcmp( get( gco,''Selected''),''on'');',...
							'set( gco,''Selected'',''off'');',...
						'else;',...
							'set( gco,''Selected'',''on'');',...
						'end;',...
					'end;',...
				'end; clear temp;',...
				'ClickPoint = get( gcf,''CurrentPoint'');'];
		set(gcf,'WindowButtonDownFcn', WBDF);
	  end

	% ========================================================================
	% MENU: 'Text ': Adjusts text properties of all selected objects in window
	% ========================================================================
	  TextMenu = uimenu( gcf, 'Label',		'Text ');
	%
	% SUBMENU: Selection
	% ----------------------------------------------------------------
	  tselmenu = uimenu( TextMenu,  'Label',	'Select...');

	  uimenu( tselmenu, ...
			  'Label', 		'All in figure',...
			  'callback', 	[...
							' set( findobj( gcf,''Type'',''text''), ',...
							'''Selected'',''on''); ' ] );

	  uimenu( tselmenu, ...
			  'Label', 		'All in selected axes',...
			  'callback', 	[...
							's = findobj( gcf,''Type'',''axes'');',...
							's = findobj( s,''Selected'',''on'');',...
							'set( findobj( s,''Type'',''text''), ',...
							' ''Selected'',''on''); clear s;' ] );
	  uimenu( tselmenu, ...
			  'Label', 		'None (deselect all)',...
			  'callback', 	'changeme(''text'',''Selected'',''off'');' );

	%
	% SUBMENU: Font Font
	% ----------------------------------------------------------------
	  tfontmenu = uimenu( TextMenu,  'Label',		'Font',...
									 'Separator',	'on' );
	
	  fontlabel = str2mat( 'Courier', 'Helvetica', 'Lucida-Bright',...
							'Palatino', 'Times', 'Symbol' );
	  default = get( 0, 'DefaultAxesFontName' );
	  for idx = 1 : size( fontlabel, 1 )
		uimenu( tfontmenu,...
				'Label',		fontlabel( idx, fontlabel(idx,:) ~= ' ' ),...
				'ForeGround',	[ strcmp( fontlabel(idx,2:5), default(2:5) ),...
								  0, 0 ],...
				'BackGround', 	[ 0.7 0.7 0.7 ],... 
					'Callback', [...
						 			'changeme(''text'',''FontName'',',...
								  	' get( gcmenu,''Label'') );' ] );
	  end;
	%
	% SUBMENU: Font Size
	% ----------------------------------------------------------------
	  tsizemenu = uimenu( TextMenu,  'Label',	'Size   ');
	
	  default = get( 0, 'DefaultAxesFontSize' );
	  for idx = [ 8 10 12 14 16 18 24 ]
	     uimenu( tsizemenu,...
			 	'Label',		num2str(idx),...
				'ForeGround',	[ idx == default, 0, 0 ],...
				'BackGround', 	[ 0.7 0.7 0.7 ],... 
				'Callback', 	[ ' changeme(''text'',''FontSize'',',...
						 		  ' str2num( get( gcmenu,''Label'') ) );' ] );
	  end;
	  uimenu( tsizemenu,...
			  'Label',		'Specify...',...
			  'Separator',	'on' ,...
		      'Callback',	[...
							' value = input(''Enter desired font size: '');',...
							' changeme(''text'',''FontSize'', value );' ] );
	%
	% SUBMENU: Font Style
	% ----------------------------------------------------------------
	  tstylemenu = uimenu( TextMenu,  'Label',	'Style  ');
	
	  stylable = str2mat('light', 'normal', 'light', 'bold' );
	  default = get( 0, 'DefaultAxesFontWeight' );
	  for idx = 1 : size( stylable, 1 )
		styletext = stylable( idx, stylable( idx, : ) ~= ' ' );
		uimenu( tstylemenu		,...
				'Label',		styletext,...
				'ForeGround',	[ strcmp( styletext, default ), 0, 0 ],...
				'BackGround', 	[ 0.7 0.7 0.7 ],... 
				'Callback', 	[ ' changeme(''text'',''FontWeight'', ',...
								  ' get( gcmenu,''Label'') );' ] );
	  end;

	  anglelabel = str2mat('italic', 'oblique' );
	  for idx = 1 : size( anglelabel, 1 )
		uimenu( tstylemenu	,...
				'Label',	anglelabel( idx, anglelabel( idx, : ) ~= ' ' ),...
		    	'Callback',	[ ' value = ( get( gcmenu,''Label'') ); ',...
							  ' changeme(''text'',''FontAngle'', value );' ] );
	  end;
	%
	% SUBMENU: Font Color
	% ----------------------------------------------------------------
	 tcolormenu = uimenu( TextMenu,  'Label',	'Color  ');
	
	 colorlabel = str2mat( 'black','white','yellow','magenta','red',...
							 'green','cyan','blue');
	 for idx = 1 : size( colorlabel, 1 )
		tempcolor = colorlabel( idx, colorlabel( idx, : ) ~= ' ' );
		uimenu( tcolormenu,...
				'Label',			tempcolor,...
				'ForeGroundColor',	tempcolor,...
				'BackGroundColor', 	[ 0.7 0.7 0.7 ],... 
				'Callback', 		[ ' changeme(''text'',''Color'', ',...
								  	  ' get( gcmenu,''Label'') );' ] );
	 end;
	 uimenu( tcolormenu,...
			 'Label',		'Specify [R,G,B]...',...
			 'Separator',	'on' ,...
		     'Callback',	[...
					' value = input(''Enter [ R, G, B ] triplet: '');',...
					' changeme(''text'',''Color'', value );' ] );
	%
	% SUBMENU: Text Orientation
	% ----------------------------------------------------------------
	  trotmenu = uimenu( TextMenu,  'Label',	'Orientation');

	  default = get(0,'DefaultTextRotation');
	  for idx = [ -90, 0, 90, 180 ] 
	     uimenu( trotmenu		,...
			 	'Label',		num2str(idx),...
				'ForeGround',	[ idx == default, 0, 0 ],...
				'BackGround', 	[ 0.7 0.7 0.7 ],... 
				'Callback', 	[ ' changeme(''text'',''Rotation'', ',...
						 	  	  ' str2num( get( gcmenu,''Label'') ) );' ] );
	  end;
	  uimenu( trotmenu		,...
			  'Label',		'Specify...',...
			  'Separator',	'on' ,...
		      'Callback',	[...
				' value = input(''Enter desired angle of orientation: '');',...
				' changeme(''text'',''Rotation'', value );' ] );
	%
	% SUBMENU: Mobilize (or park)
	% ----------------------------------------------------------------
		uimenu( TextMenu	,...
  				'Label',	'Move',...
				'Separator','on' ,...
				'Callback',	[...
		 					' selobj = findobj( gcf,''Selected'',''on'');',...
		 					' set( findobj( selobj,''Type'',''text''), ',...
							'''ButtonDownFcn'',''moveobj'');' ]);
		uimenu( TextMenu,...
  				'Label',	'Park',...
				'Callback',	[...
		 					' selobj = findobj( gcf,''Selected'',''on'');',...
		 					' set( findobj( selobj,''Type'',''text''), ',...
							'''ButtonDownFcn'','''');' ]);
	%
	% SUBMENU: Delete Text
	% ----------------------------------------------------------------
	 uimenu( TextMenu		,...
			 'Label',		'Hide',...
			 'Separator',	'on' ,...
			 'Callback', 	[ 'changeme(''text'',''Visible'',''off'');',...
							  'changeme(''text'',''Selected'',''off'');' ]);
	 uimenu( TextMenu		,...
			 'Label',		'Show Hidden',...
			 'Callback', 	[ ...
							' changeme(''text'',''Selected'',''off'');',...
							' set( findobj( findobj(''Visible'',''off''),',...
							' 	''Type'',''text''),''Visible'',''on'',',...
							'	''Selected'',''on'');' ]);
	 uimenu( TextMenu		,...
			 'Label',		'Delete',...
		     'Callback',	[...
					' delete( findobj( findobj( gcf,''Type'',''text''),',...
					' 			''flat'',''Selected'',''on'') );' ] );
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%                               REVISION HISTORY
%
% 03/31/95	Breaks off from addHamlet to become independent function.
%			Hide and Show Hidden added.
% 08/12/95  Object selection capability automatically added to window 
%			if no other WindowButtonDownFcn currently exists
