% CMTSDEMO  Demonstration program of the COMETS utility.

%  Kirill K. Pankratov,  kirill@plume.mit.edu
%  July 16, 1994

echo on

%       WELCOME TO THE  "COMETS" - MATLAB ANIMATION UTILITY!
%
%   This is a demo for one of the MATLAB "animation" program -
% COMETS. It stems from the original MATLAB program COMET which
% moves only one point with no choice of colors and linestyles.
% With the new COMETS one can produce a rather lively animation
% with many moving points or lines with chosen colors, linestyles
% and linewidths.
%   First, let's recall what the original MATLAB command COMET
% is all about. Since it is self-demonstrating, we can just invoke
% it without any input arguments:

 pause  % Hit any key to continue ...

 clg
 comet

%   The comet consists of 3 line objects - the "head", marked by 'o'
% the "body" which is a solid line and the tail - a solid line of
% different color.
%   It is often convenient to have many moving points - comets -
% simultaneously, as well as to control their parameters - colors,
% linestyle and linewidth. This is possible with the "vectorized"
% COMETS program which is demonstrated below.

 pause  % Hit any key to continue ...

%   Its general sintax is the following:
% COMETS(X,Y,P,COLOR,LINESTY,LINEWID) with the following input
% arguments:
% X,Y - coordinates of the comets, each column represent separate
%    comet: Y = [Y1 Y2 ... YN] for N comets.
% P - positive scalar from 0 to 1 - partial body length, default
%    is p = 0.1.
% COLOR = [CH1 CB1 CT1; CH2 CB2 CT2; ... ; CHN CBN CTN], where
%    CH - color of the head,  CB - body, CT - tail. The full format
%    is Nx3 string matrix if colors are letters (among 'rgbycmwk')
%    or Nx9 number matrix if colors are RGB triplets.
%    If color matrix has only one row then all the comets will have
%    the same color structure, if only one column - then heads,
%    bodies and tails of each comet will be of the same color.
% LINESTYLE = [LSH1 LSB1 LST1; ... ; LSHN LSBN LSTN], where LSH1 of
%    the size [1 2] is the linestyle of the head, etc. The full size
%    is Nx6 string matrix, each linestyle represented by [1 2] size 
%    string: 'o ', '- ', '--', etc.
%    For example LINESTYLE = ['x --- '; '* - -'] represents two comets:
%    the first one with the head 'x', the body '--' and the tail '-',
%    the second with the head '*', the body '-' and the tail '-'.    
% LINEWIDTH = [LWH1 LWB1 LWT1; ... LWHN LWBN LWTN], where LWH1
%    (positive integer) is the linewidth (or markersize) of the head,
%    etc. The full size is Nx3 matrix.

%   If all line property arguments (COLOR, LINESTYLE, LINEWIDTH)
% have only 1 row, then COMETS works in fast "vectorized" regime
% and all comets have the same colors and linestyles (only 3 line
% objects will be created). If any of these arguments have more than
% 1 row the total number of comets will be equal to the number of
% columns of matrices X and Y, each comet represented by 3 separate
% line objects (their movement is slower in this case).
% If the number of rows in the line property arguments is less than
% the number of columns in X and Y, then colors and linestyles will be
% cycled through.

 pause  % Hit any key to continue ...

%   As a first example we shall display 3 comets whose ordinates are
% cumulative sums (integrals) of random-normal sequences. 

 clg
 nstep = 200;          % Number of timesteps
 y = randn(nstep,3);   % Create 3 random-normal sequences
 y = cumsum(y);        % Sums of the sequences
 color = ('rgw')'      % Colors of all 3 comets

% !!! Notice that we made a column vector of colors.
% Were it a row vector 'rgw' it would be interpreted as 'r' - for
% a head, 'g' - or a body, 'w' - for a tail, all comets are of the
% same color.  !!!
% Now let's run the COMETS program with these arguments:

 pause  % Hit any key to continue ...

 comets(1:nstep,y,[],color)

%   To see the difference between the COLOR argument as a row and
% a column vector, let's transpose it:

 pause  % Hit any key to continue ...

 comets(1:nstep,y,[],color')

%   Now all 3 comets are of identical colors and styles. One can also
% notice that this latter case is faster. The reason is that only 
% one set of line objects is created - one "head", one "body" and
% one "tail" - 3 objects altogether.
%   Generally, if any of the line properties arguments - COLOR,
% LINESTYLE, LINEWIDTH consist of more than one row then each comet
% is represented by a separate set of 3 line objects. Total number
% of comets is equal to the number of columns of data matrices X and
% Y. For a large number of comets this can be slow. For faster 
% moving comets all the line properties arguments must be row vectors.
% This necessarily makes all of them to be similar in color and
% linestyles.
%   The linestyles of all the comets elements can be any of the
% available in MATLAB: -, --, -., :  for continuous lines and
% o, x, *, + for markers. In the "vectorized" case of 1 line for
% all the comets the heads, normally represented by marker 'o', can
% be continuous lines. In this case all the comets heads will be
% connected in one line. This can be desirable sometimes and can
% be used to produce rather neat effects.

 pause  % Hit any key to continue ...

% Here is an example of continuous-line comets:
 close
 nmode = 6;                % "Mode" number
 ncom = 60;                % Number of comets
 vrot = .2;                % "Angular velocity"
 nstep = 150;              % Numbert of timesteps
 r = (1:nstep)'/nstep;     % Radius
 th = (0:ncom)/ncom*2*pi;  % Angle
 a = .1;                   % Mode amplitude
 amp = 1+a*cos(th*nmode);
 er = ones(size(r));eth = ones(size(th));
 x = r(:,eth).*amp(er,:).*cos(vrot*2*pi*r(:,eth)+th(er,:));
 y = r(:,eth).*amp(er,:).*sin(vrot*2*pi*r(:,eth)+th(er,:));

 color = 'cwm';            % Colors (head, body, tail)
 linesty = '- ---';        % Solid line '-' for head,
                           %   dashed line '--' for body,
                           %   again solid line '-' for tail

 a1 = 1+a;
 axis([-a1 a1 -a1 a1]); hold on
 set(gca,'pos',[0 0 1 1])
 axis square, axis off

%   Now call the COMETS ...

 pause  % Hit any key to continue ...

 comets(x,y,.5,color,linesty)

 pause  % Hit any key to continue ...

%   Now another example. In this case we shall again create 3 comets
% of different color, but with thicker lines:

 r0 = .6;                            % Inner radius
 r1 = 2;                             % Outer radius
 n = 500;                            % Number of timesteps
 vrot = [100.194 100.197 100.200];   % "Angular velocities"
 th = (1:n)'/n*2*pi; th = th*vrot;
 R = [r0 r1]'*ones(1,n/2); R = R(:);
 x = R(:,ones(1,length(vrot))).*cos(th);
 y = R(:,ones(1,length(vrot))).*sin(th);

 color = ('ryc')';         % Colors for 3 comets
 lnwid = [6 4 4];          % Linewidth for head, body, tail

 pause  % Hit any key to continue ...

 close
 axis([-r1 r1 -r1 r1]), axis square, axis off, hold on, drawnow
 comets(x,y,0,color,[],lnwid)

%   Here we demonstrated some examples of usage of the COMETS command.
% With some imagination and practice one can produce much prettier
% and illustrative pictures than the ones shown in this demo.
%   As one more demonstration of the COMETS command try another
% accompanying program - FIREWORKS. Enjoy the salute!

%  If you have any problems or suggestions about this utility, please
% contact the author:
%   Kirill K. Pankratov:  kirill@plume.mit.edu

% Good luck. Thank you for your time. Bye.
 
echo off
