function cursores(fig)

%CURSORES lets the user set up to four
%cursors in a 2D figure, within which
%at least there's one line-object, and
%only one axes-object.
%It is an interactive grafic aid to
%extract numerical values
%It also lets the user perform mathematical
%operations (choosing one among seven
%predefined) between pairs of cursors
%ARGUMENT IN
%
%  'fig'   optional
%          indicates the figure over which
%          we want to operate. If not specified
%          uses 'gcf'
%___________________________________________________
%   Copyright (c) Pepe Moreno Andrades, Mayo-1996   
%
%       Grupo de Sistemas Fotonicos
%       DEPARTAMENTO DE TECNOLOGIA FOTONICA
%       E T S I TELECOMUNICACION 
%       UNIVERSIDAD POLITECNICA MADRID
%       28040 MADRID (SPAIN)
%       Tf:    (34)-1-3367318
%       Fax:   (34)-1-3367319
%       Email: pepe@tfo.upm.es
%
%
%	This Work has been supported by Spanish CICYT TIC95-0250-C02-01
%	Leadered by Professor: Miguel Angel Muriel
%________________________________________________________________________



%Analisis del argumento de entrada
if nargin<1,fig=gcf;end
if nargin==1,figure(fig);end

%Se comprueba que es una figura 2D
if get(gca,'View')~=[0 90];
   error('This function requires ''view''=[0 90]')
end

%Se analiza que en la figura no haya 'uicontrols'
fig_ch=get(fig,'Children');
lfc=length(fig_ch);
for i=1:lfc
   testigo1(i)=strcmp('uicontrol',get(fig_ch(i),'Type'));
end
if any(testigo1)
   error('This function supposes that there aren''t ''uicontrols'' in the figure')
end

%Se comprueba que solo haya un unico objeto tipo axes
for i=1:lfc
   axtest(i)=strcmp('axes',get(fig_ch(i),'Type'));
end
ax_number=find(axtest);
if length(ax_number)>1
   error('This function supposes that there''s only one axes object in the figure')
end
%Se comprueba que haya 'lineas' en la figura
ax_ch=get(gca,'Children');
lac=length(ax_ch);
for i=1:lac
   testigo2(i)=strcmp('line',get(ax_ch(i),'Type'));
end
if any(testigo2)==0
   error('This function supposes that there is one ''line'' at least in the figure')
end

%Registramos en un vector los 'handles' de las lineas
LINEAS=ax_ch(find(testigo2))';

%Redimensionamiento de la figura y ejes
%para dar cabida a los uicontrols
%OBSERVACION esta version de CURSOR05
%esta pensada para que se adapte a un
%monitor de 14 pulgadas trabajando con
%resolucion 800x600

set(fig,'Units','normalized','Position',[.001 .001 .995 .995])
set(gca,'Units','normalized','Position',[.35 .4 .6 .55])
set(gca,'Fontsize',10),figure(fig),hold on

%global LINEA_ACTIVA


%   ESTABLECIMIENTO DE UICONTROLS

%PushButton para Activar una Linea
AL=uicontrol(...
'Style','push',...
'Units','normalized','Position',[.01 .92 .25 .04],...
'String','Activate Line');


%Grupo de uicontrols para asignar cursores a la LINEA_ACTIVA

%Frame que las engloba
ACFrame=uicontrol(...
'Style','frame',...
'Units','normalized','Position',[.005 .73 .26 .18],...
'BackgroundColor',[.35 .35 .35]);

%Text para titularlo
ACTitulo=uicontrol(...
'Style','text',...
'Units','normalized','Position',[.01 .87 .25 .03],...
'BackgroundColor',[0 0 .6],...
'ForegroundColor',[1 1 1],...
'String','Assign Cursor');

%Check-box para Cursor-1
AC1=uicontrol(...
'Style','checkbox',...
'Units','normalized','Position',[.01 .83 .1 .03],...
'BackgroundColor',[.6 .83 .6],...
'String','Cursor_1');


%Check-box para Cursor-2
AC2=uicontrol(...
'Style','checkbox',...
'Units','normalized','Position',[.12 .83 .1 .03],...
'BackgroundColor',[.6 .83 .6],...
'String','Cursor_2');

%Check-box para Cursor-3
AC3=uicontrol(...
'Style','checkbox',...
'Units','normalized','Position',[.01 .79 .1 .03],...
'BackgroundColor',[.6 .83 .6],...
'String','Cursor_3');

%Check-box para Cursor-4
AC4=uicontrol(...
'Style','checkbox',...
'Units','normalized','Position',[.12 .79 .1 .03],...
'BackgroundColor',[.6 .83 .6],...
'String','Cursor_4');

%Push-Button para aceptar la asignacion de cursores
ACPush=uicontrol(...
'Style','PushButton',...
'Units','normalized','Position',[.01 .74 .12 .04],...
'String','Accept C');

%Push-Button para resetear los cursores
RCPush=uicontrol(...
'Style','PushButton',...
'Units','normalized','Position',[.14 .74 .12 .04],...
'String','Reset C',...
'CallBack','creset');


%Grupo de uicontrols para asignar funciones

%Frame que las engloba
AFFrame=uicontrol(...
'Style','frame',...
'Units','normalized','Position',[.005 .6 .26 .13],...
'BackgroundColor',[.35 .35 .35]);

%Text que lo titula
AFTitulo=uicontrol(...
'Style','text',...
'Units','normalized','Position',[.01 .69 .25 .03],...
'BackgroundColor',[0 0 .6],...
'ForegroundColor',[1 1 1],...
'String','Assign Function');

%Radio-Button para la Funcion-1
AF1=uicontrol(...
'Style','radio',...
'Units','normalized','Position',[.01 .65 .1 .03],...
'String','Function_1',...
'BackgroundColor',[.6 .83 .6]);

%Radio-Button para la Funcion-2
AF2=uicontrol(...
'Style','radio',...
'Units','normalized','Position',[.12 .65 .1 .03],...
'String','Function_2',...
'BackgroundColor',[.6 .83 .6]);

%Pop-up Menu para escoger funcion
AFPopup=uicontrol(...
'Style','popup',...
'Units','normalized','Position',[.01 .61 .1 .08],...
'String','Difference|Add|Multiply|Ratio/|Ratio\|dBc|dBi');

%Push-Button para aceptar la asignacion
AFPush=uicontrol(...
'Style','Push',...
'Units','normalized','Position',[.12 .61 .1 .03],...
'String','Accept F');

%Grupo de uicontrols para editar las lineas

%Frame que las engloba
ELFrame=uicontrol(...
'Style','frame',...
'Units','normalized','Position',[.005 .4 .26 .2],...
'BackgroundColor',[.35 .35 .35]);

%Text que lo titula
ELTitulo=uicontrol(...
'Style','text',...
'Units','normalized','Position',[.01 .56 .25 .03],...
'BackgroundColor',[0 0 .6],...
'ForegroundColor',[1 1 1],...
'String','Edit Line');

%Text para asignar color
ELCText1=uicontrol(...
'Style','text',...
'Units','normalized','Position',[.01 .52 .07 .03],...
'BackgroundColor',[.85 .85 .85],...
'String','Color');

%Slider para desplazar colores
%ELCSlider=uicontrol(...
%'Style','slider',...
%'Units','normalized','Position',[.09 .52 .1 .03],...
%'min',.01,'max',1,'value',.01);

%PushButton para elegir colores
ELCPush=uicontrol(...
'Style','push',...
'Units','normalized','Position',[.09 .52 .1 .03],...
'String','Choose Color');


%Text para mostrar color
ELCText2=uicontrol(...
'Style','text',...
'Units','normalized','Position',[.2 .52 .05 .03],...
'BackgroundColor',[.5 0 0]);

%Text para asignar grosor
ELGText1=uicontrol(...
'Style','text',...
'Units','normalized','Position',[.01 .48 .07 .03],...
'BackgroundColor',[.85 .85 .85],...
'String','Width');

%Slider para elegir grosor
ELGSlider=uicontrol(...
'Style','slider',...
'Units','normalized','Position',[.09 .48 .1 .03],...
'min',.5,'max',50.5,'value',.5);

%Text para mostrar grosor
ELGText2=uicontrol(...
'Style','text',...
'Units','normalized','Position',[.2 .48 .05 .03],...
'String','0.5',...
'BackgroundColor',[.85 .85 .85]);

%Pop-up Menu para seleccionar tipo de linea
ELPopup=uicontrol(...
'Style','popup',...
'Units','normalized','Position',[.01 .44 .1 .03],...
'String','Solid|Dash|Dotted|Dash-dot');

%PushButton para aceptar la seleccion
ELPush=uicontrol(...
'Style','push',...
'Units','normalized','Position',[.12 .44 .1 .03],...
'String','Accept EL');


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%grupo de uicontrols que definen los cursores y funciones%
%para dotar a este grupo de una estructura visual que    %    
%facilite el trabajo, habra multiples frames             % 
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%



%Frame que los engloba
CFFrame=uicontrol(...
'Style','frame',...
'Units','normalized','Position',[.005 .19 .98 .15],...
'BackgroundColor',[1 1 1]);

%text coordenada de abscisas
CFAbscisa=uicontrol(...
'Style','text',...
'Units','normalized','Position',[.01 .205 .07 .03],...
'String','X-value',...
'BackgroundColor',[0 0 .6],...
'ForegroundColor',[1 1 1]);

%text coordenada de ordenada
CFOrdenada=uicontrol(...
'Style','text',...
'Units','normalized','Position',[.01 .24 .07 .03],...
'String','Y-value',...
'BackgroundColor',[0 0 .6],...
'ForegroundColor',[1 1 1]);

%Frame para Cursor1
C1Frame=uicontrol(...
'Style','frame',...
'Units','normalized','Position',[.09 .2 .15 .13],...
'BackgroundColor',[0 0 0]);

%PushButton para el Cursor 1
C1Push=uicontrol(...
'Style','push',...
'Units','normalized','Position',[.1 .28 .13 .03],...
'String','Cursor 1');


%Texto Editable para Cursor1_abscisa
C1abs=uicontrol(...
'Style','edit',...
'Units','normalized','Position',[.1 .21 .13 .03],...
'BackgroundColor',[.75 .75 .75],...
'ForegroundColor',[0 0 0]);

%Texto Editable para Cursor1_ordenada
C1ord=uicontrol(...
'Style','edit',...
'Units','normalized','Position',[.1 .245 .13 .03],...
'BackgroundColor',[.75 .75 .75],...
'ForegroundColor',[0 0 0]);

%Frame para Cursor2
C2Frame=uicontrol(...
'Style','frame',...
'Units','normalized','Position',[.25 .2 .15 .13],...
'BackgroundColor',[0 0 0]);

%PushButton para el Cursor 2
C2Push=uicontrol(...
'Style','push',...
'Units','normalized','Position',[.26 .28 .13 .03],...
'String','Cursor 2');


%Texto Editable para Cursor2_abscisa
C2abs=uicontrol(...
'Style','edit',...
'Units','normalized','Position',[.26 .21 .13 .03],...
'BackgroundColor',[.75 .75 .75],...
'ForegroundColor',[0 0 0]);

%Texto Editable para Cursor2_ordenada
C2ord=uicontrol(...
'Style','edit',...
'Units','normalized','Position',[.26 .245 .13 .03],...
'BackgroundColor',[.75 .75 .75],...
'ForegroundColor',[0 0 0]);

%Text para la Funcion 1
F1=uicontrol(...
'Style','text',...
'Units','normalized','Position',[.41 .28 .13 .03],...
'String','Function 1',...
'BackgroundColor',[.6 .83 .6]);

%Texto Editable para Funcion 1 Abscisa
F1abs=uicontrol(...
'Style','edit',...
'Units','normalized','Position',[.41 .245 .13 .03],...
'BackgroundColor',[.85 .85 .85]);

%Texto Editable para Funcion 1 Ordenada
F1ord=uicontrol(...
'Style','edit',...
'Units','normalized','Position',[.41 .21 .13 .03],...
'BackgroundColor',[.85 .85 .85]);

%Frame para Cursor3
C3Frame=uicontrol(...
'Style','frame',...
'Units','normalized','Position',[.55 .2 .15 .13],...
'BackgroundColor',[0 0 0]);

%PushButton para el Cursor 3
C3Push=uicontrol(...
'Style','push',...
'Units','normalized','Position',[.56 .28 .13 .03],...
'String','Cursor 3');


%Texto Editable para Cursor3_abscisa
C3abs=uicontrol(...
'Style','edit',...
'Units','normalized','Position',[.56 .21 .13 .03],...
'BackgroundColor',[.75 .75 .75],...
'ForegroundColor',[0 0 0]);

%Texto Editable para Cursor3_ordenada
C3ord=uicontrol(...
'Style','edit',...
'Units','normalized','Position',[.56 .245 .13 .03],...
'BackgroundColor',[.75 .75 .75],...
'ForegroundColor',[0 0 0]);

%Frame para Cursor4
C4Frame=uicontrol(...
'Style','frame',...
'Units','normalized','Position',[.7 .2 .15 .13],...
'BackgroundColor',[0 0 0]);

%PushButton para el Cursor 4
C4Push=uicontrol(...
'Style','push',...
'Units','normalized','Position',[.71 .28 .13 .03],...
'String','Cursor 4');


%Texto Editable para Cursor4_abscisa
C4abs=uicontrol(...
'Style','edit',...
'Units','normalized','Position',[.71 .21 .13 .03],...
'BackgroundColor',[.75 .75 .75],...
'ForegroundColor',[0 0 0]);

%Texto Editable para Cursor4_ordenada
C4ord=uicontrol(...
'Style','edit',...
'Units','normalized','Position',[.71 .245 .13 .03],...
'BackgroundColor',[.75 .75 .75],...
'ForegroundColor',[0 0 0]);

%Text para la Funcion 2
F2=uicontrol(...
'Style','text',...
'Units','normalized','Position',[.85 .28 .13 .03],...
'String','Function 2',...
'BackgroundColor',[.6 .83 .6]);

%Texto Editable para Funcion 2 Abscisa
F2abs=uicontrol(...
'Style','edit',...
'Units','normalized','Position',[.85 .245 .13 .03],...
'BackgroundColor',[.85 .85 .85]);

%Texto Editable para Funcion 2 Ordenada
F2ord=uicontrol(...
'Style','edit',...
'Units','normalized','Position',[.85 .21 .13 .03],...
'BackgroundColor',[.85 .85 .85]);

%Texto Estatico para los mensajes
M=uicontrol(...
'Style','edit',...
'HorizontalAlignment','left',...
'Units','normalized','Position',[.01 .01 .98 .17],...
'BackgroundColor',[0.75 .75 .75],...
'ForegroundColor',[0 0 0],...
'min',0,'max',2);

%Se establecen las cruces que representaran
%a los cuatro cursores posibles

%primero se averiguan los valores limites
%de las coordenadas en la figura
Xl=get(gca,'xlim');
Yl=get(gca,'ylim');

%Se crean las cruces
C1cruz=plot(Xl(1),Yl(1),'+',...
'MarkerSize',50,'visible','off');
C2cruz=plot(Xl(1),Yl(1),'+',...
'MarkerSize',50,'visible','off');
C3cruz=plot(Xl(1),Yl(1),'+',...
'MarkerSize',50,'visible','off');
C4cruz=plot(Xl(1),Yl(1),'+',...
'MarkerSize',50,'visible','off');

figui=[AL,ACFrame,ACTitulo,AC1,AC2,AC3,AC4,ACPush,...
AFFrame,AFTitulo,AF1,AF2,AFPopup,AFPush,...
ELFrame,ELTitulo,...
ELCText1,ELCPush,ELCText2,...
ELGText1,ELGSlider,ELGText2,...
ELPopup,ELPush,...
CFFrame,CFOrdenada,CFAbscisa,...
C1Frame,C1Push,C1ord,C1abs,...
C2Frame,C2Push,C2ord,C2abs,...
F1,F1ord,F1abs,...
C3Frame,C3Push,C3ord,C3abs,...
C4Frame,C4Push,C4ord,C4abs,...
F2,F2ord,F2abs,...
M];

Cruces=[C1cruz,C2cruz,C3cruz,C4cruz];

set(fig,'UserData',[figui,Cruces,LINEAS]);

set(AL,'Callback',['calcb'])



msg1='                          SUGGESTED OPERATING MODE:';
msg2='Make one Line Active:		1-Press ''Activate Line''			2-Press over or near a line';
msg3='Optionally Edit the Line:		1-Choose Color, Width and Style		2-Press ''Accept EL''';
msg4='Assign Cursor/s to that Line:		1-Select the CheckBoxes			2-Press ''Accept C''';
msg5='Optionally Assign a Function:		1-Select RadioButtons			2-Choose function from the PopupMenu        3-Press over ''Accept F''';
msg6='Operate a Cursor:			1-Press its PushButton			2-Press inside the axis and move the mouse';
msg7='                  WARNING:   F(x) is always the DIFFERENCE Ci(x)-Cj(x)';
set(M,'String',str2mat(msg1,msg2,msg3,msg4,msg5,msg6,msg7))

