% DENSITYXY Plot the density contours of a scatterplot.  
% [cont] = densityxy( x, y, xbin, ybin, numconts);
% Parameters:
% x: The vector of x values
% y: The vector of y values
% xbin: The number of bins along the x-axis you want
% ybin: The number of bins along th y-axis you want
% numconts: The number of contours to use in your density plot
% Returns:
% cont: Contour structure for labeling
%
% Example:
% Plot 25 density contours for xvar by yvar, with 1% bin size.
% cs = densityxy( xvar, yvar, 100, 100, 25);
% 
% Any questions, contact Christopher Keane (keane@jei.umd.edu)

function [cont] = densityxy(x, y, xbin, ybin, numconts)

xmin = min(x);
xmax = max(x);
ymin = min(y);
ymax = max(y);

grid = zeros(xbin+1, ybin+1);   % Create the output matrix

xstep = (xmax-xmin)/xbin;
ystep = (ymax-ymin)/ybin;

for i=1:size(x)		% Check each point
	
	xtemp = fix( ( x(i)-xmin ) / xstep +1);
	ytemp = fix( ( y(i)-ymin ) / ystep +1);


	grid(ytemp, xtemp) = grid(ytemp, xtemp)+1;
end


cont = contour(grid, numconts);
return;


