function figedit(option)
% FIGEDIT Interactive 2-D plot manipluation/annotation.
%         (MS Windows only)
%
% FIGEDIT adds extra menu options to an existing figure
% that allows the user to add, move and edit graphics objects,
% examine data points, scroll and zoom data axes.
% 
% Features include:
% 1) Most MATLAB 2-D plot capabilities available from pull-down
%    menus.
% 2) Extensions to standard MATLAB graphics objects in the form of
%    keys and arrows.
% 3) Values of individual data points can be displayed using the 
%    right-hand mouse button.
% 4) Particulary good at handling multiple axes and large data sets.
%    X axes can be "linked" so that changes to one is reflected in 
%    others and x-axes can be scrolled using pushbuttons attached to 
%    the figure.
% 5) All printing functions can be achieved using dialog boxes 
%    accessible from pull down menus.
% 6) Plots can be saved to MATLAB data files for later editing or
%    printing.
% 
% To use FIGEDIT simply run it after a plot has been created,
% e.g.  
%
%           plot(1:10); figedit;
%
% FIGEDIT will add extra menu's and create a dialog text line at the
% top of the figure. "ginput" will be in operation and pressing the
% l-h mouse button will display the current cursor position 
% and pressing the r.h mouse button will annotate the closest data
% point to the cursor with a cross. To return to the command window 
% enter the RETURN key, and to use FIGEDIT again simply re-enter 
% "figedit".
%
% FIGEDIT has the following command line options,
%
% figedit('resize') - Will re-size axes to maximize space in the
%                     figure and allow extra space for the dialog
%                     line.
% figedit('linkx')  - Used with multiple axes and will link the axes
%                     so that changes to one axis are reflected in all 
%                     others.
%
% If the figure contains multiple axes then radio buttons are added
% to the top right-corner of each axis. The enabled button will
% show which axis is current and all menu options etc. will operate on
% this axis. To change the current axis simply click on a new axis
% (clicking on the radio buttons will NOT do this). 
%
% The line styles and colours of data lines can be changed using the key 
% dialog box ("Edit key" option from the "Edit/Add" menu). Up to two
% linestyles can be used with each data line by concatenating two 
% linestyle/colour descriptions together, 
% e.g. to plot a yellow solid line with green stars at each data 
%      point enter "y-g*" in the style edit box.
%
% Plots can be printed using the "Print" pull down menu and can
% be stored and retrieved using the "Save/Load" pull down menus.
%
% For more information and details contact,
% Rob Oldaker at   20 Fairfield Park Road,
%                     Bath, 
%                      UK.
%                  Tel (01225) 312933
%		   Email "R.S.Oldaker@e-eng.hull.ac.uk"
%
% A NOTE ABOUT IMPLENTATION 
% FIGEDIT uses the prefix "FG" to all global variables it uses
% and has only been tested on MATLAB V4.2. It uses functions
% FINDOBJ, DEBLANK, STR2MAT which I think were not available on
% V4.0. For anyone running v4.0 I do have m-file versions of these
% functions.
%
% A NOTE ABOUT THE AUTHOR:
% The author is now unfortunately unemployed and struggling
% to find a job and complete his PhD. If you find this package
% very useful then any job offers/financial donations would be 
% very appreciated (I have a background in applied maths, 
% control theory and computing).
% 
global FGkey
global FGfig_mode
global FGhsdaxis
global FGlinkx FGfigmu FGfigmw FGfigmh

% this means we're starting it up
if nargin==0
   option='';
end

if strcmp(option,'linkx')
   soption='resize';
   FGlinkx=1;
else
   soption=option;
end

if length(FGlinkx)==0
   FGlinkx=0;
end
% the figure units and position is stored in global memory
% so if they don't exist set to the current figure size
if length(FGfigmu)==0
      FGfigmu='inches';
end   
if length(FGfigmw)==0
   cunits=get(gcf,'units');
   set(gcf,'units',FGfigmu);
   pos=get(gcf,'position');
   FGfigmw=pos(3);
   FGfigmh=pos(4);
   set(gcf,'units',cunits);
end   


figstart(soption);
FGfig_mode=1;
cont=1;

figmess('FIGEDIT v1.0 left and right mouse buttons are active')

while(cont)
   [x,y,FGkey,pb]=figginp;
   if FGfig_mode==1
      if FGkey==13
% return key so exit
         cont=0;
         FGfig_mode=0;
      elseif FGkey==3
% right hand mouse button so show nearest point
         [xp,yp,index,hl]=fignear(FGhsdaxis,x,y);
         figselp('position',xp,yp,index,hl);
      elseif ~pb
% other wise show current cursor position
         figmess(sprintf('x=%-14.4g y=%-14.4g',x,y));
% get rid of any selected points
         figselp('remove');
      end
   elseif FGfig_mode==2
      figtext('check');
   elseif FGfig_mode==3
      figarrow('check');
   elseif FGfig_mode==4
      figkey('check');
   end

end

% disable uimenu's!
figmena(0);
figmess('');
return
end
