function figload(filename)

global FGfigmu FGfigmw FGfigmh FGlinkx

if nargin==0
   [fn,path]=uigetfile('*.fig','Enter file');
   if fn(1)==0 return; end
   filename=[path fn];
end
if length(filename)==0 return; end

eval(['load ' filename ' /mat']);

haxis=findobj(gcf,'type','axes');
delete(haxis);
hselb=findobj(gcf,'style','radiobutton');
delete(hselb);


% set up the figure position units and paper info
FGfigmu=deblank(unitslist(figdata(1),:));
FGfigmw=figdata(2);
FGfigmh=figdata(3);
FGlinkx=figdata(4);
set(gcf,'paperunits',unitslist(figdata(5),:));
set(gcf,'paperposition',figdata(6:9));
set(gcf,'papertype',papertypelist(figdata(10),:));
set(gcf,'paperorientation',orientationlist(figdata(11),:));

[no_dataaxes,n]=size(axesdata);
for i=1:no_dataaxes
% create an axis object
   axispos=axesdata(i,1:4);
   xlim=axesdata(i,5:6); ylim=axesdata(i,7:8);
   if axesdata(i,9)
      grid='on';
   else
      grid='off';
   end
   if axesdata(i,10)
      visible='on';
   else
      visible='off';
   end
   fn=deblank(fontlist(axesdata(i,11),:));
   fs=axesdata(i,12);
   hdata=axes('position',axispos,...
              'xlim',xlim,...
              'ylim',ylim,...
              'xgrid',grid,'ygrid',grid,...
              'visible',visible,...
              'fontname',fn,...
	      'box','on',...
   	      'fontsize',fs);
   figsa(hdata,0,0);
% add the lines!
   eval(['linedata=linedata' int2str(i) ';']);
   [no_lines,n]=size(linedata);
   for j=1:no_lines
      eval(['xdata=xdata' int2str(i) int2str(j) ';']);
      eval(['ydata=ydata' int2str(i) int2str(j) ';']);
      if linedata(j,1)
         visible='on';
      else
         visible='off';
      end
      ls=stylelist(linedata(j,2));
      col=linedata(j,3:5);
      lw=linedata(j,6);
      hline=line('xdata',xdata,'ydata',ydata,...
              'linestyle',ls,'color',col,'visible',visible);
      hextr=0;
      if linedata(j,7)~=0
         ls=stylelist(linedata(j,7));
         col=linedata(j,8:10);
         lw=linedata(j,11);
         ud='extraline';
         ud(2,1)=hline;
         hextr=line('xdata',xdata,'ydata',ydata,...
                    'linestyle',ls,'color',col,...
                    'visible',visible,...
		    'userdata',setstr(ud));
      end
      ud='dataline';
      ud(2,1)=0;
      ud(2,3)=hextr;
      set(hline,'userdata',setstr(ud));
   end

% titles and labels
   eval(['labels=labels' int2str(i) ';']);
   eval(['labelsdata=labelsdata' int2str(i) ';']);
   htest(1)=get(hdata,'title');
   htest(2)=get(hdata,'xlabel');
   htest(3)=get(hdata,'ylabel');
   for j=1:3
      fn=deblank(fontlist(labelsdata(j,1),:));
      fs=labelsdata(j,2);
      fw=fontweightlist(labelsdata(j,3),:);
      fa=fontanglelist(labelsdata(j,4),:);
      set(htest(j),'fontname',fn,'fontsize',fs,...
                   'fontweight',fw,'fontangle',fa,...
                   'string',deblank(labels(j,:)));
   end

% Now for the text and arows!?!
   eval(['textdata=textdata' int2str(i) ';']);
   [no_textobjects,n]=size(textdata);
   eval(['textstrings=textstrings' int2str(i) ';']);

   eval(['arrowdata=arrowdata' int2str(i) ';']);
   [no_arrowobjects,n]=size(arrowdata);
   
% create addition axis object for the text and/or arrows
   if no_textobjects>0 | no_arrowobjects>0
      htext=axes('position',axispos,...
              'xlim',[0 1],...
              'ylim',[0 1],...
              'visible','off');
% set up the userdata are for other axes
      figsa(hdata,htext,0);
   end
% the text
   for j=1:no_textobjects
      pos=textdata(j,1:3);
      un=unitslist(textdata(j,4),:);
      fn=deblank(fontlist(textdata(j,5),:));
      fs=textdata(j,6);
      fw=fontweightlist(textdata(j,7),:);
      fa=fontanglelist(textdata(j,8),:);
      rt=textdata(j,9);
      ul=textdata(j,10);
      if ul
         ul='on';
      else
         ul='off';
      end
      patchback=textdata(j,11);
      ha=halignmentlist(textdata(j,12),:);
      va=valignmentlist(textdata(j,13),:);
      tstring=deblank(textstrings(j,:));
      if patchback
         textpatch('string',tstring,'units',un,'position',pos,...
              'fontname',fn,'fontsize',fs,'fontweight',fw,...
              'fontangle',fa,'rotation',rt,'fontunderline',ul,...
              'horizontalalignment',ha,'verticalalignment',va);
 
      else
         text('string',tstring,'units',un,'position',pos,...
              'fontname',fn,'fontsize',fs,'fontweight',fw,...
              'fontangle',fa,'rotation',rt,'fontunderline',ul,...
              'horizontalalignment',ha,'verticalalignment',va);
      end
   end

% and now the arrows...
   for j=1:no_arrowobjects
      sp=arrowdata(j,1:2);
      fp=arrowdata(j,3:4);
      ls=stylelist(arrowdata(j,5),:);
      lw=arrowdata(j,6);
      col=arrowdata(j,7:9);
      hl=arrowdata(j,10);
      ha=arrowdata(j,11);
      arrow(sp,fp,hl,ha,lw,col,ls);
   end

   axes(hdata);
% now for the key
   eval(['keydata=keydata' int2str(i) ';']);
   eval(['keystrings=keystrings' int2str(i) ';']);
   if length(keydata)>0
      tstrings=[];
% use "key" to create the key axis and plot the key...
      x=keydata(1); y=keydata(2);
      bfill=keydata(3);
      fn=fontlist(keydata(4),:);
      fs=keydata(5);
      key(x,y,keystrings,bfill,fn,fs);
   end
end
