function figsave

global FGhd FGfigmu FGfigmw FGfigmh FGlinkx

[fn,path]=uiputfile('*.fig','Save figure to file');
if fn(1)==0 return; end
filename=[path fn];

fid=fopen(filename,'w');

no_dataaxes=length(FGhd);

stylelist=[];
fontlist=[];
unitslist=[];
fontweightlist=[];
fontanglelist=[];
halignmentlist=[];
valignmentlist=[];
papertypelist=[];
orientationlist=[];
axesdata=zeros(no_dataaxes,12);

% first find figure data
[mui,unitslist]=strindex(unitslist,FGfigmu);
[pui,unitslist]=strindex(unitslist,get(gcf,'paperunits'));
paperpos=get(gcf,'paperposition');
[pti,papertypelist]=strindex(papertypelist,get(gcf,'papertype'));
[poi,orientationlist]=strindex(orientationlist,get(gcf,'paperorientation'));

figdata=[mui FGfigmw FGfigmh FGlinkx pui paperpos pti poi];

matsave(fid,figdata,'figdata');

for i=1:no_dataaxes
% obtain axis handles of text and key axes
   [hdata,htext,hkey]=figga(FGhd(i));

% obtain data axes info
   cunits=get(hdata,'units');
   set(hdata,'units','normalized');
   pos=get(hdata,'position');
   set(hdata,'units',cunits);
   xlim=get(hdata,'xlim');
   ylim=get(hdata,'ylim');
   grid=get(hdata,'xgrid');
   if strcmp(grid,'on')
      grid=1;
   else
      grid=0;
   end
   visible=get(hdata,'visible');
   if strcmp(visible,'on')
      visible=1;
   else
      visible=0;
   end
   [fni,fontlist]=strindex(fontlist,get(hdata,'fontname'));
   fs=get(hdata,'fontsize');
   axesdata(i,:)=[pos xlim ylim grid visible fni fs];

% and labels...
   labelsdata=zeros(3,4);
   hlabs(1)=get(hdata,'title');
   hlabs(2)=get(hdata,'xlabel');
   hlabs(3)=get(hdata,'ylabel');
   for j=1:3
      [fni,fontlist]=strindex(fontlist,get(hlabs(j),'fontname'));
      fs=get(hlabs(j),'fontsize');
      [fwi,fontweightlist]=strindex(fontweightlist,get(hlabs(j),'fontweight'));
      [fai,fontanglelist]=strindex(fontanglelist,get(hlabs(j),'fontangle'));
      labelsdata(j,:)=[fni fs fwi fai];
   end
   labels=get(hlabs(1),'string');
   labels=str2mat(labels,get(hlabs(2),'string'));
   labels=str2mat(labels,get(hlabs(3),'string'));

   matsave(fid,labels,['labels' int2str(i)]);
   matsave(fid,labelsdata,['labelsdata' int2str(i)]);

% obtain line objects from data axis
   htest=findobj(hdata,'type','line');
   [m,n]=size(htest);
   linedata=zeros(m,11);
   keystrings=[];
% obtain valid data lines
   no_graphs=0;
% perform in reverse order?
   for j=length(htest):-1:1
      hline=0; hextr=0; hkeytext=0;
      ud=get(htest(j),'userdata');
      [m,n]=size(ud);
      if m>0
         if strcmp(ud(1,:),'dataline')
            no_graphs=no_graphs+1;
            hline=htest(j);
            hextr=abs(ud(2,3));
% store any key text
            hkeytext=abs(ud(2,2));
         end
      else
         no_graphs=no_graphs+1;
         hline=htest(j);
      end

      if hline~=0
         xdata=get(hline,'xdata');
         ydata=get(hline,'ydata');
         if strcmp(get(hline,'visible'),'on')
            visible=1;
         else
	    visible=0;
         end
         ls=get(hline,'linestyle');
         [lsn,stylelist]=strindex(stylelist,ls);
         col=get(hline,'color');
         lw=get(hline,'linewidth');
% check for extra styles
         if hextr~=0
            lse=get(hextr,'linestyle');
            [lsen,stylelist]=strindex(stylelist,lse);
            cole=get(hextr,'color');
            lwe=get(hextr,'linewidth');
         else
            lsen=0; cole=[0 0 0]; lwe=0;
         end
         linedata(no_graphs,:)=[visible lsn col lw lsen cole lwe];
         if hkeytext==0
            tstring='';
         else
            tstring=get(hkeytext,'string');
         end
         if no_graphs==1
            keystrings=tstring;
         else
            keystrings=str2mat(keystrings,tstring);
         end
         matsave(fid,xdata,['xdata' int2str(i) int2str(no_graphs)]);
         matsave(fid,ydata,['ydata' int2str(i) int2str(no_graphs)]);
      end
   end
   linedata=linedata([1:no_graphs],:);
   matsave(fid,linedata,['linedata' int2str(i)]);
   matsave(fid,keystrings,['keystrings' int2str(i)]);

% text objects
   textstrings=[];
   textdata=[];
   arrowdata=[];

   htest=findobj(hdata,'type','text');
   if length(htest)<=4
      htest=[];
   else
% don't count title and xlabels etc
      for j=1:3
         htest=htest(htest~=hlabs(j));
% this is so when re-loading the text will come out on the
% normalized text axis
      end
      set(htest,'units','normalized');
   end
   if htext~=0
      htest=[htest;findobj(htext,'type','text')];
   end
   for j=1:length(htest)
      tstring=get(htest(j),'string');
      if length(tstring)>0
         if length(textstrings)==0
            textstrings=tstring;
         else
            textstrings=str2mat(textstrings,tstring);
         end
% position is defined as three element array for
% units='data' and 'normalized' but a two element array
% for all others
         pos=get(htest(j),'position');
         if length(pos)==2
            pos=[pos 0];
         end
         [uni,unitslist]=strindex(unitslist,get(htest(j),'units'));
         [fni,fontlist]=strindex(fontlist,get(htest(j),'fontname'));
         fs=get(htest(j),'fontsize');
         [fwi,fontweightlist]=strindex(fontweightlist,get(htest(j),'fontweight'));
         [fai,fontanglelist]=strindex(fontanglelist,get(htest(j),'fontangle'));
         ul=get(htest(j),'fontunderline');
         if strcmp(ul,'on')
            ul=1;
         else
            ul=0;
         end
         rt=get(htest(j),'rotation');
         ud=get(htest(j),'userdata');
         [m,n]=size(ud);
         patch=0;
         if m>0
            if strcmp(ud(1,:),'textpatch')
               patch=1;
            end
         end
         [hai,halignmentlist]=strindex(halignmentlist,get(htest(j),'horizontalalignment'));
         [vai,valignmentlist]=strindex(valignmentlist,get(htest(j),'verticalalignment'));
         textdata=[textdata;pos uni fni fs fwi fai rt ul patch hai vai];
      end
   end

% arrow objects
   if htext~=0
      htest=findobj(htext,'type','line');
      for j=1:length(htest)
         ud=get(htest(j),'userdata');
         [m,n]=size(ud);
         if m>0
            if strcmp(ud(1,:),'arrow')
               xd=get(htest(j),'xdata');
               yd=get(htest(j),'ydata');
% calaculate start and finish positions of the
% arrow which is the start of the line
% and the head of the patch
	       xp=get(abs(ud(2,2)),'xdata');
	       yp=get(abs(ud(2,2)),'ydata');
               sp=[xd(1) yd(1)]; fp=[xp(1) yp(1)];
               hl=abs(ud(3,1)); % headlength
               ha=abs(ud(3,2)); % headangle
               [lsn,stylelist]=strindex(stylelist,get(htest(j),'linestyle'));
               lw=get(htest(j),'linewidth');
               col=get(htest(j),'color');
               arrowdata=[arrowdata;sp fp lsn lw col hl ha];
            end
         end
      end
   end
   matsave(fid,textdata,['textdata' int2str(i)]);
   matsave(fid,textstrings,['textstrings' int2str(i)]);
   matsave(fid,arrowdata,['arrowdata' int2str(i)]);

% key
   keydata=[];
   if hkey~=0
% obtain the normalized position relative to its data axis
      cunits=get(hdata,'units');
      set(hdata,'units','normalized');
      pos=get(hdata,'position');
      set(hdata,'units',cunits);
      kpos=get(hkey,'position');
      xk=(kpos(1)-pos(1))/pos(3);
      yk=(kpos(2)+kpos(4)-pos(2))/pos(4);
      if strcmp(get(hkey,'visible'),'on')
         bfill=1;
      else
         bfill=0;
      end
      hchar=findobj(hkey,'userdata','hchar');
      [fni,fontlist]=strindex(fontlist,get(hchar,'fontname'));
      fs=get(hchar,'fontsize');
      keydata=[xk yk bfill fni fs];
   end
   matsave(fid,keydata,['keydata' int2str(i)]);

end

matsave(fid,stylelist,'stylelist');
matsave(fid,fontlist,'fontlist');
matsave(fid,unitslist,'unitslist');
matsave(fid,fontanglelist,'fontanglelist');
matsave(fid,fontweightlist,'fontweightlist');
matsave(fid,halignmentlist,'halignmentlist');
matsave(fid,valignmentlist,'valignmentlist');
matsave(fid,papertypelist,'papertypelist');
matsave(fid,orientationlist,'orientationlist');
matsave(fid,axesdata,'axesdata');

fclose(fid);
