function cloglog(x,y,par)
%CLOGLOG  Same as CPLOT but using log-log scales. See CPLOT
%	  This is for MATLAB version 3.5 !

%	@LEM U. Kaestli 7-7-93
%
%	calls getplarg.m for breaking up the plot parameter string
%
if nargin < 1, error('Not enough input arguments.'); end
if nargin > 3, error('Too many input arguments.'); end

%set defaults

lwuscale  = '0.218';	% scale 1 linewdith_unit to approx. 1/8 point
linewidth = '3';	% default linewidth 3/8 points
linecol   = 'c1';	% black color for all lines
linetype  = '';		% auto selection of linetype
x_and_y_ismatrix=0;


%scan input arguments

if nargin == 1,
  if any(any(imag(x)) ~= 0),	% handle complex x
    y=imag(x);
    x=real(x);
    [rx,cx]=size(x);
    if rx == 1,		% if not column vector or matrix
      x=x';		% guarantee column vectors (needed
      y=y';		% for proper axis selection below)
    end
  else
    [rx,cx]=size(x);
    if rx == 1		% x is a row vector
      y=x';
      x=(1:cx)';
    else		% x is a column vector or matrix
      y=x;
      x=(1:rx)';
    end
  end

elseif nargin >= 2,
  if isstr(y),		% only x is a vector or matrix
    par=y;		% y is string for ploting parameters
    if any(any(imag(x)) ~= 0),	% handle complex x
      y=imag(x);
      x=real(x);
      [rx,cx]=size(x);
      if rx == 1,	% if row vector
	x=x';		% guarantee column vectors
	y=y';
      end
    else
      [rx,cx]=size(x);
      if rx == 1,		% x is a row vector
	y=x';			% guarantee column vector
        x=(1:cx)';
      else			% x is a matrix or
	y=x;			% column vector
        x=(1:rx)';
      end
    end
  else			% x and y is given
    [rx,cx]=size(x);	
    if rx == 1,		% guarantee column vector
      x=x';
      rx=cx;
      cx=1;
    end
    [ry,cy]=size(y);	% guarantee column vector
    if ry == 1,
      y=y';
      ry=cy;
      cy=1;
    end
    if cx == 1,		% if x is vector
      if ry ~= rx,
	if cy ~= rx,
	  error('Vectors must be the same lengths')
	else
	  y=y.';		% arrange y
	  [ry,cy]=size(y);
	end
      end
    else			% x is matrix, y must have same
      if cy == 1,		% dimension or be a vector
        if rx ~= ry,
	  if cx ~= ry,
	    error('Vectors must be the same lengths')
	  else
	    x=x.';		% arrange x
	    [rx,cx]=size(x);
	  end
        end
      else
 	if rx ~= ry | cx ~= cy,
	  error('Matrix dimensions must agree')
	else
	  x_and_y_ismatrix=1;
	end
      end
    end
  end
% break the plot parameter string into line type, color and width

  if exist('par') == 1,
    [col,ltype,width] = getplarg(par);
    if length(col) ~= 0,
      linecol=col;
      if length(ltype) ~= 0,
	linetype=ltype;
      else			% override autotranslation of colour
	if min(size(y)) == 1,	% into a line pattern performed by gpp
	  linetype='-';		% for vectors, when no line pattern is
	end			% is specified
      end
    else
      if length(ltype) ~= 0,
	linetype=ltype;
      end
    end
    if length(width) ~= 0,
      linewidth=width;
    end
  end
end

% plot axis if necessary (axis needs to be ploted
% separately from curve in order to insert line and
% color information for the curve in between)
[axis_state,ax] = inquire('axis');
hold_state = inquire('hold');
if hold_state == 0,
  if axis_state == 0,
    subpl=inquire('subplot');    
    %
    % only x- and y-values > 0 may be plotted (loglog!). This has to be
    % considered when plotting the axis.
    xv=x>0;
    yv=y>0;
    if x_and_y_ismatrix == 1,
      xyv=xv & yv;
      xi=find(any(xyv'));
      yi=find(any(xyv));
      xx=x(xi,yi);
      yy=y(xi,yi);
    else
      if min(size(x)) == 1,	% is x vector or matrix ?
	xi=find(xv);		% "any" behaves different
      else			% for vectors and matices !
 	xi=find(any(xv'));
      end
      if min(size(y)) == 1,	% is y vector or matrix ?
	yi=find(yv(xi));		% consider only those columns
      else			% for which x is plottable
	yi=find(any(yv(xi,:)'));
      end
      % data is columnwise plotted, consider only those row
      % columns for which at least one x and one y value is plottable
      % (this is why we need x and yvectors to be columnwise)  
      xi=xi(yi);
      xx=x(xi,:);	% reject those columns for which all
      yy=y(xi,:);	% x or all y valures are <= 0
    end
    xv=xx>0;
    yv=yy>0;
    xextr=[min(xx(xv)) max(xx(xv))];
    yextr=[min(yy(yv)) max(yy(yv))];    
    loglog(xextr,yextr,'i');
    ax=axis;
    subplot(subpl);
  end
  loglog([10 10].^ax(1:2),[10 10].^ax(3:4),'.');
  hold on
end

% set color and plot curve:
% do insert a string with "escape" sequences at an "invisible"
% position, which can be interpreted by MET2PS
setcolor=['#P',linecol,' ',linewidth,' ',lwuscale,' mul Pc#'];
text(1,.5,setcolor,'sc')	% set color/linewidth
  loglog(x,y,[linecol linetype])
text(1,.5,'#PEc#','sc')		% reset color/linewidth
if hold_state == 0,
  hold off
  if axis_state == 1,
    axis(ax);
  end
end
end
