echo on
clc
% This short demo shows how you use the gp^4 package for PostScript
% printers.

% First we create a time axis and a sine vector

t=(0:99)/100;
s=sin(2*pi*t);

% We'd like to plot the sine in red, at 20/8 points linewidth.
% The cplot function will do this, but the actual linewidth
% will only be visible on the PostScript output

cplot(t,s,'r20')

pause % Strike any key to continue
clc
% Now let's annotate the plot

% First the x-axis: symbols should be in italic, so we use
% the $ sign to switch to math mode and back again. Switching
% back to normal mode is important or the next text printed
% will be in math mode too! Again the result will only show up
% on the printed output
 
xlabel('$t$')

% the y-axis should be annotated as with the standard gpp

ylabel('Amplitude')

pause % Strike any key to continue
clc
% The Title should be set in Helvetica, #H serves this
% purpose and #T switches back to Times-Roman - if not all
% following text will be set in Helvetica!
% The ^ has the effect, that the next character will be
% printed at a superscript Position

title('#HSome of the capabilities of the $gp^4$ package#T')

% A label describing the function shall contain a greek Pi.
% We get this by using the @-operator which has the effect
% that the following letter is taken from the greek font.

% In order to increase the size of the text we use the #+
% construct to increase text by about 25% and #- to switch back
% to normal size, otherwise all following text would be printed
% at a larger size

text(0.45,0.6,'#+sin(2@p$t$)#-')

pause % Strike any key to continue
if exist('gp4demo.met') == 2,
  delete gp4demo.met
end
clc
% save the result to a meta file

meta gp4demo

pause % Strike any key to continue
clc
% Now let's compute and plot some bessel functions.
% Integer bessel functions are plotted in red and at
% a linewidth of 6/8 points (twice the default value).
% Fractional functions are plotted in blue at default
% linewidth

x=0:.2:10;

J0=bessel(0,x); J1=bessel(1,x); J2=bessel(2,x);

Jeven=[J0;J1;J2];

cplot(x,Jeven,'r6')
hold on

j0=bessel(0.5,x); j1=bessel(1.5,x); j2=bessel(2.5,x);

Jodd=[j0;j1;j2];

cplot(x,Jodd,'b')

pause % Strike any key to continue
clc
% We want the x and y labels larger than usual --> #+ and #-
% The ylabelt function will print the ylabel on top of the
% y-axes. The ylabel is "J-sub-alpha (x)"

xlabel('#+$x$')
ylabelt('$J_@a(x)$#-')

title('Some integer and fractional order Bessel functions')

% Annotate two curves J-sub-0 and J-sub-0.5
% Subsripts consisting of more than one character need to be
% placed between curly braces

ctext(1,.85,'$J_0$','r')
ctext(1.5,.7,'$J_{0.5}$','b')

pause % Strike any key to continue
clc
% Save the plot to a meta file and convert it
% to PostScript by use of the met2ps command
% instead of the usual gpp command.

meta gp4demo

!met2ps gp4demo

% You can now send the file gp4demo.ps to your printer.
% Hope the results is what we intended to get.

hold off
echo off
