function [pos,matriz]=binplot(file,hijos,opt)
%BINPLOT Plot a picture of a binary tree.
%       BINPLOT(file,hijos,opt)
%         file   es el nombre del fichero de salida (will be 'file.grf')
%         hijos  is a vector of sons pointers, with p(i) == 0 for a no son.
%         opt    es para decidir el aspecto que se quiere
%                binario ampliado (1)
%                binario no ampliado (2)
%
%       pos     matriz de coordenadas de los nodos
%       matriz  matriz de adyacencias cuando la opcion es 1
%

% si no se dice nada, dibujamos el ampliado
if nargin==2, opt=1;, end

% calculamos la lista de padres
n=max(max(hijos));
nn=size(hijos,1);

% completamos la matriz a arbol completo
% es decir hay una linea para cada nodo y los hijos de las hojas son ceros
hij=zeros(n,2);
for i=1:nn,
    for j=1:2,
        hij(hijos(i,1),j)=hijos(i,j+1);
    end
end

% creamos una lista de padres, de momento solo para encontrar la raiz
% y adjudica numeros a las hojas
hoja=n;
for i=1:n,
    for j=1:2,
        if hij(i,j)~=0,
            pad(hij(i,j))=i;
        else
            hoja=hoja+1;
            hij(i,j)=hoja;
            pad(hoja)=i;
        end
    end
end

% localiza la raiz
r=find(pad==0);
if size(r,2)~=1, disp('mas de una raiz'), return, end

% comienza a rellenar la lista lineal habitual en los binarios ampliados
% aunque puede haber huecos si no es completo
lineal(1)=r;
i=1;
j=1;

while i<=n,
    if (lineal(j)~=0 & lineal(j)<=n),
        lineal(2*j)=hij(lineal(j),1);
        lineal(2*j+1)=hij(lineal(j),2);
        i=i+1;
        j=j+1;
    else
        j=j+1;
    end
end

% adjudicamos abcisas y ordenadas
% fijamos los limites exteriores y los incrementos
nnn=size(lineal,2);
h=fix(log10(nnn)/log10(2));
deltax=.5;
firstx=.25;
deltay=.9/h;
y=.95-deltay;

% rellenamos las filas 2 y 3 con abscisas y ordenadas respectivamente
lineal(2,1)=.5;
lineal(3,1)=.95;

for ii=1:h,
    for jj=0:2^ii-1,
        lineal(3,2^ii+jj)=y;
        lineal(2,2^ii+jj)=firstx+jj*deltax;
    end
    deltax=deltax/2;
    firstx=firstx/2;
    y=y-deltay;
end

nodos=find(lineal(1,:));

%nos quedamos solo con los nodos ocupados (transponiendo para ordenar)
lineal=lineal(:,nodos)';

%ordenamos para recuperar las abcisas a dibujar
[lineal2,orden]=sort(lineal);

lineal2(:,2)=lineal(orden(:,1),2);
lineal2(:,3)=lineal(orden(:,1),3);

x=lineal2(:,2)';
y=lineal2(:,3)';

% la cantidad real de nodos del ampliado es
nnn=2*n+1;
% proporcionamos un comentario
com='arbol binario ampliado';


% es imprescindible pensar como ampliado para la correcta ubicacion de nodos
% si no queremos el ampliado, hay que eliminar las hojas aadidas
if opt==2,
    pad=pad(1:n);
    nnn=n;
    y=(y*h-1)/(h-1);
    com='arbol binario';
end

f = find(pad~=0);
pp = pad(f);
X = [x(f); x(pp); NaN*ones(size(f))];
Y = [y(f); y(pp); NaN*ones(size(f))];
X = X(:);
Y = Y(:);


    % primer calculamos la lista de adyacencias
    % calculamos la matriz de adyacencias
    j = find(pad);
    A = sparse (pad(j), j, 1, nnn, nnn);
    A = A + A';

% si se da un argumento de salida, se graba y no se dibuja (de momento)
if length(file)>0,

    putfile1(file,[x(1:nnn)' y(1:nnn)'],A,com);

else

pos=[x(1:nnn)' y(1:nnn)'];
if opt==1,
    matriz=full(A);
end

%    figure(1);set(gcf,'menubar','none','number','off','name',com);
%    if opt==1,
% ponemos los nodos de amarillo y las hojas de verde
%        plot (x(1:n), y(1:n), 'yo',x(n+1:2*n+1), y(n+1:2*n+1), 'go', X, Y, 'r-');
%    else,
%        plot (x(1:n), y(1:n), 'yo', X, Y, 'r-');
%    end;
%   xlabel(['height = ' int2str(h)]);
%    axis('normal');axis('off');axis([0 1 0 1]);

end

return
end
