function [x,y,h,s] = treelay2(parent,post,opt)
%TREELAY2 Lay out a tree or forest.
%       [x,y,h,s] = TREELAY2(parent,post,opt)
%       parent   is the vector of parent pointers, with 0 for a root.
%       post     is a postorder permutation on the the tree nodes.
%       opt      is 2 for drawing all leafs on same level, is 1 if non.
%
%       x and y  are vectors of coordinates in the unit square at which
%                to lay out the nodes of the tree to make a nice picture.
%Optionally,
%       h        is the height of the tree and
%       s        is the number of vertices in the top-level separator.

%   es una modificacion del 'treelayo.m' de sparfun matlab package
%	Copyright (c) 1984-93 by The MathWorks, Inc.

% This is based on the C code in sptrees.c by John Gilbert.
% Leaves are spaced evenly on the x axis, and internal
% nodes are centered over their descendant leaves with
% y coordinate proportional to height in the tree.

n = max(size(parent));

if nargin==2, opt=1, end

% Add a dummy root node #n+1, and identify the leaves.

parent = rem (parent+n, n+1) + 1;  % change all 0s to n+1s
isaleaf = ones(1,n+1);
isaleaf(parent) = zeros(n,1);

% In postorder, compute heights and descendant leaf intervals.
% Space leaves evenly in x (in postorder).

xmin = n*ones(1,n+1);
xmax = zeros(1,n+1);
height = zeros(1,n+1);
nkids = zeros(1,n+1);
nleaves = 0;

for i = 1:n,
    node = post(i);
    if isaleaf(node),
        nleaves = nleaves+1;
        xmin(node) = nleaves;
        xmax(node) = nleaves;
    end;
    dad = parent(node);
    height(dad) = max (height(dad), height(node)+1);
    xmin(dad)   = min (xmin(dad),   xmin(node));
    xmax(dad)   = max (xmax(dad),   xmax(node));
    nkids(dad)  = nkids(dad)+1;

end;

%tratamos de arreglar los niveles si opt=1
%cuando opt=2 las hojas aparecen en un mismo nivel

if opt==1,
    % localiza la raiz
    r=find(parent==n+1);

    % en la matriz r vamos a ir haciendo una cola de los nodos
    i=1;
    j=1;

    while j<n,
        rn=find(parent==r(i));
        hij=size(rn,2);
        if hij==0
            i=i+1;
        else
            for k=1:hij,
                height(rn(k))=height(r(i))-1;
            end
            j=j+hij;
            r=[r rn];
            i=i+1;
        end
    end
end

% Compute coordinates, leaving a little space on all sides.

treeht = height(n+1) - 1;
%deltax = 1/(nleaves+1)
%deltay = 1/(treeht+2)
deltax = 1/(nleaves+.1);
deltay = .9/treeht;
%x = deltax * (xmin+xmax)/2;
%y = deltay * (height+1);
x = deltax * (xmin+xmax-1)/2;
y = deltay * height+.05;

% Omit the dummy node.

x = x(1:n);
y = y(1:n);

% Return the height and top separator size.

%h = treeht;
%s = n+1 - max(find(nkids~=1));
