function elerbd(line_h)
%ELERBD	Elliptical error bounds
%
%	Usage:	elerbd(line_h)
%
%	line_h is a vector of line handles.  Each line is assumed to
%	contain the error bound data in its userdata matrix in the
%	following form : [ellipse_h1 ellipse_h2 ... ellipse_hn
%			  xdata1     xdata2 ...     xdatan
%			  ydata1     ydata2 ...     ydatan
%			  zdata1     zdata2 ...     zdatan (to be added)]
%

%	Rich Field
%	NASA Ames-Dryden Flight Research Facility
%	P.O. Box 273
%	Edwards, CA  93523-0273

n=length(line_h);

for i=1:n,					%Line counter
	ud=get(line_h(i),'Userdata');
	xdata=get(line_h(i),'Xdata');		%x-coordinate of center
	ydata=get(line_h(i),'Ydata');		%y-coordinate of center
	npts=size(ud,2);			%number of data points
	ell_c=get(line_h(i),'Color');
	ell_v=get(line_h(i),'Visible');
	for j=1:npts,				%Data point counter
		[x,y]=ellipse(xdata(j),ydata(j),ud(2,j),ud(3,j));
		if isnan(ud(1,j)),		%Create new ellipse
			ellipse_h=line(x,y,'Color',ell_c,'Visible',ell_v);
			ell_c=get(line_h(i),'Color');
			ud(1,j)=ellipse_h;	%ud(line)
		else				%Modify ellipse
			ud=get(line_h(i),'Userdata');
			ellipse_h=ud(1,j);	%Define ellipse handles
			set(ellipse_h,'Color',ell_c,...
			'Visible',ell_v,'Xdata',x,'Ydata',y);
		end
	end
	set(line_h(i),'Userdata',ud);		%ud(line) set
end

