function [x,y] = ellipse(x0,y0,A,B)
%ELLIPSE
%
%	Function to construct an ellipse given :
%		x0	x-coordinate of center
%		y0	y-coordinate of center
%		A	semi-major axis length (x)
%		B	semi-minor axis length (y)
%
%	Where :
%		(x-x0)^2/A^2 + (y-y0)^2/B^2 = 1
%
%	Usage: [x,y]=ellipse(x0,y0,A,B)
%

%	Rich Field
%	NASA Ames-Dryden Flight Research Facility
%	P.O. Box 273
%	Edwards, CA  93523-0273

npts=40;
theta = 0:2*pi/npts:2*pi;	%Compute unit circle
r = 1;
x1 = r * cos(theta);		%1st transformation to cartesian coordinates
y1 = r * sin(theta);

x2 = A * x1;			%2nd transformation to an ellipse
y2 = B * y1;

x = x0 + x2;			%Translation to new center
y = y0 + y2;



