echo off
%
%	Graphical User Interface (GUI) Demonstration
%

%	Rich Field
%	NASA Ames-Dryden Flight Research Facility
%	P.O. Box 273
%	Edwards, CA  93523-0273

echo on
clc
%	Matlab 4.0 introduces the Graphical User Interface (GUI) for
%	plotting data. 'gui_plot' and 'gui_plot2' are two routines that
%	utilize this utility.

pause	%press any key to continue after pauses.
clc

%	Example data is contained in the file 'gui_demo1.mat'.

load gui_demo1.mat
whos

%	The data represent various trig and log functions of x.
%	'gui_plot' uses the handle system of Matlab 4.0 to allow the user
%	to manipulate each data set independently.  Let's try it :

pause	%press any key to plot.
handle=gui_plot(x,y,names)
clc

%	You can change the line color, line style, marker style, and
%	marker size of each line.  Each line can be hidden separately so
%	the user can focus on a portion of the data at one time.

%	'gui_plot' uses the 'names' vector to entitle each pull down menu.
%	It also returns the handle to the figure window axes.

%	When you are done playing, select "Quit GUI" under the file
%	pull down menu.

pause	%press any key to continue after pauses.
clear x y names handle
clc

%	A modified version of 'gui_plot' incorporates error measurements
%	into the plots.  'gui_plot2' utilizes elliptical error bounds to
%	construct confidence bands around the results.  Check it out:

load gui_demo2.mat

%	One use of this feature is a root locus plot with error bounds.
%	Matlab's Yaw Damper for a Jet Transport (p. 1-23 of Control System
%	Toolbox) is a good example.

whos
pause	%press any key to continue after pauses.

%	A, B, C, D is a state-space representation of a Jet Transport during
%	cruise flight (two inputs and two outputs).  a, b, c, d is the
%	subsystem of input #1 to output #1 (rudder to yaw rate).  r and k
%	are the pole and gain values computed with the 'rlocus' command.

pause	%press any key to continue after pauses.
echo off
clc
n=size(A,2);

for j=1:n,
        xdata(:,j)=real(r(:,j));
        ydata(:,j)=imag(r(:,j));
        xedata(:,j)=j*xdata(:,j);
        yedata(:,j)=j*ydata(:,j);
end

xdata=xdata(1:18,:);
ydata=ydata(1:18,:);
xedata=xedata(1:18,:)/10;
yedata=yedata(1:18,:)/10;
yedata(:,3:4)=yedata(:,1:2);
echo on

%	The elliptical error bounds are a random function of the length
%	of the data vectors.  This was done for demo purposes only.

pause	%press any key to plot.

handle=gui_plot2(xdata,ydata,xedata,yedata,names)
title('Root Locus with Error Bounds (rudder to yaw rate)');
xlabel('Re(s)');
ylabel('Im(s)');
grid on;

%	The plot may be sent to the printer.  Just select "Print" under the
%	File pull down menu.

%	When you are done playing, select "Quit GUI" under the file
%	pull down menu.

pause	%press any key to continue after pauses.
clear all

echo off 
