function axeshout=gui_plot(x,y,names)
%GUI_PLOT	Graphical User Interface plotting routine
%
%	Usage: axeshout=gui_plot(x,y,names)
%
%	This function will plot x vs y using the Graphical User
%	Interface (GUI) features of Matlab 4.0.  x and y may be vectors
%	or matrices, but they must have the same number of rows and
%	columns (NaN entries are acceptable).  axeshout is an option to
%	return the handle to the current axes.  names is an (optional) matrix
%	containing the labels to each data set.  The names matrix should be
%	constructed using the str2mat function.  If not supplied, a default
%	names list will be created.
%
%	A gui_plot legend is also constructed in another figure window.

%
%	All line information is internally stored in the userdata matrix:
%		[lineh1     lineh2 ...     linehn ;
%		fix(name1)' fix(name2)'... fix(namen)']
%

%	Rich Field
%	NASA Ames-Dryden Flight Research Facility
%	P.O. Box 273
%	Edwards, CA  93523 
%	June, 1993 (v 0.1)

if nargin < 2 | nargin > 3,		%Check input arguments
 	disp('Bad number of input arguments!');
	return;
end

figh=figure('NumberTitle','off','Name','GUI Plot',...	%Create figure
	'Position',[260,544,560,420]);
axesh=gca;				%Define axes handle and draw figure

[nxrows,nxcols]=size(x);		%Check sizes of x and y
[nyrows,nycols]=size(y);

if nxrows ~= nyrows | nxcols ~= nycols,	%x and y must be the same size
	disp('x and y matrices must be the same size!');
	return;
end

ncols=nycols;				%Set number of columns

if nargin < 3,				%Default names
	names=[];
	for ln=1:ncols,
		names=[names;['Line ',int2str(ln)]];
	end
end

name_size=size(names);			%Check size of names matrix

if name_size(1) ~= ncols,		%Correct number of labels?
	disp('names and number of data sets must be equal!');
	return;
end

	H=uimenu(figh,'Label','File');
	H1=uimenu(H,'Label','Quit GUI','Callback',...
		'close(''GUI Plot'')');

for line_no=1:ncols,

	Ha=uimenu(figh,'Label',names(line_no,:));%Line menu

	lineh=line(x(:,line_no),y(:,line_no));	%Line handle
	ud=get(axesh,'UserData');		%Open userdata matrix
	ud(1,line_no)=lineh;			%1st row is list of lineh's
	set(axesh,'Userdata',ud);		%Save lineh's in ud

	Hb1=uimenu(Ha,'Label','LineStyle');	%Style menu
	Hb2=uimenu(Ha,'Label','LineColor');	%Color menu
	Hb3=uimenu(Ha,'Label','LineMarker');	%Marker menu
	Hb4=uimenu(Ha,'Label','MarkerSize');	%Marker size menu
	Hb5=uimenu(Ha,'Label','Print','Callback','printit');
						%Print the plot

	lns=int2str(line_no);			%Line number string

		%Style submenu
	Hc1=uimenu(Hb1,'Label','Solid Line','Callback',...
		['setit(',lns,',''Linestyle'',''-''),update_lgd;']);
	Hc2=uimenu(Hb1,'Label','Dotted Line','Callback',...
		['setit(',lns,',''Linestyle'','':''),update_lgd;']);
	Hc3=uimenu(Hb1,'Label','Dashdot Line','Callback',...
		['setit(',lns,',''Linestyle'',''-.''),update_lgd;']);
	Hc4=uimenu(Hb1,'Label','Dashed Line','Callback',...
		['setit(',lns,',''Linestyle'',''--''),update_lgd;']);

		%Color submenu
	Hc10=uimenu(Hb2,'Label','Yellow','Callback',...
		['setit(',lns,',''Color'',''y''),update_lgd;']);
	Hc11=uimenu(Hb2,'Label','Magenta','Callback',...
		['setit(',lns,',''Color'',''m''),update_lgd;']);
	Hc12=uimenu(Hb2,'Label','Cyan','Callback',...
		['setit(',lns,',''Color'',''c''),update_lgd;']);
	Hc13=uimenu(Hb2,'Label','Red','Callback',...
		['setit(',lns,',''Color'',''r''),update_lgd;']);
	Hc14=uimenu(Hb2,'Label','Green','Callback',...
		['setit(',lns,',''Color'',''g''),update_lgd;']);
	Hc15=uimenu(Hb2,'Label','Blue','Callback',...
		['setit(',lns,',''Color'',''b''),update_lgd;']);
	Hc16=uimenu(Hb2,'Label','White','Callback',...
		['setit(',lns,',''Color'',''w''),update_lgd;']);
	Hc17=uimenu(Hb2,'Label','Hide','Callback',...
		['setit(',lns,',''Visible'',''off''),update_lgd;']);
	Hc18=uimenu(Hb2,'Label','Show','Callback',...
		['setit(',lns,',''Visible'',''on''),update_lgd;']);

		%Marker submenu
	Hc20=uimenu(Hb3,'Label','Circle','Callback',...
		['setit(',lns,',''LineStyle'',''o''),update_lgd;']);
	Hc21=uimenu(Hb3,'Label','Plus','Callback',...
		['setit(',lns,',''LineStyle'',''+''),update_lgd;']);
	Hc22=uimenu(Hb3,'Label','Point','Callback',...
		['setit(',lns,',''LineStyle'',''.''),update_lgd;']);
	Hc23=uimenu(Hb3,'Label','Star','Callback',...
		['setit(',lns,',''LineStyle'',''*''),update_lgd;']);
	Hc24=uimenu(Hb3,'Label','x-Mark','Callback',...
		['setit(',lns,',''LineStyle'',''x''),update_lgd;']);

		%Marker size submenu
	Hc30=uimenu(Hb4,'Label','4 point','Callback',...
		['setit(',lns,',''MarkerSize'',','4),update_lgd;']);
	Hc31=uimenu(Hb4,'Label','6 point','Callback',...
		['setit(',lns,',''MarkerSize'',','6),update_lgd;']);
	Hc32=uimenu(Hb4,'Label','8 point','Callback',...
		['setit(',lns,',''MarkerSize'',','8),update_lgd;']);
	Hc33=uimenu(Hb4,'Label','10 point','Callback',...
		['setit(',lns,',''MarkerSize'',','10),update_lgd;']);
	drawnow;
end

ud=get(axesh,'Userdata');		%Names matrix is assigned to
ud=[ud;fix(names')];			%rows 2 - length(names') of
set(axesh,'Userdata',ud);		%ud(axesh_fig) matrix

axesh_lgd=create_lgd(axesh);		%Create legend and return axes handle

if nargout > 0,				%Optional figure axes handle returned
	axeshout=axesh;
end

drawnow;
