function axeshout=gui_plot2(x,y,xe,ye,names)
%GUI_PLOT	Graphical User Interface plotting routine
%
%	Usage: axeshout=gui_plot2(x,y,xe,ye,names)
%
%	This function will plot x vs y using the Graphical User
%	Interface (GUI) features of Matlab 4.0.  x and y may be vectors
%	or matrices, but they must have the same number of rows and
%	columns (NaN entries are acceptable).  xe and ye are matrices (the
%	same size as x and y) representing error bound estimates.  axeshout 
%	is an option to return the handle to the current axes.  names is an 
%	(optional) matrix containing the labels to each data set.  The names 
%	matrix should be constructed using the str2mat function.  If not 
%	supplied, a default names list will be created.
%
%	A gui_plot legend is also constructed in another figure window.
%

%	Rich Field
%	NASA Ames-Dryden Flight Research Facility
%	P.O. Box 273
%	Edwards, CA  93523-0273

if nargin < 2 | nargin > 5,		%Check input arguments
 	disp('Bad number of input arguments!');
	return;
end

x_s = size(x);
y_s = size(y);
xe_s=size(xe);
ye_s=size(ye);

if x_s ~= y_s | x_s ~= xe_s | x_s ~= ye_s,
	disp('Input arguments must be the same size!');
end

figh=figure('NumberTitle','off','Name','GUI Plot',...	%Create figure
	'Position',[260,544,560,420]);
axesh=gca;				%Define axes handle and draw figure

ncols=size(y,2);			%Set number of columns

if nargin==2 | nargin==4,		%Default names defined
	names=[];
	for ln=1:ncols,
		names=[names;['Line ',int2str(ln)]];
	end
end

name_size=size(names);			%Check size of names matrix

if name_size(1) ~= ncols,		%Correct number of labels?
	disp('names and number of data sets must be equal!');
	return;
end

H=uimenu(figh,'Label','File');
H1=uimenu(H,'Label','Quit GUI','Callback','close(''GUI Plot'')');
H2=uimenu(H,'Label','Print','Callback','printit');

ls=['o','+','.','*','x','o','+'];		%Line style string
lc=['y','m','c','r','g','b','w'];		%Line color string
for line_no=1:ncols,	%7 is max because only 7 elements in ls, lc
	
	Ha=uimenu(figh,'Label',names(line_no,:));%Line menu

	lineh=line(x(:,line_no),y(:,line_no),'Linestyle',ls(line_no),...
		'Color',lc(line_no));		%Line handle
	ud=[NaN*ones(1,length(xe(:,line_no)));xe(:,line_no)';ye(:,line_no)'];
						%Line userdata defined
	set(lineh,'Userdata',ud);		%Line userdata set

	ud=get(axesh,'UserData');		%Open axes userdata matrix
	ud(1,line_no)=lineh;			%1st row is list of lineh's
	set(axesh,'Userdata',ud);		%Save lineh's in ud(axesh)

	Hb1=uimenu(Ha,'Label','LineStyle');	%Style menu
	Hb2=uimenu(Ha,'Label','LineColor');	%Color menu
	Hb3=uimenu(Ha,'Label','LineMarker');	%Marker menu
	Hb4=uimenu(Ha,'Label','MarkerSize');	%Marker size menu
	Hb5=uimenu(Ha,'Label','Print','Callback','printit');
						%Print the plot

	lns=int2str(line_no);			%Line number string

		%Style submenu
	Hc1=uimenu(Hb1,'Label','Solid Line','Callback',...
		['setit(',lns,',''Linestyle'',''-''),update_lgd2;']);
	Hc2=uimenu(Hb1,'Label','Dotted Line','Callback',...
		['setit(',lns,',''Linestyle'','':''),update_lgd2;']);
	Hc3=uimenu(Hb1,'Label','Dashdot Line','Callback',...
		['setit(',lns,',''Linestyle'',''-.''),update_lgd2;']);
	Hc4=uimenu(Hb1,'Label','Dashed Line','Callback',...
		['setit(',lns,',''Linestyle'',''--''),update_lgd2;']);

		%Color submenu
	Hc10=uimenu(Hb2,'Label','Yellow','Callback',...
		['setit(',lns,',''Color'',''y''),update_lgd2;']);
	Hc11=uimenu(Hb2,'Label','Magenta','Callback',...
		['setit(',lns,',''Color'',''m''),update_lgd2;']);
	Hc12=uimenu(Hb2,'Label','Cyan','Callback',...
		['setit(',lns,',''Color'',''c''),update_lgd2;']);
	Hc13=uimenu(Hb2,'Label','Red','Callback',...
		['setit(',lns,',''Color'',''r''),update_lgd2;']);
	Hc14=uimenu(Hb2,'Label','Green','Callback',...
		['setit(',lns,',''Color'',''g''),update_lgd2;']);
	Hc15=uimenu(Hb2,'Label','Blue','Callback',...
		['setit(',lns,',''Color'',''b''),update_lgd2;']);
	Hc16=uimenu(Hb2,'Label','White','Callback',...
		['setit(',lns,',''Color'',''w''),update_lgd2;']);
	Hc17=uimenu(Hb2,'Label','Hide','Callback',...
		['setit(',lns,',''Visible'',''off''),update_lgd2;']);
	Hc18=uimenu(Hb2,'Label','Show','Callback',...
		['setit(',lns,',''Visible'',''on''),update_lgd2;']);

		%Marker submenu
	Hc20=uimenu(Hb3,'Label','Circle','Callback',...
		['setit(',lns,',''LineStyle'',''o''),update_lgd2;']);
	Hc21=uimenu(Hb3,'Label','Plus','Callback',...
		['setit(',lns,',''LineStyle'',''+''),update_lgd2;']);
	Hc22=uimenu(Hb3,'Label','Point','Callback',...
		['setit(',lns,',''LineStyle'',''.''),update_lgd2;']);
	Hc23=uimenu(Hb3,'Label','Star','Callback',...
		['setit(',lns,',''LineStyle'',''*''),update_lgd2;']);
	Hc24=uimenu(Hb3,'Label','x-Mark','Callback',...
		['setit(',lns,',''LineStyle'',''x''),update_lgd2;']);

		%Marker size submenu
	Hc30=uimenu(Hb4,'Label','4 point','Callback',...
		['setit(',lns,',''MarkerSize'',','4),update_lgd2;']);
	Hc31=uimenu(Hb4,'Label','6 point','Callback',...
		['setit(',lns,',''MarkerSize'',','6),update_lgd2;']);
	Hc32=uimenu(Hb4,'Label','8 point','Callback',...
		['setit(',lns,',''MarkerSize'',','8),update_lgd2;']);
	Hc33=uimenu(Hb4,'Label','10 point','Callback',...
		['setit(',lns,',''MarkerSize'',','10),update_lgd2;']);
end

ud=get(axesh,'Userdata');		%Names matrix is assigned to
ud=[ud;fix(names')];			%rows 2 - length(names') of
set(axesh,'Userdata',ud);		%ud(axesh_fig) matrix

axesh_lgd=create_lgd(axesh);		%Create legend and return axes handle

if nargout > 0,				%Optional figure axes handle returned
	axeshout=axesh;
end
figure(figh)
update_lgd2
