function mk_tmplt(form_length)
%
%  Create_form.m
%
%		This function creates the m-file by gathering information
%		about the current figure created by guimaker.m and creates
%		a template m-file function that recreates the GUI.  This
%		template is fully functional and only needs to have the
%		"guts" of the application filled in to do what you want it
%		to do.
%
%  usage:
%		Create_form(form_length);
%  where
%
%		form_length  :	Size of text matrix ('short', 'medium', 
%				'long' -> default = 'long').
%		command_number : Command number uicontrol object should
%				 callback.
%
%  Author :  Patrick Marchand
%  Mods.  :  
%   

%  Copyright (c) 1994 by Patrick Marchand 
%       Permission is granted to modify and re-distribute this 
%	code in any manner as long as this notice is preserved. 
%	All standard disclaimers apply. 

if nargin == 0
  form_length = 'long';
end

[filename,filepath] = uiputfile('*.m','Save As');
if filename == []
   filename = ['template'];
end
if isstr(filename)
  if strcmp(filename((length(filename)-1):length(filename)),'.m')
	filename = filename(1:(length(filename)-2));
  end

    fid = fopen([filename '.m'],'w');

% Header Creation

	txt = ['function ' filename '(command,param1)'];
        fprintf(fid,'%s \n',txt);
	txt = ['%  Template for uicontrol form.'];
        fprintf(fid,'%s \n',txt);
	txt = ['%  '];
        fprintf(fid,'%s \n',txt);
	txt = ['%  1. Optional: Replace all occurances of ''' filename ...
		''' with' ...
		' desired ''filename''.'];
        fprintf(fid,'%s \n',txt);
	txt = ['%  2. Optional: Resave this file as that ''filename''.'];
        fprintf(fid,'%s \n',txt);
	txt = ['%  3. Optional: Fill in the ''elseif command == ...'' sections with'];
        fprintf(fid,'%s \n',txt);
	txt = ['%          code that does something other than display which'];
        fprintf(fid,'%s \n',txt);
	txt = ['%          uicontrol button was pressed. Be creative!'];
        fprintf(fid,'%s \n',txt);
	txt = ['%  4. Optional: Change each ''h(index)'' ,where index is' ...
		' 1,2,3,..'];
        fprintf(fid,'%s \n',txt);
	txt = ['%               to a functionally more descriptive name.'];
        fprintf(fid,'%s \n',txt);
	txt = ['%  5. Optional: Delete these first 10 comment lines.'];
        fprintf(fid,'%s \n',txt);
	txt = ['%  '];
        fprintf(fid,'%s \n',txt);
	txt = ['%  ' filename '.m'];
        fprintf(fid,'%s \n',txt);
	txt = ['%  '];
        fprintf(fid,'%s \n',txt);
	txt = ['%  usage:       ' filename '(command,parameter1)'];
        fprintf(fid,'%s \n',txt);
	txt = ['%  '];
        fprintf(fid,'%s \n',txt);
	txt = ['%           where'];
        fprintf(fid,'%s \n',txt);
	txt = ['%  '];
        fprintf(fid,'%s \n',txt);
	txt = ['%               ''command'' is used to perform some ' ...
		'defined operation'];
        fprintf(fid,'%s \n',txt);
	txt = ['%               ''parameter1'' can be used pass extra ' ...
		'information'];
        fprintf(fid,'%s \n',txt);
	txt = ['%                              to a defined operation'];
        fprintf(fid,'%s \n',txt);
	txt = ['%  '];
        fprintf(fid,'%s \n',txt);
	txt = ['%           If no arguements are used the GUI is initialized.'];
        fprintf(fid,'%s \n',txt);
	txt = ['%  '];
        fprintf(fid,'%s \n',txt);
	txt = ['%  '];
        fprintf(fid,'%s \n',txt);
	txt = ['%  Created: ' date];
        fprintf(fid,'%s \n',txt);
	txt = ['%  Using  : guimaker by Patrick Marchand'];
        fprintf(fid,'%s \n',txt);
	txt = ['%                         (pmarchan@motown.ge.com)'];
        fprintf(fid,'%s \n',txt);
	txt = ['%  Author : '];
        fprintf(fid,'%s \n',txt);
	txt = ['%  Mods.  : '];
        fprintf(fid,'%s \n',txt);
	txt = ['%  '];
        fprintf(fid,'%s \n',txt);
	fprintf(fid,'\n');
	txt = ['%  Copyright (c) 1994 by Patrick Marchand'];
        fprintf(fid,'%s \n',txt);
	txt = ['%       Permission is granted to modify and re-distribute ' ...
		'this'];
        fprintf(fid,'%s \n',txt);
	txt = ['%	code in any manner as long as this notice is ' ...
		'preserved.'];
        fprintf(fid,'%s \n',txt);
	txt = ['%	All standard disclaimers apply.'];
        fprintf(fid,'%s \n',txt);
	fprintf(fid,'\n');
	fprintf(fid,'\n');

	% Determine and label uicontrol objects
	h = find_ui;

	% Sort order of uicontrol objects
	frame_hand = [];
        other_hand = [];
	for loop1 = 1:length(h)
	  if strcmp(get(h(loop1),'style'),'frame')
	    frame_hand = [frame_hand h(loop1)];
	  else
            other_hand = [other_hand h(loop1)];
	  end
        end
	h = [frame_hand other_hand];
	
	num_uicontrol = length(h);
	for loop1 = 1:num_uicontrol
	    name = get(get(h(loop1),'userdata'),'string');
	    if ~valid_fn(name)
		name = strrep(name,' ','');
		if ~valid_fn(name)
		  name = ['h' name];
		  if ~valid_fn(name)
		    name = input('Enter a valid handle name:','s');
		  end
		end
	    end
	    if loop1 == 1
		nameset = name;
	    else
		nameset = str2mat(nameset,name);
	    end
	end

	h_list = [];
	ht_uilist = [];
	checked_last_f = 0;
	for loop1 = 1:length(h)
	  if rem(loop1,6) ~= 0
	     h_list = [h_list ' ' deblank(nameset(loop1,:))];
	     checked_last = 0;
	  else
	     h_list = [h_list ' ' deblank(nameset(loop1,:))];
	     if checked_last_f == 0
		ht_uilist = h_list;
		checked_last_f = 1;
	     else
		ht_uilist = str2mat(ht_uilist,h_list);
	     end
	     h_list = [];
	     checked_last = 1;
	  end
	end
	if checked_last == 0
	  if checked_last_f == 0
	   ht_uilist = h_list;
	  else
	   ht_uilist = str2mat(ht_uilist,h_list);
	  end
	end

	t = find_txt;
	num_text = length(t);
	h_list = [];
	ht_tlist = [];
	t_userdatalist = [];
	checked_last_f = 0;
	for loop1 = 1:length(t)
	  if isstr(get(t(loop1),'userdata')) | ...
		length(get(t(loop1),'userdata')) == 0
		t_userdatalist(loop1) = 0;
	  else
		t_userdatalist(loop1) = get(t(loop1),'userdata');
	  end
	  if rem(loop1,6) ~= 0
	     h_list = [h_list ' ' ['txt' num2str(loop1)]];
	     checked_last = 0;
	  else
	     h_list = [h_list ' ' ['txt' num2str(loop1)]];
	     if checked_last_f == 0
		ht_tlist = h_list;
		checked_last_f = 1;
	     else
		ht_tlist = str2mat(ht_tlist,h_list);
	     end
	     h_list = [];
	     checked_last = 1;
	  end
	end
	if checked_last == 0
	  if checked_last_f == 0
	   ht_tlist = h_list;
	  else
	   ht_tlist = str2mat(ht_tlist,h_list);
	  end
	end

	% Create Nargin Check Section
	txt = ['if nargin == 0'];
        fprintf(fid,'%s \n',txt);
	fprintf(fid,'\t');
	txt = ['command = ''new'';'];
        fprintf(fid,'%s \n',txt);
	txt = ['end'];
        fprintf(fid,'%s \n',txt);

	fprintf(fid,'\n');

	% Create Initialization Check Section
	txt = ['if isstr(command)'];
        fprintf(fid,'%s \n',txt);
	fprintf(fid,'\t');
	txt = ['if strcmp(lower(command),''initialize'') | ' ...
		  'strcmp(lower(command),''new'')'];
        fprintf(fid,'%s \n',txt);
	fprintf(fid,'\t');
	fprintf(fid,'\t');
	txt = ['command = 0;'];
        fprintf(fid,'%s \n',txt);
	for loop1 = 1:num_uicontrol
	  fprintf(fid,'\t');
	  txt=['elseif strcmp(lower(command),lower(''' ...
		deblank(nameset(loop1,:)) '''))'];
          fprintf(fid,'%s \n',txt);
	  fprintf(fid,'\t');
	  fprintf(fid,'\t');
	  txt = ['command = ' num2str(loop1) ';'];
          fprintf(fid,'%s \n',txt);
	end
	fprintf(fid,'\t');
	txt = ['end'];
        fprintf(fid,'%s \n',txt);
	txt = ['end'];
        fprintf(fid,'%s \n',txt);

	fprintf(fid,'\n');

	txt = ['if command ~= 0'];
        fprintf(fid,'%s \n',txt);
	fprintf(fid,'\t');
	txt = ['handle_list = get(gcf,''userdata'');'];
        fprintf(fid,'%s \n',txt);
	fprintf(fid,'\t');
	txt = ['if length(handle_list) > 0'];
        fprintf(fid,'%s \n',txt);

	for loop1 = 1:num_uicontrol
	 fprintf(fid,'\t');
	 fprintf(fid,'\t');
	 txt = [deblank(nameset(loop1,:)) ' = handle_list(' ...
		num2str(loop1) ');'];
         fprintf(fid,'%s \n',txt);
	end
	for loop1 = 1:num_text
	 fprintf(fid,'\t');
	 fprintf(fid,'\t');
	 txt = ['txt' num2str(loop1) ' = handle_list(' ...
		num2str(loop1+num_uicontrol) ');'];
         fprintf(fid,'%s \n',txt);
	end

	fprintf(fid,'\t');
	txt = ['end'];
        fprintf(fid,'%s \n',txt);
	txt = ['end'];
        fprintf(fid,'%s \n',txt);

	fprintf(fid,'\n');
	fprintf(fid,'\n');

	txt = ['if command == 0'];
        fprintf(fid,'%s \n',txt);


	% Determine figure position
	pos = get(gcf,'position');
	rs = get(gcf,'resize');
	txt = ['figure(''position'',' mat2str2(pos) ',''resize'',''' rs ''');'];
	fprintf(fid,'\t');
	fprintf(fid,'%s \n',txt);
	txt = ['set(gca,''visible'',''off'');'];
	fprintf(fid,'\t');
	fprintf(fid,'%s \n',txt);
	fprintf(fid,'\n');


	% Write uicontrol object structure to file
	fprintf(fid,'\t');
	txt = ['%  Uicontrol Object Creation'];
        fprintf(fid,'%s \n',txt);
	for loop1 = 1:length(h)
	    name = get(get(h(loop1),'userdata'),'string');
	    if ~valid_fn(name)
		name = strrep(name,' ','');
		if ~valid_fn(name)
		  name = ['h' name];
		  if ~valid_fn(name)
		    name = input('Enter a valid handle name:','s');
		  end
		end
	    end
%	    name = ['h(' num2str(loop1) ')'];
	    txt = mk_ui_t(h(loop1),name,form_length,loop1,filename);
	    [numrow,numcol] = size(txt);

	    for loop2 = 1:numrow
		if loop2 == 1
		   fprintf(fid,'\t');
		   fprintf(fid,'%s \n',deblank(txt(loop2,:)));
		else
		   fprintf(fid,'\t');
		   fprintf(fid,'\t');
		   fprintf(fid,'%s \n',deblank(txt(loop2,:)));
		end
	    end
	end

	fprintf(fid,'\n');

	[nr_ht_uilist,nc_ht_uilist] = size(ht_uilist);
	for loop2 = 1:nr_ht_uilist
	  tmp_list = deblank(ht_uilist(loop2,:));
	  if loop2 == 1
	    txt = ['handle_ui_list = [' tmp_list ];
	  else
	    txt = [tmp_list];
	  end
	  if loop2 == nr_ht_uilist
	    txt = [txt ' ];'];
	  else
	    txt = [txt ' ...'];
	  end
	  if loop2 > 1
	    fprintf(fid,'\t');
	    fprintf(fid,'\t');
	  end
	  fprintf(fid,'\t');
	  fprintf(fid,'%s \n',txt);
	end
	if nr_ht_uilist == 0
	  txt = ['handle_ui_list = [];'];
	  fprintf(fid,'\t');
	  fprintf(fid,'%s \n',txt);
	end

	fprintf(fid,'\n');
	fprintf(fid,'\n');

	% Print out Text Objects to file
	fprintf(fid,'\t');
	txt = ['%  Text Object Creation'];
        fprintf(fid,'%s \n',txt);

	for loop1 = 1:length(t)
	    name = ['txt' num2str(loop1)];
	    txt = mk_txt_t(t(loop1),name,form_length);
	    [numrow,numcol] = size(txt);

	    for loop2 = 1:numrow
		if loop2 == 1
		   fprintf(fid,'\t');
		   fprintf(fid,'%s \n',deblank(txt(loop2,:)));
		else
		   fprintf(fid,'\t');
		   fprintf(fid,'\t');
		   fprintf(fid,'%s \n',deblank(txt(loop2,:)));
		end
	    end
	end

	fprintf(fid,'\n');

	[nr_ht_tlist,nc_ht_tlist] = size(ht_tlist);
	for loop2 = 1:nr_ht_tlist
	  tmp_list = deblank(ht_tlist(loop2,:));
	  if loop2 == 1
	    txt = ['handle_txt_list = [' tmp_list ];
	  else
	    txt = [tmp_list];
	  end
	  if loop2 == nr_ht_tlist
	    txt = [txt ' ];'];
	  else
	    txt = [txt ' ...'];
	  end
	  if loop2 > 1
	    fprintf(fid,'\t');
	    fprintf(fid,'\t');
	  end
	  fprintf(fid,'\t');
	  fprintf(fid,'%s \n',txt);
	end
	if nr_ht_tlist == 0
	  txt = ['handle_txt_list = [];'];
	  fprintf(fid,'\t');
	  fprintf(fid,'%s \n',txt);
	end

	fprintf(fid,'\n');
	fprintf(fid,'\n');

	txt = ['handle_list = [handle_ui_list handle_txt_list];'];
	fprintf(fid,'\t');
	fprintf(fid,'%s \n',txt);

	txt = ['set(gcf,''userdata'',handle_list);'];
	fprintf(fid,'\t');
	fprintf(fid,'%s \n',txt);

	fprintf(fid,'\n');
	fprintf(fid,'\n');

	% Write uicontrol object callback commands
	for loop1 = 1:num_uicontrol
	txt = ['elseif command == ' num2str(loop1)];
        fprintf(fid,'%s \n',txt);
	  fprintf(fid,'\t');
	  txt = ['disp(''' deblank(nameset(loop1,:)) ' selected.'')'];
          fprintf(fid,'%s \n',txt);
	  if sum(h(loop1) == t_userdatalist) > 0
		t_ud_ind = find(h(loop1) == t_userdatalist);
	        for loop2 = t_ud_ind
		   txt = ['set(txt' num2str(loop2) ',''string'',num2str(' ...
			'get(' ...
			 deblank(nameset(loop1,:)) ',''value'')));'];
		   fprintf(fid,'\t');
        	   fprintf(fid,'%s \n',txt);
		end
	  end
	end

	txt = ['else'];
        fprintf(fid,'%s \n',txt);
	txt = ['error(''Error: ' filename ...
		'.m called with incorrect command.'')'];
	fprintf(fid,'\t');
        fprintf(fid,'%s \n',txt);
	txt = ['end'];
        fprintf(fid,'%s \n',txt);


   fclose(fid);

end
