function txt = mk_txt_t(handle,name,form_length);
%
%  mk_txt_t.m
%
%  usage:
%		mk_txt_t(handle,name,form_length);
%  where
%
%		handle : handle of text object whose properties are
%			 to be turned in to a text matrix.
%		name   : name that should be applied to this text object.
%		form_length  :	Size of text matrix ('short', 'medium', 
%				'long' -> default = 'long').
%
%  Author :  Patrick Marchand
%  Mods.  :  
%   

%  Copyright (c) 1994 by Patrick Marchand 
%       Permission is granted to modify and re-distribute this 
%	code in any manner as long as this notice is preserved. 
%	All standard disclaimers apply. 

if nargin < 1
	error('Error: mk_txt_t.m used incorrectly');
elseif nargin < 2
	name = [];
	form_length = 'long';
elseif nargin < 3
	form_length = 'long';
end

if strcmp(lower(form_length),'long')
   infoset1 = [
	'Color              '
	'EraseMode          '
	'FontAngle          '
	'FontName           '
	'FontSize           '
	'FontWeight         '
	'FontStrikeThrough  '
	'FontUnderline      '
	'HorizontalAlignment'
	'Position           '
	'Rotation           '
	'String             '
	'Units              '
	'VerticalAlignment  '
	'ButtonDownFcn      '
	'Clipping           '
	'Interruptible      '
	'Selected           '
	'UserData           '
	'Visible            '];
elseif strcmp(lower(form_length),'medium')
   infoset1 = [
	'Color              '
	'EraseMode          '
	'HorizontalAlignment'
	'Position           '
	'Rotation           '
	'String             '
	'Units              '
	'VerticalAlignment  '
	'UserData           '
	'Visible            '];
elseif strcmp(lower(form_length),'short')
   infoset1 = [
	'Color              '
	'EraseMode          '
	'Position           '
	'Rotation           '
	'String             '];
end

[numrow,numcol] = size(infoset1);

txt = [name ' = text(...'];
for loop = 1:numrow
    infosup = get(handle,deblank(infoset1(loop,:)));

    if strcmp(deblank(infoset1(loop,:)),'EraseMode')
	tmp_val = get(handle,'userdata');
	if length(tmp_val) > 0
	  if isstr(tmp_val(1))
	    infosup = ['normal'];
	  else
	    infosup = ['xor'];
	  end
	else
	    infosup = ['normal'];
	end
    end

    if strcmp(deblank(infoset1(loop,:)),'UserData')
	infosup = [];
    end

    if strcmp(deblank(infoset1(loop,:)),'Selected')
	infosup = ['off'];
    end

    if loop ~= numrow
     if isstr(infosup)
       txt = str2mat(txt,['''' deblank(infoset1(loop,:)) ''',''' ...
	infosup ''',...']);
     else
       txt = str2mat(txt,['''' deblank(infoset1(loop,:)) ''',' ...
	mat2str2(round(infosup*100)/100) ',...']);
     end
    else
     if isstr(infosup)
       txt = str2mat(txt,['''' deblank(infoset1(loop,:)) ''',''' ...
	infosup ''');']);
     else
       txt = str2mat(txt,['''' deblank(infoset1(loop,:)) ''',' ...
	mat2str2(round(infosup*100)/100) ');']);
     end
    end
end
