function txt = mk_ui_t(handle,name,form_length,command_number,filename);
%
%  mk_ui_t.m
%
%  usage:
%		mk_ui_t(handle,name,form_length,command_number);
%  where
%
%		handle : handle of uicontrol object whose properties are
%			 to be turned in to a text matrix.
%		name   : name that should be applied to this uicontrol object.
%		form_length  :	Size of text matrix ('short', 'medium', 
%				'long' -> default = 'long').
%		command_number : Command number uicontrol object should
%				 callback.
%		filename : file name of function used in the callback
%
%  Author :  Patrick Marchand
%  Mods.  :  
%   

%  Copyright (c) 1994 by Patrick Marchand 
%       Permission is granted to modify and re-distribute this 
%	code in any manner as long as this notice is preserved. 
%	All standard disclaimers apply. 

if nargin < 1
	error('Error: mk_ui_t.m used incorrectly');
elseif nargin < 2
	name = [];
	form_length = 'long';
elseif nargin < 3
	form_length = 'long';
end

if strcmp(lower(form_length),'long')
   infoset1 = [
	'BackgroundColor    '
	'ButtonDownFcn      '
	'CallBack           '
	'ForegroundColor    '
	'HorizontalAlignment'
	'Max                '
	'Min                '
	'Position           '
	'Enable             '
	'String             '
	'Style              '
	'Units              '
	'Value              '
	'Visible            '
	'ButtonDownFcn      '
	'Clipping           '
	'Interruptible      '
	'Selected           '
	'UserData           '];
elseif strcmp(lower(form_length),'medium')
   infoset1 = [
	'BackgroundColor    '
	'CallBack           '
	'ForegroundColor    '
	'HorizontalAlignment'
	'Max                '
	'Min                '
	'Position           '
	'Enable             '
	'String             '
	'Style              '
	'Units              '
	'Value              '
	'Visible            '
	'UserData           '];
elseif strcmp(lower(form_length),'short')
   infoset1 = [
	'BackgroundColor    '
	'CallBack           '
	'ForegroundColor    '
	'Position           '
	'String             '
	'Style              '
	'Units              '
	'Visible            '
	'UserData           '];
end

[numrow,numcol] = size(infoset1);

txt = [name ' = uicontrol(...'];
for loop = 1:numrow
    if strcmp(deblank(infoset1(loop,:)),'CallBack')
     if nargin == 5
       infosup = [filename '(''''' name ''''');'];
     else
       infosup = ['disp(''''' name ''''');'];
     end
    else
      infosup = get(handle,deblank(infoset1(loop,:)));
    end

    if strcmp(deblank(infoset1(loop,:)),'String')
	[nrs,ncs] = size(infosup);
	tmp_infosup = [' '];
	for loopstr = 1:nrs
	  if loopstr == 1
	    tmp_infosup = [infosup(loopstr,:)];
	  else
	    tmp_infosup = [tmp_infosup '|' infosup(loopstr,:)];
	  end
	end
	infosup = tmp_infosup;
    end

    if strcmp(deblank(infoset1(loop,:)),'UserData')
	infosup = [name];
    end

    if strcmp(deblank(infoset1(loop,:)),'Selected')
	infosup = ['off'];
    end

    if loop ~= numrow
     if isstr(infosup)
       txt = str2mat(txt,['''' deblank(infoset1(loop,:)) ''',''' ...
	infosup ''',...']);
     else
       txt = str2mat(txt,['''' deblank(infoset1(loop,:)) ''',' ...
	mat2str2(round(infosup*100)/100) ',...']);
     end
    else
     if isstr(infosup)
       txt = str2mat(txt,['''' deblank(infoset1(loop,:)) ''',''' ...
	infosup ''');']);
     else
       txt = str2mat(txt,['''' deblank(infoset1(loop,:)) ''',' ...
	mat2str2(round(infosup*100)/100) ');']);
     end
    end
end

