function plpt(x,y,t)
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% plpt          extends to 8 the number of point-types in plot
%
% plpt(x,y,n)   plots a symbol at (x,y) on an "existing" plot
%
%               n=1    'o'     n=5    square
%                 2    '*'       6    triangle
%                 3    '+'       7    
%                 4    'x'       8    diamond
%
%               x, y can be a vector
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% COMMENTS: plpt is normally used to mark chosen points on a
%           curve "already" draw using the regular plot()
%           function.
%
%           It takes a little longer to draw the "square",
%           "triangle", and "diamond", but not unbearably long.
%
%           A "square" (etc.) may not appear a perfect square
%           on a graphics terminal, and the size varies
%           slightly according to the relative position on the
%           plot, but it will come out OK on a laser-printed
%           hardcopy.
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

ax=axis;
hold on

xss=(ax(2)-ax(1))/2200; yss=(ax(4)-ax(3))/1500;
xs=xss*5; ys=yss*5;
if t==1
  plot(x,y,'o')
elseif t==2
  plot(x,y,'*')
elseif t==3
  plot(x,y,'+')
elseif t==4
  plot(x,y,'x')
elseif t==5
  x1=x-10*xss; x2=x+10*xss; y1=y-10*yss; y2=y+10*yss;
  for i=-10:10
    plot(x1,y+i*yss,'.')
    plot(x2,y+i*yss,'.')
    plot(x+i*xss,y1,'.')
    plot(x+i*xss,y2,'.')
  end
elseif t==6
  x1=x-10*xss; x2=x+10*xss; y1=y-7*yss; y2=y+14*yss;
  ys=(y2-y1)/20;
  for i=1:20
    plot(x1+i*xss/2,y1+i*ys,'.')
    plot(x2-i*xss/2,y1+i*ys,'.')
    plot(x1+i*xss,y1,'.')
  end
elseif t==7
  plot(x-xs,y-ys,'+')
  plot(x-xs,y+ys,'+')
  plot(x+xs,y-ys,'+')
  plot(x+xs,y+ys,'+')
elseif t==8
  xss=xss*1.4; yss=yss*1.4;
  x1=x-10*xss; x2=x+10*xss; y1=y-10*yss; y2=y+10*yss;
 for i=1:10
  plot(x1+i*xss,y+i*yss,'.')
  plot(x+i*xss,y2-i*yss,'.')
  plot(x2-i*xss,y-i*yss,'.')
  plot(x-i*xss,y1+i*yss,'.')
 end
else
  plot(x,y)
end
