%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% zoom    to zoom in on a part of an "existing" plot
%
%         You must have an M-file to create the original plot.
%         The name of the M-file is then assigned to a global
%             variable PLOT.                           ------
%
% zoom(x,y,n)  redraws the plot with a magnification factor n
%              about the point (x,y).  Effects of successive
%              zooms are accumulative.  n can be any real.
%              (n < 1 means zooming out.)
%
% zoom(x1,y1,x2,y2)  redraws the plot with the specified
%              rectangle as the new boundary.  Can be followed
%              by a zoom of the first form.
%
% zoom(0)      recovers the original plot.
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% EXAMPLE: Create an M-file "plgraph.m" containing the lines:
%
%                                _____________________________
% global PLOT, PLOT='plgraph';  %
% x = 0.001 : 0.001 : 3;        % x, y, z may be data obtained
% y = x.*sin(x.^(-1));          %    from earlier computations.
% z = x.*cos(3*x);              % If so, they do not have to
% plot(x,y,'-',x,z,'--')        %    be defined in the M-file.
% title('Zoom For Fun')         %_____________________________
%
%
% IMPORTANT: The M-file CANNOT contain an "axis" statement
%            ---------------------------------------------
%
%     Issue the command "plgraph" to plot the original graph.
%     Then use zoom(0,0,2) or zoom(.2,.2,3) a few times.
%
%     The accuracy of the magnified graph is determined by
%         the data supplied in "plgraph".  zoom DOES NOT put
%         in extra points.  To increase the accuracy of the
%         zoomed in graphs, you must change the 1st statement
%         in "plgraph.m" to something like
%
% x=0.0001:0.0001:0.001.
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function zoom(x,y,x1,y1)

if exist('PLOT') ~= 1
  disp('')
  disp('^* You must have a global variable PLOT holding the name of an M-file')
  disp('    that defines the plot.  Use the command:')
  disp('')
  disp('global PLOT, PLOT = ''plgraph''')
  disp('')
elseif exist(PLOT) ~= 2
  disp('')
disp('^* The graph plotting M-file defined by')
PLOT
disp('^* does not exist')
  disp('')
else
  hold off
if nargin == 3
  n=x1;
  ax1=axis;
  hold off
  axx=(ax1(2)-ax1(1))/(2*n);
  axy=(ax1(4)-ax1(3))/(2*n);
  axis([ x-axx x+axx y-axy y+axy ])
  eval(PLOT)
  hold off
elseif nargin == 4
  tmp=y; y=x1; x1=tmp;
  ax=[ x x1 y y1 ];
  axis(ax)
  eval(PLOT)
  hold off
elseif nargin == 1
  eval(PLOT)
else
  disp('Error in  of arguments')
end
end
