function  links = findlink(objlist);

% FINDLINK  Find all links in the group of objects
%     Checks  "userdata" properties of all the objects in the group
%     and finds rows whose first element (or first group of characters
%     for string) coincides with "link identification number".
%    LINKS = FINDLINK(OBJLIST) returns the matrix of all links
%     found among the objects with handles specified by OBJLIST.

%  Kirill K. Pankratov,  kirill@plume.mit.edu
%  April 3, 1994

lex = .234886;    % Generic link identification number

slex = sprintf('%7.6f',lex);
slex = slex(2:length(slex));
lslex = length(slex);

objlist = objlist(:);

% Store all text links in the matrix "Links"
links = [];
for jk = 1:length(objlist)
  usd = get(objlist(jk),'user');  % Get userdata
  szu = size(usd);
  iss = isstr(usd);
  if iss                   % If userdata is string
    if szu(2)>lslex+10      % Find coinciding characters
      A = (usd(:,1:lslex)==slex(ones(szu(1),1),:));
      A = A+(usd(:,2:lslex+1)==slex(ones(szu(1),1),:));
      A = A+(usd(:,3:lslex+2)==slex(ones(szu(1),1),:));
      fnd = find(all(A'));
      for jf = 1:length(fnd)  % Add to the links matrix
        clink = sscanf(usd(fnd(jf),:),'%g');
        links(size(links,1)+1,1:length(clink)+1) = [objlist(jk) clink(:)'];
      end
    end
  else                     % If userdata is a number
    if szu(2)>10
      A = usd(:,1)-floor(usd(:,1));
      fnd = find(abs(A-lex)<1e-10);
      for jf = 1:length(fnd)
        clink = usd(fnd(jf),:);
        links(size(links,1)+1,1:length(clink)+1) = [objlist(jk) clink(:)'];
      end
    end
  end
end
