function  txto = findtxto(h)

% FINDTXTO  Finds all text objects of a given parent.
%     TXTO = FINDTXTO(H)  returns the column vector TXTO
%       containing handles of all text objects with parent H.
%       If H is figure returns the children, titles and labels of
%       text objects from all axes of this figure.
%       If H is axes returns their children, titles and labels.
%       If H is a text object, returns itself.
%       If H is any other object, returns [].
%       If H is not specified, it set to be the handle of 
%       the current figure.

%  Kirill K. Pankratov  kirill@plume.mit.edu
%  April 3 1994.

if nargin==0, h = gcf; end  % Default parent is current figure

 % Get relevant axes
kida = [];
if strcmp('figure',get(h,'type'))    % Parent handle is figure
  kids = get(h,'children');
  for jk = 1:length(kids)
    if strcmp('axes',get(kids(jk),'type'))
      kida = [kida; kids(jk)];
    end
  end
elseif strcmp('axes',get(h,'type'))   % Parent handle is axes
  kida = h;
else                                  % Parent handle is object itself
  if strcmp('text',get(h,'type')), txto = h; end
  return
end

 % Get children and labels of all relevant axes
kids = [];
for jk = 1:length(kida)
   kids = [kids; get(kida(jk),'child')];
   kids = [kids; get(kida(jk),'title'); get(kida(jk),'xlabel')];
   kids = [kids; get(kida(jk),'ylabel'); get(kida(jk),'zlabel')];
end

 % Now find all text objects among kids
txto = [];
for jk = 1:length(kids)
  if strcmp('text',get(kids(jk),'type'))
    txto = [txto; kids(jk)];
  end
end

