% LINKDEMO  Demonstration program of the LINK utility.
%   Invoked by itself or by the command   LINK DEMO

%  Kirill K. Pankratov,  kirill@plume.mit.edu
%  April 3, 1994

echo on

%        WELCOME TO THE  "LINK"  UTILITY!
%
%   LINK is a toolbox which allows user to easily create complex text
% objects with different fonts, styles, subscripts and superscripts,
% consisting of several lines with various alignment and spacing.
% This program demonstrates just a few of its capabilities. The main
% command of this toolbox is LINK(OBJECT,FLAG) which is applied to one
% or several text objects with handles OBJECT and string FLAG specifies
% the type of operation.
%   This toolbox requires 4.1 and later versions since it operates
% directly with MATLAB Handle Graphics objects.

 pause  % Hit any key to continue ...
 figure

%   Before explaining the rules and the grammar to build a complex
% text, let's show a simple example:

 x = 0:.1:2*2*pi; y = cos(x).^2;
 plot(x,y,x,zeros(size(x)),'c--',x,ones(size(x)),'c--')
 axis([min(x) max(x) -.2 1.2])

 string = ['\link Here is a simple rule:  \yellow cos^{2}'...
           '{\cyan \alpha} = (1-cos{\cyan 2\alpha})/2']

% Create a text object containing this string:

 t1 = text(2,1.1,string);

 pause   % Hit any key to continue ...

% Now process it with a LINK command, in it simplest form:

 link;

%   You can see that the original text disappeared (actually it is just
% made invisible) but instead we obtain a nicer-looking text containing
% greek as well as latin letters, superscript and different colors.
%   Those of you familiar with  LaTeX editor would immediately recognize
% the syntax for making composed texts. Well, it is not exactly like in 
% LaTeX, but many tricks are identical or similar. If you haven't used
% LaTeX this can serve as a simple itroduction to its syntax.

  pause   % Hit any key to continue ...

%   The main points of the syntax are following:
%
%   The commands that determine the appearance of the text (fonts,
% sizes, color, subscripts etc.) are written together with the text
% itself but distinguished from it by special characters like
%  "\", "{", "}", "_", "^".
%   There are more special characters in the LaTeX itself, but for our
% case a simpler grammar would suffice. All commands (as distinguished
% from the text itself) should  start with "\", for example  \red 
% (equivalent to \color{[1 0 0]}) or \Large (equivalent to \fontsize{18})
% or  \n  which starts a new line (note that this is C and MATLAB 
% rather than the LaTeX notation).
% The command must end with a blank character (in which case it is 
% ignored for text), one of the special charatcers: "{", "}", "_", "^",
% or one of the other "separator" characters:
% ".", ",", ";" ,"(", ")" "=".
%   The commands typically define the "environment" for the subsequent 
% text until a new command for the same property (color, fontsize, etc.)
% is encountered. The curly brackets "{}" define a different environment
% inside them and when closed the "old" commands, issued before
% opening brackets, are valid.
%   For example the string:
%
%  \yellow We shall start with {\em yellow} text, then insert a {\blue
% blue word}, and shall end with \times \white some white-colored text
%
% will be interpreted in a following manner: "We shall start with "
% will be yellow with normal font angle, "yellow" will be also yellow
% and italic (\em and \italic are equivalent), " text, then insert 
% " will be normal again, "blue word" will be blue, ", and shall end
% with " yellow again, "some white-colored text" will be white and
% in times fontname.

%  !!!   One important thing: text must start with "\link" or simply 
%       "\l" command to be interpreted in this manner.   !!!

 pause   % Hit any key to continue ...
 clg

% Let's make another, more sophisticated example:

 string = ['\l \doublespace \center {\color{[1 .3 1]} \LARGE Good '...
          'news! } \n Now you can write '...
          'a text with {\palatino different } {\times  fonts,} '... 
          '{\courier sizes,} \n like \yellow {\Large large}, {\huge huge} '...
          'or {\small small} and {\tiny tiny}\n \white and also \cyan words'...
          '^{with super-} _{and subscripts} \n \white as well as '...
          '\italic greek letters: \alpha,\beta,\gamma, ...']

 t2 = text(.1,.8,string);  % Create a text object ...
 pause   % Hit any key to continue...

 link(t2);  % Please be patient, it will take some time ...

%   OK, we've got it.
% Generally we need to input the object to be "linked" (in our case t2).
% If object is not specified the command LINK will find all the text
% objects of the current figure and and "link" all of them whose string
% starts with "\l".
%   In our present example the text consist of multiple lines. Their 
% alignment and spacing can also be controlled by the inside LaTeX-type
% commands:
%   \singlespace, \doublespace, \linespace{1.5}   are among the legal
% options,
% \flushleft, \center \flushright   will control the alignment of
% different lines.
%   Greek characters are produced by writing their English spelling after
% "\": \alpha, \Epsilon etc. The command LINK GREEK displays the part of
% the "dictionary" LINKSYNT file with the Greek alphabet.
%   Another feature which you can notice is subscript and superscript
% words. This can be produced again similar to LaTeX by typing  _{any 
% text} for a subscript and  ^{any text} for a superscript.

 pause   % Hit any key to continue...

%   Now let's try to compose some relatively complex mathematical
% statement:

 string = ['\l \yellow \flushleft \f14 Discrete {\myc Fourier transform}'...
           '\n can be'... 
           ' written {\em  as follows:} \doublespace \n '...
           'F(k) = {\LARGE \Sigma}'...
           ' _{\small j=0}^{\small j=N} f(x_{j})*exp^{-i*2\pi kx_{j}}']

 t3 = text(.1,.3,string);  % Create a text object ...
 pause   % Hit any key to continue...

 link(t3);

%   This example illustrates more complex sub- and superscripting and
% also another feature, available for many text editors, including the
% LaTeX: the "macros" commands.
%   You can make a short versions of the more complicated commands 
% and denote them with some name you chose. Then the command such as 
% "\myname" will be interpreted as "macro" and the program will look 
% into the "dictionary" file LINKMACR for "translation" of this
% command. In our case there are two "macros": \f14  which  is 
% translated as "\fontsize{14}" and "\myc" which stands for
% "\color{[.5 1 1]}" (see LINKMACR file). You can put there any commands
% that you consider convenient. We hope the syntax is not very
% difficult and you can learn it youself by trying.
%   The LINKMACR file can be displayed in your command window by the
% typing  LINK MACRO, (or, equivalently, LINK('MACRO')),
% actually even  LINK MA  would suffice.

 pause   % Hit any key to continue...

%   If we want to change the position and rotation of the "root" text,
% it should affect the properties of other text objects "linked" to
% it. For example:

 set(t3,'position',[.0 .0],'rotation',45)

 % Now to make necessary changes we need to "update" the "link":

 link(t3,'update');    %  Actually   link(t3,'up')  will do ...

%   OK, the text shifted and turned as we wanted.
% 
 pause  % Hit any key to continue ...

%  You can impose some properties of the text in the usual Handle
% Graphics manner, setting them to the "root" text object;

 string = ['\l {\slanted P}(x_{1},x_{2}) = {\bold \Large e} '...
          '^{-x\2_{1}-x_{2}\2}']
 ylabel(string)
 t4 = get(gca,'ylabel');

 set(t4,'fontsize',14,'color',[1 1 0]) % This will set text properties

 link(t4);

 pause  % Hit any key to continue ...

%  Special characters themselves can be plotted again using the command
% character "\"

 string = ['\l {\bf MATLAB} uses character  \^  for power, '...
           '\n like 2\^ 3 = 8,  \\  as "left" division for matrices,'...
           '\n and brackets  \{, \}  are not used at all']
 t5 = text(.4,.25,string)

 L = link(t5)      % This command will return the "link" matrix

 pause  % Hit any key to continue ...

%   The returned matrix  L contains information about the "links" or
% connections between the different text objects. This information
% is also written into "userdata" property of these objects.
 
%    Now suppose we want to change the size of the window and the
% limits of the axes:

 axis([-.3 1.2 0 1])
 set(gcf,'pos',[150 400 1000 450])

%   The different text objects are shifted and do not look very nice
% now. To bring them back together you need to "update" the links
% between them. To illustrate the command which does that we shall
% make it in two steps. First, we shall update only two composed 
% texts:

 pause  % Hit any key to continue ...

 link([t2 t3],'update')

 pause  % Hit any key to continue ...

%  Now let's update the rest of them:

 link('up');

%   All the texts are back to normal.
%   If you do not like the appearance of some of the objects or want
% to delete them use the command LINK with a flag CLOSE.
% Let's delete the last composed text:

 link(t5,'close');

 pause  % Hit any key to continue ...

%   Now suppose you want to print the result on paper. Generally
% the size of the figure on the screen and on paper are different.
% The text groups which look right on screen will be distorted.
%    You need to prepare the figure for printing, that is make it
% appear on screen as it will look on paper. To do this we supplied
% the command PREPRINT. Its general syntax is
%   PREPRINT(POSITION,COLOR)
% and controls the position (4 numbers) of the figure on paper (in inches)
% and if necessary will make background specified by  COLOR
% (3 numbers), this is convenient to make color slides.
% PREPRINT by itself will set the screen position specified by the 
% "paperposition" property of the figure.
% You can also set the position and the background color by
% "macros" instead of numbers. For example we want to print our figure 
% in the upper part of a paper sheet:

 preprint upper

 pause  % Hit any key to continue ...

%   You can find the "macros" in the text file PPMACR. the command
% PREPRINT MACRO will display its content. You can put additional
% positions and colors for your convenience.

%   The command PREPRINT  also updates all links automatically.
% You can use it event if you do not have LINK environment, in this
% case only positionand background color will be affected.
%   Now you can print the result of this demonstration if you wish.

 pause  % Hit any key to continue ...

%   Finally we shall make a summary of the link command with its
% different flags (options).

% Its general syntax is   LINK(OBJECTS,FLAG), where
%  OBJECTS are the handles of the  original (root) text objects to
% be "linked". The LINK command will be applied to only those texts
% whose string begins with "\link" (or "\l") command. If OBJECTS
% are not specified then all texts of the current figure (incliding 
% title and labels) are considered for "linking".
%  FLAG is the name of the operation within the LINK environment.
%  If FLAG is not specified the new text objects are created,
%  according to the commands written in the string of the root objects.
% LINK('ON') or LINK('ENABLE')  "activate" existing links, while
% LINK('OFF') or LINK('DISABLE') "disable" them, without deleting the
%  text objects or loss of information about the "links".
% LINK('UPDATE')  "updates" the positions of the text objects 
%  according to new axes limits or figure position.
% LINK('CLOSE') closes (deletes) all the text objects "linked" to the
%  root objects, specified by OBJECTS handles.
%    There are also some helping and displaying options:
% LINK('INFO') (or LINK INFO) displays some additional information
%  about this utility.
% LINK('DEMO')  runs this demonstration,
% LINK('MACRO') displays the list of "macros" in the LINKMACR file,
% LINK('SYNT')  displays the main "dictionary" file  LINKSYNT,
% LINK('GREEK') displays the part of this file containing Greek letters,
% LINK('STYLES') displays the other part of this file, with main 
%  environment commands, specifying text properties.
%   For all these options the abbreviations are possible: for example
% LINK ST will suffice for "STYLES".

 pause  % Hit any key to continue ...

%   OK. We have considered only a few examples and capabilities of
% the LINK command. To learn more about it, look directly into
% the HELP and INFO utilities of the LINK command and to the
% "dictionary" file  LYNKSYNT.  We hope you will master the grammar
% of composed texts easily enough.

%  If you have any problems or suggestions about this utility, please
% contact the author:
%   Kirill K. Pankratov:  kirill@plume.mit.edu

% Good luck. Thank you for your time. Bye.
 
echo off

