function  linkupd(Link)

% LINKUPD   "Updates" the links between the different parts of a
%     complex text.
%     Positions text objects according to the links prescribed
%     in the  Link  matrix.
%     Invoked from the command LINK or MAKELINK.

%  Kirill K. Pankratov
%  April 1, 1994

 % Make root a first line .........................
A = Link(:,[4:6 8:10]);
fnd = find(all(A'==0));
if fnd==[], fnd = 1; end
num = [fnd(1) 1:fnd(1)-1 fnd(1)+1:size(Link,1)];
Link = Link(num,:);

 % Get various figure and axes properties .........
oldunits = get(Link(1,1),'units');
set(Link(1,1),'units','norm')
posr = get(Link(1,1),'position');  % Root text position
set(Link(1,1),'pos',posr)
angr = get(Link(1,1),'rotation');  % Root text orientation
ax = axis;
fig = get(0,'currentfigure');
oldaxunits = get(gca,'units');  % Axes units
set(gca,'units','pixels')       % Set to pixels temporarily
sza = get(gca,'pos'); 
sza = sza(3:4);                 %  Size of the axes in pixels

set(Link(1,1),'Visible','off')

 % Get the root horizontal and vertical alignment .......
ha = get(Link(1,1),'horizontalalignment');
ha = strcmp(ha,'left')+2*strcmp(ha,'center')+3*strcmp(ha,'right');
va = get(Link(1,1),'verticalalignment');
num = va(1)=='tcmb';
va = num(1)+num(2)+2*num(3)+3*num(4);
set(Link(1,1),'units','norm')

 % First update of the links ..................................
for jl = 2:size(Link,1)
  set(Link(jl,1),'rot',0)
  pos = get(Link(jl,1),'pos');
  if Link(jl,3)
    ext = get(Link(jl,4),'extent');
    pos(1) = ext(1)+Link(jl,5)+ext(3)*Link(jl,6);
  end
  if Link(jl,7)
    ext = get(Link(jl,8),'extent');
    pos(2) = ext(2)+Link(jl,9)+ext(4)*Link(jl,10);
  end
  set(Link(jl,1),'units','norm','pos',pos)
  set(Link(jl,1),'fontsize',get(Link(jl,1),'fontsize'))
  set(Link(jl,1),'fontname',get(Link(jl,1),'fontname'))
  set(Link(jl,1),'fontweight',get(Link(jl,1),'fontweight'))
  set(Link(jl,1),'fontangle',get(Link(jl,1),'fontangle'))
end

linenum = Link(2:size(Link,1),12);
lineflush = 10*(linenum-floor(linenum));
linenum = floor(linenum);
linenum = linenum+(linenum<1);
nline = max(linenum);
exh = zeros(nline,2);
num = 1;
for jl = 1:nline
  fnd = find(linenum==jl);
  ext = zeros(length(fnd),4);
  for jf = 1:length(fnd)
    ext(jf,:) = get(Link(fnd(jf)+1,1),'extent');
  end
  ext(:,3:4) = ext(:,1:2)+ext(:,3:4);
  [ext(:,3),num1] = sort(ext(:,3));
  num = [num; fnd(num1)+1];
  exh(jl,:) = [min(ext(:,1)) max(ext(:,3))];
  if jl==1, exv(2) = max(ext(:,4)); end     % Max. vertical
  if jl==nline, exv(1) = min(ext(:,2)); end % Min. vertical
end
Link = Link(num,:);  % Sorted links


 % Adjust the positions for each line .........................
 % Horizontal positions:
widl = exh(:,2)-exh(:,1);    % Width of each line
cnum = find(widl==max(widl));
cnum = min(find(linenum==cnum))+1;
posw = get(Link(cnum,1),'pos');
posw(1) = posr(1)-max(widl)*(ha-1)/2;  % Widest line
set(Link(cnum,1),'pos',posw)
 % Set the position of the beginning of each line
for jl = 1:nline
  cnum = min(find(linenum==jl))+1;
  pos = get(Link(cnum,1),'pos');
  pos(1) = posw(1)+(lineflush(cnum-1)-1)/2*(max(widl)-widl(jl));
  set(Link(cnum,1),'pos',pos)
  Link(cnum,3) = 0;  % Disable x-link temporarily
end

 % Vertical position
pos = get(Link(2,1),'pos');
ext = get(Link(2,1),'ext');
pos(2) = posr(2)+(exv(2)-exv(1))*(va-1)/2-1.7*ext(4);
set(Link(2,1),'pos',pos)


 % Update once more ..........................................
set(Link(1,1),'units','norm')
for jl = 3:size(Link,1)
  pos = get(Link(jl,1),'pos');
  exto = get(Link(jl,1),'extent');
  extr = get(Link(jl,4),'extent');
  ext0(1) = extr(1)+Link(jl,5)+extr(3)*Link(jl,6);
  if floor(Link(jl,11)), ext0(1) = ext0(1)-4/sza(1); end
  extr = get(Link(jl,8),'extent');
  ext0(2) = extr(2)+Link(jl,9)+extr(4)*Link(jl,10);
  if Link(jl,3), pos(1) = pos(1)+ext0(1)-exto(1)+2/sza(1); end
  if Link(jl,7), pos(2) = pos(2)+ext0(2)-exto(2); end
  set(Link(jl,1),'pos',pos);
end

 % Adjust the baseline for different fontsizes ...........
for jl = 2:size(Link,1)
  ftsz = get(Link(jl,1),'fontsize');
  pos = get(Link(jl,1),'pos');
  pos(2) = pos(2)-(ftsz-12)/6/sza(2);
  set(Link(jl,1),'pos',pos);
end

 % Rotate all pieces if necessary ........................
if angr~=0
  angr = angr*pi/180;
  for jl = 2:size(Link,1)
    ar = sza(2)/sza(1);
    pos = get(Link(jl,1),'pos');
    vec = pos-posr; vec(2) = vec(2)*ar;
    ang = angr;
    pos(1) = posr(1)+vec(1)*cos(angr)-vec(2)*sin(angr);
    pos(2) = posr(2)+vec(1)*sin(angr)+vec(2)*cos(angr);
    pos(2) = pos(2)/ar;
    set(Link(jl,1),'pos',pos,'rotation',angr*180/pi)
  end
end

if strcmp(get(Link(1,1),'visible'),'on') % Hide labels
  set(Link(1,1),'color',get(gcf,'color'));
end
set(gca,'units',oldaxunits)      % Set axes unit back
set(Link(1,1),'units',oldunits)  % Set root object units back
