function  Link = makelink(obj,ln,string)

% MAKELINK  Translates the input string (in LaTeX-type mode)
%    and creates text objects for complex texts.
%   MAKELINK(OBJ,LN,STRING) translates the STRING of the root object
%    OBJ and creates "links" with link id number LN.
%    All 3 input arguments are nesessary.
%    Internal program for LINK utility, invoked inside LINK command

%  Kirill K. Pankratov,  kirill@plume.mit.edu
%  April 2, 1994, last revision April 21, 1994.

lid = ln+.234886;  % Link identification number

 % Enter relative position coefficients
coeflx = [0 0; 0 1; .001 0];
lnspcf = .5;   % Relative unit space between the lines
coefly = [0 0; 0 .0; 0 -.3; 0 .5; 0 -lnspcf];

 % Translation of string for text linking
linkmacr = file2strmat('linkmacr');
linksynt = file2strmat('linksynt');

 % Find macros and commands .......................................
cstr = ['  ' string ' '];
fnd = 1;
sep = [' ,.;={}()']'; es = ones(size(sep));
while fnd~=[]
  fndbc = find(cstr=='}');
  if fndbc~=[]
    str = cstr(fndbc+1);
    fndbc = fndbc(find(str=='_'|str=='^'|str=='{'));
    numbr = [1:length(cstr) fndbc];
    cstr = [cstr setstr(' '*ones(size(fndbc)))];
    [numind,numbr] = sort(numbr);
    cstr = cstr(numbr);
  end

  fndo = find(cstr=='\');
  vec1 = any(sep(:,ones(size(cstr)))==cstr(es,:));
  fndo = fndo(cstr(fndo-1)~='\');
  fndc = find(vec1|cstr=='_'|cstr=='^');
  vec2 = sort([fndo fndc]);
  vec1 = zeros(size(cstr));
  vec1(fndc) = ones(size(fndc));
  vec1 = vec1(vec2);
  fnd = find(diff(vec1)==1);
  fndc = vec2(fnd+1);
  entries = cstr(fndo(1)+1:fndc(1));
  for jc = 2:length(fndo)
    num = fndo(jc)+1:fndc(jc)-(fndc(jc)-fndo(jc)>1);
    cmd = cstr(num);
    entries = str2mat(entries,cmd(1:length(cmd)));
  end

   % Insert macros
  [ech,head] = findecho(linkmacr,entries);
  fnd = find(ech(:,1)~='?');
  if fnd~=[]
    for jf = 1:length(fnd)
      nc = fnd(jf);
      word = ech(nc,:);
      word = word(1:max(find(word~=' ')));
      lw = length(word);
      lm = fndc(nc)-fndo(nc);
      cstr = [cstr(1:fndo(nc)-1) word cstr(fndc(nc):length(cstr))];
      fndo = fndo+lw-lm; fndc = fndc+lw-lm;
    end
  end
end

lstr = length(cstr);
fndbo = find(cstr=='{');
if fndbo~=[], fndbo = fndbo(cstr(fndbo-1)~='\'); end
fndbc = find(cstr=='}');
if fndbc~=[], fndbc = fndbc(cstr(fndbc-1)~='\'); end
numbr = zeros(size(cstr));
numbr(fndbo) = ones(size(fndbo));
numbr(fndbc) = -ones(size(fndbc));
numbr = cumsum(numbr);

fndl = find(cstr(fndbo-1)=='_'&cstr(fndbo-2)~='\');
fndu = find(cstr(fndbo-1)=='^'&cstr(fndbo-2)~='\');
numind = zeros(size(cstr));
numind(fndbo(fndl)) = ones(size(fndbo(fndl)));
numind(fndbo(fndu)) = 2*ones(size(fndbo(fndu)));
for jc = 1:length(fndl)   % Lower index
  nc = fndbo(fndl(jc));
  ns = min(find(numbr(nc:lstr)<numbr(nc)))-1;
  numind(nc+ns) = -1;
end
for jc = 1:length(fndu)   % Upper index
  nc = fndbo(fndu(jc));
  ns = min(find(numbr(nc:lstr)<numbr(nc)))-1;
  numind(nc+ns) = -2;
end
numind = cumsum(numind);

fndc1 = fndc(cstr(fndc)==' ');
vec1 = zeros(size(cstr));
vec1(fndo) = ones(size(fndo));
vec1(fndc) = -ones(size(fndc));
vec1 = cumsum(vec1);
vec1 = 1-vec1;
vec2 = [fndo fndbo(fndl)-1 fndbo(fndu)-1 fndbo fndbc];

 % Translate commands
[ech,head] = findecho(linksynt,entries);
A = ech==' ';
fnd = find(all([A A]'));
if fnd~=[], ech(fnd,1:size(entries,2)) = entries(fnd,:); end
if size(head,2)==1, head = [head setstr(' '*ones(size(head,1),1))]; end
isloc = head(:,2)=='\';
iscmd = head(:,1)==' '&head(:,2)==' ';
islit = isloc|iscmd;
fnd = find(islit);
for jf = 1:length(fnd)
  word = ech(fnd(jf),:);
  word = word(1:max(word~=' '));
  nc = fndo(fnd(jf));
  num1 = nc+1:nc+length(word);
  vec1(num1) = ones(size(word));
  cstr(num1) = word;
end
fnd = find(isloc);
[ech1,head1] = findecho(linksynt,head(fnd,3:size(head,2)));
A = ech1==' ';
num1 = find(all([A A]'));
if num1~=[]
  ech1(num1,1:size(head,2)-2) = head(fnd(num1),3:size(head,2));
  ech(isloc,1:size(ech1,2)) = ech1;
  head(isloc,1:size(head1,2)) = head1;
end
iscmd = head(:,1)==' '&head(:,2)==' ';
fnd = find(~iscmd);
numcmd = zeros(size(cstr));
numcmd(fndo(fnd)) = ones(size(fndo(fnd)));
numcmd = cumsum(numcmd);
head = head(fnd,:);
ech = ech(fnd,:);
fndo = fndo(fnd);
fndc = fndc(fnd);
lstr = length(cstr);

  % Check for input '<'
fnd = find(ech(:,1)=='<');
for jf = 1:length(fnd)
  nc = fndc(fnd(jf));
  if cstr(nc) == '{'  % If there is an input
    lmin = min([find(cstr(nc+1:lstr)=='}') lstr])-1;
    word = cstr(nc+1:nc+lmin);
    ech(fnd(jf),:) = setstr(' '*ones(1,size(ech,2)));
    ech(fnd(jf),1:lmin) = word;
    vec2 = [vec2 nc:nc+lmin+1];
  else
    ech(fnd(jf),:) = [ech(fnd(jf),2:size(ech,2)) ' '];
  end
end
fnd = find(ech(:,1)=='?');
ech(fnd,:) = setstr(' '*ones(size(fnd),size(ech,2)));
head(fnd,:) = setstr(' '*ones(size(fnd),size(head,2)));
head = head(:,2:size(head,2));
ech = setstr(ech+' '*(ech==0));
head = setstr(head+' '*(head==0));

 % Find if new name
A = head*head';
v1 = sum((head.*head)');
A = v1(ones(size(A,1),1),:)-A;
A = cumprod(A~=0);
v1 = sum(A)+1;
v2 = zeros(size(v1));
v2(v1)=1:length(v2);
fndp = find(v2);
propn = head(fndp,:);
v2(fndp) = 1:length(fndp);
v2 = v2(v1);
lh = size(head,1);
npn = size(propn,1);
Nump = zeros(lh,npn);
Nump((v2-1)*lh+(1:lh)) = 1:lh;


 % Check for cumulatives (new lines) ......
word = 'linenum=';
lmin = min(length(word),size(propn,2));
A = word(ones(size(propn,1),1),1:lmin)==propn(:,1:lmin);
fndl = find(all([A A]'));
if fndl~=[], Nump(:,fndl) = cumsum(Nump(:,fndl)>0)+1; end

 % Extract text ...........................
vec1(vec2) = zeros(size(vec2));
vec1([1 2 length(cstr)]) = zeros(1,3);
cstr = cstr(vec1);
numbr = numbr(vec1);
numind = numind(vec1);
numcmd = numcmd(vec1);
vec1(fndc1) = 2*ones(size(fndc1));
vec2 = vec1(find(vec1));

lstr = length(cstr);
Num = zeros(lstr,size(Nump,2));
Lin = zeros(lstr,1);
isl = zeros(1,size(Nump,2));
if fndl~=[]
  linenum = Nump(:,fndl);
  isl(fndl) = ones(size(fndl));
else
  linenum = ones(size(Nump,1),1);
end

 % Check for fontsize
word = 'fontsize';
lmin = min(length(word),size(propn,2));
A = word(ones(size(propn,1),1),1:lmin)==propn(:,1:lmin);
fndf = find(all([A A]'));
if fndf==[], fndf = 0; end

 % Set properties according to environment
ftind = zeros(lstr,1);
for jc = 1:size(Nump,1)
  lmin = max([find(numcmd<jc) 0])+1;
  lmax = min([lmin+find(numbr(lmin:lstr)<numbr(lmin))-1 lstr+1])-1;
  if isloc(jc), lmax = lmin; end
  nc = find(Nump(jc,:)&isl==0);
  Lin(lmin:lstr) = linenum(jc)*ones(size(lmin:lstr))';
  if nc~=[]&lmin
    num = (lmin:lmax)';
    Num(num,nc) = jc*ones(size(num));
    if nc==fndf(1)&all(numind(num))
      ftind(num) =  ones(size(num));
    end
  end
end
Num = [Num numind' Lin];
fnd = [0; find(any(diff(Num)'))'; lstr];   % New words

 % Extract non-property commands
ispr = zeros(size(propn,1),1);
for jp = 1:size(propn,1)
  word = propn(jp,:);
  word = word(1:max(find(word~=' ')));
  if word~=[], ispr(jp) = word(length(word))=='=';
  else, ispr(jp) = -1; end
end
fndc = find(ispr==1);
fndp = find(ispr==0);

 % Make explicit commands to create text objects .................
lname  = 'linkobj';
digits = abs(':.0123456789')';
ed = ones(size(digits,1),1);

texm = ' ';
jw = 1;
numind = 0; linenum = 0;
isftsz = 0;
Cmd = [];
for jf = 2:length(fnd)   % Begin words cycle ````````````````````````
  num = fnd(jf-1)+1:fnd(jf);
  num = num(find(vec2(num)~=2));
  word = cstr(num);
  noword = word==[]|strcmp(word,' ');
  if ~noword
     % Commands
    if fndc~=[], Cmd(jw,:) = Num(num(1),fndc); end
    numind(jw,:) = Num(num(1),size(Num,2)-1);
    nbr(jw) = numbr(num(1));
    linenum(jw) = Lin(num(1));
    isftsz(jw) = ftind(num(1));
    pv = Num(num(1),fndp);
    fndn = find(pv);
    pv = pv(fndn);
    jw = jw+1;
    str = [lname '(' num2str(jw) ')' '=text(''string'',''' word ''','];
    texm = str2mat(texm,str);
     % Now insert all properties
    for jp = 1:size(pv,2) % Begin properties cycle ``````````````
      cpn = propn(fndp(fndn(jp)),:);
      cpn = cpn(1:max(find(cpn~=' ')));
      cpv = ech(pv(jp),:);
      cpv = cpv(1:max(find(cpv~=' ')));
      if cpn~=[]&cpv~=[]      % If both name and value not empty
        isn = all(any(cpv(ed,:)==digits(:,ones(1,size(cpv,2)))));
        if cpv(1)~='['&~isn
          str = [' ''' cpn ''',''' cpv ''','];
        else
          str = [' ''' cpn ''',' cpv ','];
        end
      end
      texm = str2mat(texm,str);
    end   % End jp (properties) cycle '''''''''''''''''''''''''''
    texm(size(texm,1),length(str):length(str)+1) = ');';
  end
end   %  End words cycle ''''''''''''''''''''''''''''''''''''''''''''''''
texm = texm(2:size(texm,1),:);
texm = setstr(texm+' '*(texm==0));
%disp(texm)
Cmd = Cmd+(Cmd==0);


 % Create text objects written in "texm" ...................
linkobj = zeros(jw,1);
linkobj(1) = obj;
fnd = [find(texm(:,1)~=' '); size(texm,1)+1];
for jf = 1:length(fnd)-1  % For each piece of text
  str = texm(fnd(jf):fnd(jf+1)-1,:)';
  str = str(:)';
  eval(str)
end

 % Other commands
linespace = ones(length(linkobj)-1,1);
lineflush = ones(length(linkobj)-1,1);
for jf = 1:length(fndc)
  word = propn(fndc(jf),:);
  word = word(1:max(find(word~=' ')));
  if ~strcmp(word,'linenum=')
    num = ech(Cmd(:,jf),:)';
    fnd = find(all(num==' '));
    if fnd~=[], num(1,fnd) = setstr('1'*ones(size(fnd))); end
    num = sscanf(num(:)','%f');
    eval([word 'num;'])
  end
end

 % Form "Link" matrix ...............................................
 % Fill in general information
Link = zeros(size(linkobj,1),12);     % Create Link matrix
Link(:,2) = lid*ones(size(linkobj));  % Link id
Link(:,1) = linkobj;                  % Object handles
Link(:,3) = ones(size(linkobj));      % Enable x
Link(:,7) = ones(size(linkobj));      % Enable y
Link(2,5:6) = coeflx(1,:);            % First piece
Link(2,9:10) = coefly(1,:);           % First piece
Link(2,[4 8]) = [Link(1,1) Link(1,1)];

 % Fill in for all other pieces of text:
for jl = 3:length(linkobj)
  ind = numind(jl-1);
  if ind
    num = (nbr(1:jl-1)<nbr(jl-1))|(numind(1:jl-1)==0)';
    yref = max(find(num))+1;
    if ind>2, ind = ind-numind(yref-1); end
    xref = linkobj(yref);
    if all(numind(jl-3+(jl==3):jl-2)>=numind(jl-1))
      xref = linkobj(jl-1);
    end  
    if ind==numind(jl-2), xref = linkobj(jl-1); end
    yref = linkobj(yref);
    Link(jl,9:10) = coefly(ind+2,:);
  else
    xref = linkobj(jl-1);
    yref = max(find(~numind(1:jl-2)))+1;
    yref = linkobj(yref);
    Link(jl,9:10) = coefly(2,:);
  end
  Link(jl,5:6) = coeflx(2,:);
  newl = linenum(jl-1)-linenum(jl-2);
  if newl
    yref = linkobj(min(find(linenum(1:jl-2)==linenum(jl-2)))+1);
    xref = yref;
    Link(jl,5:6) = coeflx(3,:);
    Link(jl,9:10) = coefly(5,:)-[0 lnspcf*linespace(jl-1)];
  end
  Link(jl,4) = xref;
  Link(jl,8) = yref;
end
Link(2:size(Link,1),11) = numind+.1*isftsz';
Link(2:size(Link,1),12) = linenum'+.1*lineflush;

indsz = .75;
for jl = 2:length(linkobj)
  set(linkobj(jl),'horizontal','left','vertical','bottom')
  if numind(jl-1)&~isftsz(jl-1)
    ftsz = get(Link(jl,8),'fontsize');
    set(linkobj(jl),'fontsize',ceil(ftsz*indsz))
  end
end
