function [ok]=m2vr(f,fname)
%
%M2VR	Generates VRML file with objects from figure f.
% 	OK=M2VR(F,FNAME)  
%       F figure handle
%       FNAME file name
%       OK result: OK=0 no file written as F is not a figure handle; OK=1 file written.
%
% Have you ever seen your results,
%    2D diagrams,
%    3D diagrams,
%    the famous Klein bottle example klein1
% in virtual reality or on a Web page?
% Or have you ever sliped into the four-dimensional space of xpklein ?
% 
% If not, then draw some graphs in Matlab, e.g. start by executing the
% Matlab example file klein1. You will see your 3D object in a graphics
% window. If you want to see this object from the back or from any other
% view, you have to change the viewing parameters using MATLAB statements.
% For a more flexible handling of MATLAB 3D graphics and for importing
% MATLAB results into virtual reality environments or Web pages, the
% converter m2vr.m has been written.
% 
% With m2vr the figure object is taken and converted to a virtual reality
% object in VRML 1.0 (Virtual Reality Modelling Language). You can perform
% this by typing
%             m2vr(gcf,'klein1.wrl')
% m2vr converts the graphics in the current figure to VRML and generates
% the VRML file klein1.wrl. This file contains the complete VRML description
% to be viewed by any VR Viewer or Browser. m2vr is optimized for the
% Live3D Plugin from Netscape. Having MATLAB graphics on the Web, take the
% Netscape Browser 3.0 and install the Live3D plugin from
% http://home.netscape.com/comprod/products/navigator/live3d/index.html
% Start the Netscape Browser, open file klein.wrl and use your mouse to
% navigate around or into the bottle object. For optimal colouring, switch
% off the Live3D lightning by pressing the Light button and in- or decreasing
% the light intensity. Hope you have much fun, also with your graphs.
% 
%
%  Support: m2vr converts
%                            axes objects lin or log and labels, titles
%                            line objects, only solid but all colors
%                            surface objects
%                            multiple axes generated by subplot
%  Restrictions: m2vr ignores
%                            text objects
%                            patch objects
%                            image objects
%                            uimenu objects
%                            uicontrol objects
%
%                                  }}}}{{{   
%  If you have problems ask       // ~ ~ \\
%                                 (  @ @  )
%*------------------------------oOOo-(_)-oOOo-----------------------------*
%|                                                                        |
%| Priv.-Doz. Dr.-Ing. Christian Schmid Tel: +49 234 700 4093             |
%| Ruhr-Universitaet Bochum IC3/141   E-mail: cs@esr.ruhr-uni-bochum.de   |
%| D-44780 Bochum, Germany  Web: http://www.esr.ruhr-uni-bochum.de/esr/cs |
%|                                                                        |
%*--------------------------------------Oooo.-----------------------------*
%                            .oooO      (   )
%                            (   )       ) /
%                             \ (       (_/
%                              \_)
%
error(nargchk(2,2,nargin));
ok=0;
Hc = get(f,'Children');
if ~isempty(Hc)
%fname='fifi.wrl';
	fid=fopen(fname,'w');
%
%	VRML heading and parameters
	t=clock;
	fprintf(fid,'#VRML V1.0 ascii\nInfo{string "This scene has been automatically generated at %s %i:%i from MATLAB figure %s by f2v V1.0 (C) Chr. Schmid, ESR, Ruhr-University Bochum"}\n',date,t(4:5),get(f,'Name'));
	BackgroundColor=get(f,'Color');
	FigPos=get(f,'Position');az=-37.5/180*pi;el=30/180*pi;
	zscale=0.5*(FigPos(3)+FigPos(4));
	viewd=.75*(FigPos(3)+FigPos(4));
	x=1;y=2;z=3;fontsize0=.045;exps='10^';
	fprintf(fid,'DEF BackgroundColor Info {string "1 1 1"}\n');
	fprintf(fid,'DirectionalLight {direction 1 -1 -1 intensity 0.2 on TRUE}\n');
	fprintf(fid,'BrowserHints{fields [SFBool headlight] headlight TRUE}\n');
	fprintf(fid,'ShapeHints{vertexOrdering COUNTERCLOCKWISE shapeType SOLID faceType CONVEX}\n');
%
%	Views of the scene
	fprintf(fid,'DEF Front PerspectiveCamera{orientation 0 0 1 0 position 0 0 %f focalDistance %f}\n',viewd,zscale);
	fprintf(fid,'DEF Right PerspectiveCamera{orientation 0 1 0 -1.570796326795 position %f 0 0 focalDistance %f}\n',-viewd,zscale);
	fprintf(fid,'DEF Back  PerspectiveCamera{orientation 0 1 0 3.14159 position 0 0 %f focalDistance %f}\n',-viewd,zscale);
	fprintf(fid,'DEF Left  PerspectiveCamera{orientation 0 1 0  1.570796326795 position %f 0 0 focalDistance %f}\n',viewd,zscale);
	dir=[-sin(az)*cos(el),-sin(el),-cos(el)*cos(az)]; zdir=[0 0 -1]; 
	fprintf(fid,'DEF Matlab PerspectiveCamera{orientation %f %f %f %f position %f %f %f focalDistance %f}\n',cross(zdir,dir),acos(dot(zdir,dir)),-viewd*dir,zscale);
%
%	Begin of object scene
	fprintf(fid,'DEF Object Separator{\n');
	fprintf(fid,'Scale{scaleFactor %f %f %f}\n',FigPos(3:4),zscale);
	fprintf(fid,'Transform{translation -.5 -.5 -.5}\n');
	fprintf(fid,'DEF GridColor Material{ambientColor 1 1 1 diffuseColor .5 .5 .5 emissiveColor .5 .5 .5}\n');
	nrax=0;
	for HoA=Hc'
		if findobj(HoA,'Type','axes')
%
%			Axes section and axes parameters
			nrax=nrax+1;
			lim=[get(HoA,'Xlim');get(HoA,'Ylim');get(HoA,'Zlim')];
			xlog=findobj(HoA,'XScale','log');
			ylog=findobj(HoA,'YScale','log');
			zlog=findobj(HoA,'ZScale','log');
			if xlog, lim(x,:)=log10(lim(x,:)); end
			if ylog, lim(y,:)=log10(lim(y,:)); end
			if zlog, lim(z,:)=log10(lim(z,:)); end
			delta=lim(:,2)-lim(:,1);
			Visible=length(get(HoA,'Visible'))==2; % Test auf on
			View=get(HoA,'View');
			v3d=View(1)~=0 | View(2)~=90; 
			if v3d, Pos=[.13 1-.13; .11 1-.11; .11 1-.11]; else Pos=[.13 1-.13; .11 1-.11; 0 1];end 
			Position=get(HoA,'Position');
			Box=isempty(findobj(HoA,'Box','off'));
			fontsize=fontsize0*get(HoA,'FontSize')/12;
%
%			find Position of axis within subplot frame
			xn=fix(1/(Position(3)+.13));xi=0;xn=max(xn,1);
			yn=fix(1/(Position(4)+.11));yi=0;yn=max(yn,1);
			while (xi*(1/xn)<Position(1)) 
				xi=xi+1;
			end
			while (yi*(1/yn)<Position(2)) 
				yi=yi+1;
			end
			xi=max(xi,1);yi=max(yi,1);
%
%			Begin of subplot section 
			fprintf(fid,'DEF Subplot%i Separator{\n',nrax);
			fprintf(fid,'Transform{translation %f %f 0}\n',xi-1,yi-1);
%
%			Subplot volume
			if v3d, fprintf(fid,'Transform{translation .5 .5 .5 rotation 1 0 0 %f}Transform{translation -.5 -.5 -.5\n}',-pi/2); end
			fprintf(fid,'Separator{Material{ambientColor 1 1 1 emissiveColor %f %f %f}\n',BackgroundColor);
			fprintf(fid,'Coordinate3{point[0 0 0, 1 0 0, 1 1 0, 0 1 0, 0 0 1, 1 0 1, 1 1 1, 0 1 1]}\n');
			fprintf(fid,'IndexedFaceSet{coordIndex[0,1,2,3,-1,7,6,5,4,-1,1,5,6,2,-1,0,3,7,4,-1,2,6,7,3,-1,0,4,5,1,-1]}}\n');
			fprintf(fid,'Material{ambientColor .75 .75 .75}\n');
%
%			Axes cross
			fprintf(fid,'DEF Axis%i Separator{\n',nrax);
			deltaPos=Pos(:,2)-Pos(:,1);
			if Visible
				fprintf(fid,'Coordinate3{point[');
				if v3d
					fprintf(fid,'%f %f %f,',...
					Pos(x,1),Pos(y,1),Pos(z,1),...
					Pos(x,2),Pos(y,1),Pos(z,1),...
					Pos(x,1),Pos(y,2),Pos(z,1),...
					Pos(x,2),Pos(y,2),Pos(z,1),...
					Pos(x,1),Pos(y,1),Pos(z,2),...
					Pos(x,2),Pos(y,1),Pos(z,2),...
					Pos(x,1),Pos(y,2),Pos(z,2),...
					Pos(x,2),Pos(y,2),Pos(z,2));
				else
					fprintf(fid,'%f %f %f,',...
					Pos(x,1),Pos(y,1),0.5,...
					Pos(x,2),Pos(y,1),0.5,...
					Pos(x,1),Pos(y,2),0.5,...
					Pos(x,2),Pos(y,2),0.5);
				end
				fprintf(fid,']}\n');
				TickLength=get(HoA,'Ticklength')*max(deltaPos);
				if(findobj(HoA,'Tickdir','out')),TickLength=-TickLength;end
				TickDir=get(HoA,'TickDir');
				fprintf(fid,'FontStyle{size %f}\n',fontsize);
%
%				X-axis line and box
				XColor=get(HoA,'Xcolor');
				fprintf(fid,'DEF XColor Material{emissiveColor %f %f %f diffuseColor %f %f %f}\n',XColor,XColor);
				fprintf(fid,'IndexedLineSet{coordIndex[0,1,-1');
				if Box, fprintf(fid,',2,3,-1'); if v3d, fprintf(fid,',4,5,-1,6,7,-1');end, end
				fprintf(fid,']}\n'); 
%
%				Y-axis line and box
				YColor=get(HoA,'Ycolor');
				fprintf(fid,'DEF YColor Material{emissiveColor %f %f %f diffuseColor %f %f %f}\n',YColor,YColor);
				fprintf(fid,'IndexedLineSet{coordIndex[0,2,-1');
				if Box, fprintf(fid,',1,3,-1'); if v3d, fprintf(fid,',4,6,-1,5,7,-1');end, end
				fprintf(fid,']}\n');  
%
%				Z-axis line and box
				Posz1=0.5; tl=1; Posfontz=0;
				if v3d,
					Posz1=Pos(z,1); tl=2; Posfontz=-fontsize;
					ZColor=get(HoA,'ZColor');
					fprintf(fid,'DEF ZColor Material{emissiveColor %f %f %f diffuseColor %f %f %f}\n',ZColor,ZColor);
					fprintf(fid,'IndexedLineSet{coordIndex[2,6,-1');
					if Box, fprintf(fid,',1,5,-1,3,7,-1,0,4,-1'); end
					fprintf(fid,']}\n');  
				end
%
%				X-axis ticks, labels, grids
				XTick=get(HoA,'XTick');
				if ~isempty(XTick)
%
%					X-axis ticks
					if xlog, XTick=log10(XTick);ls=exps;else ls=''; end
					l=length(XTick);o=ones(1,l);ol=0:l-1;
					p=deltaPos(x)*(XTick-lim(x,1))/delta(x)+Pos(x,1);
					fprintf(fid,'Coordinate3{point[');
					fprintf(fid,'%f %f %f,',[p;o*Pos(y,1);o*Posz1;p;o*(Pos(y,1)+TickLength(tl));o*Posz1]);
					fprintf(fid,']}\nUSE XColor\nDEF XTick IndexedLineSet{coordIndex[');
					fprintf(fid,'%i,%i,-1,',[2*ol;2*ol+1]);
					fprintf(fid,']}\n');
					if (Box & ~v3d),
						fprintf(fid,'Coordinate3{point[');
						fprintf(fid,'%f %f %f,',[p;o*Pos(y,2);o*Posz1;p;o*(Pos(y,2)-TickLength(tl));o*Posz1]);
						fprintf(fid,']}\nUSE XTick\n');
					end
%
%					X-axis labels
					XTickLabels=get(HoA,'XTickLabels');
					for i=1:l
						fprintf(fid,'Separator{Transform{translation %f %f %f}AxisAlignment{alignment ALIGNAXISXYZ}AsciiText{string "%s%s" justification CENTER}}\n',p(i),Pos(y,1)-fontsize-abs(TickLength(tl)),Posz1+Posfontz,ls,XTickLabels(i,:));
					end
					if ~xlog
						ex=round(log10((XTick(l)-XTick(1))/(str2num(XTickLabels(l,:))-str2num(XTickLabels(1,:)))));
						if ex~=0
							if v3d
								fprintf(fid,'Separator{Transform{translation %f %f %f}AxisAlignment{alignment ALIGNAXISXYZ}AsciiText{string "x 10^%i" justification CENTER}}\n',(p(l)+p(l-1))/2,Pos(y,1)/2,Posz1-fontsize-abs(TickLength(tl)),ex);
							else
								fprintf(fid,'Separator{Transform{translation %f %f %f}AxisAlignment{alignment ALIGNAXISXYZ}AsciiText{string "x 10^%i" justification CENTER}}\n',(p(l)+p(l-1))/2,Pos(y,1)/2-fontsize,Posz1+fontsize+abs(TickLength(tl)),ex);
							end
						end
					end
%
%					X-axis grids
					if (findobj(HoA,'XGrid','on'))
						gridline = ~(XTick==lim(x,1) | (Box & XTick==lim(x,2)));
						if any(gridline)
							pp=[p;o*Pos(y,1);o*Posz1;p;o*Pos(y,2);o*Posz1];
							if v3d, pp=[pp;p;o*Pos(y,2);o*Pos(z,2)]; end
							fprintf(fid,'Coordinate3{point[');
							fprintf(fid,'%f %f %f,',pp);
							fprintf(fid,']}\n');
							gridline=gridline.*(1:l);gridline=gridline(gridline>0)-1;
							fprintf(fid,'USE GridColor\nIndexedLineSet{coordIndex[');
							if v3d,
								fprintf(fid,'%i,%i,%i,-1,',[3*gridline;3*gridline+1;3*gridline+2]);
							else
								fprintf(fid,'%i,%i,-1,',[2*gridline;2*gridline+1]);
							end
							fprintf(fid,']}\n');
						end
					end
				end
%
%				Y-axis ticks, labels, grids
				YTick=get(HoA,'YTick');
				if ~isempty(YTick)
%
%					Y-axis ticks
					if ylog, YTick=log10(YTick);ls=exps;else ls=''; end
					l=length(YTick);o=ones(1,l);ol=0:l-1;
					p=deltaPos(y)*(YTick-lim(y,1))/delta(y)+Pos(y,1);
					fprintf(fid,'Coordinate3{point[');
					fprintf(fid,'%f %f %f,',[o*Pos(x,1);p;o*Posz1;o*(Pos(x,1)+TickLength(tl));p;o*Posz1]);
					fprintf(fid,']}\nUSE YColor\nDEF YTick IndexedLineSet{coordIndex[');
					fprintf(fid,'%i,%i,-1,',[2*ol;2*ol+1]);
					fprintf(fid,']}\n');
					if (Box & ~v3d)
						fprintf(fid,'Coordinate3{point[');
						fprintf(fid,'%f %f %f,',[o*Pos(x,2);p;o*Posz1;o*(Pos(x,2)-TickLength(tl));p;o*Posz1]);
						fprintf(fid,']}\nUSE YTick\n');
					end
%
%					Y-axis labels
					YTickLabels=get(HoA,'YTickLabels');
					for i=1:l
						fprintf(fid,'Separator{Transform{translation %f %f %f}AxisAlignment{alignment ALIGNAXISXYZ}AsciiText{string "%s%s" justification RIGHT}}\n',Pos(x,1)-abs(TickLength(tl)),p(i)-fontsize/2,Posz1+Posfontz,ls,YTickLabels(i,:));
					end
					if ~ylog
						ex=round(log10((YTick(l)-YTick(1))/(str2num(YTickLabels(l,:))-str2num(YTickLabels(1,:)))));
						if ex~=0
							if v3d
								fprintf(fid,'Separator{Transform{translation %f %f %f}AxisAlignment{alignment ALIGNAXISXYZ}AsciiText{string "x 10^%i" justification CENTER}}\n',Pos(x,1)/2,(p(l)+p(l-1))/2,Pos(z,1)-fontsize-abs(TickLength(tl)),ex);
							else
								fprintf(fid,'Separator{Transform{translation %f %f %f}AxisAlignment{alignment ALIGNAXISXYZ}AsciiText{string "x 10^%i" justification LEFT}}\n',Pos(x,1),Pos(y,2)+abs(TickLength(tl)),Posz1,ex);
							end
						end
					end
%
%					Y-axis grids
					if (findobj(HoA,'YGrid','on'))
						gridline = ~(YTick==lim(y,1) | (Box & YTick==lim(y,2)));
						if any(gridline)
							pp=[o*Pos(x,1);p;o*Posz1;o*Pos(x,2);p;o*Posz1];
							if v3d, pp=[pp;o*Pos(x,2);p;o*Pos(z,2)]; end
							fprintf(fid,'Coordinate3{point[');
							fprintf(fid,'%f %f %f,',pp);
							fprintf(fid,']}\n');
							gridline=gridline.*(1:l);gridline=gridline(gridline>0)-1;
							fprintf(fid,'USE GridColor\nIndexedLineSet{coordIndex[');
							if v3d
								fprintf(fid,'%i,%i,%i,-1,',[3*gridline;3*gridline+1;3*gridline+2]);
							else
								fprintf(fid,'%i,%i,-1,',[2*gridline;2*gridline+1]);	
							end
							fprintf(fid,']}\n');
						end
					end
				end
%
%				Z-axis ticks, labels, grids
				ZTick=get(HoA,'ZTick');
				if (~isempty(ZTick) & v3d)
%
%					Z-axis ticks
					if zlog, ZTick=log10(ZTick);ls=exps;else ls=''; end
					l=length(ZTick);o=ones(1,l);ol=0:l-1;
					p=deltaPos(z)*(ZTick-lim(z,1))/delta(z)+Pos(z,1);
					fprintf(fid,'Coordinate3{point[');
					fprintf(fid,'%f %f %f,',[o*(Pos(x,1)+TickLength(tl));o*(Pos(y,2)-TickLength(tl));p;o*Pos(x,1);o*Pos(y,2);p]);
					fprintf(fid,']}\n');
					fprintf(fid,'USE ZColor\nDEF ZTick IndexedLineSet{coordIndex[');
					fprintf(fid,'%i,%i,-1,',[2*ol;2*ol+1]);
					fprintf(fid,']}\n');
%
%					Z-axis labels
					ZTickLabels=get(HoA,'ZTickLabels');
					for i=1:l
						fprintf(fid,'Separator{Transform{translation %f %f %f}AxisAlignment{alignment ALIGNAXISXYZ}AsciiText{string "%s%s" justification RIGHT}}\n',Pos(x,1)-abs(TickLength(tl)),Pos(y,2)+abs(TickLength(tl)),p(i)-fontsize/2,ls,ZTickLabels(i,:));
					end
					if ~zlog
						ex=round(log10((ZTick(l)-ZTick(1))/(str2num(ZTickLabels(l,:))-str2num(ZTickLabels(1,:)))));
						if ex~=0
							fprintf(fid,'Separator{Transform{translation %f %f %f}AxisAlignment{alignment ALIGNAXISXYZ}AsciiText{string "x 10^%i" justification LEFT}}\n',Pos(x,1),Pos(y,2),Pos(z,2)+abs(TickLength(tl)),ex);	
						end
					end
%
%					Z-axis grids
					if (findobj(HoA,'ZGrid','on'))
						gridline = ~(ZTick==lim(z,1) | (Box & ZTick==lim(z,2)));
						if any(gridline)
							fprintf(fid,'Coordinate3{point[');
							fprintf(fid,'%f %f %f,',[o*Pos(x,1);o*Pos(y,2);p;o*Pos(x,2);o*Pos(y,2);p;o*Pos(x,2);o*Pos(y,1);p]);
							fprintf(fid,']}\n');
							gridline=gridline.*(1:l);gridline=gridline(gridline>0)-1;
							fprintf(fid,'USE GridColor\nIndexedLineSet{coordIndex[');
							fprintf(fid,'%i,%i,%i,-1,',[3*gridline;3*gridline+1;3*gridline+2]);
							fprintf(fid,']}\n');
						end
					end
				end
%
%				X-axis label
				HoL=get(HoA,'XLabel');
				if ~isempty(HoL)
					XLabel=get(HoL,'String');
					if length(XLabel>0)
						fprintf(fid,'Separator{USE XColor Transform{translation %f %f %f}AxisAlignment{alignment ALIGNAXISXYZ}AsciiText{string "%s" justification CENTER}}\n',(Pos(x,1)+Pos(x,2))/2,Pos(y,1)-2*fontsize-abs(TickLength(tl)),Posz1+2*Posfontz,XLabel);
					end
				end
%
%				Y-axis label
				HoL=get(HoA,'YLabel');
				if ~isempty(HoL)
					YLabel=get(HoL,'String');
					if length(YLabel>0)
						if v3d
							fprintf(fid,'Separator{USE YColor Transform{translation %f %f %f}AxisAlignment{alignment ALIGNAXISXYZ}AsciiText{string "%s" justification CENTER}}\n',Pos(x,1)-2*fontsize-abs(TickLength(tl)),(Pos(y,1)+Pos(y,2))/2,Posz1+2*Posfontz,YLabel);
						else
							fprintf(fid,'Separator{USE YColor Transform{rotation 0 0 1 1.570796326795 translation %f %f %f}AsciiText{string "%s" justification CENTER}}\n',Pos(x,1)-2*fontsize-abs(TickLength(tl)),(Pos(y,1)+Pos(y,2))/2,Posz1+2*Posfontz,YLabel);
						end
					end
				end
%
%				Z-axis label
				HoL=get(HoA,'ZLabel');
				if ~isempty(HoL)& v3d
					ZLabel=get(HoL,'String');
					if length(ZLabel>0)
						fprintf(fid,'Separator{USE ZColor Transform{rotation 1 -1 1 2.0944 translation %f %f %f}AsciiText{string "%s" justification CENTER}}\n',Pos(x,1)-2*fontsize-abs(TickLength(tl)),Pos(y,2),(Pos(z,1)+Pos(z,2))/2,ZLabel);
					end
				end
%
%				Figure title
				HoL=get(HoA,'Title');
				if ~isempty(HoL)
					Title=get(HoL,'String');
					if length(Title>0)
						TitleColor=get(HoL,'Color');
						fprintf(fid,'Separator{Material{emissiveColor %f %f %f diffuseColor %f %f %f}\n',TitleColor,TitleColor);
						if v3d
							fprintf(fid,'Transform{translation %f %f %f}AxisAlignment{alignment ALIGNAXISXYZ}AsciiText{string "%s" justification CENTER}}\n',(Pos(x,1)+Pos(x,2))/2,Pos(y,2),Pos(z,2)+fontsize,Title);
						else
							fprintf(fid,'Transform{translation %f %f %f}AxisAlignment{alignment ALIGNAXISXYZ}AsciiText{string "%s" justification CENTER}}\n',(Pos(x,1)+Pos(x,2))/2,Pos(y,2)+fontsize,Posz1,Title);
						end
					end
				end
			end
			fprintf(fid,'} #Axis%i\n',nrax);
%
%			End of Axes section
%
%			Begin of data section
			Hcc = get(HoA,'Children');
			nrline=0;nrsurface=0;
			for Hoc=Hcc'
%
%				Line object section
				if findobj(Hoc,'Type','line')
					nrline=nrline+1;
					XData=get(Hoc,'XData');YData=get(Hoc,'YData');ZData=get(Hoc,'ZData');
					if xlog, XData=log10(XData);end
					if ylog, YData=log10(YData);end
					if zlog, ZData=log10(ZData);end
					Color=get(Hoc,'Color');
					fprintf(fid,'DEF Subplot%iLine%i Separator{\n',nrax,nrline);
					fprintf(fid,'Material{emissiveColor %f %f %f}\n',Color);
					fprintf(fid,'Coordinate3{point[');
					if isempty(ZData), ZData=zeros(size(XData)); end
%
%					Detection of sublines by NaN detection
					aha0=(1-isnan(XData)).*(1:length(XData));
					ahaz=(isnan(XData)).*(1:length(XData));ahaz=ahaz(ahaz>0);
					XData(ahaz)=zeros(size(ahaz));YData(ahaz)=zeros(size(ahaz));ZData(ahaz)=zeros(size(ahaz));
%
					XData=deltaPos(x)/delta(x)*(XData-lim(x,1))+Pos(x,1);
					YData=deltaPos(y)/delta(y)*(YData-lim(y,1))+Pos(y,1);
					ZData=deltaPos(z)/delta(z)*(ZData-lim(z,1))+Pos(z,1);
					fprintf(fid,'%f %f %f,',[XData;YData;ZData]);
					fprintf(fid,']}\nIndexedLineSet{coordIndex[');
					fprintf(fid,'%i,',aha0-1);
					fprintf(fid,'-1]}\n');
					fprintf(fid,'} #Subplot%iLine%i\n',nrax,nrline);
%
%				Surface object section
				elseif findobj(Hoc,'Type','surface')
					nrsurface=nrsurface+1;
					XData=get(Hoc,'XData');YData=get(Hoc,'YData');ZData=get(Hoc,'ZData');
					if xlog, XData=log10(XData);end
					if ylog, YData=log10(YData);end
					if zlog, ZData=log10(ZData);end
					fprintf(fid,'DEF Subplot%iSurface%i Separator{\n',nrax,nrsurface);
					fprintf(fid,'Material{emissiveColor [\n');
					cmap=colormap;   
					fprintf(fid,'%f %f %f,\n',cmap');
					fprintf(fid,']}\n');
					%fprintf(fid,'MaterialBinding{value PER_VERTEX_INDEXED}\n');
					fprintf(fid,'ShapeHints{vertexOrdering UNKNOWN_ORDERING shapeType UNKNOWN_SHAPE_TYPE faceType CONVEX}\n');
					%fprintf(fid,'Transform{translation %f %f %f scaleFactor %f %f %f}\n',Pos(:,1),(Pos(:,2)-Pos(:,1))./(lim(:,2)-lim(:,1))); 
					%fprintf(fid,'Transform{translation %f %f %f}\n',-lim(:,1));
					[m,n]=size(XData);
					if m*n==n, [XData,YData]=meshdom(XData,YData); end
					[m,n]=size(XData);
					if isempty(ZData), ZData=zeros(m,n); end					
					XData=XData(:)';YData=YData(:)';ZData=ZData(:)';
					[jj,ii]=meshgrid(1:n-1,1:m-1);jjj=jj(:)';iii=ii(:)';
					wi=[m*(jjj-1)+iii-1;m*(jjj-1)+iii;m*jjj+iii;m*jjj+iii-1];
%
%					Detection of wholes by NaN detection
					ahaz=isnan(ZData).*(1:length(ZData));ahaz=ahaz(ahaz>0);
					XData(ahaz)=zeros(size(ahaz));YData(ahaz)=zeros(size(ahaz));ZData(ahaz)=zeros(size(ahaz));
					for aha=ahaz
						wi=wi(:,sum(wi~=(aha-1))==4);
					end
%
					XData=deltaPos(x)/delta(x)*(XData-lim(x,1))+Pos(x,1);
					YData=deltaPos(y)/delta(y)*(YData-lim(y,1))+Pos(y,1);
					ZData=deltaPos(z)/delta(z)*(ZData-lim(z,1))+Pos(z,1);
					fprintf(fid,'Coordinate3{point[');
					fprintf(fid,'%f %f %f,\n',[XData;YData;ZData]);
					fprintf(fid,']}\n');
					fprintf(fid,'IndexedFaceSet {coordIndex[');
					fprintf(fid,'%i,%i,%i,%i,-1,\n',wi);
					%lcmap=length(cmap);
					%fprintf(fid,']\nmaterialIndex[');
					%fprintf(fid,'%i,\n',fix((zz-Zlim(1))/(Zlim(2)-Zlim(1))*(lcmap-1)));
					fprintf(fid,']}\n');
					fprintf(fid,'} #Subplot%iSurface%i\n',nrax,nrsurface);
				end
			end
		fprintf(fid,'} #Subplot%i\n',nrax);
		end
	end  
	fprintf(fid,'} #Object\n');
	fclose(fid);
	ok=1;
end


