function makemenus()
% This function makes a set of menus which do 
% a variety of things.  The menus include:
% 
% Workspace-
% New Figure, Load, Save, Save As, Print, Quit;
% All pretty much self-explanatory.
% 
% Text-
% Font:   Allows you to change the font of a 
%         selected text object.  Limited to fonts
%         available on your system
% Size:   Allows you to change the size of a 
% 		selected text object.  Limited to font
% 		sizes available on your system.
% Style:  Allows you to change the style of a
% 		selected text object.  Limited to font
% 		styles available on your system.
% Move:   When this item is selected you may grab
% 		text objects with your mouse and drag them
% 		wherever you want.
% Rotate: When this item is selected you may grab 
% 		text objects with your mouse and rotate them.
% Delete: Deletes a selected text object
% 
% Figure-
% Landscape/Portrait toggle: controls orientation of your plot
% Page Title:  Prompts for a plot title centered on the page,
% 			 not the current axis.  Useful for cases when you
% 			 have a 2x2 subplot grid or something of the sort.
% Colormap:    Allows you to change the colormap.
% 
% Axis-
% Too many features to describe them all, but note that
% there is a zoom function and a 3-d viewer.  The viewer
% will control the perspective for the figure that was previously
% in front.  The zoom function has a default magnification level
% of 2, but this can be changed from the zoom submenu.
% 
% Keith Rogers 11/30/93

if(~(strcmp(computer,'MAC') | strcmp(computer,'MAC2')))

% WorkCallback commands
% 1:	Load 
% 2:	Save
% 3:	Save As
% 4:	New Figure

	workspace = uimenu('Label','Workspace');
	uimenu(workspace,'Label','New Figure', 'Callback','WorkCallback',...
		'Accelerator','N');
	uimenu(workspace,'Label','Load', 'Callback','WorkCallback',...
		'Accelerator','L');
	uimenu(workspace,'Label','Save', 'Callback','WorkCallback',...
		'Accelerator','S');
	uimenu(workspace,'Label','Save As', 'Callback','WorkCallback',...
		'Accelerator','A');
	uimenu(workspace,'Label','Print','Callback','print',...
		'Accelerator','P');
	uimenu(workspace,'Label','Quit', 'Callback','exit',...
		'Separator','on','Accelerator','Q');
end

% For TextCallback the command parameter is 
% 1:	Set font
% 2:	Set angle
% 3:	Set weight
% 4:    Set to plain
% 5:	Set Size
% 6:	Move Text
% 7:	Rotate Text
% 8:	Delete Text

% TextMenu UserData:
% 1:	Move_Text menu item handle
% 2:	Rotate_Text menu item handle

TextMenu = uimenu('Label','Text');
FontMenu = uimenu(TextMenu,'Label','Font');
StyleMenu = uimenu(TextMenu,'Label','Style');
SizeMenu = uimenu(TextMenu,'Label','Size');

% Font Menu

uimenu(FontMenu,'Label','Avant Garde', ...
	'Callback','TextCallback(1,''Avant Garde'')');
uimenu(FontMenu,'Label','Bookman', ...
	'Callback','TextCallback(1,''Bookman'')');
uimenu(FontMenu,'Label','Courier', ...
	'Callback','TextCallback(1,''Courier'')');
uimenu(FontMenu,'Label','Helvetica', ...
	'Callback','TextCallback(1,''Helvetica'')');
uimenu(FontMenu,'Label','Helvetica Narrow', ...
	'Callback','TextCallback(1,''Helvetica Narrow'')');
uimenu(FontMenu,'Label','New Century Schoolbook', ...
	'Callback','TextCallback(1,''New Century Schoolbook'')');
uimenu(FontMenu,'Label','Palatino', ...
	'Callback','TextCallback(1,''Palatino'')');
uimenu(FontMenu,'Label','Symbol', ...
	'Callback','TextCallback(1,''Symbol'')');
uimenu(FontMenu,'Label','Times', ...
	'Callback','TextCallback(1,''Times'')');
uimenu(FontMenu,'Label','Zapf Chancery', ...
	'Callback','TextCallback(1,''Zapf Chancery'')');
uimenu(FontMenu,'Label','Zapf Dingbats',...
	'Callback','TextCallback(1,''Zapf Dingbats'')');

% Style Menu

uimenu(StyleMenu,'Label','Plain','Callback','TextCallback(4,''plain'')');
uimenu(StyleMenu,'Label','Italic','Callback','TextCallback(2,''italic'')');
uimenu(StyleMenu,'Label','Oblique','Callback','TextCallback(2,''oblique'')');
uimenu(StyleMenu,'Label','Light','Callback','TextCallback(3,''light'')');
uimenu(StyleMenu,'Label','Demi','Callback','TextCallback(3,''demi'')');
uimenu(StyleMenu,'Label','Bold','Callback','TextCallback(3,''bold'')');

% Size Menu

uimenu(SizeMenu,'Label','6','Callback','TextCallback(5,6)');
uimenu(SizeMenu,'Label','9','Callback','TextCallback(5,9)');
uimenu(SizeMenu,'Label','12','Callback','TextCallback(5,12)');
uimenu(SizeMenu,'Label','14','Callback','TextCallback(5,14)');
uimenu(SizeMenu,'Label','18','Callback','TextCallback(5,18)');
uimenu(SizeMenu,'Label','24','Callback','TextCallback(5,24)');
uimenu(SizeMenu,'Label','Other','Callback','TextCallback(5,0)');

%  Move Text

Move_Text = uimenu(TextMenu,'Label','Move','Callback',...
			'TextCallback(6,0)','Accelerator','M','Checked','off');

%  Rotate Text

Rotate_Text = uimenu(TextMenu,'Label','Rotate','Callback',...
			'TextCallback(7,0)','Accelerator','R','Checked','off');

TextUserData = [Move_Text;Rotate_Text];
set(TextMenu,'UserData',TextUserData);

% Delete Text objext

uimenu(TextMenu,'Label','Delete','Callback','TextCallback(8,0)',...
	'Separator','on','Accelerator','D');

%%%%%%%%%%%%%%%%%% Begin Figure Menu %%%%%%%%%%%%


% For FigureCallback the command parameter is
% 1:    set paper orientation


% Choose portrait or landscape

FigMenu = uimenu('Label','Figure');
if(strcmp(get(gcf,'PaperOrientation'),'portrait'))
	uimenu(FigMenu,'Label','Landscape','Callback','FigureCallback(1,0)');
else
	uimenu(FigMenu,'Label','Portrait','Callback','FigureCallback(1,0)');
end

% Title for entire figure

uimenu(FigMenu,'Label','Page Title','Callback',...
	'streamer(input(''Figure Title?'',''s''))');

% Colormap

ColorMenu = uimenu(FigMenu,'Label','ColorMap');

uimenu(ColorMenu,'Label','Default','Callback',...
	'colormap(''default'')');
uimenu(ColorMenu,'Label','Gray','Callback',...
	'colormap(''gray'')');
uimenu(ColorMenu,'Label','Hot','Callback',...
	'colormap(''hot'')');
uimenu(ColorMenu,'Label','Cool','Callback',...
	'colormap(''cool'')');
uimenu(ColorMenu,'Label','Copper','Callback',...
	'colormap(''copper'')');
uimenu(ColorMenu,'Label','Pink','Callback',...
	'colormap(''pink'')');


AxMenu = uimenu('Label','Axis');

% AxisCallback commands
% 1:	Linear/Log toggle
% 2:	AutoRange Min
% 3:	AutoRange Max
% 4:	Hold on/off toggle
% 5: 	Axis Auto/Freeze toggle
% 6:	Zoom Axis toggles
% 9:	Zoom Magnification Level


uimenu(AxMenu,'Label','Clear','Callback','cla','Accelerator','K');
uimenu(AxMenu,'Label','Grid','Callback','grid');
if(strcmp(axis('state'),'manual'))
	uimenu(AxMenu,'Label','Auto',...
	'Callback','AxisCallback(5,0');
else
	uimenu(AxMenu,'Label','Freeze',...
	'Callback','AxisCallback(5,0)');
end
AspectMenu = uimenu(AxMenu,'Label','Aspect');
uimenu(AspectMenu,'Label','Normal','Callback','axis(''normal'')');
uimenu(AspectMenu,'Label','Square','Callback','axis(''square'')');
uimenu(AspectMenu,'Label','Image','Callback','axis(''image'')');
uimenu(AspectMenu,'Label','Equal','Callback','axis(''equal'')');

Xaxis = uimenu(AxMenu,'Label','X Opts');
Yaxis = uimenu(AxMenu,'Label','Y Opts');
Zaxis = uimenu(AxMenu,'Label','Z Opts');

if(strcmp(get(gca,'XScale'),'linear'))
	uimenu(Xaxis,'Label','Log','Callback','AxisCallback(1,''X'')');
else
	uimenu(Xaxis,'Label','Linear','Callback','AxisCallback(1,''X'')');
end
uimenu(Xaxis,'Label','Auto Min','Callback','AxisCallback(2,''X'')');
uimenu(Xaxis,'Label','Auto Max','Callback','AxisCallback(3,''X'')');
if(strcmp(get(gca,'YScale'),'linear'))
	uimenu(Yaxis,'Label','Log','Callback','AxisCallback(1,''Y'')');
else
	uimenu(Yaxis,'Label','Linear','Callback','AxisCallback(1,''Y'')');
end
uimenu(Yaxis,'Label','Auto Min','Callback','AxisCallback(2,''Y'')');
uimenu(Yaxis,'Label','Auto Max','Callback','AxisCallback(3,''Y'')');
if(strcmp(get(gca,'ZScale'),'linear'))
	uimenu(Zaxis,'Label','Log','Callback','AxisCallback(1,''Z'')');
else
	uimenu(Zaxis,'Label','Linear','Callback','AxisCallback(1,''Z'')');
end
uimenu(Zaxis,'Label','Auto Min','Callback','AxisCallback(2,''Z'')');
uimenu(Zaxis,'Label','Auto Max','Callback','AxisCallback(3,''Z'')');


if(ishold)
	uimenu(AxMenu,'Label','Hold off','Callback','AxisCallback(4,0)');
else
	uimenu(AxMenu,'Label','Hold on','Callback','AxisCallback(4,0)');
end

ZoomMenu = uimenu(AxMenu,'Label','Zoom');

maglevel = 2;

%  Zoom Menu has user data
%  Userdata(1) = X zoom flag
%  Userdata(2) = Y zoom flag
%  Userdata(3) = Z zoom flag
%  Userdata(4) = magnification level

set(ZoomMenu,'UserData',[1;1;0;maglevel]);

uimenu(ZoomMenu,'Label','Zoom in','Callback','zoom(1)',...
	'Accelerator','[');
uimenu(ZoomMenu,'Label','Zoom out','Callback','zoom(2)',...
	'Accelerator',']');
uimenu(ZoomMenu,'Label','X Axis','Checked','on',...
	'Callback','AxisCallback(6,''X'')','Separator','on');
uimenu(ZoomMenu,'Label','Y Axis','Checked','on',...
	'Callback','AxisCallback(6,''Y'')');
uimenu(ZoomMenu,'Label','Z Axis','Checked','off',...
	'Callback','AxisCallback(6,''Z'')');
uimenu(ZoomMenu,'Label',['Mag Level -' num2str(maglevel) '-'],'Callback','AxisCallback(7,0)',...
	'Separator','on');

uimenu(AxMenu,'Label','Viewer','Callback','viewer');

set(gcf,'WindowButtonDownFcn','tsel');
