function viewer()
%function viewer()
%Creates a new figure containing 3 slide bars
%which can be used to control the view orientation
%for the figure currently selected. A popup menu
%allows control of the system used to determine
%the point of view. The system can be
%
%'xyz' in which case the sliders control fixed-axis
%rotations about the x, y, and z axes in that order,
%
%'El-Az' in which case the standard MATLAB elevation
% and azimuth controls are used, or
%
%'pyr' in which case the sliders control body-axis 
%rotations about the pitch, yaw, and roll (y-z-x)
%axes in that order.
%
% Keith Rogers 11/30/93

global viewerfig;
allfigs = get(0,'children');

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% If the viewer figure exists, bring it to the foreground.
% If it does not exist,create it.
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

if(any(allfigs==viewerfig))
	figure(viewerfig)
else
	viewerfig = figure('Position',[150 350 270 75],...
					   'Name','3-D Viewer',...
					   'ButtonDownFcn','ViewerCallback(11)');
	viewerax = axes('Position',[0 0 1 1],'Visible','off');

	view_button = uicontrol('Style','Popup',...
							'Units','normalized',...
							'String','XYZ|El-Az|PYR',...
							'Position',[.11 .76 .3 .24],...
							'Callback','ViewerCallback(10)',...
							'Value',1);
	set(view_button,'UserData',0);


	%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
	% UserData(1) = handle of slider #1
	% UserData(2) = handle of slider #2
	% UserData(3) = handle of slider #3
	% UserData(4) = handle of text for slider #1
	% UserData(5) = handle of text for slider #2
	% UserData(6) = handle of text for slider #3
	% UserData(7) = handle of text for slider #3
	% UserData(8) = handle of text for slider #3
	% UserData(9) = handle of text for slider #3
	% UserData(10) = handle of view_button
	%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

	UserData = zeros(10,1);
	UserData(10) = view_button;

	set(viewerfig,'UserData',UserData);
	ViewerCallback(10);
end
