function orthplot(X,Xlabs,tit)
%  ORTHPLOT   3D plot with orthogonal projections.
%	      ORTHPLOT(Z) plots the matrix Z in 3D and three
%             orthogonal projections of Z onto facing walls
%             in the plot box.  The size of Z is [N 3] where
%	      N is the number of points to plot in three space.
%
%	      ORTHPLOT(Z,ZLABELS,ZTITLE) labels the x, y, and z
%	      axes with the corresponding components in the string 
%	      array ZLABELS.  The title of the plot is designated
%	      by the string ZTITLE.  Both ZLABELS and ZTITLE are
%	      optional parameters whose default values are 
%	      ['X'; 'Y'; 'Z'] and [''], respectively. 
%
%	      e.g. 
%
%		global SIGMA RHO BETA
%		SIGMA = 10; RHO = 28; BETA = 8/3;
%		[T,Y] = ode23('lorenzeq',0,50,[1 1 1]');
%		clear global SIGMA RHO BETA;
%		labels = str2mat('X[n]','Y[n]','Z[n]');
%		titl = 'ORTHPLOT Example:  Lorenz Attractor';
%		orthplot(Y,labels,titl)
%
%             See also PLOT3.
%
%  William Constantine
%  University of Washington 
%  12/12/95
if (nargin < 3) tit = ''; end
if (nargin < 2); Xlabs = str2mat('X','Y','Z'); end
if ~(nargin < 1)
   for i = 1:3,
     eval(['x' int2str(i) '=X(:,' int2str(i) ');']);
   end

   figure(gcf)
   plot3(x1,x2,x3,'y','mark',2)
   set(gca,'box','on')
   xlabel(Xlabs(1,:));ylabel(Xlabs(2,:));
   zlabel(Xlabs(3,:));title(tit);

   ax=axis;hold on;
   plot3(x1, ax(4)*ones(1,length(x3)), x3, 'r.','mark',2)
   plot3(ax(2)*ones(1,length(x3)), x2, x3, 'b.','mark',2)
   plot3(x1, x2, ax(5)*ones(1,length(x3)), 'g.','mark',2)
   hold off;
else
   error('No data supplied.  Please supply Nx3 matrix X.')
end



