function [] = plot_all(x, y, z, showtitle, hidetitle, hidexlabel, hideylabel);  
% PLOT_ALL  plots every vector from a matrix in an own subplot. To get
%           an own figure of a subplot, please click with the mouse
%           in this subplot! To compair two vectors, the difference
%           between the vectors will be added. For better oversight
%           it is possible to input hide title, xlabel and ylabel.
%  
%           use:  
%           plot_all([x], y, [z], [showtit], [hidtit], [hidxla], [hidyla]);  
%  
%           x -> x-data of the function, e.g. x=time (vector), optional 
%           y -> y-data of the function (vector or matrix)  
%           z -> z-data of the function (vector or matrix), for a   
%                comparison of function y and z, optional  
%           showtitle  -> titlestring  shown in subplots, optional
%           hidetitle  -> titlestring  shown in own figure plot, optional
%           hidexlabel -> xlabelstring shown in own figure plot, optional
%           hideylabel -> ylabelstring shown in own figure plot, optional
%  
% 1. example:  t=0:0.001:6;   
%              y=[sin(2*pi*t); t; t.^2; t.^0.5];  
%              z=[sin(2*pi*t); t; t.^2; t.^0.5]*1.1;  
%              plot_all(t, y, z)  
%  
% 2. example:  t=0:0.001:6;   
%              y=[sin(2*pi*t); t; t.^2; t.^0.5];  
%              z=[sin(2*pi*t); t; t.^2; t.^0.5]*1.1;  
%              showtit=['fig1';'fig2';'fig3';'fig4'];
%              hidetit=['fig-x1';'fig-x2';'fig-x3';'fig-x4'];
%              hxlabel=['t [s]';'t [s]';'t [s]';'t [s]'];
%              hylabel=['x1 [N]  ';'x2 [N/s]';'x3 [J]  ';'x4 [Nm] '];
%              plot_all(t, y, z, showtit, hidetit, hxlabel, hylabel)  
%  
%           L. Merz, 03. July 1995  
%           DASA-Airbus Hamburg, EDB, Kreetslag 10, 21129 Hamburg, Germany  
%           Phone: +49.40.7437.3367  
%           Fax:   +49.40.7437.4187  
%           Email Ludger.Merz@airbus.de  
  
global button_555;  
 
if nargin >= 2 & isstr(y),
   if exist('showtitle'),
      showtitle1 = showtitle;
   end;   
   showtitle = y;
   
   if nargin >= 3,
      if exist('hidetitle'),
         hidetitle1 = hidetitle;
      end;   
      hidetitle = z;
   end;   
  
   if nargin >= 4,
      hidexlabel = showtitle1;
   end;   
  
   if nargin == 5,
      hideylabel = hidetitle1;
   end;   
   y = x;  
   x = [1:1:length(y)];  
   z = [];  
end;

if nargin >= 3 & isstr(z),  
   showtitle1 = showtitle;
   showtitle = z;
   z = [];  
   
   if nargin >= 4,
      if exist('hidetitle'),
         hidetitle1 = hidetitle;
      end;   
      hidetitle = showtitle1;
   end;   
  
   if nargin >= 5,
      if exist('hidexlabel'),
         hidexlabel1 = hidexlabel;
      end;   
      hidexlabel = hidetitle1;
   end;   
  
   if nargin == 6,
      hideylabel = hidexlabel1;
   end;   
end; 
 
if nargin == 2,  
   z = [];  
   if isstr(y),  
      showtitle = y;
      y = x;  
      x = [1:1:length(y)];  
   end; 
end;  
  
if nargin == 1,  
   y = x;  
   x = [1:1:length(y)];  
   z = [];  
end;  
  
  
[m,n] = size(y);  
if n ~= length(x),  
   y = y';  
   z = z';  
   [m,n] = size(y);  
end;     
     
% -------------------------------------------------  
%  calculate the number of subplots  
% -------------------------------------------------  
spm = ceil( sqrt(m) );  
spn = ceil( m / spm );  
  
if exist('showtitle'), 
   if size(showtitle,1) ~= m,
      disp('wrong size of showtitle');
      clear showtitle
   end;
end;

if exist('hidetitle'),
   if size(hidetitle,1) ~= m,
      disp('wrong size of hidetitle');
      clear hidetitle
   end;
end;

if exist('hidexlabel'),
   if size(hidexlabel,1) ~= m,
      disp('wrong size of hidexlabel');
      clear hidexlabe
   end;
end;

if exist('hideylabel'),
   if size(hideylabel,1) ~= m,
      disp('wrong size of hideylabel');
      clear hideylabel
   end;
end;

% -------------------------------------------------  
%  plot the function   
% -------------------------------------------------  
for i=1:m,  
    subplot (spm, spn, i);  
    if z == [],  
       plot(x, y(i,:), 'm'); grid  
    else  
       plot(x, y(i,:), 'm', x, z(i,:), 'c'); grid  
    end;    

    if exist('showtitle'),
       title(deblank(showtitle(i,:)));
    end;    
      
    if exist('hidetitle'),
       set(gca,'Userdata',deblank(hidetitle(i,:)));
    else if exist('showtitle'),
            set(gca,'Userdata',deblank(showtitle(i,:)));
         end;
    end; 
         
    if exist('hidexlabel'),
       xlabel(deblank(hidexlabel(i,:)), 'visible','off');
    end;      
    if exist('hideylabel'),
       ylabel(deblank(hideylabel(i,:)), 'visible','off');
    end;      
end;  
  
  
%-----------------------------------------------  
% select a spezial subplot with the mouse and  
% plot the new figure  
%-----------------------------------------------  
command = ['''if get(we,''''string'''') == ''''Differenz ein'''',',...  
           '   set(hd,''''visible'''',''''on'''');',...  
           '   set(we,''''string'''', ''''Differenz aus'''');',...  
           'else,',...  
           '   set(hd,''''visible'''',''''off'''');',...  
           '   set(we,''''string'''', ''''Differenz ein'''');',...  
           'end;'''];  
             
button_555  = ['we = uicontrol(gcf, ''style'',''pushbutton'','...  
                               '''position'',[15 3 100 18],'...  
                               '''Callback'',',command,...  
                              ',''string'',''Differenz aus'');'];  


wbd=[...
     'global button_555;',...
     'h1 = get(gca, ''Children'');',...
     'h2=[];',...
     'for i=1:length(h1),',...
     '    if strcmp(get(h1(i), ''type''), ''line''),',...
     '       h2 = [h2 h1(i)];',...
     '    end,',...
     'end,',...
     'x_spe = get(h2(1), ''Xdata'');',...
     'y_spe = get(h2(1), ''Ydata'');',...
     'if length(h2) >= 2,',...
     '   z_spe = get(h2(2), ''Ydata'');',...
     '   v = axis;',...
     'else,',...
     '   z_spe = [];',...
     'end;',...   
     'title_spe = get(gca, ''Userdata'');',...
     'h1 = get(gca, ''xlabel'');',...
     'xlabel_spe = get(h1, ''String'');',...
     'h1 = get(gca, ''ylabel'');',...
     'ylabel_spe = get(h1, ''String'');',...
     'h1 = get(0, ''Children'');',...     
     'figure(length(h1)+1);',...
     'if length(h2) >= 2,',...
     '   diff = abs(z_spe-y_spe);',...
     '   fill([x_spe x_spe(length(x_spe))],[diff+v(3)*ones(size(diff)) v(3)],''g''),',...
     '   hd = get(gca, ''children'');',...
     '   set(hd, ''FaceColor'', [0.7 0.7 0.7]);',...
     '   axis(v);',...
     '   hold on,',...
     '   plot([v(1),v(2),v(2), v(1), v(1)], [v(3),v(3),v(4), v(4), v(3)], ''w'');',...
     '   eval(button_555);',...
     'end;',...   
     'if z_spe == [],',...
     '   plot(x_spe, y_spe, ''m'');',...
     'else,',...
     '   plot(x_spe, z_spe, ''m'', x_spe, y_spe, ''c'');',...
     'end;',...   
     'grid,',...
     'if title_spe ~= [], title(title_spe); end;',...
     'if xlabel_spe ~= [], xlabel(xlabel_spe); end;',...
     'if ylabel_spe ~= [], ylabel(ylabel_spe); end;',...
     'hold off,',...
     'zoom;',...
     ];

set(gcf,'windowbuttondownfcn',wbd);

