function spanplot (t,z,s)
% Spanplot (t,z,s)
% SPANPLOT takes a one dimensional vector t (xaxis) and
% a two dimensional matrix, z, (yaxis) and plots an
% spectrum analyzer type waterfall plot of each column
% back to back with the first column plotted on the top
% and the last column plotted on the bottom of the page.
% The y axis is re-scaled in the same units to span the entire plot.
% s is the plot string defined by the plot command.

% Copyright Roger Meredith January-1994:
% NRL Code 7172

if nargin ==1
	z=t;
end

a=size(z);
nrow=a(1);
ncol=a(2);
maxvals=max(abs(z));
spcintv= 2*std(maxvals); % spacing interval btwn plots bigger is more space
maxspc = ncol*spcintv; % max offset = offset for 1st column

newz = z(:,1:ncol) + ones(nrow,1)* (maxspc - [1:ncol]*spcintv);

if nargin==3
	plot(t,newz,s);
elseif nargin==2
	plot(t,newz);
else
	plot(newz);
end
