function xlabtex(pvec)
%XLABTEX -- a function to allow the use of greek characters,
%       subscripts and superscripts in a text label placed as 
%       the label to the x-axis
%
%       syntax is a little tricky.
%       xlabtex([any vector of calls to five primitive functions])
%               ntex(string)    --- for normal text
%               gtex(string)    --- for greek text (string contains
%                                   ascii equivalents of greek chars
%                                   see gtex help)
%               stex(string)    --- for subscript text
%               ptex(string)    --- for superscript text
%               sptex(s-string,p-string) -- for both sub & super text
%       NEW     gstex(string)   --- for greek subscripts text
%       NEW     gptex(string)   --- for greek superscript text
%       NEW     gsptex(s-string,p-string)
%                               --- for both sub and super greek text
%
%       put together calls to primitives with spaces in appropriate
%       places to produce a "complex" text string as one string.
%    EXAMPLE: xlabtex([ntex('H'),stex('2'),ntex('O')]) for water
%             xlabtex([gtex('a'),ntex(' is an alpha and '), ...
%               gtex('b'),ntex(' is a beta.')])
%
%     NEW:
%       Greek characters can now also be put in subscript and/or
%       superscript
%
%       AUTHOR: Dan(k) Braithwaite Dept. of Hydrology U.of.A
%                       5/93
%
%       Modifed by Louis Verhagen, Dep. Of Civil Engineering Canberra
%       Australia       24/3/94
%
%       The position of the xlabel didn't take into account the "10" in
%       log plots. This has been changed 
%       Louis Verhagen 19/6/94
 
 
nv = length(pvec);
delprev('xlb')
 
unis = get(gca,'units');
set(gca,'units','norm');
axrect = get(gca,'posi');
set(gca,'units',unis);
 
unis = get(gcf,'units');
set(gcf,'units','pixels');
frect = get(gcf,'posi');
set(gcf,'units',unis);
 
imp = get(pvec(1),'userdata');
 
if (strcmp(imp,'sub') |strcmp(imp,'low') |strcmp(imp,'gub') |strcmp(imp,'glw'))
   vt = 'top';
elseif (strcmp(imp,'sup') |strcmp(imp,'upp') |strcmp(imp,'gup') |strcmp(imp,'gpp'))
   vt = 'bottom';
else
   vt = 'middle';
end
 
set(findthx,'units',get(gcf,'paperunits'),'posit',get(gcf,'paperposit'));
paperextn = mget(pvec,'extent');
set(findthx,'units','norm','posit',[0 0 1 1]);
 
bgn = max(paperextn(:,4));
 
x = ((axrect(3) - (sum(paperextn(:,3))-((6*(nv-1))/frect(3))))/2)+axrect(1);
if strcmp(get(gca,'xscale'),'log')
  y = axrect(2) - (.5*bgn) - .02 -(get(gca,'defaultaxesfontsize')*1.5/frect(4));
else
  y = axrect(2) - (.5*bgn) - .02 -(get(gca,'defaultaxesfontsize')/frect(4));
end
x = ((axrect(3) - (sum(paperextn(:,3))-((6*(nv-1))/frect(3))))/2)+axrect(1);
 
set(pvec(1),'position',[x,y],'vertical',vt,'horiz','left','vis','on','userdata','xlb');
 
for i=2:nv
   imp = get(pvec(i),'userdata');
   if(~strcmp(imp,'upp') & ~strcmp(imp,'gpp'))
     x = x+paperextn(i-1,3)-(6/frect(3));
   end
 
   if (strcmp(imp,'sub') |strcmp(imp,'low') |strcmp(imp,'gub') |strcmp(imp,'glw'))
      vt = 'top';
   elseif (strcmp(imp,'sup') |strcmp(imp,'upp') |strcmp(imp,'gup') |strcmp(imp,'gpp'))
      vt = 'bottom';
   else
      vt = 'middle';
   end
 
   set(pvec(i),'position',[x,y],'vertical',vt,'horiz','left','vis','on','userdata','xlb');
end
