function ylabtex(pvec)
%YLABTEX -- a function to allow the use of greek characters,
%       subscripts and superscripts in a text label placed as 
%       the label to the y-axis
%
%       syntax is a little tricky.
%       ylabtex([any vector of calls to five primitive functions])
%               ntex(string)    --- for normal text
%               gtex(string)    --- for greek text (string contains
%                                   ascii equivalents of greek chars
%                                   see gtex help)
%               stex(string)    --- for subscript text
%               ptex(string)    --- for superscript text
%               sptex(s-string,p-string) -- for both sub & super text
%       NEW     gstex(string)   --- for greek subscripts text
%       NEW     gptex(string)   --- for greek superscript text
%       NEW     gsptex(s-string,p-string)
%                               --- for both sub and super greek text
%
%       put together calls to primitives with spaces in appropriate
%       places to produce a "complex" text string as one string.
%    EXAMPLE: ylabtex([ntex('H'),stex('2'),ntex('O')]) for water
%             ylabtex([gtex('a'),ntex(' is an alpha and '), ...
%               gtex('b'),ntex(' is a beta.')])
%
%     NEW:
%       Greek characters can now also be put in subscript and/or
%       superscript
%
%       AUTHOR: Dan(k) Braithwaite Dept. of Hydrology U.of.A
%                       5/93
%
%       Modifed by Louis Verhagen, Dep. Of Civil Engineering Canberra
%       Australia       24/3/94
%
%       The position of the ylabel didn't take into account the "10" in
%       log plots. This has been changed 
%       Louis Verhagen 19/6/94
 
nv = length(pvec);
delprev('ylb')
 
unis = get(gca,'units');
set(gca,'units','norm');
axrect = get(gca,'posi');
set(gca,'units',unis);
 
unis = get(gcf,'units');
set(gcf,'units','pixels');
frect = get(gcf,'posi');
set(gcf,'units',unis);
 
set(pvec,'rotation',90,'horiz','left');
set(findthx,'units',get(gcf,'paperunits'),'posit',get(gcf,'paperposit'));
paperextn = mget(pvec,'extent');
set(findthx,'units','norm','posit',[0 0 1 1]);
bgn = max(paperextn(:,4));
 
 
ytl = get(gca,'yticklabels');
if strcmp(get(gca,'yscale'),'log')
   sizeytl=size(ytl,2)+3;
else
   sizeytl=size(ytl,2)+1;
end
fs = 6;
y = ((axrect(4) - (sum(paperextn(:,4))-(((nv-1)*6)/frect(4))))/2)+axrect(2);
x = axrect(1) - (.2*bgn) - (sizeytl*fs/frect(3));
 
imp = get(pvec(1),'userdata');
 
if (strcmp(imp,'sub') |strcmp(imp,'low') |strcmp(imp,'gub') |strcmp(imp,'glw'))
   vt = 'top';
elseif (strcmp(imp,'sup') |strcmp(imp,'upp') |strcmp(imp,'gup') |strcmp(imp,'gpp'))
   vt = 'bottom';
else
   vt = 'middle';
end
 
 
set(pvec(1),'position',[x,y],'vertical',vt,'vis','on','userdata','ylb');
 
for i=2:nv
 
   imp = get(pvec(i),'userdata');
   if(~strcmp(imp,'upp') & ~strcmp(imp,'gpp'))
     y = y+paperextn(i-1,4)-(6/frect(4));
   end
 
   if (strcmp(imp,'sub') |strcmp(imp,'low') |strcmp(imp,'gub') |strcmp(imp,'glw'))
      vt = 'top';
   elseif (strcmp(imp,'sup') |strcmp(imp,'upp') |strcmp(imp,'gup') |strcmp(imp,'gpp'))
      vt = 'bottom';
   else
      vt = 'middle';
   end
 
   set(pvec(i),'position',[x,y],'vertical',vt,'vis','on','userdata','ylb');
end
 
