function h=meshztri(x,y,z,c)
%MESHZ	3-D mesh with reference plane.
%	MESHZTRI(...) is the same as MESHTRI(...) except that a "curtain" or
%	reference plane is drawn beneath.
%
%	This routine only works for surfaces defined on a square
%	grid.  The matrices X and Y define the axis limits only.
%
%	See also MESHTRI.

%	Copyright (c) 1993 by ZIB,
%	Copyright (c) in parts 1984-1992 by The MathWorks, Inc.


%	G.W. Zumbusch 16-2-93




error(nargchk(1,4,nargin));

if nargin==1,  % Generate x,y matrices for surface z.
  if min(size(x)) == 1 | isstr(x)
      error('Invalid input argument.')
  end
  z = x;
  [m,n] = size(z);
  [x,y] = meshgrid(0:n-1,0:m-1);
  c = z;

elseif nargin==2,
  if isstr(x) | isstr(y)
	error('Invalid input argument (text).')
  end
  if min(size(x)) == 1 | min(size(y)) == 1
      error('Invalid input argument size.')
  end
  z = x; c = y;
  [m,n] = size(z);
  [x,y] = meshgrid(0:n-1,0:m-1);
  if any(size(c) ~= size(z))
      error('Invalid input argument size.')
  end

elseif nargin>=3,
  if isstr(x) | isstr(y) | isstr(z)
      error('Invalid input argument (text).')
  end
  [m,n] = size(z);
  [mx,nx] = size(x);
  [my,ny] = size(y);
  if m == 1 | n == 1
      error('Invalid input argument size.')
  end
  if nargin == 3
	c = z;
  end
  if any(size(c) ~= size(z))
      error('Invalid input argument size.')
  end
  if any(size(z) ~= size(x)) | any(size(z) ~= size(y))
      error('Invalid input argument size.')
  end
end
if isstr(c)
      error('Invalid input argument (text).')
end


if m ~= n
  error('only square matrices');
end

	m = 2*m-1;
	xneu = NaN * ones(m,m);
	yneu = xneu;
	zneu = yneu;
	cneu = zneu;

	for i2 = 1:m
	   i = i2*.5;
	   for j2 = 1:min(m,m+2-i2)
		j = (rem(i2+1,2) + j2) * .5;
		xneu(i2,j2)	= x(i,j);
		yneu(i2,j2)	= y(i,j);
		zneu(i2,j2)	= z(i,j);
		cneu(i2,j2)	= c(i,j);
	   end
	end


[m,n] = size(zneu);

% Define position of curtains
zref = min(min(zneu(finite(zneu))));

% Define new x,y,z and then do mesh.
zrow = zref*ones(1,n); zcol = zref*ones(m,1);

 newZ = [zref,zrow,zref;zcol, zneu, zcol;zref,zrow,zref];
 newX = [xneu(1,1),xneu(1,:),xneu(1,m);xneu(:,1), xneu, xneu(:,n);xneu(m,1),xneu(m,:),xneu(m,n)];
 newY = [yneu(1,1),yneu(1,:),yneu(1,m);yneu(:,1), yneu, yneu(:,n);yneu(m,1),yneu(m,:),yneu(m,n)];
 c    = [cneu(1,1),cneu(1,:),cneu(1,m);cneu(:,1), cneu, cneu(:,n);cneu(m,1),cneu(m,:),cneu(m,n)];


	[m,n] = size(newZ);

	for i = 2:m
	  newZ(i,m+2-i)	= newZ(i,m+1-i);
	  newY(i,m+2-i) = newY(i,m+1-i);
	  newX(i,m+2-i) = newX(i,m+1-i);
	end
	for i = 3:2:m
	  newZ(i,m+2-i)	= zref;
	end

	for i = 3:m
	  newZ(i,m+3-i)	= zref;
	  newY(i,m+3-i) = newY(i,m+2-i);
	  newX(i,m+3-i) = newX(i,m+2-i);
	end

user_view = 0;
cax = newplot;
fc = get(gca,'color');
if strcmp(lower(fc),'none')
	fc = get(gcf,'color');
end

 hh = surface(newX,newY,newZ,c,'FaceColor',fc,'EdgeColor','flat');
 

next = lower(get(cax,'NextPlot'));
if ~ishold & ~user_view
	view(322.5,30);
end
if nargout == 1
	h = hh;
 
end
