function uiInput(title, buttonList, callback, siz, n1,i1, n2,i2, n3,i3, n4,i4)

%uiInput     Display dialog box with buttons and optionally allow text entry.
%
% uiInput(title, buttonNames, callback)
%    Display the title and buttons and return.  The callback is evaluated
%    when the user clicks a button, with the global variable uiInputButton
%    set to the button number clicked on.  The names in buttonNames should 
%    be separated by | characters.  The title may contain newline characters
%    (value 10) for multi-line text.
%
% uiInput(title, buttonlist, callback, size)
%    As above, but you can specify the size of the displayed box as 
%    [wide high].  If the size is [] the default size is used.
%    If siz is a scalar, it is the width; the default height is used.
%
% uiInput(title, buttonlist, callback, size, 'name', 'init')
%    As above, but also display a text box for the user to edit.
%    'name' is the caption appearing above the edit box, and 'init'
%    is the initial value of the edit box.  Upon callback, the global
%    variable uiInput1 has the edited string.
%
% uiInput(title, buttonlist, callback, size, name1, init1, name2, init2, ...)
%    As above, but show two or more edit boxes with captions, with
%    successive values in uiInput2, uiInput3, uiInput4.  Up to four edit
%    boxes can be handled.  If empty, the last init string may be omitted.
%
% Examples:
% uiInput('Replace file?', 'OK|Cancel', 'mycallback')
% uiInput('', 'OK|Cancel', 'mycallback', [], 'New scaling value', num2str(x))
% uiInput('Size', 'OK|Yes|Why not', 'mycallback', [], 'Length','','Height', '')
%
% Written by Dave Mellinger, dkm1@cornell.edu .  This version 1/18/94.

global uiInputFig uiInputButton uiInputEdits uiInputCallback
global uiInput1 uiInput2 uiInput3 uiInput4

sep = 10;		% newline: separator character for successive lines

if strcmp(title, 'XXXkeyXXX') | strcmp(title, 'XXXclickXXX')
  if strcmp(title, 'XXXkeyXXX')
    c = get(gcf,'CurrentCharacter');
    if c ~= 10 & c ~= 13
      return
    end
    uiInputButton = 1;
  else
    uiInputButton = buttonList;
  end
  if (length(uiInputButton) ~= 1)
    error('Internal error: Didn''t find exactly one button to match.');
  end
  for i = 1:length(uiInputEdits)
    eval(['uiInput',num2str(i),' = get(uiInputEdits(i),''String'');']);
  end
  delete(uiInputFig);
  uiInputFig = 0;
  eval(uiInputCallback);

else
  nedit = floor((nargin - 3) / 2);
  if (nargin < 4), siz = [0 0]; end
  if (~length(siz)), siz = [0 0]; elseif (length(siz) == 1), siz = [siz 1]; end
  if (all(siz == [0 0])), siz = [400 1]; end	% MATLAB can't take [400 0]
  uiInputCallback = callback;

  if (exist('uiInputFig')), if (uiInputFig > 0), delete(uiInputFig); end; end
  uiInputFig = figure('Units', 'pixels', 'NumberTitle', 'off', ...
      'Position', [0 0 1 1], 'Color', [.7 .7 .7], ...
      'Pointer', 'arrow', 'KeyPressFcn', 'uiInput(''XXXkeyXXX'');');
  set(gca, 'Visible', 'off', 'Units', 'pixels');
  bbot	 = 20;
  bhigh	 = 30;
  btop	 = 15;
  ebot	 = 10;
  ehigh	 = 20;
  nbot	 = 10;
  nlhigh = 18;		% height of each line in name
  tbot	 = 10;
  tlhigh = 20;		% height of each line in title
  top	 = 5;

  bwide  = 80;
  bsep   = 20;
  tleft  = 15;
  eleft  = 25;
  eright = eleft;
  nleft  = eleft;

  % Create buttons.
  div = [0, find([buttonList,'|'] == '|')];
  nbut = length(div) - 1;
  btotw	 = nbut*bwide + (nbut-1)*bsep;
  left	 = (siz(1) - btotw) / 2;
  bot    = bbot;
  for i = 1:nbut
    uicontrol('Style', 'PushB', 'Units', 'pixels', ...
	'Position', [left bot bwide bhigh], ...
	'String', buttonList(div(i)+1 : div(i+1)-1), ...
	'Callback', ['uiInput(''XXXclickXXX'', ',num2str(i),')']);
    left = left + bwide + bsep;
  end
  bot = bot + bhigh + btop;

  % Create edit boxes and names.
  ewide = siz(1) - eleft - eright;
  uiInputEdits = [];
  for i = nedit:-1:1
    s = num2str(i);
    bot = bot + ebot;
    if (nargin < 4 + i*2), eval(['i',s,' = '''';']); end
    uiInputEdits(i) = uicontrol('Style','Edit','String', eval(['i',s]), ...
	'Position',[eleft bot ewide ehigh],'BackgroundColor',[1 1 1]);
    bot = bot + ehigh + nbot;
    t = uiMultiText(nleft, bot, ['-',eval(['n',s])], nlhigh, ...
	'Units', 'pixels', 'Color', [0 0 0]);
    bot = bot + nlhigh*length(t);
  end

  % Create title box.
  if length(title)
    bot = bot + tbot;
    t = uiMultiText(tleft, bot, ['-', title], tlhigh, 'Units', 'pixels', ...
	'Color', [0 0 0]);
    for i = t; set(i, 'fontsize', 18); end
    bot = bot + tlhigh * length(t);
  end
  bot = bot + top;
  
  % Put figure at correct position.
  set(0, 'Units', 'pixels');  ss = get(0, 'ScreenSize');
  if (siz(2) < 2), siz(2) = bot; end
  set(uiInputFig, 'Position', [ss(3:4)/2 - siz/2, siz]);
  set(gca,'Visible','off');
end
