% Abstract

% The following two files provide an interactive graphics function
% gplot to use instead of plot in most cases.
% File: gplot.m
function [index,x,y] = ...
 gplot(xa,xb,xc,xd,xe,xf,xg,xh,xi,xj,xk,xl,xm,xn,xo,xp,xq,xr)
% get index from plot
%    [index, x, y] = gplot(x1,...,x18)
%    returns cross position index or index of tagged points respectively
%
%    cursor forward/backward            moves cross
%    cursor up                          redraw
%    cursor down                        show index
%    enter                              tag point
%    page up/down                       jump with cross
%    home/end                           first/last position on screen
%    cntl home/end                      first/last position
%    escape or [F10]                    quit
%    [F3]/[F4]                          lower/upper window border
%    [F9]                               console input
%    [F8]                               zoom all
%    grey +/-                           jump wider/shorter
%    left mouse                         position cross
%    right mouse                        specify window
%
%    min. 2 and max. 18 arguments, with syntax of plot command
%    for more arguments and non-IBM keyboard see m-file

% GPLOT.M               3/17/91                            Hilmar Schlegel
% Central Institute of Electron Physics, Hausvogteiplatz 5-7, 1086 Berlin
% e-Mail: SCHLEGEL@DB0ADW11.bitnet
% Latest change: 5/3/91, 10/20/91
% PROBLEMS:
%        Color i doesn't work for Hercules graphics,
%       On TVGA clg doesn't work unless graph is shown
%       On 386-computer without mouse the cursor keys aren't available,
%       If GINPUT absent, GETKEY(2) must be supplied via DOS console input,
%       Control via cursor and function keys on non-IBM keyboards, i.e.
%       getting a unique key-code for keys which send escape seqs.
%       This is resolved here in the following way:
%       function key              number key

%       [F1..10]       -->       1..0
%       cursor block            cursor diamond control keys(control,upper,lower)

%       home  up  pgup              W    E    R
%           <-  ->                A     S  D    F
%       end  dwn  pgdwn             Z     X    C

%       ->                     space
%       <-                     backspace

% EXAMPLE:       [x, y] = fplot('sin', 0:10);
%              minima = gplot(x, y, x, y, 'o');       % tag minima of curve

% gplot('string',xb,...)
% if isstr(xa)
%       control_string = xa;
%else
%       control_string = [];
%end

% gplot(X)       spread input
% [xa,xb,xc] = X
% [[xa,xb..],[xk,...xl],[...],...] = (xa,xb,.....,xk,..xl..)

[m,n] = size(xa);
if n>m
       xa=xa.';
       [m,n]=size(xa);
end
ltype = '-w';              % standard linetype
if nargin >= 2
       if isstr(xb)
              ltype = xb;
       end
end

if (nargin == 1 ) & n ~= 1       % spread a input matrix
       for i = 1:n
              eval([ 'x', '`'+n+1-i ,'=xa(:,', int2str(n+1-i), ');' ]);
       end
else
       n = nargin;
end

if n == 1                     % accept a vector
       xb = xa;
       xa = 1:length( xb);       % supply first axis
       n = 2;
end
ende = length(xa);
div = ende /16;                     % divide full scale in 16 jumps
close = ende;                     % length of window
window = 1:close;              % window contains full range
if n>2
       if isstr(xc)               % extract linetype specification
              ltype = xc;
              if n>3              % arglist = xd,...
                     arglist = ['x'*ones(1,n-3);  '`'+(4:n);...
                              ','*ones(1,n-4) ' '];
              else
                     arglist = [];
              end
       else
       arglist = ['x'*ones(1,n-2);  '`'+(3:n);  ','*ones(1,n-3) ' '];
       end
else
       arglist = [];
end
arglist = arglist(:)';
mark = '+';                     % cursor shape
color = 'g';                     % cursor color
index = 1;                     % cursor position
hold off
shg
if isempty(arglist)
       plot(xa(window),xb(window),ltype,xa(1),xb(1),'+g');
else
       eval(['plot(xa(window),xb(window),ltype,xa(1),xb(1),[mark,color],'...
               ,arglist,')']);
end
hold on              % include all arguments in first scaling
%eval(control_string);
points = [];                     % tagged points
key = 0;
PC = 0;
if exist('graphkey') == 2
       key_input = 'graphkey(1)';
else
       PC = 1;
       key_input = 'sum(getkey(2))';
end
while isempty(find(key(1) == [27 324 48])),% checks for [F10] or escape
       if find(key(1) == [333 32 4 68 100]) & (index<ende)       % step up
              plot(xa(index),xb(index),[mark, 'i'])
              index = index+1;
              plot(xa(index),xb(index),[mark, color])
       elseif       find(key(1) == [331 8 19 83 115]) & index>1  % step down
              plot(xa(index),xb(index),[mark, 'i'])
              index = index-1;
              plot(xa(index),xb(index),[mark, color])
       elseif       find(key(1) == [329 3 67 99]) & (index+div<ende)% pgup
              plot(xa(index),xb(index),[mark, 'i'])
              index = index+round(div);
              plot(xa(index),xb(index),[mark, color])
       elseif       find(key(1) == [337 18 82 114]) & (index-div>1)  % pgdn
              plot(xa(index),xb(index),[mark, 'i'])
              index = index-round(div);
              plot(xa(index),xb(index),[mark, color])
       elseif       find(key(1) == [327 65 97])  & index>1           % home
              plot(xa(index),xb(index),[mark, 'i'])
              index = window(1);
              plot(xa(index),xb(index),[mark, color])
       elseif       find(key(1) == [335 70 102]) & (index<ende)       % end
              plot(xa(index),xb(index),[mark, 'i'])
              index = window(close);
              plot(xa(index),xb(index),[mark, color])
       elseif       find(key(1) == [375 23 87 119]) & index>1     % cntl home
              plot(xa(index),xb(index),[mark, 'i'])
              index = 1;
              plot(xa(index),xb(index),[mark, color])
       elseif       find(key(1) == [373 26 90 122]) & (index<ende) % cntl end
              plot(xa(index),xb(index),[mark, 'i'])
              index = ende;
              plot(xa(index),xb(index),[mark, color])
       elseif       find(key(1) == [336 24 88 120])              % disp index
              fprintf(' i: %g  x: %f  y: %f \n',...
                     index,xa(index),xb(index))
              if ~PC                     % comment out on
                     pause              % multi-window
              end                     % system|
       elseif       key(1) == 13                                 % tag position
              m = find(index == points);
              if m
                     points(m) = [];
              plot(xa(index),xb(index),'oi')
              else
                     points = [points;index];
              plot(xa(index),xb(index),'og')
              end
       elseif       find(key(1) == [323 57])              % checks for [F9]
              disp(' ')
              keyboard                                   % console input
              shg
       elseif key(1) == 1 & length(key)>1                     % goto pointer
              plot(xa(index),xb(index),[mark, 'i'])              % left mouse
              if key(2) > max(xa)
                     [m, index] = max(xa);
              elseif key(2) < min(xa)
                     [m, index] = min(xa);
              else
                     [m, index] = min(abs(xa-key(2)));
              end
              plot(xa(index),xb(index),[mark, color])
       elseif key(1) == 2 & length(key)>1                     % right mouse
              window1 = key(2);
              key = eval(key_input);
              if key(1) == 2
                     window1 = sort([window1,key(2)]);
                     window1(2) = min([max(xa),window1(2)]);
                     window1(1) = max([min(xa),window1(1)]);
                     window1 = find(window1(1) <= xa & xa <= window1(2));
                     if ~isempty(window1)
                            window = window1;
                     end
                     close = length(window);
                     div = max([close/16,1]);
                     if index>window(close)
                            index = window(close);
                     elseif index<window(1)
                            index = window(1);
                     end
                     if ~PC
                            key = 328;              % redraw
                     end

              end
       elseif        key(1) == 43                            % inc. step width
              div = 2*div;
       elseif        key(1) == 45                            % dec. step width
              div = max([div/2,1]);
       elseif       ~isempty(find(key(1) == [317 51])) : index<window(1)
              window = index:window(close);              % checks for [F3]
              close = length(window);
              div = close/16;
              if isempty(find(key(1) == [317 51])) & ~PC
                     key = 328;              % redraw
              end
       elseif       ~isempty(find(key(1) == [318 52])) : index>window(close)
              window = window(1):index;              % checks for [F4]
              close = length(window);
              div = close/16;
              if isempty(find(key(1) == [318 52])) & ~PC
                     key = 328;              % redraw
              end
       elseif       find(key(1) == [315 49])              % checks for [F1]
              help gplot
              pause
       elseif       find(key(1) == [322 56])              % checks for [F8]
              window = 1:ende;
              close = length(window);
              div = close/16;
              key = 328;              % redraw
       end
       if       find(key(1) == [328 5 69 101])              % redraw
              hold off                     % cursor always on plot
          plot(xa(window),xb(window),ltype,xa(index),xb(index),[mark, color]);
              hold on
              if ~isempty(arglist)
                     eval(['plot(',arglist,')'])       % show rest of data
              end
              if ~isempty(points)
                     plot(xa(points),xb(points),'og')% mark tagged points
              end
%              eval(control_string);
       end
       key = eval(key_input);
end
if ~isempty(points)              % tagged points
       index = points;
end
if nargout == 2                     % [x(index), y(index)] = gplot(..)
       x = xb(index);
       index = xa(index);
end
if nargout >= 3                     % [index, x(index), y(index)] = gplot(..)
       x = xa(index);
       y = xb(index);
end
hold off


