function places=show_plt_menu(items,x,y)
% function places=show_plt_menu(items,x,y)
% Returns array containing locations of shown menu items
% as : places(1:4,1:n) , where n is the number of menu items.
% places contains screen coordinates of upper-left (1:2,:) and
% lower-right (3:4,:) corners of sreen areas connected with
% given menu items.
% Limitations: number of items <=10; length of item name<=8.
% Arguments:
% items is a text array e.g.: ['item_1';'item_2';'item_3']
% (x,y) is an optional location of the first menu item in
%   screen coordinates, if used, the user is responsible for
%   possible the effects of limited screen area
%

% KNOWN BUGS:
% As it is impossible to clear "clicks" and keyboard buffer from
% within Matlab, some "old" clicks will sometimes be interpreted
% by the program which will result in erratic but not disastrous
% effects. To avoid this, click buttons briefly and keep the
% mouse stationary when clicking.
%
% HARDWARE:   SUN 3/60, Matlab version: 3.27a
%
% Please, report bugs, modifications etc. to:
%       W. Tych,
%       Dept. of Environmental Sciences
%       University of Lancaster
%       e-mail:            tych@uk.ac.lancs.cent1
%             from BITNET: tych@cent1.lancs.ac.uk
%
% Wlodek Tych, 24.3.89.
%
if nargin==1, x=0.12; y=0.0; end
[n,m]=size(items);
xx=x;yy=y;
field_width=fix(50/n);   % menu width: 50 chars
empty=field_width-m;     % number of spaces to add to each item
empty_sc=empty/70;       % 70 chars=approx. 1 screen unit
full_sc=m/70;
for i=1:n
        text(xx,yy,items(i,:),'sc');
        places(1,i)=xx-0.0125;
        places(2,i)=yy+0.028;
        places(3,i)=xx+full_sc+0.0125;
        places(4,i)=yy;
        xx=xx+empty_sc+full_sc;
end
lx=[0 1];ly=[0.038 0.038];polyline(lx,ly,'sc');
%
