
function zoom3d

%++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
%
%
% Function  ZOOM3D : Zooms MESH and SURF plots 
%                    works only for monotonously increasing x and y -values !
%                    
%
% Gaby Gniss  
% ggniss@elserv.ffm.fgan.de  
% 
%
% Using parts of:
%
% File:   subzoom.m  written by Doug Harriman 
%         (ftp.mathworks.com/pub/contrib/graphics/subzoom.m)
%
%++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
%
% Syntax    :    >> zoom3d
%
% WORKS ONLY FOR MONOTONOUSLY INCREASING X AND Y VALUES !     
%
% Zoom3d opens a further figure window displaying the 2-D surface plot.   
% Use mouse to select first the zoom region and second the size of window
% for displaying the zoomed figure. After doing that the 2-D surface plot
% disappears and as a result you will obtain the zoomed
% 3-D Mesh or Surf Plot. 
% 
%         
% Examples  :    >> mesh(peaks); zoom3d
%                >> surf(peaks); zoom3d
%                >> surf(peaks); shading flat; zoom3d
%                >> surf(peaks); shading interp; zoom3d
%                >>[x,y]=meshgrid(-2:.1:2,-2:.1:2)
%                  !!! use meshgrid not meshdom !!!
%                >>z=peaks(x,y); mesh(x,y,z); colorbar; zoom3d
%   
%++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++



 handl=gca;
 par=get(handl,'parent');
 chi=get(par,'children');
 for i=1:length(chi)
  azel=get(chi(i),'view');
  if azel(1)~=0 & azel(2)~=0
   az=azel(1); el=azel(2);
  end;
 end;

 for k=1:length(chi)
  child=get(chi(k),'children');
  for i=1:length(child)
   ptype=get(child(i),'type');
   if strcmp(ptype,'surface'); nr=i; break; end;
 end; 
   if strcmp(ptype,'surface'); break; end;
 end;

 if ~strcmp(ptype,'surface')
  disp(setstr(7)), disp('error, no surface plot'),return; end; 

 x=get(child(nr),'xdata');
 y=get(child(nr),'ydata');  
 z=get(child(nr),'zdata');
 edgecol = get(child(nr),'edgecolor') ;
 facecol = get(child(nr),'facecolor'); 

 map=colormap;
 figure;
 oncemore='y';

 while strcmp(oncemore,'y')  
  
   if strcmp(edgecol,'flat')
     mesh(x,y,z); 
   end; 

   if strcmp(facecol,'flat')
    surf(x,y,z); 
   end; 
  
   if strcmp(edgecol,'none') & strcmp(facecol,'flat')
    surf(x,y,z); shading flat;
   end;

   if strcmp(edgecol,'none') & strcmp(facecol,'interp')
    surf(x,y,z); shading interp;
   end;

  view(2); 
  colormap(map); 
  % Meshplot title
  ptitle = 'Zoomed Region' ;

  % Move to correct figure 
    figure(gcf) ;

  % Disable any widowbutton down functions
   set(gcf,'windowbuttondownfcn',' ') ;

  % Get zoom box
    disp('Use mouse to select Region to Zoom')
    waitforbuttonpress            ;
    pnt = get(gcf,'currentpoint') ;
    xy1 = get(gca,'currentpoint') ;
    rbbox([pnt 0 0],pnt)          ;
    xy2 = get(gca,'currentpoint'); 

  % Clean up data 
    xy1 = xy1(1,1:2) ;
    xy2 = xy2(1,1:2) ;
    xx  = [xy1(1) xy2(1) ] ;
    yy  = [xy1(2) xy2(2) ] ;

  % Default  (important!)
   xx1=[]; xx2=[]; yy1=[]; yy2=[];


  % Get new plot area

    disp('Use mouse to select Size of Window for Display')
    waitforbuttonpress ;
    pnt1 = get(gcf,'currentpoint') ;
    rbbox([pnt1 0 0],pnt1) ;
    pnt2 = get(gcf,'currentpoint') ;
 

  % Clean up data
    pntx = [pnt1(1) pnt2(1)] ;
    pnty = [pnt1(2) pnt2(2)] ;

  % Create axes
    mainaxhan = gca ;
    pos = get(gcf,'position') ;
    corner = [min(pntx)/pos(3) min(pnty)/pos(4)] ;
    width  = [abs(diff(pntx))/pos(3) abs(diff(pnty))/pos(4)] ;
    if width(1)==0 | width(2)==0, width(1)=0.3; width(2)=0.3; end;
    axhan = axes('position',[corner width],'box','on') ;

  % Set fontsize
    factor = 1 ;
    psize = get(mainaxhan,'fontsize') ;
    set(axhan,'fontsize',factor*psize) ;


  % Set aspectratio
  % Comment this out if you want to set you own aspect ratio
    aspect = get(mainaxhan,'aspectratio') ;
    set(axhan,'aspectratio',aspect) ;

  % Get Data to plot

    kids = get(mainaxhan,'children') ;
    hold on


 %  xdata row vector   
    xdata = get(kids,'xdata') ; 
    [row,col]=size(xdata);
    if col>1,xdata=xdata(1,:); else, xdata=xdata.'; end;  
        
 %  ydata column vector   
    ydata = get(kids,'ydata') ; 
    [row,col]=size(ydata); 
    if row>1,ydata=ydata(:,1); else, ydata=ydata(:); end;

    if diff(xdata)<=0 
     disp(setstr(7))
     disp('error : x values not monotonously increasing')
     close(gcf);
     return 
    end;
    if diff(ydata)<=0 
     disp(setstr(7))
     disp('error : y values not monotonously increasing')
     close(gcf);
     return 
    end;

  
    if rem(xdata,1)==0 & xdata(1)==1;
      xx1=round(xx(1));xx2=round(xx(2)); 
      if xx1>xx2, xxh=xx1; xx1=xx2; xx2=xxh; end;
      if xx1<1,xx1=1; end;
      if xx2>length(xdata); xx2=length(xdata); end; 

    else

      if xx(1)>xx(2); xxh=xx(1); xx(1)=xx(2); xx(2)=xxh; end;
      l=find(xx(1)>xdata); if l~=[]; xx1=l(length(l)); end;
      l=find(xx(2)<xdata); if l~=[]; xx2=l(1); end;

    end;

    if rem(ydata,1)==0 & ydata(1)==1;
      yy1=round(yy(1)); yy2=round(yy(2)); 
      if yy1>yy2; yyh=yy1; yy1=yy2; yy2=yyh; end;
      if yy1<1; yy1=1; end;
      if yy2>length(ydata); yy2=length(ydata); end; 

    else

      if yy(1)>yy(2); yyh=yy(1); yy(1)=yy(2); yy(2)=yyh; end;
      l=find(yy(1)>ydata);  if l~=[]; yy1=l(length(l)); end;
      l=find(yy(2)<ydata);  if l~=[]; yy2=l(1); end;

   end;

  
      zdata = get(kids,'zdata') ; 

    if length(xdata)==length(ydata)      ;
      if xx1==[]; xx1=1; end;
      if xx2==[]; xx2=length(xdata); end;
      if yy1==[]; yy1=1;  end;
      if yy2==[]; yy2=length(ydata); end;    
      xdat=ydata(xx1:xx2);
      ydat=xdata(yy1:yy2);
      zdat=zdata(yy1:yy2,xx1:xx2); 
   else

      if xx1==[]; xx1=1; end;
      if xx2==[]; xx2=length(xdata); end;
      if yy1==[]; yy1=1;  end;
      if yy2==[]; yy2=length(ydata); end;
      xdat=xdata(xx1:xx2);
      ydat=ydata(yy1:yy2);
      zdat=zdata(yy1:yy2,xx1:xx2); 
    end;  

   
    cdat=zdat; 
    axu=min(min(zdata)); axo=max(max(zdata)); 
    zz1=min(min(zdat)); zz2=max(max(zdat)); 

    edgecolor = get(kids,'edgecolor') ;     
    facecolor = get(kids,'facecolor') ;
    linestyle = get(kids,'linestyle') ;
    linewidth = get(kids,'linewidth') ;


  if min(xdat)>=max(xdat) | min(ydat)>=max(ydat) | zz1>=zz2 
     disp(setstr(7))
     disp('error : zoom region too small try it again')
     close(gcf);
     return 
  end;
  if min(xdat)==[]==1 | max(xdat)==[]==1 | min(ydat)==[]==1 | max(ydat)==[]==1 ...
     | zz1==[]==1 | zz2==[]==1 
     disp(setstr(7))
     disp('error : x or y values not monotonously increasing')
     close(gcf);
     return 
  end;

    axis([min(xdat) max(xdat) min(ydat) max(ydat) zz1 zz2]); view(3);

 
    if strcmp(edgecol,'flat')
      surfacehan=mesh(xdat,ydat,zdat); 
    end;  
    if strcmp(facecol,'flat')
     surfacehan=surf(xdat,ydat,zdat); 
    end;
    if strcmp(edgecol,'none') & strcmp(facecol,'flat')
     surfacehan=surf(xdat,ydat,zdat); shading flat;
    end;
   if strcmp(edgecol,'none') & strcmp(facecol,'interp')
     surfacehan=surf(xdat,ydat,zdat); shading interp;
    end; 
    view([az,el]);                            
         
    set(surfacehan,'edgecolor',edgecolor) ;
    set(surfacehan,'facecolor',facecolor) ;
    set(surfacehan,'linestyle',linestyle) ;
    set(surfacehan,'linewidth',linewidth) ;
    
    hold off

   % Label 
    titlehan = get(axhan,'title') ;
    set(titlehan,'string',ptitle,...
    'fontsize',psize*factor) ;

    delete(mainaxhan);
    caxis([axu,axo]);

    clear xx1 xx2 yy1 yy2;
% with more=k(eyboard) you can change shading,view,title
%                      or you can give print command  and so on

   disp(setstr(7))
   oncemore=input('once more ?  (y/n/k(eyboard)) : ','s');
   oncemore=lower(oncemore);
   while ~strcmp(oncemore,'y') & ~strcmp(oncemore,'n') & ~strcmp(oncemore,'k')
    disp(setstr(7));
    disp('incorrect input use only y/n/k')  
    oncemore=input('once more ?  (y/n/k(eyboard)) : ','s');
    oncemore=lower(oncemore);
   end;


  if strcmp(oncemore,'k')
   keyboard; 
   disp(setstr(7));
   oncemore=input('once more ?  (y/n/k(eyboard)) : ','s');
   oncemore=lower(oncemore);

   while ~strcmp(oncemore,'y') & ~strcmp(oncemore,'n') & ~strcmp(oncemore,'k')
    disp(setstr(7));
    disp('incorrect input use only y/n/k')  
    oncemore=input('once more ?  (y/n/k(eyboard)) : ','s');
    oncemore=lower(oncemore);
   end;
 end;

  if strcmp(oncemore,'y'),clf; end;
 end;   % while-loop

% End of Function

