function [I]=dquad(Fun,a1,a2,a3,a4)

% DQUAD	    Numerically integrates an expression using QUAD.
%	    I = DQUAD('1/(1+x^3)',a,b) approximates,
%
%	                              a
%                                    /
%                                   |     1    
%                                   | ----------- dX
%                                   |        3
%                                   |  (1 + x  )
%                                  /
%                                  b
%
%	    I = DQUAD('1/(1+z^3)','z',a,b) integrates with
%           respect to 'z' rather than 'x' (the default).
%	    I = DQUAD('1/(1+z^3)','z',a,b,tol) integrates
%	    to a relative error of tol. If warning messages are
%	    generated, try DQUAD8.
%	    See QUAD, QUAD8, DQUAD8

%	D. Thomas  2/93
%	dethomas@athena.mit.edu

var = 'x';
tol=1e-3;
if nargin<3,
help dquad
return
end
if nargin == 3,
    xmin=a1;
    xmax=a2;
elseif nargin == 4,
   if (isstr(a1)),
    var=a1;
    xmin=a2;
    xmax=a3;
   else
    xmin=a1;
    xmax=a2;
    tol=a3;
   end
else
    var=a1;
    xmin=a2;
    xmax=a3;
    tol=a4;
end

%
%      Change matrix operators to elementwise operators
%

t=sort([find(Fun=='*'),find(Fun=='/'),find(Fun=='^')]);
[ignore,N]=size(t);
[ignore,M]=size(Fun);
a=1;
for i=1:N,
  Funx=[Funx,Fun(a:(t(i)-1))];
   if (Fun(t(i)-1)~='.'),
      Funx=[Funx,' .',Fun(t(i))];
   else
      Funx=[Funx,Fun(t(i))];
   end
  a=t(i)+1;
end
Funx=[Funx,Fun(a:M)];

%
%	Write function as /tmp/qxmfun.m and call quad
%

if exist('qxmfun'),
	delete /tmp/qxmfun.m
end
fname='/tmp/qxmfun.m';
A=matlabpath;matlabpath(['/tmp:',A]);
fprintf(fname,['function OuTpUt=qxmfun(',var,')\n']);
fprintf(fname,['OuTpUt=',Funx,';']);
I=quad('qxmfun',xmin,xmax,tol);
matlabpath(A);
delete /tmp/qxmfun.m


