function [I]=dquad8(Fun,a1,a2,a3,a4)

% DQUAD	    Numerically integrates an expression using QUAD8.
%	    I = DQUAD8('exp(-x^2)/(1+x^(1/2))',a,b) approximates,
%
%	                           a
%                                 /        2
%                                |  exp(- x )
%                                |  --------- dx
%                                |        1/2
%                               /    1 + x
%                               b
%
%	    I = DQUAD8('exp(-z^2)/(1+z^(1/2))','z',a,b) integrates
%           with respect to 'z' rather than 'x' (the default).
%	    I = DQUAD8('exp(-z^2)/(1+z^(1/2))','z',a,b,tol) integrates
%	    to a relative error of tol.
%	    See QUAD, QUAD8, DQUAD

% 	D.Thomas  2/93
%	dethomas@athena.mit.edu

var = 'x';
tol=1e-3;
if nargin<3,
help dquad8
return
end
if nargin == 3,
    xmin=a1;
    xmax=a2;
elseif nargin == 4,
   if (isstr(a1)),
    var=a1;
    xmin=a2;
    xmax=a3;
   else
    xmin=a1;
    xmax=a2;
    tol=a3;
   end
else
    var=a1;
    xmin=a2;
    xmax=a3;
    tol=a4;
end

%
%      Change matrix operators to elementwise operators
%

t=sort([find(Fun=='*'),find(Fun=='/'),find(Fun=='^')]);
[ignore,N]=size(t);
[ignore,M]=size(Fun);
a=1;
for i=1:N,
  Funx=[Funx,Fun(a:(t(i)-1))];
   if (Fun(t(i)-1)~='.'),
      Funx=[Funx,' .',Fun(t(i))];
   else
      Funx=[Funx,Fun(t(i))];
   end
  a=t(i)+1;
end
Funx=[Funx,Fun(a:M)];

%
%	Write function as /tmp/qxmfun.m and call quad8
%

if exist('qxmfun'),
	delete /tmp/qxmfun.m
end
fname='/tmp/qxmfun.m';
fprintf(fname,['function OuTpUt=qxmfun(',var,')\n']);
fprintf(fname,['OuTpUt=',Funx,';']);
A=matlabpath;matlabpath(['/tmp:',A]);
I=quad8('qxmfun',xmin,xmax,tol);
matlabpath(A);
delete /tmp/qxmfun.m



