function pd = jlsode(t,y,ml,mu,rwork,iwork)
%
pd(1,1) = -.04d0;
pd(1,2) = 1.d4*y(3);
pd(1,3) = 1.d4*y(2);
pd(2,1) = .04d0;
pd(2,3) = -pd(1,3);
pd(3,1) = 0;
pd(3,2) = 6.d7*y(2);
pd(3,3) = 0;
pd(2,2) = -pd(1,2) - pd(3,2);

lsode_examp.f
c  this exmple is taken from the lsode source.
c  the following is a simple example problem, with the coding
c  needed for its solution by lsode.  the problem is from chemical
c  kinetics, and consists of the following three rate equations..
c      dy1/dt = -.04*y1 + 1.e4*y2*y3
c      dy2/dt = .04*y1 - 1.e4*y2*y3 - 3.e7*y2**2
c      dy3/dt = 3.e7*y2**2
c  on the interval from t = 0.0 to t = 4.e10, with initial conditions
c  y1 = 1.0, y2 = y3 = 0.  the problem is stiff.
c 
c  the following coding solves this problem with lsode, using mf = 21
c  and printing results at t = .4, 4., ..., 4.e10.  it uses
c  itol = 2 and atol much smaller for y2 than y1 or y3 because
c  y2 has much smaller values.
c  at the end of the run, statistical quantities of interest are
c  printed (see optional outputs in the full description below).
   
      program lsexamp
   
      external fex, jex
      double precision atol, rtol, rwork, t, tout, y
      dimension y(3), atol(3), rwork(58), iwork(23)
      neq = 3
      y(1) = 1.d0
      y(2) = 0.d0
      y(3) = 0.d0
      t = 0.d0
      tout = .4d0
      itol = 2
      rtol = 1.d-4
      atol(1) = 1.d-6
      atol(2) = 1.d-10
      atol(3) = 1.d-6
      itask = 1
      istate = 1
      iopt = 0
      lrw = 58
      liw = 23
      mf = 21
      do 40 iout = 1,12
        call lsode(fex,neq,y,t,tout,itol,rtol,atol,itask,istate,
     1     iopt,rwork,lrw,iwork,liw,jex,mf)
        write(6,20)t,y(1),y(2),y(3)
 20     format(7h at t =,e12.4,6h   y =,3e14.6)
        if (istate .lt. 0) go to 80
 40     tout = tout*10.d0
      write(6,60)iwork(11),iwork(12),iwork(13)
 60   format(/12h no. steps =,i4,11h  no. f-s =,i4,11h  no. j-s =,i4)
      stop
 80   write(6,90)istate
 90   format(///22h error halt.. istate =,i3)
      stop
      end
      
      subroutine fex (neq, t, y, ydot)
      double precision t, y, ydot
      dimension y(3), ydot(3)
      ydot(1) = -.04d0*y(1) + 1.d4*y(2)*y(3)
      ydot(3) = 3.d7*y(2)*y(2)
      ydot(2) = -ydot(1) - ydot(3)
      return
      end
      
      subroutine jex (neq, t, y, ml, mu, pd, nrpd)
      double precision pd, t, y
      dimension y(3), pd(nrpd,3)
      pd(1,1) = -.04d0
      pd(1,2) = 1.d4*y(3)
      pd(1,3) = 1.d4*y(2)
      pd(2,1) = .04d0
      pd(2,3) = -pd(1,3)
      pd(3,2) = 6.d7*y(2)
      pd(2,2) = -pd(1,2) - pd(3,2)
      return
      end
 
c  the output of this program (on a cdc-7600 in single precision)
c  is as follows..
c 
c    at t =  4.0000e-01   y =  9.851726e-01  3.386406e-05  1.479357e-02
c    at t =  4.0000e+00   y =  9.055142e-01  2.240418e-05  9.446344e-02
c    at t =  4.0000e+01   y =  7.158050e-01  9.184616e-06  2.841858e-01
c    at t =  4.0000e+02   y =  4.504846e-01  3.222434e-06  5.495122e-01
c    at t =  4.0000e+03   y =  1.831701e-01  8.940379e-07  8.168290e-01
c    at t =  4.0000e+04   y =  3.897016e-02  1.621193e-07  9.610297e-01
c    at t =  4.0000e+05   y =  4.935213e-03  1.983756e-08  9.950648e-01
c    at t =  4.0000e+06   y =  5.159269e-04  2.064759e-09  9.994841e-01
c    at t =  4.0000e+07   y =  5.306413e-05  2.122677e-10  9.999469e-01
c    at t =  4.0000e+08   y =  5.494529e-06  2.197824e-11  9.999945e-01
c    at t =  4.0000e+09   y =  5.129458e-07  2.051784e-12  9.999995e-01
c    at t =  4.0000e+10   y = -7.170586e-08 -2.868234e-13  1.000000e+00
c 
c    no. steps = 330  no. f-s = 405  no. j-s =  69
c -----------------------------------------------------------------------
