function [dl,dr,alpha,hn] = block_ratint(y,z,F,p,factor,transp);
%BLOCK_RATINT  
%        An auxiliary routine called by BLOCK_HSOLVE.
%
%        Written by Peter Kravanja and Marc Van Barel
%                   Dept. Computer Science
%                   Katholieke Universiteit Leuven
%                   Celestijnenlaan 200 A, B-3001 Heverlee, Belgium
%
%                   E-mail: na.pkravanja@na-net.ornl.gov
%                           marc@cs.kuleuven.ac.be
%        (October 10, 1996)

%-----------------------------------------------------------------------
%
  n = size(y,1);
  reps = abs(factor)*eps;

  for r = 1:n,
    for t = 1:p,
      s((r-1)*p+t,1) = y(r);
      s((n+r-1)*p+t,1) = z(r);
    end;
  end;
  for r = 1:2*n,
    residuals((r-1)*p+1:(r-1)*p+p,1:p) = eye(p);
    residuals((r-1)*p+1:(r-1)*p+p,p+1:2*p) = ...
      - F((r-1)*p+1:(r-1)*p+p,:);
  end;

  for r = 1:2*p,
    C(r) = 1;
  end;

  CoeffUpper = zeros(2*p^2);
  CoeffLower = zeros(n+1,2*p^2);
  for r = 1:p,
    CoeffUpper((r-1)*p+r) = 1;
    CoeffLower(1,(p+r-1)*p+r) = 1;
  end;
  DegUpper = 1 + zeros(p,2*p);
  DegLower = 1 + zeros(p,2*p); 
%-----------------------------------------------------------------------
  alpha = max(max( [ abs(real(residuals(:,p+1:2*p))), ...
                     abs(imag(residuals(:,p+1:2*p))) ] ));
  residuals(:,p+1:2*p) = residuals(:,p+1:2*p)/alpha;  
%-----------------------------------------------------------------------
  for j = 1:2*p*n,
    maximum = 0;
    for l = 1:2*p,
      if C(l)
        if j < 2*p*n
          [maxl,posl] = max( [ abs(real(residuals(j:2*p*n,l))), ...
                               abs(imag(residuals(j:2*p*n,l))) ] );
        else
          maxl = [ abs(real(residuals(2*p*n,l))) ...
                   abs(imag(residuals(2*p*n,l))) ];
          posl = [ 1  1 ];
        end; 
        [mx,ps] = max(maxl);
        if mx > maximum
          maximum = mx;
          piv = posl(ps) + j - 1 ;
          col = l;
        end; 
      end; 
    end;
    if maximum < reps
      hn = j-1;
      return;
    end;  
%-----------------------------------------------------------------------
    hold = s(j); s(j) = s(piv); s(piv) = hold;
    reshold = residuals(j,:); 
    residuals(j,:) = residuals(piv,:);
    residuals(piv,:) = reshold; 
%-----------------------------------------------------------------------
    for l = 1:2*p,
      if ~(l == col)
        mu(l) = residuals(j,l)/residuals(j,col);
      end;
    end;

    for t = 1:p,
      for r = 1:2*p,
        if ~(r == col)
          if DegUpper(t,r) == DegUpper(t,col)
            CoeffUpper((r-1)*p+t) = CoeffUpper((r-1)*p+t) - ...
              mu(r)*CoeffUpper((col-1)*p+t);
          end;
        end;
      end;
      DegUpper(t,col) = DegUpper(t,col) + 1;
    end;

    for t = 1:p,
      for r = 1:2*p,
        if ~(r == col)
          range = 1:DegLower(t,col);
          CoeffLower(range,(r-1)*p+t)=CoeffLower(range,(r-1)*p+t)- ...
            mu(r)*CoeffLower(range,(col-1)*p+t);
        end;
      end;
      hh = CoeffLower(DegLower(t,col),(col-1)*p+t);
      if DegLower(t,col) >= 2
        CoeffLower(2:DegLower(t,col),(col-1)*p+t) = ...
        CoeffLower(1:DegLower(t,col)-1,(col-1)*p+t) - s(j) * ...
        CoeffLower(2:DegLower(t,col),(col-1)*p+t);
      end;
      CoeffLower(1,(col-1)*p+t)= -s(j)*CoeffLower(1,(col-1)*p+t);
      CoeffLower(1+DegLower(t,col),(col-1)*p+t) = hh;
      DegLower(t,col) = DegLower(t,col) + 1;
    end;
 
    for k = j+1:2*p*n,
      for l = 1:2*p, 
        if ~(l == col)
          residuals(k,l) = residuals(k,l) - mu(l)*residuals(k,col);
        end;
      end;
      residuals(k,col) = (s(k)-s(j))*residuals(k,col);
    end;
       
    C(col) = 0;
    if all(1-C)
      for r = 1:2*p,
        C(r) = 1;
      end;
    end;
 
  end;
  hn = 2*p*n;
%-----------------------------------------------------------------------
  cfs = zeros(p*(n+1),2*p);
  for q = 1:n+1,
    for t = 1:p,
      for r = 1:2*p,
        cfs((q-1)*p+t,r) = CoeffLower(q,(r-1)*p+t);
      end;
    end;
  end;

  HDCoeff = zeros(2*p,2*p);
  for t = 1:p,
    for r = 1:2*p,
      HDCoeff(t,r) = CoeffUpper((r-1)*p+t);
    end;
  end;
  HDCoeff(p+1:2*p,1:2*p) = cfs(p*n+1:p*n+p,1:2*p);
  cfs = cfs * inv(HDCoeff);

  for q = 1:n+1,
    for t = 1:p,
      for r = 1:2*p,
        CoeffLower(q,(r-1)*p+t) = cfs((q-1)*p+t,r);
      end;
    end;
  end;
%-----------------------------------------------------------------------
  if transp

   for t = 1:p,
      for r = 1:p,
        vec = CoeffLower(1:n,(t-1)*p+r);
        vec = conj(fft(conj(vec)));
        for q = 1:n,
          dl((q-1)*p+t,r) = vec(q);
        end;
      end;
    end;
    for t = 1:p,
      for r = 1:p,
        vec = CoeffLower(1:n,(t+p-1)*p+r);
        vec = conj(fft(conj(vec)));
        for q = 1:n,
          dr((q-1)*p+t,r) = vec(q);
        end;
      end;
    end;
    for q = 1:n,
      dr((q-1)*p+1:(q-1)*p+p,1:p) = dr((q-1)*p+1:(q-1)*p+p,1:p)+eye(p);
    end;

  else

    zeta = z(1);
    for t = 1:p,
      for r = 1:p,
        vec = CoeffLower(1:n,(r-1)*p+t);
        for q = 2:n,
          vec(q) = (zeta^(q-1))*vec(q);
        end;
        vec = conj(fft(conj(vec)));
        for q = 1:n,
          dl((q-1)*p+t,r) = vec(q);
        end; 
      end;
    end;
    for t = 1:p,
      for r = 1:p,
        vec = CoeffLower(1:n,(r+p-1)*p+t);
        for q = 2:n,
          vec(q) = (zeta^(q-1))*vec(q);
        end;
        vec = conj(fft(conj(vec)));
        for q = 1:n,
          dr((q-1)*p+t,r) = vec(q);
        end;
      end;
    end;
    for q = 1:n,
      dr((q-1)*p+1:(q-1)*p+p,1:p) = dr((q-1)*p+1:(q-1)*p+p,1:p)-eye(p);
    end;

  end; 
  return;
%-----------------------------------------------------------------------
