function [y,resid] = gje(a,b,tol,dopivot,dgts)
% [y,resid] = gje(a,b,tol,dopivot,dgts)
% Perform Guass-Jordan elimination to solve the system a*y=b.
% When dopivot equals one, then row pivoting is used. If a
% diagonal smaller than tol is encountered, then the solution
% process is abandoned. When dgts is greater than zero, then
% calculations are carried out to dgts decimal places.

%         by Howard Wilson, Sept,1988

if nargin<5, dgts=-1; end, if nargin<4, dopivot=0; end
if nargin<3, tol=100*eps; end
tol=tol*max(abs(a(:))); akeep=a; a=[a,b]; [nrow,ncol]=size(a);
% function rou(mat,dgts) rounds elements of mat to dgts digits
if dgts>0, a=rou(a,dgts); b=rou(b,dgts); end
for i=1:nrow
   if dopivot==1, vpivot=abs(a(i:nrow,i));
      [vpivot,ibest]=max(vpivot); ibest=ibest+i-1;
      a([i ibest],:)=a([ibest i],:);
   end
   if abs(a(i,i)) < tol, y=[]; resid=[];
      'singular matrix in function gje', return
   end
   for j=1:nrow
      if j ~= i, r = a(j,i)/a(i,i);
        if dgts>0, r=rou(r,dgts); end
        a(j,:) = a(j,:) - r*a(i,:);
      end
   end
   if dgts>0, a(:,i:ncol)=rou(a(:,i:ncol),dgts); end
end
y = a(:,ncol)./diag(a); if dgts>0, y=rou(y,dgts); end
if nargout==2,  resid = akeep*y-b; end
