function [u,q,rank,flps,x]=gramsol(a,b)
% [u,q,rank,flps,x]=gramsol(a,b)
% This function solves a system of linear equations a*x=b.
% Use is made of the decomposition a*u=q with q'*q= eye_
% where eye_ is a modified identity matrix which may have
% some zeros on the main diagonal. The solution is based on
% the modified Gram-Schmidt which produces a orthonormal
% basis q for the column space. The rank and the flop count
% are given along with the solution vector for x which is
% given as u*q'*b.
%
%              by H. B. Wilson, Fall 1989
%
flps=flops; [m,n]=size(a); siz=sum(abs(a)); zro=zeros(m,1);
u=eye(n); rank=0; nm=min(n,m); tiny=100*eps;
for i=1:nm, ai=a(:,i); vi=norm(ai);
  if vi>siz(i)*tiny
    rank=rank+1; ai=ai/vi; a(:,i)=ai; u(:,i)=u(:,i)/vi;
    for j=i+1:n
      vj=ai'*a(:,j);
      a(:,j)=a(:,j)-ai*vj;
      u(:,j)=u(:,j)-u(:,i)*vj;
    end
  else
    a(:,i)=zro;
  end
end
q=a;
if nargin==2, x=u*q'*b; end
flps=flops-flps;
