function [dl,dr,alpha,hn]=ratint(z,f,m,factor);
%RATINT  An auxiliary routine called by HSOLVE.
%
%        Written by Peter Kravanja and Marc Van Barel
%                   Dept. Computer Science
%                   Katholieke Universiteit Leuven
%                   Celestijnenlaan 200 A, B-3001 Heverlee, Belgium
%
%                   E-mail: na.pkravanja@na-net.ornl.gov
%                           marc@cs.kuleuven.ac.be
%        (July 10, 1996)

%-----------------------------------------------------------------------
%  status = 1 : both left and right choice are possible
%  status = 2 : only left  choice is possible
%  status = 3 : only right choice is possible
%
%  flow = 1 : the left  column contains the pivot element
%  flow = 2 : the right column contains the pivot element
%-----------------------------------------------------------------------
%
  alpha = max(max([abs(real(f)),abs(imag(f))]));
  f=f/alpha;
%-----------------------------------------------------------------------
  L = ones(m,1); R = -f;
  status = 1;
  coeffDL = zeros(m,1); coeffDR = zeros(m,1);
  coeffDR(1) = 1.;
  degl = 1; degr = 1;
  reps = abs(factor)*eps;
%-----------------------------------------------------------------------
  for i = 1:m,
    if status == 1
      Rh=[real(R(i:m)),imag(R(i:m))];
      [maxpivR,ipivR]=max(max(abs(Rh'))); ipivR = ipivR + i-1;
      Lh=[real(L(i:m)),imag(L(i:m))];
      [maxpivL,ipivL]=max(max(abs(Lh'))); ipivL = ipivL + i-1;
      if (maxpivR < reps) | (maxpivL < reps) 
        status = 1;
        hn = i-1;
        return;
      end;
      if maxpivR > maxpivL
        ipiv = ipivR; flow = 2; status = 2;
      else 
        ipiv = ipivL; flow = 1; status = 3;
      end;
    elseif status == 2
      Lh=[real(L(i:m)),imag(L(i:m))];
      [maxpivL,ipivL]=max(max(abs(Lh'))); ipivL = ipivL + i-1;
      if maxpivL < reps
        status = 2;
        hn = i-1;
        return;
      end;
      ipiv = ipivL; flow = 1; status = 1;
    elseif status == 3
      Rh=[real(R(i:m)),imag(R(i:m))];
      [maxpivR,ipivR]=max(max(abs(Rh'))); ipivR = ipivR + i-1;
      if maxpivR < reps
        status = 3;
        hn = i-1;
        return;
      end;
      ipiv = ipivR; flow = 2; status = 1;
    end; 
%-----------------------------------------------------------------------
    hold = z(i); z(i) = z(ipiv); z(ipiv) = hold;
    hold = L(i); L(i) = L(ipiv); L(ipiv) = hold;
    hold = R(i); R(i) = R(ipiv); R(ipiv) = hold;
%-----------------------------------------------------------------------
    if flow == 1
      mult = -R(i)/L(i);
      R(i+1:m) = R(i+1:m) + mult*L(i+1:m);
      coeffDR(1:degl) = coeffDR(1:degl) + mult*coeffDL(1:degl);
      hh = coeffDL(degl);
      if degl >= 2
        coeffDL(2:degl) = coeffDL(1:degl-1) - z(i)*coeffDL(2:degl);
      end;
      coeffDL(1) = - coeffDL(1)*z(i);
      coeffDL(degl + 1) = hh;
      degl = degl + 1;
      for k = i+1:m,
        L(k) = L(k) * (z(k) - z(i));
      end;
    elseif flow == 2
      mult = -L(i)/R(i);
      L(i+1:m) = L(i+1:m) + mult*R(i+1:m);
      coeffDL(1:degr) = coeffDL(1:degr) + mult*coeffDR(1:degr);
      hh = coeffDR(degr);
      if degr >= 2
        coeffDR(2:degr) = coeffDR(1:degr-1) - z(i)*coeffDR(2:degr);
      end;
      coeffDR(1) = - coeffDR(1)*z(i);
      coeffDR(degr + 1) = hh;
      degr = degr + 1;
      for k = i+1:m,
        R(k) = R(k) * (z(k) - z(i));
      end;
    end;
  end;
  hn = m;  
%-----------------------------------------------------------------------
  dl = conj(fft(conj(coeffDL)));
  dr = conj(fft(conj(coeffDR))); 
  return;
%-----------------------------------------------------------------------
