function sin_theta = spangle(X,Y)
% sin_theta = spangle(X,Y)
% sin_theta = spangle(X,Y,approx)
%
% Computes sine to the subspace angle theta between the
% ranges of the matrices X and Y, whose columns must be
% orthonormal.  If they are not, use spangle(orth(X),orth(Y)).
%
% If nargin = 3, then a cheap approximation is computed.

% Per Christian Hansen, UNI-C, 01/05/91.

[m,nx] = size(X); [m,ny] = size(Y);
if (nx<ny), T = X; X = Y; Y = T; clear T; end
for i=1:nx
  Y = Y - X(:,i)*(X(:,i)'*Y);
end

if (nargin==2)
  sin_theta = norm(Y);
else
  col_norm = zeros(1,ny);
  for i=1:ny, col_norm(i) = norm(Y(:,i)); end
  sin_theta = max(col_norm);
end

if (sin_theta>1), sin_theta = 1; end
