function x = sub_select(A,V,b,k)
% x = sub_select(A,V,b,k)
%
% Computes the subset-selection solution defined
% via the SVD of A.  This solution minimizes
%    min || [ B, 0 ] x - b ||
% where B consists of the k `most linearly independent' columns
% of A as defined via a QR factorization of V, the right singular
% vector in the SVD of A.

% Ref.: G. H. Golub & C. F. Van Loan, "Matrix Computations", 2. Ed.,
% Johns Hopkins, 1989.  Section 12.2.

% Per Christian Hansen, UNI-C, 01/05/91.

[m,n] = size(A);
if (k<1 | k>n), error('illegal k'), end

[Q,R,P] = qr(V(:,k+1:n)');

x = P(:,n:-1:1)*[(A*P(:,n:-1:n-k+1))\b;zeros(n-k,1)];
