function X = tls(A,B,rank)
% X = tls(A,B)
% X = tls(A,B,rank)
%
% Given A, B and rank = rank(A), compute the Total Least Squares
% solution X based on the SVD of the compound matrix [A,B].
%
% If nargin = 2, it is assumed that rank = n.

% Ref.: G. H. Golub & C. F. Van Loan, "Matrix Computations", 2. Ed.,
% Johns Hopkins, 1989.  Subsection 12.3.

% Per Christian Hansen, UNI-C, 01/05/91.

% Initialization.
[m,n] = size(A); [m1,p] = size(B);
if (nargin==2), rank = n; end
if (m1~=m), error('A and B must have the same number of rows'), end
if (m<n-rank+p), error('The system is underdetermined'), end

% Compute the SVD of [A,B].
[U,S,V] = svd([A,B]); V = V(:,rank+1:n+p); clear U S

% Compute the TLS-SVD solution.
X = -((V(n+1:n+p,:)')\(V(1:n,:)'))';
