function x = tqr(Q,R,Pi,b,rank)
% x = tqr(Q,R,Pi,b,rank)
%
% Compute the truncated QR solution.  If the RRQR of A is
%    A*Pi = Q*R = Q [ R_11 R_12 ] ,
%                   [  0   R_22 ]
% where R_11 is rank-by-rank, then the TQR solution is
%    x = Pi*pinv([ R_11 R_12 ])*Q'*b .
%               ([  0    0   ])

% Ref.: G. H. Golub & C. F. Van Loan, "Matrix Computations", 2. Ed.,
% Johns Hopkins, 1989.  Subsection 5.5.2.

% Per Christian Hansen, UNI-C, 02/26/90.

[P,RR] = qr(R(1:rank,:)'); P = P(:,1:rank); RR = RR(1:rank,:);
x = Pi*P*(RR'\(Q(:,1:rank)'*b));
