function x = tsvd_rrqr(Q,R,Pi,W,b)
% x = tsvd_rrqr(Q,R,Pi,W,b)
%
% Computes the truncated SVD solution to
%    min || A*x - b ||
% without computing the SVD, using instead the RRQR factorization.

% This algorithm is described in: T. F. Chan & P. C. Hansen,
% "Computing truncated SVD least squares solutions by rank revealing
% QR factorizations", SISSC 11 (1990), 519-530.

% Per Christian Hansen, UNI-C, 01/05/1991.

[n,n] = size(R); [n,nu] = size(W);
if (nu == 0), x = Pi*(R\(Q'*b)); return, end

% Compute bases for the left and right null-spaces of R.
[U0,V0] = spit(R,Pi'*W);

% Compute the truncated SVD solution by means of deflation.
x = Pi*(eye(n) - V0*V0')*(R\(eye(n) - U0*U0')*Q'*b);
