function b = beta(x)
% b = beta(x)
% plots a log log plot of the periodogram of a time series x
% of length N and determines its slope b (beta).  N/2-1 frequencies
% are plotted. 2 values of slope are determined by simple regression:
% b(1) uses all the plotted data, b(2) truncates the first 16, and
% the last N/32 frequencies.
help beta
N = length(x)
mx = mean(x)
Y = fft(x - mx)/N;
Pyy = Y .* conj(Y);       % power
lP = log(Pyy(2:N/2)); % skip first (zero) value,
                                          %     take logs of first
half
lf = log(1: N/2 - 1)'; % make log frequency scale
plot(lf, lP), xlabel('log frequency'), ylabel('log power');
hold on;
Nmin = 16;
Nmax = floor(15*N/32);
p1 = polyfit(lf, lP, 1);
p2 = polyfit(lf(Nmin:Nmax), lP(Nmin:Nmax),1);
b(1) = p1(1);
b(2) = p2(1);
s1 = num2str(b(1));
s2 = num2str(b(2));
ss = ['Slope estimates are:  ' s1 ' and ' s2];
f1 = polyval(p1, lf);
f2 = polyval(p2, lf(Nmin:Nmax));
plot(lf, f1, 'g', lf(Nmin:Nmax), f2, 'r'), title(ss)

