function Y = divider2(x)
% Y = divider2(x)
% Plots the total length of a time series x_i, as a function of the
% spacing ni between the values.  x is a vector of length N, so
% i = 1,2,...N. The spacing is allowed to increase from 1,2,4,..2^(n-1)
% where 2^n < N/2.  Y has n cols, each of which is the total
% length for a spacing ni, obtained by traversing 2^(n-1) points.
% There are also m rows, each corresponding to starting the
% measurement at 1,2,...m  In this version m = 20.  The plot
% shows m points for each value of the spacing, and the regression
% line based upon all the data except the largest spacing
% Written by Gerry Middleton (middleto@mcmaster.ca) Jan. 1996
% Press <space> to start
help divider2;
pause;
N = length(x)
N2 = N/2;
n = floor(log2(N2))
m = 20;
for j = 1:m
   for i = 1:n
      ni = 2^(i-1);                           % (i.e., 1,2,4,...)
      nn(i) = ni;                                 % store for plot as
row vector
      xi = x(j+ni:ni:j-1+N2+ni);  % x lagged by ni and j,
                                                          %     at
intervals of n
i
      Y(i,j) = sum(abs(x(j:ni:j-1+N2) - xi));
      end
   end
lnn = log2(nn)';                              % log2 of n as column
vector
lY = log2(Y);                                     % log2 of Y matrix
for j = 1:m
    plot(lnn, lY(:,j), 'o');
        hold on;
        end
lYv = reshape(lY(1:n-1,:),m*(n-1),1);    % remove nth value and reshape
lnv = reshape(lnn(1:n-1)*ones(1,m),m*(n-1),1);
p = polyfit(lnv,lYv,1)                    % linear regression
f = polyval(p,lnv(1:n-1));
s = num2str(p(1));
ss = ['Slope = ' s];
plot(lnv(1:n-1),f);
ylabel('log2(total length)'), xlabel('log2(interval)')
title(ss);

