function y = mpdwalk(yb,yf,n,H)
% y = mpdwalk(yb,yf,n,H)
% returns a vector y consisting of steps in a fractional random
% walk from y = yb to y = yf.  The number of steps is 2^n, i.e.,
% n is the number of times the line is divided into midpoints.
% H is the Hurst coefficient: H = 0.5 for Brownian walks
% 0.5 < H < 1 implies long-range correlation (persistence)
% 0 < H < 0.5 implies antipersistence.  Press space-bar to start.
% Written by Gerry Middleton, December 1995, using the mid-point
% displacement algorithm.
help mpdwalk;
pause;
y = zeros(2^n +1,1);
for i = n:-1:1
        xl = 1;                    % start at left
        dx = 2^(i-1);      % increment to mid-pt
        jlim = 2^(n-i);    % jlim = 1,2,4,8,...
        for j = 1:jlim
                xr = xl + 2*dx;   % xright
                xm = xl + dx;     % xmid
                y(xm) = 0.5*y(xl) + 0.5*y(xr) + randn*dx^H;      % ymid
                xl = xr;           % new xl is old xr
                end     % for j
        end     % for i
plot(y)

