function [f,alpha]=falpha(x,trace);
% [f, alpha] = falpha(x, trace)
% Estimates multi-fractal f(alpha) curve of a set of points x;
% produces a piecewise linear curve, the pieces depending upon q.
% v0.10  01/7/94, copyright AJ Roberts, aroberts@usq.edu.au
% Made publically available under the GNU arrangements.
%
% x(j,:) = coordinates of the jth point of a set
% trace  = optional argument: set to 1 if you want trace prints and graphics,
%          otherwise omit or set to 0
%
% The values for q may be changed to give better resolution
q=(-10:1:10);
nalpha=40; 
%
if nargin<2, trace=0; end
dq=fdim(q,x,1);     % change 0 to trace, if display is required (slow!) 
if trace, plot(q,dq,'g*'); 
   title('interpolated Dq curve');
   xlabel('q'), ylabel('Dq'); 
   hold on;
   end;
while length(q)<nalpha,
   q=hint(q);
   dq=hint(dq);
   end;
if trace,
   disp(sprintf('\a\a\a\a\a\a\a\a\a\a\a\a\a\a\')); 
   plot(q,dq); 
   hold off;
   print -dwin;   % comment out if this graph is not to be printed
   pause; 
   end;
tau=(1-q).*dq;
alpha=-diff(tau)./diff(q);
amin=min(alpha);
amax=max(alpha);
alpha=amin+(0:nalpha)*(amax-amin)/nalpha;
f=min( tau'*ones(size(alpha))+q'*alpha );
alpha=alpha(f>-0.1);
f=f(f>-0.1);
if trace, 
   plot(alpha,f); 
   axis([0 ceil(max(alpha)) 0 ceil(max(f))]);
   title('Multi-fractal  f(alpha) curve'); 
   xlabel('alpha'), ylabel('f(alpha)');
end;
end;

