function y = mwfract(H,n)
% y = mwfract(H,n)
% Generates a fractal time-series by the Mandelbrot-Weierstrass
% method: see H.M. Hastings and G. Sugihara, 1993, Fractals: a
% User's Guide for the Natural Sciences. OUP.
% H is the Hurst coefficient, the number of data generated are
% N = 2^n, e.g., n = 10 yields a time series of length 1024
% MATLAB version written by Gerry Middleton, December 1995
% It differs from the Hastings/Sugihara algorithm by imposing
% symmetry (antisymmetry) on magnitudes (phases).
% Press <space> to continue
help mwfract;
pause;
N = 2^n;
m = N/2;
Hp = H + 0.5;
k = 0:N-1;
r = randn(m,1);   % vector of normally distributed random nos
lni = log(1:m);   % row vector of nat logs
lni = lni';               % convert to col
mag1 = r .* exp(-Hp*lni);  % vector of magnitudes
mag1 = abs(mag1);                  % convert to absolute values
mag2 = mag1(m:-1:1);       % reverse order
mag = [0; mag1; mag2(2:m)]; % symmetrical vector of magnitudes
phi1 = 2*pi*(rand(1,m) - 0.5);  % vector of phases
phi2 = -phi1(m:-1:1);      % reverse order and sign
phi = [0 phi1 phi2(2:m)]'; % antisymmetric vector of phases
figure;
subplot(211);
stem(k, mag), title('magnitudes');
subplot(212);
stem(k, phi), title('phases');
pause;
S = mag .* exp(i*phi);   % constructed Fourier transform
Pyy = S .* conj(S);              % make powers
figure;
stem(k(1:m), 2*Pyy(1:m)), title('periodogram');
pause;
figure;
loglog(k(1:m),2*Pyy(1:m)), title('log-log plot of periodogram');
pause;
y = ifft(S);
figure;
s = num2str(H,4);
ss = ['Random walk, H = ' s];
plot(k, real(y)), title(ss);


