function s = poxplot(x)
% s = poxplot(x)
% prepares a 'pox plot' of the time series x
% first converts x from walk to noise y by differencing
% then reshapes vector y into a matrix with seg columns
% where seg = 1, 2, 4,...(m-2), N <= M = 2^m
% and dy rows where dy = M, M/2, M/4,...M/(m-2).
% For each column one determines S, the standard deviation
% and (after taking the cumulative sum) R, the range. Finally,
% the values of log(R/S) are plotted against log(dy).
% The slope is determined by linear regression, using two
% methods (i) regression on all data, (ii) regression on
% segment means.
% Written by Gerry Middleton (middleto@mcmaster.ca), Jan. 1996,
% after a FORTRAN program by Roy Plotnick.
% Press <space> to continue after each pause.
help poxplot.m
pause;
N = length(x)
m = floor(log2(N-1))
NN = 2^m
segmax = m-2;
x1 = x(2:NN+1);
y = x(1:NN) - x1;
plot(y), title('Noise derived from input walk');
pause;
s = std(y);                                     % computation for whole
series
xmax = max(x(1:NN));
xmin = min(x(1:NN));
r = xmax-xmin;
dy(1) = log2(NN);
RS(1) = log2(r/s);
mdy(1) = dy(1);
mRS(1) = RS(1);
for i = 1:segmax
   nseg = 2^i;                             % number of segments 2,4,..

   lseg = NN/nseg;                         % length of each
   Y = reshape(y, lseg, nseg);
   S = std(Y);                             % vector of SDs
   X = cumsum(Y);
   Xmax = max(X);
   Xmin = min(X);
   R = Xmax-Xmin;                          % vector of ranges
   RSi = log2(R./S);                       % log ratios
   mRS(i+1) = mean(RSi);                     % mean
   RS = [RS; RSi'];                        % add to RS
   dyi = ones(nseg,1)*lseg;        % vector of segment lengths
   dyi = log2(dyi);                        % convert to logs
   mdy(i+1) = log2(lseg);
   dy = [dy; dyi];                         % add to dy
   end
plot(dy, RS, 'o'), xlabel('log2 segment length');
ylabel('log2 R/S');
hold on;
p = polyfit(dy,RS,1);
s1 = num2str(p(1));
fit = polyval(p, dy);
plot(dy, fit, 'r');
pm = polyfit(mdy, mRS,1);
s2 = num2str(pm(1));
fit2 = polyval(pm, mdy);
ss = ['Slopes are: (i) ' s1 ' (ii) ' s2];
plot(mdy, mRS, 'g*', mdy, fit2, 'g'), title(ss);

