function P=defbox(vertex1,vertex2,typ); 
% Generates an axis aligned box in GBT polytope format. 
% Usage : 
%         P=defbox(Vertex1,Vertex2,typ)  
% 
%         creates box P, where Vertex1, Vertex2 are two opposite corners  
%         of the box.  
% 
%  GBT, S Hermsmeyer, 1993 
 
if (nargin==2), form='type4'; ,end; 
 
% CHECK DIMENSIONS AND ENSURE COLUMN FORMAT 
[vert1r,vert1c]=size(vertex1); 
[vert2r,vert2c]=size(vertex2); 
vertl=length(vertex1); 
if ((vert1r~=1 & vert1c~=1) | vertl~=length(vertex2)), 
   disp('Require compatible vertices.'); 
   break; 
end; 
 
if (vertl==1), 
  P=[2 2; 1 max(vertex1,vertex2); -1 -min(vertex1,vertex2)]; 
  return; 
end 
 
if (vert1r==1), vertex1=vertex1'; ,end; 
if (vert2r==1), vertex2=vertex2'; ,end; 
 
% BUILD HYPERPLANE MATRIX 

R=[eye(vertl),-min([vertex1';vertex2'])']; 
R=[R;-eye(vertl),max([vertex1';vertex2'])']; 
 
% BUILD MATRIX OF THE BOXES' VERTICES  

S=[vertex1(vertl-1)*[1 1];vertex1(vertl),vertex2(vertl)]; 
B=[0 0;0 1]; 
for i=2:vertl-1, 
   [br,bc]=size(S); 
   hS=vertex1(vertl-i)*ones(1,2*bc); 
   hB=zeros(1,2*bc); 
   S=[hS;S,[vertex2(vertl-i+1)*ones(1,bc);S(2:br,:)]]; 
   B=[hB;B,[ones(1,bc);B(2:br,:)]]; 
end; 
S=[[S,(vertex1+vertex2)*ones(1,2^(vertl-1))-S];ones(1,2^vertl)]; 
B=[B,~B]*vertl+(1:vertl)'*ones(1,2^vertl); 
 
% BUILD THE RESULTING POLYTOPE 
if (strcmp(form,'type4')), 
  P=[[2,2*vertl,2^vertl,zeros(1,vertl-2)];R;S';[B',zeros(2^vertl,1)]]; 
elseif (strcmp(form,'type2')), 
  P=[[3,2*vertl,2^vertl,zeros(1,vertl-2)];R;S']; 
else disp('Incorrect input. Format must be "type2" or "type4" .'); 

end; 

return; 
end;
