function S=defsimp(d,a,c,typ);
%  Defines a regular simplex in polytope format of GBT
%  Usage:
%           S = defsimp(d,a,c,typ)
%
%  d = dimension of the simplex
%  a = length of edges (one dimensional faces), all equal 
%      (=1 if not given) 
%  c = centre of symmetry of the simplex (=origin if not given)
%  typ = 'type4' if polyhedron format is required
%
% GBT, S M Veres, 1993

% Input checks
if (nargin<2), a=1; end;
if (nargin<3), c=zeros(1,d); end;
if (nargin<4), typ='';end;
if (d==1), S=[4,2;c-0.5*a,1;c+0.5*a,1];return;end;
[cr,cc]=size(c);if (cr>1),c=c';end;

% Generation of vertices
v=zeros(d+1,d);
v(1,1)=-0.5*a;v(2,1)=0.5*a;
a0=a;

for i=2:d,
  hlp1=mean(v(1:i,:));
  r=hlp1-v(1,:);ra=r*r';
  v(i+1,:)=[hlp1(1:i-1) sqrt(a0*a0-ra) zeros(1,d-i)];
  hlp=v(i,:)-v(i-1,:);
  a0=sqrt(hlp*hlp');
end;

% centering to the origin  
v0=v-ones(d+1,1)*mean(v); 

% Creating the hyperplane list  h
H=[];
for i=1:d+1,
  if (i==1),j=2; else j=i-1;end;
  H=[H; -v0(i,1:d), -v0(i,1:d)*v0(j,1:d)']; 
  h(i,:)=sum([v0(1:i-1,:);v0(i+1:d+1,:)]);
end;

% Creating vertex-hyperplane adjacency list
p=zeros(d+1,d);
for i=1:d+1,
  p(i,:)=[(1:i-1),(i+1:d+1)];
end;

% Defining the polytope GBT-form of the simplex
% centering to  c

v0=v0+ones(d+1,1)*c;
S  =[2 d+1 d+1 zeros(1,d-2);
         H              ;
        v0  ones(d+1,1);
         p  zeros(d+1,1) ];

if (typ=='type4'), S=convp_ph(S); end;

return;
end;
