function P=polybnd(R0,P0)
%         Recursive  polytope updating and intersecting polytopes.
%  Usage:
%          P=polybnd(R,P0), P=polybnd(R,THMIN) 
%
%          intersects the initial polytope P0 with the half spaces given in 
%          R, where R=[A,b] represents the inequality (Ax<=b); if no P0 is 
%          given, vector THMIN specifies a lower bound for the intersection 
%          of halfspaces.
%
%          P=polybnd(R) takes the elements of THMIN to be 1e-6.
%
%          P=polybnd(P1,P0) calculates the intersection of two polytopes.
%
%  Check at "http://sun1.bham.ac.uk/veressm/gbt.html " for new routines.
%
%  GBT, S Hermsmeyer, 1993 
 
% Checking the record format
[recr,recc]=size(R0);

if (recc<=2),
  P=intupd(R0,P0);return;
end;

p0r=0; p0c=0;
typr=(R0(1,1)==2 | R0(1,1)==4);
typr=(typr & (R0(1,2)+2*R0(1,3)+1==recr));

% Two input arguments *************************************
if (nargin==2),   
   [p0r,p0c]=size(P0);   
   typp=((P0(1,1)==2| P0(1,1)==4) & p0r>1 & p0c>1);
   typp=(typp & (P0(1,2)+2*P0(1,3)+1==p0r));

% First argument: polytope ********************************
  if typr, 
     if ~typp, 
	disp('P1 is a polytope, P0 must be as well.');
	break;
     else
	if ~(bounded(R0)),
	disp('Initial polytope into "polybnd.m" must be bounded.');break;,end;
	if (R0(1,1)==4), R0=convph_p(R0);end;
	if ~(bounded(P0)),
	disp('Initial polytope into "polybnd.m" must be bounded.');,break;,end;
	if (P0(1,1)==4), P0=convph_p(P0);end;
   
	d=recc-1;

% Extracting vertices and hyperplanes
	S0=[R0(R0(1,2)+2:R0(1,2)+1+R0(1,3),1:d)';ones(1,R0(1,3))];
	S=[-P0(P0(1,2)+2:P0(1,2)+1+P0(1,3),1:d)';ones(1,P0(1,3))];
	[sr,sc]=size(S);
	R=P0(2:P0(1,2)+1,:);
	ind=P0(P0(1,2)+P0(1,3)+2:p0r,1:d); 

% Finding minimal values for coordinate transformation
	thmin=min(S0(1:d,:)');
	thmin_P0=min(-S(1:d,:)');
	thmin=min([thmin_P0;thmin]);

% Transforming polytope 2
	S(1:d,:)=S(1:d,:)-thmin'*ones(1,sc);
	R(:,p0c)=R(:,p0c)+R(:,1:p0c-1)*thmin';
    
% Interpreting polytope 1 as a collection of hyperplanes
       ar=R0(1,2);
       A0=-R0(2:ar+1,1:recc-1);
       A=[A0,[R0(2:ar+1,recc)+A0*thmin']];
     end;

% First argument: Data set **************************************
   else
    d=recc-1;

% Second argument: THMIN ****************************************
    if (p0r==1 | p0c==1),
       if (p0r==1), thmin=P0;
       else thmin=P0'; ,end;
       P0=[];
       S=eye(d+1);
       R=eye(d+1);


% Second argument: Polytope *************************************
    else
	if ~typp, disp('Require polytope P0'); ,break; ,end;
	if ~(bounded(P0)),
	disp('Initial polytope into "polybnd.m" must be bounded.');break;,end;
	if (P0(1,1)==4), P0=convph_p(P0);end;
	if (p0c-1~=d), disp('P0 and R are of different dimension.'); ,break; ,end;
	
	S=[-P0(P0(1,2)+2:P0(1,2)+1+P0(1,3),1:d)';ones(1,P0(1,3))];
	[sr,sc]=size(S);
	R=P0(2:P0(1,2)+1,:);
	thmin=min(-S(1:d,:)');
	thmin=min([thmin;zeros(1,d)]);
	S(1:d,:)=S(1:d,:)-thmin'*ones(1,sc);
	R(:,p0c)=R(:,p0c)+R(:,1:p0c-1)*thmin';
	ind=P0(P0(1,2)+P0(1,3)+2:p0r,1:d);
    end;
   end;
 else
   d=recc-1;
   thmin=-1e6*ones(1,d);
   P0=[];
   S=eye(d+1);
   R=eye(d+1);
 end;

% Extracting matrix of homogeneous system
 if ~typr,   
    A0=R0(1:recr,1:recc-1);
    A=[A0,[R0(1:recr,recc)+A0*thmin']];
    ar=recr;
 end;


% Computing auxiliary matrix matrix B 
 if (exist('ind')==1),
    hlp=ones(P0(1,2),sc);
    B=hlp;
    ind=(ind+(0:sc-1)'*P0(1,2)*ones(1,d))';
    hlp(ind)=zeros(d*sc,1);
    B(:)=hlp;
 else
    B=(R*S>1e-12*ones(size(R*S)));
 end;
 Bprev=B;
 feas=[];

% Main loop over all rows (hyperplanes) of the homogeneous equation system
for k=1:ar,
     update=1;
     B12=[];
     alpha=A(k,:)*S;
     [br,bc]=size(B);
% HLP1 =0, IF alpha(i)>=0, =1 ELSE
     hlp1=(alpha>zeros(size(alpha)));

% Sb HOLDS ALL VERTICES ON THE FEASIBLE SIDE OF THE HYPERPLANE
     Sb=S(:,hlp1);
     
% IF NO VERTEX ON THE FEASIBLE SIDE => HYPERPLANE INTERPRETED AS OUTLIER
% ELSE POLYTOPE UPDATE ONLY NECESSARY, IF SOME VERTICES NOT ON FEASIBLE SIDE
     if (sum(hlp1)==0), P=[];return;
     elseif (sum(hlp1)<length(hlp1)),
	B11=B(:,hlp1);
       
	for i=1:bc,
	     for j=i+1:bc,
		if (alpha(i)*alpha(j)<0),
% CHECK ALL COMBINATIONS i,j OF VERTEX PAIRS ON DIFFERENT SIDES OF HYPERPLANE
%
% BOOLEAN VECTOR hlp3(k)=1 IF COLS. B(:,i),B(:,j) ARE BOTH ZERO, =0 ELSE
		    hlp3=((~B(:,i)) & (~B(:,j)));
		    nz=sum(hlp3);
% hlp4 IS A MATRIX WITH ROWS ACCORDING TO hlp3(k)=1; hlp4(.,.)=1 IF B(.,.)=0,
%   =0 ELSE
		    hlp4=(~B(hlp3,:));
% (sum(hlp4))(k)=nz FOR ALL COLS WITH ONLY ZEROS AS ELEMENTS (i,j AND MAYBE                     
%   SOME MORE)
% VERTICES ADJACENCY TEST. NECESSARY: nz>=d-1
%                          SUFFICIENT: NO OTHER COL r THAN i,j OF hlp4 HOLDS
%                                      ONLY ZERO ELEMENTS (=> SUM=2)
		    
		    [hlp4r,hlp4c]=size(hlp4);
		    if (hlp4r==1), hlp4=[zeros(size(hlp4));hlp4]; ,end;
		    if ((sum(sum(hlp4)==nz*ones(1,bc))==2) & (nz>=d-1)),
			 B12=[B12,~hlp3];
% CALCULATE A NEW VERTEX AND UPDATE AUXILIARY MATRIX Sb
			 s_new=abs(alpha(i))*S(:,j)+abs(alpha(j))*S(:,i);
			 if (s_new(d+1)~=0.0)
			     Sb=[Sb,s_new/s_new(d+1)];
			 else
			     Sb=[Sb,s_new];
			 end;
		    end;
		end;
	     end;
	end;
% UPDATE BOOLEAN MATRIX B. hlp5(.,.)=1 WHERE B(.,.)=0, =0 ELSE
	hlp5=(B==zeros(size(B)));
% hlp6(k,i)=1 WHERE BOTH B(k,i)=0 AND alpha(i)<=0, =0 ELSE
	hlp6=(hlp5 & ones(br,1)*(alpha<=zeros(size(alpha))));
% hlp7(k)=1 WHERE ALL B(k,i)=0 ARE ASSOCIATED TO alpha(i)<=0 (i.e. THE 
% NEC. AND SUFF. CRITERION FOR DELETING ROW k OF B AND R), =0 ELSE
	hlp7=(sum(hlp6')==sum(hlp5'));
% hlp8 IS BASIS FOR THE UPDATED BOOLEAN MATRIX B
	hlp8=[B11,B12];
% DELETING ROWS IN B AND R
	B=hlp8(~hlp7,:);
	R=R(~hlp7,:);
% ADDING ROWS TO B AND R
	[b12r,b12c]=size(B12);
	B=[B;(alpha(hlp1)>zeros(1,sum(hlp1))),zeros(1,b12c)];
	R=[R;A(k,:)];
% ASSIGNING THE NEW VERTEX MATRIX S
	S=Sb;
     end;
 end;

% Creating output polytope
 [rr,rc]=size(R);
 [sr,sc]=size(S);
% B=(R*S>1e-19*ones(size(R*S)));
 S(1:sr-1,:)=S(1:sr-1,:)+thmin'*ones(1,sc);
 b=R(:,rc)-R(:,1:rc-1)*thmin';
 B1=~B;  
 if (sum(abs((sum(B1)-d*ones(1,sc))))>0),
    disp('Program error. Some vertex defined by more than d planes.');
    update=0;
 end;
 if (update),
 [d1,sc]=size(B1);
 ind=zeros(d,sc);hlp=(1:d1)'*ones(1,sc);
 for i=1:sc, 
 ind(:,i)=hlp(B1(:,i),i);
 end;
 end;
 S=[-S(1:rc-1,:);ones(1,sc)];
 P=[2,rr,sc,zeros(1,rc-3);[R(:,1:rc-1),b];S';[ind',zeros(sc,1)]];
else P=P;end;
end; 

% if (feas~=[]),  disp('*** Outlier ***');  disp(feas); ,end;

return;
end;
