function P=polyhedr(R0,P0);
%  Calculates intersection of a set of halfspaces with a polyhedron
%  Usage:
%
%       P =  polyhedr(R0,P0)
%
%       R0 =   [A b] to represent inequalities Ax <= b
%               A  is (n x m) matrix, b is (n x 1) column vector
%       P0 =   old polyhedron (the whole space if not defined)
%       P  =   polyhedron obtained
%
%  GBT,  S M Veres, 1993

%  *** Checking input variables
if (nargin<1), 
  disp(' Requires input matrix R=[A,b] to represent Axb.');
  P=[];return;
end;
[r,c]=size(R0);
if (c<=2),
  if (nargin<2),P=intupd(R0);else P=intupd(R0,P0);end;return;
end;
if (r<1), 
  disp('No empty input-matrix allowed in "polyhedr".');
  P=[];return;
end;  
if (c<2), 
  disp('Input matrix is too small into "polyhedr"');
  P=[];return;else d=c-1;
end;

% *** Defining initial polytope as the whole space if there 
%     is no input polytope 
if (nargin<2), P=[4 0 zeros(1,d-1)];else P=P0;end; 
  if (P(1,1)<4),
    P=convp_ph(P);
  end;

%  ****** Large loop starts for updating with a row of R0 
for t=1:r,

% Testing for zero vector:
  if (sum(abs(R0(t,1:d)))<1.0e-10),
    if (R0(t,d+1)<1.0e-12), P=[];return;end;   
  else 
    R0(t,1:d)=R0(t,1:d)+rand(1,d)*1.0e-8;
  end;

%  *** Check if number of hyperplanes is low 
  if (P(1,2)<d-1),
    P=[P;R0(t,:)];;P(1,2)=P(1,2)+1;

%  *** Check when the first vertex appears:
  elseif(P(1,2)==d-1),
     P=[P;R0(t,:)];P(1,2)=P(1,2)+1;
    A=P(2:d+1,1:d);vertex=inv(A)*P(2:d+1,d+1);
    P=[P;vertex' 1;(1:d) 0;zeros(1,d) 0];
    P(1,3)=1;P(1,2)=d;

% *** When both hyperplanes and vertices exists:
  elseif(P(1,2)>d-1),

% Checking whether P is a polytope
  if bounded(P), 
     R1=R0(t:r,:); P=convph_p(P);
     P=polybnd(R1,P); P=convp_ph(P);return;
  end;

%  *** Checking vertices for belonging to new pol.: indic, ray is produced
  nv=P(1,3);nh=P(1,2);
  H=P(2:nh+1,:);
  V=P(2+nh:1+nh+nv,1:d);
  VH=P(2+nh+nv:1+nh+2*nv,1:d);
  VV=P(2+nh+2*nv:1+nh+3*nv,1:d);

% *** Definition of inner, outer vertices and those with infinite rays
  in=(R0(t,:)*[V';-ones(1,nv)]<zeros(1,nv));
  out=~in;
  noin=sum(in);
  ray=(sum((VV'<0.1*ones(d,nv)))>zeros(1,nv));
  nr=sum(ray);

% ** Initialization of new vertex tables
  NEWV=V;NEWVH=VH;NEWVV=VV;

% Producing arrays of new vertices obtained by intersection with finite edge
  VI=VV(in',1:d);
  VHin=VH(in',1:d);
  Vind=(1:nv);Vind=Vind(in');
  nvi=nv;

  for i=1:noin,
    vired=VI(i,(VI(i,1:d)>0));
    Vd=V(vired,:);
    mask=out(vired);
    VC=Vd(mask',:);
    [rvc,cvc]=size(VC);
    if (rvc>0),
      hlp=[-VC ones(rvc,1)];
      hlp1=(ones(rvc,1)*V(Vind(i),1:d)-VC)*R0(t,1:d)';
      lam=(hlp*R0(t,:)')./hlp1;
      VC=lam*V(Vind(i),1:d)+((ones(rvc,1)-lam)*ones(1,d)).*VC;  
      NEWV=[ NEWV ; VC ];
      Vhc=VH(vired,:);
      VHc=inter(Vhc(mask',:),VHin(i,:));
      VHc=[VHc(:,1:d-1) ones(rvc,1)*(nh+1)];
      NEWVH=[NEWVH ; VHc];
      NEWVV=[NEWVV ; [(nvi+1:nvi+rvc)' zeros(rvc,d-1)] ]; 
      nvi=nvi+rvc;
    end;
  end;

%  Producing arrays for new vertices obtained by intersecting with 
%  infinite rays

  if (nr>0),
    VHr=VH(ray',:);VVr=VV(ray',:);
    indx=(1:d);indr=(1:nv)';
    for i=1:nr,
% the adjacent vertices:
      VVr(i,:);
      vmask=(VVr(i,:)>zeros(1,d));
      vrred=VVr(i,vmask);
      [nvr,nvc]=size(vrred);
% the hyperplanes of adjacent vertices:
      VHred=VH(vrred',:);
% running through all adjacent hyperplanes:
    for j=1:d,
% Checking which of the vertices are opposite 
      hyperpl=VHr(i,j);
      inh=inter(VHred,[VHr(i,j)]);
      oppos=~(sum(inh')>zeros(1,nvr));
      if (sum(oppos)>0),
        opp(i,j)=1; 
      else
        opp(i,j)=0;
        HM=VHr(i,~(VHr(i,:)==ones(1,d)*VHr(i,j)));
        HH=H(HM',:);
        XA=[HH(:,1:d);R0(t,1:d)];
        xb=[HH(:,d+1);R0(t,d+1)];
        if (rank(XA)>=d),cross=XA\xb;end;

        if (H(VHr(i,j),:)*[cross' -1]'<0),
          nvi=nvi+1;
          NEWV=[NEWV;cross'];
          NEWVH=[NEWVH;[HM nh+1]];
          NEWVV=[NEWVV;[ nvi zeros(1,d-1)] ]; 
        end;
      end;
    end;
  end;
  end;

% *** Producing new vertex-vertex lists for new vertices
  in1=[in,ones(1,nvi-nv)];newnv=sum(in1);
%  if (newnv<1), R1 =[ R0(t,:); R0(1:t-1,:)];P=polyhedr(R1);end;
  NEWV=NEWV(in1',:);NEWVH=NEWVH(in1',:);NEWVV=NEWVV(in1',:);
  Vind=(1:nvi);Vind=Vind(in1');
  for i=1:newnv,
    build=[];   
    for j=1:newnv,
      if ~(i==j),
         if (sum((inter(NEWVH(i,:),NEWVH(j,:))>0))==d-1),
           build=[build Vind(j)];
         end;
      end;
    end;
    [br,bc]=size(build);
    if (bc<d),build=[build (nvi+1)*ones(1,d-bc)];end;
    build=build(1:d);
    NEWVV(i,:)=build;
  end;

% ***  Reindexing of vertices in vertex tables
  for i=1:nvi, 
    newind(i)=sum(in1(1:i));
  end;
  newind(nvi+1)=0;
  for i=1:newnv, 
    for j=1:d, 
      NEWVV(i,j)=newind(NEWVV(i,j));
    end;
  end;

% *** Reducing the number of hyperplanes and the vertex-hyperplane list
  mask0=zeros(1,nh+1);
  for i=1:newnv,
    mask=zeros(1,nh+1);
    for j=1:d, mask(NEWVH(i,j))=1;end;
    mask0=mask0+mask;
  end;
  mask0=(mask0>0);
  for i=1:nh+1, newhind(i)=sum(mask0(1:i));end;
  for i=1:newnv,
    for j=1:d,
      NEWVH(i,j)=newhind(NEWVH(i,j));
    end;
  end;
  newnh=sum(mask0);
  H=[H;R0(t,:)];
  NEWH=H(mask0',:);

%  ***  Building the new polytope
  if (d<3),d2=2-d;d1=3-d;end;
  if (3<=d),d2=0;d1=1;end;
    P=[4  newnh newnv zeros(1,d-2);
       NEWH  zeros(newnh,d2);   
       NEWV  ones(newnv,d1);
       NEWVH zeros(newnv,d1);
       NEWVV zeros(newnv,d1)];
% *** Case of existing vertices ends here
  end;
% if the number of hyperplanes d
end;
% *** Main loop of updating ends here
end;
end;

return;
end;
