function [XE,YE,XP,YP,AXES]=viewgbt(EOP,a,col,hld)
% VIEWGBT plots the orthogonal projection of geometric bodies.
% Usage: 
%       [XE,YE,XP,YP,AXOUT]=VIEWGBT(EP,A,COLOUR,HLD); 
%
%       projects a list of ellipsoids and polytopes EP=[EP1;EP2;...], 
%       where vector A defines the two or three spanning vectors of 
%       the projection. 
%       COLOUR  specifies the plot colour/pattern and HLD 'on' holds the 
%       current plot. In case of three projections it must be HLD=AXIN, with
%       AXIN the scaling of the plots. XE,YE are the coordinate pairs of the 
%       ellipsoids and XP,YP of the polytopes. AXOUT provides the axis 
%       scalings of the plots. 
%
%       VIEWGBT(EP,A); plots the projections with MATLAB default colours
%       and clears the current plot. 
%
%  Check at "http://sun1.bham.ac.uk/veressm/gbt.html " for new routines.
% 
%  GBT, S Hermsmeyer, 1993


[nd,d]=size(EOP);d=d-1;
if (d<=1), disp('Dimension of objects must be at least 2 in "viewgbt.m".');
break;end;
al=length(a);
axin=[0,0];

if (EOP(1,1)==6),  % case of regular (non-simple)polytope 
  if (nargin<3), hld='off';end; 
  if strcmp(hld,'on'), hd=1; else hd=0;end;  
% if (nargin>3), edges=viewreg(EOP,a,hd,col); else edges=viewreg(EOP,a,hd);end;
  return;
end;


% SORTING OUT THE FUNCTION ARGUMENTS colour AND hld
setupcol=0;
if (nargin<3), hld='off'; ,col='grbwgrbwgrbw'; 
   pat=setstr(ones(12,1)*'-');
elseif (nargin<4),
   if (isstr(col)==0), hld='on'; axin=col;
      hld=col; ,col='grbwgrbwgrbw'; ,pat=setstr(ones(12,1)*'-');
   elseif (strcmp(col,'on')==1 | strcmp(col,'off')==1),
      hld=col; ,col='grbwgrbwgrbw'; ,pat=setstr(ones(12,1)*'-');
   else
      hld='off'; setupcol=1;
   end;
else setupcol=1;
   if (isstr(hld)==0), axin=hld; ,hld='on';  end;
end;

if (al==3 & strcmp(hld,'on') & size(axin)~=[1,4]),
  disp(' Incorrect input argument HLD.') 
  disp(' Holding a three-projection screen requires HLD to be a')
  disp(' matrix containing the axis scaling of the plots.')
  break;
elseif (al==2 & strcmp(hld,'on') & size(axin)~=[1,4]),
  axin=axis 
  pause
  axis;
end;

% SETTING UP COLOURS AND PATTERNS
if setupcol,
  if (col(1)=='-'),    % no explicit colour 
    pat=setstr(ones(12,1)*col(1:min([length(col),2])));
    col='grbwgrbwgrbw';
  elseif (length(col)==1),
    if (col(1)=='g'|col(1)=='r'|col(1)=='b'|col(1)=='w'|col(1)=='i'),
      col=setstr(ones(12,1)*col(1));
      pat=['-',setstr(0);'--';'-.']; 
      pat=[pat;pat;pat;pat];
    else
      disp('specified colour/pattern is not a valid option.');
      break;
    end;
  elseif (col(2)=='-'),  % explicit col and pattern
    pat=setstr(ones(12,1)*col(2:min([length(col),3])));
    if (col(1)=='g'|col(1)=='r'|col(1)=='b'|col(1)=='w'|col(1)=='i'),
      col=setstr(ones(12,1)*col(1));
    else
      disp('specified colour/pattern is not a valid option.');
      break;
    end;

  else   % no explicit pattern
    tst=(col==setstr('g'*ones(1,length(col))));
    tst=tst+(col==setstr('r'*ones(1,length(col))));
    tst=tst+(col==setstr('b'*ones(1,length(col))));
    tst=tst+(col==setstr('w'*ones(1,length(col))));
    tst=tst+(col==setstr('i'*ones(1,length(col))));
    if (sum(tst~=ones(1,length(col)))>0),
      disp('specified colour/pattern is not a valid option.');
      break;
    else
      col=[col,'grbwgrbwgrbwgrbwgrbwgrbwgrbwgrbwgrbwgrbwgrbwgrbw'];
      pat=setstr(ones(48,1)*'-');
    end;
  end;  
end;

% CHECKING THE PROJECTION VECTOR a (ASSUMPTION: DIMENSION < 10)
if (al<2 | al>3), disp('Length of a must be 2 or 3.'); ,break; ,end;
if (min(a)<1 | max(a)>d | max(a)>9),
   disp('a inconsistent with dimension of EOP');
   break;
end;

% MISCELLANEOUS INITIAL VARIABLES
labelnum='123456789';
labeltxt='Theta_';
if (al==2), acomb=[a(1) a(2)]; ,ar=1; 
else acomb=[a(1) a(2);a(3) a(2);a(1) a(3)]; ,ar=3; 
end;
phi=[cos(0:pi/540:2*pi);sin(0:pi/540:2*pi)];
XE=[]; YE=[];
XP=[]; YP=[];
e_count=0;
p_count=0;
o_count=0; ecol=[]; pcol=[];
eop_count=1;

% SIZE OF THE OBJECTMATRIX EOP, DIMENSION OF THE OBJECTS
[eopr,eopc]=size(EOP);
%d=eopc-1;

% MAIN LOOP OVER ALL OBJECTS IN EOP
while (eop_count<eopr),
   typ=EOP(eop_count,1);

% CHECKING THE OBJECT TYPE: ELLIPSOID
   if (typ==1),
      er=eopc; ec=er;
      E=EOP(eop_count:eop_count+er-1,:);

      thM=E(2:er,ec);
      Minv=inv(E(2:er,1:ec-1));
      [mr,mc]=size(Minv);

      for k=1:ar,
	if (mr<3),
	   M=Minv;
	else
	   ax=(1:mr);
	   ax(acomb(k,:))=[];
	   M11=Minv(acomb(k,:),acomb(k,:));
	   M12=Minv(acomb(k,:),ax);
	   M22=Minv(ax,ax);
	   M=M11-M12*inv(M22)*M12';
	end;
        
        [Qmm,Lmm]=eig(M);Lmm2=1./sqrt(diag(Lmm));
	hlp=Qmm*diag(Lmm2)*phi;
	[lenn,len]=size(hlp);
	
	XE=[XE,thM(acomb(k,1))*ones(len,1)+hlp(1,:)'];
	YE=[YE,thM(acomb(k,2))*ones(len,1)+hlp(2,:)'];
      end;
      e_count=e_count+1; o_count=o_count+1; ecol=[ecol,o_count];
      eop_count=eop_count+er;

% CHECKING THE OBJECT TYPE: POLYTOPE
   elseif (typ==2 | typ==4),
     if (typ==2),
       pr=EOP(eop_count,2)+2*EOP(eop_count,3)+1;
       pr2=pr-EOP(eop_count,3); 
     else
       pr=EOP(eop_count,2)+3*EOP(eop_count,3)+1;
       pr2=pr-2*EOP(eop_count,3); 
     end;
     pr1=pr2+EOP(eop_count,3);
     P=EOP(eop_count:eop_count+pr-1,:);
     rr=P(1,2);
     sc=P(1,3);
     R=P(2:rr+1,:);
     S=[P(rr+2:pr2,1:d)';ones(1,sc)];
     if (typ>1),
	ind=P(pr2+1:pr1,1:d);
	ind=ind+(0:sc-1)'*rr*ones(1,d);
	hlp=ones(rr,sc);
	B=hlp;
	hlp(ind)=zeros(d*sc,1);
	B(:)=hlp;
     else
	B=R*S;
	B=(abs(B)>1e-9*ones(size(B)));
     end;
     x=[];y=[];z=[];xr=0;
     if (p_count==0), xpr=0; ,xpc=0; ,end;

% ADJACENCY TEST: CHECK EVERY PAIR OF VERTICES (Si,Sj)
     for i=1:sc,
 
      hlp1=((~B(:,i))*ones(1,sc-i) & (~B(:,i+1:sc)));
      nz=sum(hlp1);

      for j=i+1:sc,
	hlp2=(~B(hlp1(:,j-i)',:));
	[hlp2r,hlp2c]=size(hlp2);
	if (hlp2r==1), hlp2=[zeros(size(hlp2));hlp2]; ,end;
		
%        if (sum(hlp1(:,j-i))>1),
	    if ((sum(sum(hlp2)==nz(j-i)*ones(1,sc))==2) & nz(j-i)>=d-1),
	       xnew=[S(a(1),i),S(a(1),j)];
	       ynew=[S(a(2),i),S(a(2),j)];
	       if (al==2),
		  if (sum(sum(([x y]==ones(xr,1)*[xnew,ynew])')==4*ones(1,xr))==0)
		     x=[x;xnew];
		     y=[y;ynew];
		     [xr,xc]=size(x);
		  end;
	       else
		  znew=[S(a(3),i),S(a(3),j)];
		  if (sum(sum(([x,y,z]==ones(xr,1)*[xnew,ynew,znew])')==6*ones(1,xr))==0)
		     x=[x;xnew];
		     y=[y;ynew];
		     z=[z;znew];
		     [xr,xc]=size(x);
		  end;
	       end;
	    end;
%        end;
      end;
     end;
     if (al==2), 
	XP=[XP,x(1)*ones(xpr,-min(xpc(p_count+1)-xr,0));x',x(1)*ones(2,max(xpc(p_count+1)-xr,0))]; 
	YP=[YP,y(1)*ones(xpr,-min(xpc(p_count+1)-xr,0));y',y(1)*ones(2,max(xpc(p_count+1)-xr,0))]; 
     else 
	XP=[XP,x(1)*ones(xpr,-min(xpc(p_count+1)-xr,0));[x';z';x'],x(1)*ones(6,max(xpc(p_count+1)-xr,0))]; 
	YP=[YP,y(1)*ones(xpr,-min(xpc(p_count+1)-xr,0));[y';y';z'],y(1)*ones(6,max(xpc(p_count+1)-xr,0))]; 
     end;
     p_count=p_count+1; o_count=o_count+1; pcol=[pcol,o_count];
     [xpr,xpc(p_count+1)]=size(XP);
     eop_count=eop_count+pr;

% CHECKING THE OBJECT TYPE: NO MATCH
   else
      disp('VIEWGBT requires ellipsoid or polytope of type 2 or type 4.'); ,break; ,end;
   end;

% END OF THE  WHILE-LOOP => ALL OBJECTS PROCESSED
end;
if (p_count>0), xpc(1)=[]; ,end;
col=[col(ecol),col(pcol)];
pat=[pat(ecol,:);pat(pcol,:)];

% PLOT OBJECTS: 1.PROJECTION INTO ONE PLANE
if (al==2),
   if (strcmp(hld,'off')), hold off; ,clg;
     subplot(111);
   else
     hold on; 
   end;

% SCALING THE PLOTS
%   if (e_count+p_count>1),
      if (e_count==0),
	 xmax=max(max(XP)); xmin=min(min(XP)); ymax=max(max(YP));
	 ymin=min(min(YP));
      elseif (p_count==0),
	 xmax=max(max(XE)); xmin=min(min(XE)); ymax=max(max(YE));
	 ymin=min(min(YE));
      else
	 xmax=max([max(XE),max(XP)]); xmin=min([min(XE),min(XP)]);
	 ymax=max([max(YE),max(YP)]); ymin=min([min(YE),min(YP)]);
      end;
      if (strcmp(hld,'off')),
	hlpb=[xmin,-xmax,ymin,-ymax];
	hlp=[xmin,xmax,ymin,ymax];
	plot(xmin,ymin,'i');
	axis(hlp*diag(1.02-(hlpb>zeros(1,4))*0.04));
	hold on; axis(axis);        
      end;
%   end;

   for i=1:e_count,
      plot(XE(:,i),YE(:,i),[col(i),pat(i,:)]);
   end;
   for i=1:p_count,
      j=i+e_count;
      plot(XP(2*i-1:2*i,1:xpc(i)),YP(2*i-1:2*i,1:xpc(i)),[col(j),pat(j,:)]);
   end;
   xlabel([labeltxt,labelnum(a(1))]);
   ylabel([labeltxt,labelnum(a(2))]);
   AXES=axis;

else
% PLOT OBJECTS: 1.PROJECTION INTO ONE PLANE
   if (strcmp(hld,'off')), hold off; ,clg;
      e_ind=[]; p_ind=[];
      for k=1:e_count,
	 e_ind=[e_ind,[1 0 0]];
      end;
      for k=1:p_count,
	 p_ind=[p_ind,[1 1 0 0 0 0]];
      end;
      subplot(221);
%      if (e_count+p_count>1),
	 if (e_count==0),
	    xmax=max(max(XP(p_ind,:))); xmin=min(min(XP(p_ind,:))); 
	    ymax=max(max(YP(p_ind,:))); ymin=min(min(YP(p_ind,:)));
	 elseif (p_count==0),
	    xmax=max(max(XE(:,e_ind))); xmin=min(min(XE(:,e_ind))); 
	    ymax=max(max(YE(:,e_ind))); ymin=min(min(YE(:,e_ind)));
	 else
	    xmax=max([max(XE(:,e_ind)),max(XP(p_ind,:))]); 
	    xmin=min([min(XE(:,e_ind)),min(XP(p_ind,:))]);
	    ymax=max([max(YE(:,e_ind)),max(YP(p_ind,:))]); 
	    ymin=min([min(YE(:,e_ind)),min(YP(p_ind,:))]);
	 end;
	 if (strcmp(hld,'off')),
	   hlpb=[xmin,-xmax,ymin,-ymax];
	   hlp=[xmin,xmax,ymin,ymax];
	   plot(xmin,ymin,'i');
	   axis(hlp*diag(1.02-(hlpb>zeros(1,4))*0.04));
	   hold on; axis(axis);
	 end;
%      end;
   else subplot(221); 
   hold on; ,axis(axin(1,:));
   axis(axis);
   end;

   for i=1:e_count,
      plot(XE(:,3*i-2),YE(:,3*i-2),[col(i),pat(i,:)]);
   end;
   for i=1:p_count,
      j=i+e_count;
      plot(XP(6*i-5:6*i-4,1:xpc(i)),YP(6*i-5:6*i-4,1:xpc(i)),[col(j),pat(j,:)]);
   end;
   xlabel([labeltxt,labelnum(a(1))]);
   ylabel([labeltxt,labelnum(a(2))]);
   AXES=axis;

   subplot(222);
   if (strcmp(hld,'off')),
      hold off;
% SCALING THE PLOTS
      if (e_count>0), e_ind(1:2)=[]; ,e_ind=[e_ind,1,0]; ,end;
      if (p_count>0), p_ind(1:4)=[]; ,p_ind=[p_ind,1,1,0,0]; ,end;

%      if (e_count+p_count>1),
	 if (e_count==0),
	    xmax=max(max(XP(p_ind,:))); xmin=min(min(XP(p_ind,:))); 
	    ymax=max(max(YP(p_ind,:))); ymin=min(min(YP(p_ind,:)));
	 elseif (p_count==0),
	    xmax=max(max(XE(:,e_ind))); xmin=min(min(XE(:,e_ind))); 
	    ymax=max(max(YE(:,e_ind))); ymin=min(min(YE(:,e_ind)));
	 else
	    xmax=max([max(XE(:,e_ind)),max(XP(p_ind,:))]); 
	    xmin=min([min(XE(:,e_ind)),min(XP(p_ind,:))]);
	    ymax=max([max(YE(:,e_ind)),max(YP(p_ind,:))]); 
	    ymin=min([min(YE(:,e_ind)),min(YP(p_ind,:))]);
	 end;
	 if (strcmp(hld,'off')),
	   hlpb=[xmin,-xmax,ymin,-ymax];
	   hlp=[xmin,xmax,ymin,ymax];
	   plot(xmin,ymin,'i');
	   axis(hlp*diag(1.02-(hlpb>zeros(1,4))*0.04));
	   hold on; axis(axis);
	  end;
%      end;
   else subplot(222); axis(axin(2,:)); hold on; axis(axis);
   end;
   for i=1:e_count,
      plot(XE(:,3*i-1),YE(:,3*i-1),[col(i),pat(i,:)]);
   end;
   for i=1:p_count,
      j=i+e_count;
      plot(XP(6*i-3:6*i-2,1:xpc(i)),YP(6*i-3:6*i-2,1:xpc(i)),[col(j),pat(j,:)]);
   end;
   xlabel([labeltxt,labelnum(a(3))]);
   ylabel([labeltxt,labelnum(a(2))]);
   AXES=[AXES;axis];

   subplot(223);
   if (strcmp(hld,'off')),
      hold off;
% SCALING THE PLOTS
      if (e_count>0), e_ind(1:2)=[]; ,e_ind=[e_ind,0,1]; ,end;
      if (p_count>0), p_ind(1:4)=[]; ,p_ind=[p_ind,0,0,1,1]; ,end;

%      if (e_count+p_count>1),
	 if (e_count==0),
	    xmax=max(max(XP(p_ind,:))); xmin=min(min(XP(p_ind,:))); 
	    ymax=max(max(YP(p_ind,:))); ymin=min(min(YP(p_ind,:)));
	 elseif (p_count==0),
	    xmax=max(max(XE(:,e_ind))); xmin=min(min(XE(:,e_ind))); 
	    ymax=max(max(YE(:,e_ind))); ymin=min(min(YE(:,e_ind)));
	 else
	    xmax=max([max(XE(:,e_ind)),max(XP(p_ind,:))]); 
	    xmin=min([min(XE(:,e_ind)),min(XP(p_ind,:))]);
	    ymax=max([max(YE(:,e_ind)),max(YP(p_ind,:))]); 
	    ymin=min([min(YE(:,e_ind)),min(YP(p_ind,:))]);
	 end;
	 if (strcmp(hld,'off')),
	   hlpb=[xmin,-xmax,ymin,-ymax];
	   hlp=[xmin,xmax,ymin,ymax];
           plot(xmin,ymin,'i');
	   axis(hlp*diag(1.02-(hlpb>zeros(1,4))*0.04));
	 hold on; axis(axis); 
	 end;
%      end;
   else subplot(223); axis(axin(3,:)); hold on; axis(axis);
   end;
   for i=1:e_count,
      plot(XE(:,3*i),YE(:,3*i),[col(i),pat(i,:)]);
   end;
   for i=1:p_count,
      j=i+e_count;
      plot(XP(6*i-1:6*i,1:xpc(i)),YP(6*i-1:6*i,1:xpc(i)),[col(j),pat(j,:)]);
   end;
   xlabel([labeltxt,labelnum(a(1))]);
   ylabel([labeltxt,labelnum(a(3))]);
   AXES=[AXES;axis];

end;
hold off;
return;
end;
