function s=signsum(u,v);
%SIGNSUM first computes the sign of each summand for the
%        inner product of two vectors, u and v, subject
%        to the rules that 0*(anything) = 0 and that 
%        NaN*(nonzero) = NaN.  Then the sum of the products
%        is computed.  If all nonzero summands have the 
%        same sign, then that sign is returned.  If all
%        summands are zero, then s = 0.  If alternating
%        signs occur, or if a summand is NaN, then NaN is
%        returned. 

%        Jeff Stuart, USM Math Department, April 1996.
%        jeffrey_stuart@bull.cc.usm.edu
          
if size(u)~=size(v), u=u'; end
su=signs(u);
sv=signs(v);
zeroindu=(u==0);
zeroindv=(v==0);
su(zeroindv)=zeros(sum(zeroindv),1);
sv(zeroindu)=zeros(sum(zeroindu),1);
t=su.*sv;
if sum(isnan(t))>0,
   s = NaN;
elseif (sum(t>0))>0 & (sum(t<0))>0,
   s = NaN;
else s = sign(sum(t));
end
 
   
end
  