function A = randpdef(n,flag);
%RANDPDEF generates a random n x n positive definite matrix.
%
%RANDPDEF generates a random n x n symmetric, positive definite real
%         matrix with integer eigenvalues uniformly distributed in
%         the open interval (0,n^2).  When any second input argument
%         is specified, the matrix generated is complex positive
%         definite with real eigenvalues in the open interval (0,n^2).
%
%June 1994, Jeff Stuart, Univ. of Southern Mississippi
%           jeffrey_stuart@bull.cc.usm.edu

%Real, Positive Definite Matrix Generator
if  nargin ==1,
	if n == 2
	   t = rand;
	   s = sin(2*pi*t);
	   c = cos(2*pi*t);
	   Q = [c s; -s c];
	   D = diag(round(0.5 + (n^2)*rand(n,1)));
	   A= Q*D*Q';
	end
 
	if n >= 3
	   Q = zeros(n,n);
	   while rank(Q) < n
	      [Q,R]=qr(rand(n,n));
	   end
	   D = diag(round(0.5 + (n^2)*rand(n,1)));
	   A= Q*D*Q';
	end
end

%Complex, Positive Definite Matrix Generator 
if nargin ==2
	   Q = zeros(n,n);
	   while rank(Q) < n
	      [Q,R]=qr(rand(n,n)+sqrt(-1)*rand(n,n));
	   end
	   D = diag( (n^2)*rand(n,1));
	   A= Q*D*Q';
end
