%JACOB0	Compute manipulator Jacobian in world coordinates
%
%	JACOB0(DH, Q) returns a Jacobian matrix for the current pose Q.
%
% 	The manipulator Jacobian matrix maps differential changes in joint space
%	to differential Cartesian motion (world coord frame) of the end-effector.
%			dX = J dQ
%
%	For an n-axis manipulator the Jacobian is a 6 x n matrix.
%
%	See also JACOBN, DIFF2TR, TR2DIFF, DIFF

%	Copyright (C) Peter Corke 1993
function J = jacob0(dh, q)
	%
	%   dX_tn = Jn dq
	%
	Jn = jacobn(dh, q);	% Jacobian from joint to world space
	tn = fkine(dh, q);
	%
	%   dX_tn = Jtn dX
	%   dX = Jtn^-1 dX_tn
	%
	Jtn = tr2jac(tn);	% Jacobian from world to Tn frame

	%
	%  dX = Jtn^-1 Jn dq
	%
	J = inv(Jtn) * Jn;
