%TRINTERP	Interpolate homogeneous transformations
%
%	T = TRINTERP(T0, T1, R)
%	T = TRINTERP(DP, R)
%
%	Returns a homogeneous transform interpolation between T0 and T1 as
%	R varies from 0 to 1.
%
%	The second form uses a drive parameter matrix computed by DRIVEPAR
%	which represents the `difference' between T0 and T1 and may
%	be more efficient for computing many points between the same 
%	two endpoints.
%
%	See also CTRAJ, DRIVEPAR.

%	Copyright (C) 1993 Peter Corke
function t = trinterp(a1, a2, a3)
	t = zeros(4,4);

	if nargin == 3,
		dp = drivepar(a1, a2);
		r = a3;
	else
		dp = a1;
		r = a2;
	end
	srp = sin(dp(4)*r);
	crp = cos(dp(4)*r);
	srt = sin(dp(5)*r);
	crt = cos(dp(5)*r);
	vrt = 1 - crt;
	sp = sin(dp(6));
	cp = cos(dp(6));

	t(1,2) = -srp*(sp^2*vrt+crt)+crp*(-sp*cp*vrt);
	t(2,2) = -srp*(-sp*cp*vrt)+crp*(cp^2*vrt+crt);
	t(3,2) = -srp*(-cp*srt)+crp*(-sp*srt);

	t(1,3) = cp*srt;
	t(2,3) = sp*srt;
	t(3,3) = crt;

	t(1:3,1) = cross(t(1:3,2), t(1:3,3));

	t(:,4) = [dp(1:3)*r 1]';
