function [i,j,k,v] = find3d(x,siz)
%FIND3D	Return position of non-zero elements in 3-D matrix.
%	FIND3D(X,[M N P]) returns the element position of the
%	non-zero elements of the M-by-N-by-P matrix A.
%
%	[I,J,K] = FIND3D(X,[M,N,P]) returns the row, column
%	and depth indices of the nonzero entries in the matrix X.
%
%	[I,J,K,V] = FIND3D(X,[M N P]) also returns a column vector
%	of the nonzero entries in X.  Note that find3d(X,[M N P])
%	and find3d(X~=0,[M N P]) will produce the same I, J, and K,
%	but the latter will produce a V with all 1's.

%	Clay M. Thompson 11-5-92
%	Copyright (c) 1992 by The MathWorks, Inc.
%	$Revision: 1.5 $  $Date: 1993/07/01 19:24:38 $

if nargout<=1,
  i = find(x);

else
  [r,k,v] = find(x);
  j = floor((r-1)/siz(1)) + 1;
  i = r - (j-1)*siz(1);
end
