function chaparab(xrang,x0,r,niter)
% chaparab(xrang,x0,r,niter).
% This example illustrates results of attempts to find a root
% of the equation x=r*x(1-x) by successive substitutions. The
% parabola is plotted between limits xrang(1) to xrang(2).
% The iteration begins with a value x0 and a series of niter
% values are computed and plotted in the formula
%                 xn1=r*xn*(1-xn)
% When r is larger than about 3.6, iteration fails to converge
% and xn simply oscillates chaotically. Suggested test values
% are chaparab( [0,1],3.8,50).
%       by Howard Wilson, U. of Alabama, Fall 1989
x1=max(0,xrang(1)); x2=min(1,xrang(2));
x=x1:(x2-x1)/200:x2;
y=r*x.*(1-x); hold off; clg;
plot(x,y,[x1,x2],[x1,x2]); hold on;
if x0<0, x0=eps; end
if x0>1, x0=1-eps; end
xn=x0; for i=1:niter, xn1=r*xn*(1-xn);
plot([xn,xn1,xn1],[xn1,xn1,r*xn1*(1-xn1)]); xn=xn1; end
rs=num2str(r);
title(['ITERATIVE SOLUTION OF X = R * X * (1-X) FOR R = ',rs])
hold off;
meta chaparab.met
