function v = COMPLEMENT(a,b)
%
% COMPLEMENT produces a row vector containing the elements of the
% universal set b not belonging to the intersection of sets a and b.
% a and b are each sets of numbers represented as row vectors. The
% output, the ``complementary'' set c, is also represented 
% as a row vector
% 
%    Sets a and b may be any size and may have repeated elements.
%    Repeated elements in the complement set are removed. 
%    By definition, elements in set a not in b are ignored.
%    Requires the functions INTERSEC.m and UNION.m also available 
%         from the MATLAB CONTRIB collection.
%    (If function INTERSEC not available, then comment out this call -- 
%         in this case, elements of set a not in the universal set b 
%         will appear in the complement).
% -----------------------------------------
% EXAMPLE: a=[1 2 3 4 5], b=[4 5 6 7 8];
%  c=complement(a,b) --> c=[6 7 8]
% comment: since the elements {1,2,3} in set a do not belong to the 
% "universal set" b, the elements {1,2,3} are by default ignored
% -----------------------------------------
%
% Uses: Set Complement
% Author: Jay I. Simon
%         MIT Lincoln Laboratory
%         Lexington, MA
%         (jsimon@ll.mit.edu)    
% Nov 28, 1995
 
if nargin<=1
  v = [];
elseif nargin==2
  a=a(:).';b=b(:).';
  c=intersec(a,b); 
  v = sort([union(c) union(b)]);
  n=length(v);
  x1=[(v(2:n)-v(1:n-1)) 0];
  ix=find(x1==0); ix=ix(1:length(ix)-1);
  x1(ix+1)=zeros(size(ix));
  x2=[0 (v(1:n-1)-v(2:n))];
  ix=find(x2==0); ix=ix(2:length(ix));
  x2(ix-1)=zeros(size(ix));
  x=x1 | x2;
  v=v(x);
end


