function isp = isprime(p)
%ISPRIME  ISPRIME(X) returns 1s where the elements of X are prime and
%         0s where they are not.  The working definition of a prime number
%         is a positive integer which has no factor other than itself and one.

% written by:   Douglas M. Schwarz
%               Eastman Kodak Company
%               schwarz@kodak.com

% Initialize some variables
[n,m] = size(p);
isp = zeros(n,m);
max_p = max(max(p));
maxtest = floor(sqrt(max_p));

% Generate list of all primes from 2 to maxtest.  Use fact that multiples of
% prime numbers are not prime numbers.
maxindex = floor((maxtest-1)/2);
flags = ones(1,maxindex);
primes = 3;                 % Initialize list of primes with first odd prime.

i = 1;
next_prime = primes(i);
while  next_prime <= sqrt(maxtest)
  index = ((3*next_prime - 1)/2):next_prime:maxindex;
  flags(index) = zeros(1,length(index));
  primes = 2*find(flags) + 1;
  i = i + 1;
  next_prime = primes(i);
end
primes = [2 primes];        % Add 2 to the list


% Now, use this list of primes in the following tests:
for i = 1:(n*m)
  if  any(p(i) == primes)          % Is p(i) in the previously generated list?
    isp(i) = 1;
  elseif  p(i) == 1                % Is p(i) == 1?
    isp(i) = 1;
  elseif  p(i) <= 0                % Is p(i) positive?
    isp(i) = 0;
  elseif  p(i) - floor(p(i)) ~= 0  % Is p(i) an integer?
    isp(i) = 0;
  else
    b = p(i)./primes;              % See if p(i) is divided evenly by any prime
    isp(i) = ~any(b == floor(b));  % number between 2 and square root of max
                                   % possible value of p(i).
  end
end


