function isp = isprime(p)
%ISPRIME True for prime numbers.
%	ISPRIME(P) returns 1s for the prime elements in matrix P and
%	0s for the others.

%	Loren Shure & Mark Reichelt, 6-29-93.

% first find the likely candidates for being a prime
kpcan = find((p > 1) & (fix(p) == p) & ~imag(p));
possp = p(kpcan);
possp = possp(:)';
isp = zeros(size(p));
% set isp to ones for the elements that are prime candidates
isp(kpcan) = ones(size(kpcan));

% only need to check numbers up to sqrt(largest_valid_p)
maxprime = floor(sqrt(max(max(possp))));

% if max(possp) is 2 or 3 (which are prime) we're done
% otherwise we need to do some more checking
if maxprime > 1
% find possible divisors
   divs = (2:maxprime)';
% cull out only the prime ones of these
   divs = divs(find(isprime(divs)));
% build up possp and divs matrices to get ready for rem
% have possp's run across the rows and divs run down columns
   possp = possp(ones(1,length(divs)),:);
   divs = divs(:,ones(1,length(kpcan)));
% find any divisors that are bigger than sqrt(possp) and replace with
% a number that cannot divide it evenly
% we want to avoid the case in which p=2:4, maxprime is 2
% and 2 divides 2 evenly so would show up as not being prime
   kdivs = find(divs > floor(sqrt(possp)));
   divs(kdivs) = possp(kdivs)+1;
% get the matrix of results
   results = rem(possp,divs);
   if min(size(results)) > 1
% if any element in a given column is 0, the corresponding number
% must be composite - find it's index
      checkp = find(any(results == 0));
   elseif length(kpcan) == 1
% if there's only one possp, then results is a column vector
% check it for and zeros.  If no zeros, then the possp is prime
% and we don't want to do anything else
      checkp = any(results == 0);
      if checkp == 0
          checkp = [];
      end
   else
% if there is only one possible prime (i.e., 2) we have a single
% row of results and we want to look at each of these separately for
% each possp
      checkp = find(results == 0);
   end
% set the composite elements in isp back to zero
   isp(kpcan(checkp)) = zeros(size(checkp));
end
