function Y=isprime(X)
%ISPRIME  --  ISPRIME(X) returns 1's where the elements of X are prime 
%                        and 0's where they are not. 
%
% Routine uses the Encyclopedia Britannica (1967) definition of Prime
% Numbers:  "A positive integer (whole number) greater than 1 that cannot
% be expressed as the product of two positive integers neither of which 
% is 1."  

% Keith Jobe,  SLAC - The Stanford Linear Accelerator Center
% internet:    rkj@SLAC.Stanford.EDU

% this is a negative logic routine, where values are disqualified
% on a case by case basis.  The values remaining at the end of 
% the testing, are considered prime.

%- pre-allocate memory:

  [m,n] = size(X);
  Y = ones(m,n);

%- handle the few special cases where the number is known to not be
%- prime.

  not_prime = find(X <= 1 | rem(X,1) ~= 0 | imag(X) ~= 0);
  Y(not_prime) = zeros(1,length(not_prime));

%- bound the search at the square root of the largest member:

  largest_divisor = floor(sqrt(max(max(X(find(Y))))));

%- create a list of primes up the 'largest_divisor', working the hard
%- way to make a list of primes.  This extra work pays off later when
%- testing the elements of the input data, especially if the largest
%- element is >> 1000 or the input data set is large.

  primes = 2;
  for i=3:2:largest_divisor
    if all(rem(i,primes))
      primes = [primes i];
    end
  end

%- Search stratagy:  Look only at elements still considered canidate
%- primes.  This list starts long, and shortens to approximately
%- [1 .5 .3 .3 .2 ...] if input data size, thus significantly reducing %- the search lengths.
%
%- as usual -- zero out elements as hits are found.

  for test=1:length(primes)
    canidates = find(Y & (X >= primes(test)*primes(test)));
    hit = find( ~rem(X(canidates), primes(test)) );
    Y(canidates(hit)) = zeros(1,length(hit));
  end

