        function isp = isprime(p)

%       Usage   : isp = isprime(p)
%       Purpose : test which elements osf an integer matrix are primes
%       Input   : p = an integer matrix 
%       Output  : isp(i,j)=1 if p(i,j) is a prime, =0 elsewhere
%       Method  : the sieve of Eratosthenes

%       Author  : Osmo Kaleva; e-mail: kaleva@butler.cc.tut.fi
%       Address : Tampere University of Tecnology
%                 Department of Mathematics
%                 P.O.Box 692, SF-33101 Tampere, Finland
 
        [mp,np] = size(p); maxp = max(max(p));
        if maxp < 2 isp = zeros(p); return, end

%       generate all primes from 2 to maxp by the sieve of Eratosthenes

        primes = [2:maxp]'; 
        for i = 1:floor(sqrt(maxp))
          if primes(i) > 0
             primes(2*i+1:i+1:maxp-1) = zeros(1,floor((maxp-1-i)/(i+1)));
          end
        end
        primes(primes == 0) = [];

%       form isp rowwise

        for i = 1:mp
          rowp = p(i,:); aprim = primes(primes <= max(rowp));
          if max(size(aprim)) == 0
             isp(i,:) = zeros(1,np);
          else
             isp(i,:) = any(~(rowp(ones(length(aprim),1),:) - ...
                              aprim(:,ones(1,np))));
          end
        end

