  function isp = isprime(p)
% isp = isprime(p): test elements of p for primality, return Boolean matrix
%                   *REQUIRES rabin.m*
% p = matrix of integers, isp is Boolean matrix with same shape as p.
%
% if n = p(i,j), ispn = isp(i,j), then:
%                ispn == 0 means that n is definitely not prime.
%                ispn == 1 means that n is prime _if_ n < 94,906,265,
%                          otherwise it merely means n has no factors < 100.
%
% Methods used: as n increases: prime list, dividing by prime list, Rabin test.
% Extensions (ran out of time) - add multiple precision version of Rabin,
%     add Lucas test. Reference in rabin.m conjectures this would be true test.
% Assumptions: maxint assumed to be 2^53 (as in IEEE arithmetic)
% R.A. Fowell, 6/30/93, fowell@netcom.com

  c1   = [ 2 3 5 7 11 13 17 19 23 29 31 37 41 43 47 53 59 ]';
  c2   = [ 61 67 71 73 79 83 89 97]';
  c    = [c1 ; c2];
  cmax2 = (101)^2;     % smallest composite w/o factor in c
  clen = length(c);
  cmax = c(clen);
  rlim = 94906265; % sqrt(2^53)

  isp = rem(p,2) == 1;    % eliminate nonintegers, nonpositive integers,
%                         % integers > maxint (they are all even, anyway)
  isp = isp | (p == 2);   % add "2"s back.
%
  largei = find(isp == 1 & p > cmax); 
%
  for i = 2:clen,
      if length(largei) == 0, break, end
      comp = rem(p(largei),c(i)) == 0;
      if max(comp) > 0,
              tmp = largei(comp);
              isp(tmp) = 0*tmp;
              if min(comp) > 0,
                   largei = [];
              else
                   largei = largei(~comp);
              end
       end
  end
%
% for integers up to sqrt(maxint), use Rabin test.
% sqrt(2^53) = 94,906,265
  rabini = find((isp == 1) & (p >= cmax2) & (p < rlim));
  lr = length(rabini); 
%
  for i = 1:lr,
      j = rabini(i);
      n = p(j);
      flag = 0;
      if rabin(n,2) == 1,
          if rabin(n,3) == 1,
              if rabin(n,5) == 1,
                  if n ~= 25326001,
                       flag = 1;
                  end
              end
          end
      end
      isp(j) = flag;
  end
%
% Replace elements of c:
%
  smalli = find(isp == 1 & p <= cmax); % indices that need to be tested.
  if length(smalli) == 0,
     return;
  end
  small  = p(smalli);
%
  psmall = 0*small;
  for i= 1:clen,
      psmall = psmall | ( small == c(i));
  end
%
  isp(smalli) = psmall;

