function isp = isprime(p);

%  isprime(p) returns 1s for the prime elements in the matrix p
%  zeros otherwise
%
%  Inputs -
%
%	p - an array of positive integers.  
%
%  Outputs -
%
%	isp - an array the same size as p, with 1's in the positions
%	      where p's elements are prime.
%
%
%
%  Method - compute remainder of p(i,j) after division by primes from 2 
%           thru sqrt(p(i,j)) , stopping the first time the remainder is zero.
%	    Do this in a vectorized fashion.
%
%  Ram Shenoy, Schlumberger-Doll Research

if any(any((floor(p) ~= p)))
	error('entries must be integers')
end
if any(any(p<1))
	error('entries must be positive')
end

[m n]=size(p);
isp=ones(m,n);				% isp(i,j) is 1 if p(i,j) is 
					% still not known to be composite
					% 0 otherwise

r= floor(sqrt(p));			% maximum possible divisors
max_r = max(max(r));

divisors=[1:max_r];			% candidates for divisors of p

index = [ 0; ones(max_r-1,1)];		% index is 0 if divisors(index) is a
					% prime that has been tested on p
					% or if it is a multiple of a prime
					% that has been tested on p
					% 1 otherwise

y=divisors(min(find(index>0)));		% y is the current lowest prime to test

v=find(y < r);				% only need to test if y < sqrt(p(i,j))
while ((v ~= []) & (y ~= []))	

	v = find((isp ~=0) & (y < r));	% find elements still not known to
					% be composite and for which y <
					% maximum possible divisor

	isp(v) = rem(p(v), y ) & isp(v);% check if y is a divisor, update isp

	index(y:y:max_r)=zeros(length(y:y:max_r),1); % eliminate y and its 
	y=divisors(min(find(index>0)));		     % multiples		
	
end

