function q = isprime(p)
%ISPRIME Find the prime elements of a matrix.
%       ISPRIME(P) finds the prime elements of the matrix P. All elements of
%       P must be integers greater or equal 0. ISPRIME then returns 1s for 
%       the prime elements in matrix P and 0s otherwise. 
%       0 and 1 are not prime numbers.

%       Author: Th. Ernst 6-30-93, ernst@isi.ee.ethz.ch
%       Signal Processing Laboratory (ISI), ETH Zuerich (Switzerland)

% Find the maximum element of p
sqrtpmax = floor(sqrt(max(max(p))));

% Generate the vector of integers from 1:sqrtpmax
pvec = 1:sqrtpmax;

% In pvec set those elements to 0 which are not a prime number
for i=2:length(pvec),
  if pvec(i)~=0,
    pvec(2*pvec(i):pvec(i):length(pvec)) = ...
      zeros(1,length(2*pvec(i):pvec(i):length(pvec)));
  end;
end;

% Set the 0-elements of pvec to sqrtpmax to avoid NaN in later divisions
pvec(find(pvec==0)) = sqrtpmax*ones(1,sum(pvec==0));

% Test each element of p for primality
for m=1:size(p,1),
  for n=1:size(p,2),
    remvec = rem(p(m,n),pvec(2:sqrt(p(m,n))));
    q(m,n) = (prod(remvec)~=0);
  end;
end;

% 0 and 1 are not prime numbers
q(find(p<2)) = zeros(1,length(find(p<2)));


