function [order]=getorder(x)
%GETORDER Finding order in an integer matrix
%         GETORDER(x) returns a matrix containing  the
%         numerical  order  of  the   elements  in the
%         integer matrix x, provided that the elements
%         of x fall in the range 1..KMAX
%
%         Input :-
%      
%            x - An arbitrary M x N matrix of integers
%                subjected to the restriction that all
%                its elements are in the range 1..KMAX
%
%         Output :-
%  
%            order - An  M x N matrix of integers such
%                that   order(i,j)  is  the  numerical 
%                order  of  x(i,j) within the elements
%                of x
%
%         Submitted by :-
%
%            Keerthi Angammana
%            Department of Civil Engineering
%            Stanford University, CA94305
%
%         You may send my T-shirt(s) to :-
%
%            P.O Box 8649
%            Stanford, CA 94309
%
%         Please  note that I will NOT accept a mouse 
%         pad or a mug under ANY circumstances.
%----------------------------------------------------
 
%
% The  largest  integer  that  can  be  in x
%
 
  KMAX=255;
 
%
% Find the places where the sequence 1..KMAX
% is  broken by the data. Here we put a 1 in
% location  gaps(k)  if  the  integer  k  is 
% missing from the data
%
  [M,N]=size(x);
  gaps=ones(KMAX,1);
  order=zeros(M,N);
  gaps(x)=order;        
 
%
% Set  gaps(k)  to the total number of holes
% from 1..k
%
 
  gaps=cumsum(gaps);
 
%
% Only  you  matlab  folks  will know if all
% this  reshaping  is really necessary or if
% commands  can  be  combined  for  a  speed
% advantage.  Finals  are just too close for
% me to want to find out :-)
%
 
  order=reshape(order,M*N,1);
  order=gaps(x);
  order=reshape(order,M,N);
  order=x-order;
