function [Zm,map]=cmap(Z)
 
%CMAP   Remap Z to colormap indices
%       [ZM,MAP]=cmap(Z) returns colormapped image ZM and colormap MAP
%       given matrix Z containing only integers in range [1,255], so that
%       MAP(ZM(i))==Z(i).
 
%       Michael Maurer, 2 December 1993
 
P=255;                          % max integer in Z
[M,N]=size(Z);
occ=zeros(P,1);                 % occurrence vector for pixel values
occ(Z(:))=Z(:);                 % fill occurrence vector
                                % uses fact that Z~=0, saves ones() memory
occ(find(occ))=[1:sum(occ>0)]'; % number occurring pixel values in order
Zm=zeros(M,N);
Zm(:)=occ(Z(:));                % remap from Z to map index
 
if nargout>1,
   map=find(occ);
end
