function result = remap(input)
%REMAP Re-maps K distinct integers to the range [1,K].
% REMAP(X) returns a matrix in which the K distinct integers in X are
% re-mapped to the integers from 1 to K, preserving order.
 
% written by
%   Douglas M. Schwarz
%   Eastman Kodak Company
%   schwarz@kodak.com
%   5 December 1993
 
 
% First, we determine the dimensions of the input.
 
    dim = size(input);
 
 
% Next, we build a lookup table vector, lut, of length max(max(input)),
% which contains 1's in the K positions corresponding to values present
% in input.
 
    lut(input) = ones(dim);
 
 
% Now, we replace the K 1's in the lookup table with the integers from
% 1 to K.
 
    lut(lut) = 1:length(lut(lut));
 
 
% Finally, we create the properly-sized result matrix and apply the lookup.
 
    result = zeros(dim);
    result(:) = lut(input);
