% lexsort - Lexical sorting.
%
% Sorts the rows of a string matrix  in dictionary order (ignoring
% leading spaces). Ex:
%
%       A = ['hello'
%             'foo  '
%             ' bar '];
%
%       lexsort(A) =>  [' bar '
%                       'foo  '
%                       'hello'];
%
 
% Author: Carlos Fonseca (C.Fonseca@shef.ac.uk)
% Date: 8/Feb/94
 
function Aout = lexsort(Ain);
 
% Initialization
[r,c] = size(Ain);
Aout = zeros(r,c);
 
% Remove leading spaces
NonSp = (Ain ~= ' ');
TotCh = sum(NonSp');
for i = 1:r,
        Aout(i,1:TotCh(i)) = Ain(i,NonSp(i,:));
end
 
% Sort 
ix1 = 1:r;
for i = c : -1 : 1,
        [ans,ix] = sort(Aout(ix1,i));
        ix1 = ix1(ix);
end
 
% Output
Aout = Ain(ix1,:);
 
end
