function [time] = etime2(t1,t2);
%
% [TIME] = ETIME2(T1,T2) computes the elapsed time in seconds and days
% between any two dates.  The dates must be entered as row vectors giving
% year, month, day, hour, minute, and second.  For example, the time
% 9:57 PM and 32.4 seconds on June 20, 1987 would be entered as
% [1987,6,20,21,57,32.4].  The output is a 2-vector containing the elapsed
% time in seconds and days.
%      Bruce Gretz
%      3939 Fabian Way
%      Ford Aerospace & Communications Corp.
%      Palo Alto, CA 94303
%
secday = 24*3600;
t = [t1',t2']';
dt = t2(1) - t1(1);
time = (t(:,2) - [1,1]')*30 + t(:,3) - [1,1]';
time = t(:,4) + time*24;
time = t(:,5) + time*60;
time = t(:,6) + time*60;
time = 365*secday - time(1) + (dt - 1)*365*secday + time(2);
l1 = fix( 1 - rem( t1(1)/4, 1 ) );
l2 = fix( 1 - rem( t2(1)/4, 1 ) );
nl = fix( dt/4 ) - l1*l2;
time = time + nl*secday;
lp1 = [1 1 0 0 0 0 0 0 0 0 0 0];
lp2 = [0 0 1 1 1 1 1 1 1 1 1 1];
time = ( l1*lp1( t1(2) ) + l2*lp2( t2(2) ) )*secday + time;
day = [0, 1,-1, 0, 0, 1, 1, 2, 3, 3, 4, 4 ];
time = ( day(t2(2)) - day(t1(2)) )*secday + time;
time = [ time , time/secday];
