% CTR_DEMO: To be call from FISDEMO.M.

% FISMAT: Fuzzy Inference Systems toolbox for MATLAB
% (c) A. Lotfi, University of Queensland (Email: lotfia@s1.elec.uq.oz.au)
% 13-10-93
% The program has been tested on MATLAB version 4.1, Sun workstation.
%
% 16-4-94
% The program has been modified for MATLAB version 3.5b, Personal Computer.

echo on
load ctrdemo.mat
clc;
% To illustrate application of approximate reasoning methods in close
% loop control systems, truck backer-upper control system , inverted
% pendulum system and Fan Speed control are taken as test_bed.

% Backing a truck to a loading dock is a nonlinear control problem
% which can involve extensive computation time to steer the truck to a
% prescribed loading zone. The dynamic of truck backer-upper is given
% in truck.m file. The input of this function are position
% of truck (x,y in yard), azimuth angle (Phi) of truck and the
% steering angle of truck (Theta). The function will return the
% next state of system.

% The range of variables for simulated truck and controllers are
% as follows;

X=[0:4:100];
Phi=[-90:10:270];
Theta=[-30:2:30];

pause % Press any key to continue
clc;
% Since we presuppose adequate clearance between the truck and the
% loading dock, state variable Y can be abandoned. Therefore the
% inputs of controller are X and Phi.

% The control goal is to steer the truck from any initial position to
% prespecified loading dock with a right azimuth angle (Phi_final=90)
% and coincided rear position. The steering angle Theta is the control
% action which is provided by the designed fuzzy  controller.

% There are different control strategy for this control problem. In
% this demonstration we show that the truck control is possible only
% with maximum 9 rules.

[a1,b1,c1,a2,b2,c2,ahat,bhat,chat]=t_rule9;

[A1,A2,B]=rulebase(1,X,a1,b1,c1,1,Phi,a2,b2,c2,1,Theta,ahat,bhat,chat);

%>> mfplot(A1,X,A2,Phi,B,Theta);

pause % Press any key to continue
mfplot(A1,X,A2,Phi,B,Theta);pause;
clc;
% We can select any approximate reasoning methods explained earlier,
% the method we are going to use here is MAMDANI.
% The initial state of truck must be given for running simulation.
% We can assume;

truck_state_0=[20,20,90]'  %[X_position, Y_position, Azimuth angle Phi]


pause % Press any key to continue
clc
% The truck trajectory from three initial position has been shown.
% This tracking ability are related to Mamdani approach (Min-Max)
% and centroid defuzzification.

%>> state=[];trst=truck_state_0;
%>> for i=1:100
%>> [fuzzy_decision]=mamdani(A1,trst(1),X,A2,trst(3),Phi,U2,B,1,1);
%>> steer_angle=defzfir(fuzzy_decision,Theta,1);
%>> trst=truck(trst,steer_angle);
%>> state=[state, trst];
%>> end

pause % Press any key to continue

%                       Wait Please ........

echo off;
trst=truck_state_0;
state1=[];state2=[];state3=[];sangle1=[];sangle2=[];sangle3=[];

clg;

truck_state_0=[20,20,90]';
trst=truck_state_0;state=[];

step=1;
   while step < 300
   state1=[state1,trst];
   [fuzzy_decision]=mamdani(A1,trst(1),X,A2,trst(3),Phi,B,1,1);
   steer_angle=defzfir(fuzzy_decision,Theta,1);
   trst=truck(trst,steer_angle);

        if trst(2) >= 100
                step=301;
        end

   step=step+1;
   end

axis([0 100 0 100]);

truck_state_0=[80,30,120]';
trst=truck_state_0;state=[];

step=1;
while step < 300
   state2=[state2,trst];
[fuzzy_decision]=mamdani(A1,trst(1),X,A2,trst(3),Phi,B,1,1);
steer_angle=defzfir(fuzzy_decision,Theta,1);


        trst=truck(trst,steer_angle);
        if trst(2) >= 100
                step=301;
        end

step=step+1;
end


truck_state_0=[60,40,-90]';
trst=truck_state_0;state=[];

step=1;
while step < 300
   state3=[state3,trst];
[fuzzy_decision]=mamdani(A1,trst(1),X,A2,trst(3),Phi,B,1,1);
steer_angle=defzfir(fuzzy_decision,Theta,1);

        trst=truck(trst,steer_angle);
        if trst(2) >= 100
                step=301;
        end

step=step+1;
end

    plot(state1(1,:),state1(2,:),'r*',state2(1,:),state2(2,:),'g*',state3(1,:),state3(2,:),'w*');
    xlabel('X position');ylabel('Y position');title('Loading dock');
    text(20,20,'Initial Position');pause;
echo on;
clc;
% Calculated steering angle is a continuse variable in the universe of
% Theta. We may want to quantize this control action and then applying
% it to truck. The function that can quantize the variable with a
% quantum size Q.

%>> for i=1:100
%>> [fuzzy_decision]=mamdani(A1,trst(1),X,A2,trst(3),Phi,U2,B,1,1);
%>> steer_angle=defzfir(fuzzy_decision,Theta,1);
%>> steer_angle_q=quantize(steer_angle,2);
%>> trst=truck(trst,steer_angle_q);
%>> end

pause % Press any key to continue

%                       Wait Please ........

echo off;


trst=truck_state_0;
state1=[];state2=[];state3=[];sangle1=[];sangle2=[];sangle3=[];

clg;

truck_state_0=[20,20,90]';
trst=truck_state_0;state=[];

step=1;
   while step < 300
   state1=[state1,trst];
   [fuzzy_decision]=mamdani(A1,trst(1),X,A2,trst(3),Phi,B,1,1);
   steer_angle=defzfir(fuzzy_decision,Theta,1);
   steer_angle_q=quantize(steer_angle,2);
   trst=truck(trst,steer_angle_q);

        if trst(2) >= 100
                step=301;
        end

   step=step+1;
   end

axis([0 100 0 100]);

truck_state_0=[80,30,120]';
trst=truck_state_0;state=[];

step=1;
while step < 300
   state2=[state2,trst];
[fuzzy_decision]=mamdani(A1,trst(1),X,A2,trst(3),Phi,B,1,1);
steer_angle=defzfir(fuzzy_decision,Theta,1);
   steer_angle_q=quantize(steer_angle,2);


        trst=truck(trst,steer_angle_q);
        if trst(2) >= 100
                step=301;
        end

step=step+1;
end


truck_state_0=[60,40,-90]';
trst=truck_state_0;state=[];

step=1;
while step < 300
   state3=[state3,trst];
[fuzzy_decision]=mamdani(A1,trst(1),X,A2,trst(3),Phi,B,1,1);
steer_angle=defzfir(fuzzy_decision,Theta,1);
   steer_angle_q=quantize(steer_angle,2);

        trst=truck(trst,steer_angle_q);
        if trst(2) >= 100
                step=301;
        end

step=step+1;
end

    plot(state1(1,:),state1(2,:),'r*',state2(1,:),state2(2,:),'g*',state3(1,:),state3(2,:),'w*');
    xlabel('X position');ylabel('Y position');title('Loading dock');
    text(20,20,'Initial Position');pause;
echo on;
clc;
% To investigate the control strategy globally, we can construct the
% decision surface related to any fuzzy approximation method.


%>> [S_truck9]=ctrsurf('mamdani',A1,X,A2,Phi,B,Theta,1,1);


pause % Press any key to continue
mesh(S_truck9');xlabel('X Position');ylabel('Azimuth angle');title('Control Surface for Truck Backer-Upper Control 9 Rules');pause;

clc;clg;
% Now we can compare the control performance with 9 rules and 36 rules
% as proposed by Kosko.

[a1,b1,c1,a2,b2,c2,ahat,bhat,chat]=t_rule36;

[A1,A2,B]=rulebase(1,X,a1,b1,c1,1,Phi,a2,b2,c2,1,Theta,ahat,bhat,chat);

% The approximate reasoning that we are going to use in this part of
% demonstration is LARSEN. (The initial positions are as before)

%>> state=[];trst=truck_state_0;
%>> for i=1:100
%>> [fuzzy_decision]=larsen(A1,trst(1),X,A2,trst(3),Phi,U2,B,1,1);
%>> steer_angle=defzfir(fuzzy_decision,Theta,1);
%>> trst=truck(trst,steer_angle);
%>> state=[state,trst];
%>> end

pause % Press any key to continue

%                       Wait Please ........

echo off;
trst=truck_state_0;
state1=[];state2=[];state3=[];sangle1=[];sangle2=[];sangle3=[];

clg;

truck_state_0=[20,20,90]';
trst=truck_state_0;state=[];

step=1;
   while step < 300
   state1=[state1,trst];
   [fuzzy_decision]=larsen(A1,trst(1),X,A2,trst(3),Phi,B,1,1);
   steer_angle=defzfir(fuzzy_decision,Theta,1);
   trst=truck(trst,steer_angle);

        if trst(2) >= 100
                step=301;
        end

   step=step+1;
   end

axis([0 100 0 100]);

truck_state_0=[80,30,120]';
trst=truck_state_0;state=[];

step=1;
while step < 300
   state2=[state2,trst];
[fuzzy_decision]=larsen(A1,trst(1),X,A2,trst(3),Phi,B,1,1);
steer_angle=defzfir(fuzzy_decision,Theta,1);


        trst=truck(trst,steer_angle);
        if trst(2) >= 100
                step=301;
        end

step=step+1;
end


truck_state_0=[60,40,-90]';
trst=truck_state_0;state=[];

step=1;
while step < 300
   state3=[state3,trst];
[fuzzy_decision]=larsen(A1,trst(1),X,A2,trst(3),Phi,B,1,1);
steer_angle=defzfir(fuzzy_decision,Theta,1);

        trst=truck(trst,steer_angle);
        if trst(2) >= 100
                step=301;
        end

step=step+1;
end

    plot(state1(1,:),state1(2,:),'r*',state2(1,:),state2(2,:),'g*',state3(1,:),state3(2,:),'w*');
    xlabel('X position');ylabel('Y position');title('Loading dock');
    text(20,20,'Initial Position');pause;
echo on;
clc;
% To investigate the control strategy globally, we can construct the decision
% surface related to any fuzzy approximation method.


%>> [S_truck36]=ctrsurf('larsen',A1,X,A2,Phi,B,Theta,1,1);

pause % Press any key to continue
mesh(S_truck36');xlabel('X Position');ylabel('Azimuth angle');title('Control Surface for Truck Backer-Upper Control  36 Rules');pause;

clc;clg;
% The next control problem which we are going to explain is Inverted
% Pendulum System. It is composed of a rigid pole and a cart on which
% the pole is hinged. The state of this system is given by the pole's
% angle and angular velocity and the cart's horixzontal position and
% velocity. The only available control action is to exert forces on
% the cart that push it to left or right.
% Let's assume the initial conditions of the system as follows;

% [cart position, cart velocity, pole angle , pole angular velocity]
invpend_state_0=[-5,1,20,0]'

pause % Press any key to continue
clc;
% There are four independent states, Since our control goal is to
% balance the pole regardless the cart's position and velocity, hence
% only two states (angular potion and angular velocity of pole) are
% relevant in this simulation.

% The universe of angular position Theta and angular velocity Theta_dot
% are chosen as follows;

Theta=[-40:2:40];
Theta_dot=[-100:5:100];

% The rules are given in "i_rule4". It is to be noted that since we
% want to use SUGENO's method, the rules are given the same format.

[a1,b1,c1,a2,b2,c2,P]=i_rule4;

[A1,A2]=rulebase(2,Theta,a1,b1,c1,2,Theta_dot,a2,b2,c2);

%>> mfplot(A1,Theta,A2,Theta_dot)

pause % Press any key to continue
mfplot(A1,Theta,A2,Theta_dot);pause;
hold off;clc;
% The dynamic of inverted pendulum system  is given in invpend.m file.
% The input of this function are position of cart, velocity of cart,
% pole angle, angular velocity of pole and control force. The function
% will return the derivative of the state of system.

% The reasoning which we are going to use here is SUGENO.

%>> state=invpend_state_0;
%>> for i=1:300
%>> [force]=sugeno(A1,state(3),Theta,A2,state(4),Theta_dot,P,1);
%>> [state_dot]=invpend(state,force);
%>> state=state+ .01*state_dot;
%>> end

pause % Press any key to continue

%                            Wait Please .....
echo off
hold off;clg;
x=invpend_state_0(1);theta=invpend_state_0(3);
state_stuck=[];state=invpend_state_0;

for i=1:300
        [force]=sugeno(A1,state(3),Theta,A2,state(4),Theta_dot,P,1);
        [state_dot]=invpend(state,force);
        state=state+ .01*state_dot;
        state_stuck=[state_stuck, state];
end

time_pend=[0:.01:2.99];
subplot(221);plot(time_pend,state_stuck(1,:));xlabel('Time (Sec.)');title('Cart position');
subplot(222);plot(time_pend,state_stuck(2,:));xlabel('Time (Sec.)');title('Cart velocity');
subplot(223);plot(time_pend,state_stuck(3,:));xlabel('Time (Sec.)');title('Pole angle');
subplot(224);plot(time_pend,state_stuck(4,:));xlabel('Time (Sec.)');
title('Pole anglular velocity');pause;

echo on;
clc;
% The control action surface related to two inputs ,pole angle and angular
% velocity of pole, can be constructed as follows;


%                        Wait Please ......

%>> [S_invpend]=ctrsurf('sugeno',A1,Theta,A2,Theta_dot,P,2);

pause % Press any key to continue
clg;
mesh(S_invpend');xlabel('Pole angle (degree)');ylabel('Angular velocity');title('Control Surface for Inverted Pendulum System with 4 rules');pause;

clc;
% The third control problem which we are going to investigate is
% designed to control the temperature and humidity of a bathroom,
% where the ideal condition is "warm and dry", . The only parameter
% for control task is fan speed. The universes considered for our
% simulation are;

Tem=[40:2:120];
Hum=[0:2:100];
Speed=[0:20:1000];

pause % Press any key to continue
clc;
% The fuzzy values for temperature, humidity and speed are defined as follows;

cool=trapeze(Tem,.05,30,45);
warm=trapeze(Tem,.05,0,80);
hot =trapeze(Tem,.05,30,115);

dry =trapeze(Hum,.04,30,10);
moist=trapeze(Hum,.04,0,50);
wet=trapeze(Hum,.04,30,90);

low=trapeze(Speed,.004,300,100);
med=trapeze(Speed,.004,0,500);
high=trapeze(Speed,.004,300,900);

pause % Press any key to continue
clc;
% The table of rules for control of fan speed can be taken as follows;
%
%                              TEMPERATURE
%
%                            COOL  WARM   HOT
%                           -----------------
%                    DRY    | LOW | MED | MED
%                           -----------------
%      HUMIDITY      MOIST  | LOW | MED | HIGH
%                           -----------------
%                    WET    | MED | MED | HIGH     SPEED
%

A1=[cool; warm; hot; cool;  warm;  hot;   cool; warm; hot];
A2=[dry;  dry;  dry; moist; moist; moist; wet;  wet;  wet];
B =[low;  med;  med; low;   med;   high;  med;  med;  high];


%>> mfplot(A1,Tem,A2,Hum,B,Speed);

pause % Press any key to continue

mfplot(A1,Tem,A2,Hum,B,Speed);pause;
clc;
% The control surface related to these membership functions and table of
% rules can be calculated.

%>> [S_fan]=ctrsurf('larsen',A1,Tem,A2,Hum,B,Speed,2,1);

pause % Press any key to continue
clg;
cont_surf=mesh(S_fan);xlabel('Temperature (F)');ylabel('Humidity (%)');title('Control Surface for Fan Speed Control');pause;

clc;
% In this part of demonstration the following functions are introduced.
%
%       CTRSURF, QUANTIZE
%       INVPEND, I_RULE4
%       TRUCK, T_RULE9, T_RULE36

pause % Press any key to continue
echo off
