function str = jmamat2str(MTX,NDIG);
% String to represent a NUM. matrix correctly (right inverse of 'eval',
%   for a numeric matrix, i.e., so that 'eval(<result>)' = the matrix,
%   to within several digits of accuracy):
%	str = jmamat2str(MTX,NDIG)
% where
%   MTX	= the matrix (including vector or even scalar) to be represented
%	to 'NDIG' digits of accuracy;
%   NDIG = max. number of digits to be used for any entry in the matrix
%	(> 0) -- optional: if '[]' or absent, default = 16.
% Examples:
% 1.	jmamat2str(3) returns '[3]'.
% 2.	jmamat2str([1 2;3 4]) returns '[1,2;3,4]'.
% 3.	jmamat2str([1+1.e-8;2+.3*i]) returns '[1.00000001;2+0.3i]'.
% Note: The decision to include a '+...i' (for imag. part) is
%   made independently on every row.
%
% See also: strmat2str, numcons, NUM2STR.

if nargin < 2, NDIG = []; end
if NDIG == [],
   NDIG = 16;	% No need to type-check.
else
   %%% Type-echeck:
	if ~dtchk_len1(NDIG),
	   error(['Number of digits for formatting must be ' ...
	   		'a positive integer.'])
	end
   %%% End check.
end

% Alas, note that we CANNOT use '%.*g' for formatting, because
%   MATLAB's 'sprintf' will loop over the 'MTX' elements, inserting
%   them BOTH into the '*' position AND into the (desired) 'g' position.
% So construct the formats explicitly, in advance:
realfmt = sprintf(',%%.%dg',NDIG);	% Dflt = ",%.16g".
cpxfmt = sprintf(',%%.%dg%%+.%dgi',NDIG,NDIG);	% Dflt = ",%.16g%+.16gi"
% '*fmt' is the 'sprintf' format to be used for each row of 'MTX'.

str = '';
for ii = 1:size(MTX,1)	% For each row (ending with ';'):
   % Put comma BEFORE each entry:
   if any(imag(MTX(ii,:))~=0),
      row = '';
      for jj = 1:size(MTX,2)
         row = [row sprintf(cpxfmt, ...
         		real(MTX(ii,jj)), imag(MTX(ii,jj)))];
      end
   else	% No 'sprintf' complication for Real & Imag parts:
      row = sprintf(realfmt, MTX(ii,:));
   end
   row(1) = ';';	% End of prev. row (overwrite 1st comma).
   str = [str row];
end
% >> Each row starts with ';', and
%	each entry after 1st of each row starts with comma. <<

% Fix up punct.:
str(1) = '[';
str = [str ']'];
