function matprint(marker,matrix)
%  FUNCTION MATPRINT (MARKER, MATRIX)
%
%  Displays a text string which will result in
%  a pretty printing of matrix when editor is used.
%  editor is a global variable which may be either
%  'MSWORD' or 'TEX'.  If not specified beforehand,
%  editor defaults to 'TEX'
%
%  marker contains the type of delineator for the
%  matrix, either '[', '{', or '('.
%
%  May also be called with MATPRINT (matrix), 
%  in which case marker defaults to '['.
%
%  If matrix is a string, MATPRINT looks for !'s to
%  delineate columns and #'s at the end of each row.
%  This feature only works with MSWORD
%
%	Written by Keith Rogers (kerog@athena.mit.edu) 
%	Last revised 8/12/93

global editor

if ~exist('editor')
	editor = 'TEX';
end
while (~(strcmp(editor,'TEX') | strcmp(editor,'MSWORD')))
	editor = input2('Unrecognized editor! Do you want TEX or MSWORD?','TEX');
end
if nargin == 1,			% Default to Microsoft Word and [
	matrix = marker;
	marker = '[';
end
[m,n] = size(matrix);
columns = 1;
i = 1;

% if EDITOR is MSWORD, check for string matrix printing

if strcmp(editor,'MSWORD'),
	if isstr(matrix),
	  while (strcmp(matrix(1,i),'#')==0),
	   if strcmp(matrix(1,i),'!'),
		 columns = columns + 1;
	   end
	   i = i+1;
	  end
	string = ['\B\BC\' marker '(\A\HS7\CO' num2str(columns) '('];
	  for i = 1:m
	   for j = 1:n
		if(strcmp(matrix(i,j),'!') | strcmp(matrix(i,j),'#')),
		  string = [string ','];
		else
		  string = [string matrix(i,j)];
		end
		if (i == m & j == n),
		  string = [string '))'];
		end
	   end
	  end
	else
	 string = ['\B\BC\' marker '(\A\HS7\CO' num2str(n) '('];
	 for i = 1:m
	  for j = 1:n
	   if (i == m & j == n),
		string = [string com2str(matrix(i,j)) '))'];
	   else
		string = [string com2str(matrix(i,j)) ','];
	   end
	  end
	 end
	end
elseif strcmp(editor,'TEX'),
	if (marker == '{'),
	  marker = '\{';
	  endmark = '\}';
	elseif (marker == '('),
	  endmark = ')';
	elseif (marker == '['),
	  endmark = ']';
	elseif (marker == '<'),
	  endmark = '>';
	else 
	  rmarker = marker;
	end
	string = ['\left' marker '\matrix{'];
	if(isstr(matrix)),
	 for i = 1:m
	  for j = 1:n
	   if(matrix(i,j) == '!')
	   	string = [string ' & '];
	   elseif(matrix(i,j) == '#')
	   	string = [string ' \cr '];
	   else
	    string = [string matrix(i,j)];
	   end
	  end
	 end
 	else
	 for i = 1:m
	  for j = 1:n
	   if (j == n),
		string = [string com2str(matrix(i,j)) '\cr'];
	   else
		string = [string com2str(matrix(i,j)) '&'];
	   end
	  end
	 end
	end
	string = [string '}\right' endmark];
end
disp(string)
