function [vol,rcg,vrr,secs]=polhedrn(idf,xdata)
% [vol,rcg,vrr,secs]=polhedrn(idf,xdata)
% This function computes geometrical properties of a polyhedron.
%
% INPUT :
% xdata - Coordinate data.
% idf   - Information defining the faces.
%
% OUTPUT :
% vol   - The volume of the polyhedron.
% vcg   - The centroidal coordinate of the polyhedron.
% vrr   - The second moment of volume of the polyhedron.
% secs  - The computation time in seconds.
%
%         by H. B. Wilson and G. S. Chang  June 1989
%
secs=clock; [nf,nc]=size(idf);
vol=0; rcg=zeros(3,1); vrr=zeros(3,3);
for j=1:nf, ndxfac=idf(j,:); ncrnrs=sum(ndxfac~=0);
ndxfac=ndxfac(1:ncrnrs); ndxfac=ndxfac(:);
[utmp,htmp,atmp,ratmp,rratmp]=polygon(ndxfac,xdata);
vol=vol+htmp*atmp; rcg=rcg+htmp*ratmp; vrr=vrr+htmp*rratmp; end
vol=vol/3; rcg=rcg/(4*vol); vrr=vrr/5; secs=etime(clock,secs);
