function [un,h,area,ra,rra]=polygon(id,x)
% [un,h,area,ra,rra]=polygon(id,x)
% Geometrical properties of a polygon in 3 dimensions.
%
% INPUT :
% id    - The index defines the surface.
% x     - Coordinate data.
%
% OUTPUT :
% un    - The unit normal vector of the plane.
% h     - The normal distance to the plane.
% area  - The polygon area.
% ra    - The first moment of area.
% rra   - The second moment of area.
%
%         by H. B. Wilson and G. S. Chang  June 1989
%
r=x(id,:)'; n=length(id); rn=r(:,n); r1=r(:,1); p=zeros(n-2,3);
for j=2:n-1, p(j-1,:)=cross(r(:,j)-r1,r(:,j+1)-r1)'; end
un=sum(p); a2=norm(un); un=un(:)/a2; p=[zeros(1,3);p]*un;
ra=r1*a2; rra=rn*(p(n-1)*rn');
for j=2:n-1, rj=r(:,j); s=rj+r(:,j+1); v=p(j)*s; ra=ra+v;
rra=rra+v*s'+rj*rj'*(p(j-1)+p(j));end
h=r1*ra'; rra=(rra+h+h')/24; ra=ra/6; h=un'*r1; area=.5*a2;
