function [sys,x0]=eulrotds(t,x,u,flag,WorkingFig)
%EULROTDS Animation for EULROT.C
%	[SYS,XO]=EULROTDS(T,X,U,FLAG,WORKINGFIG) is the S-Function used
%	for the Euler rotation block in Simulink.  
%
%	WORKINGFIG is the handle of the figure that the animation takes
%	place on.
%
%	See also EULROT.C, QUATDEMO.

%	Loren Dean  July, 1995.
%	Copyright (c) 1995 by The MathWorks, Inc.

InvalidHandle=0;
eval('InvalidHandle=~strcmp(get(WorkingFig,''Tag''),''QuatWorkingFig'');', ...
     'InvalidHandle=1;'                                                    ...
     );

if InvalidHandle,WorkingFig=[];end

if WorkingFig~=[],Data=get(WorkingFig,'UserData');end

if flag==0|flag==9,
  
  if ~isempty(WorkingFig),
    Data=get(WorkingFig,'UserData');
    ResetHandle=Data(5);
    Data(1:5)=[];
    PsiSlide=Data(1)      ;PsiText=Data(2);
    ThetaSlide=Data(7)    ;ThetaText=Data(8);
    PhiSlide=Data(13)      ;PhiText=Data(14);
    AzimuthSlide=Data(19)  ;AzimuthText=Data(20);
    ElevationSlide=Data(25);ElevationText=Data(26);
    BetaSlide=Data(31)    ;BetaText=Data(32);
    Frames=Data(59:62);
    StatHandles=Data(1:18);DynHandles=Data(37:54);
    StaticButton=Data(56);
    DynamicButton=Data(57);
  end % if ~isempty
  
end % if flag

if flag==0, % Initialize everything
  sys=[0 0 0 -1 0 0];
  x0=[];

  if ~isempty(WorkingFig),
    set(StatHandles,'Visible','on');
    set(DynHandles,'Visible','off');
  
    set([ResetHandle Frames(4)  StaticButton DynamicButton  ...
         Data([1  5  6   7  11 12   13 17 18                ...
               19 23 24  25 29 30   31 35 36 ])]          , ...       
         'Visible','off');
  
    set([PsiText ThetaText PhiText AzimuthText ElevationText BetaText], ...
        'Callback','');
  end % if ~isempty
  
elseif flag==3,
  if ~isempty(WorkingFig),
    psi=u(1);theta=u(2);phi=u(3);
    quatdemo(WorkingFig,psi,theta,phi);
  end % WorkingFig
  sys=[];

elseif flag==9,
  sys=[];
  if ~isempty(WorkingFig),
    set([ResetHandle Frames(4)                   ...
         Data([1  5  6   7  11 12   13 17 18     ...
               19 23 24  25 29 30   31 35 36 ]), ...       
        ],'Visible','on');  

    comp=computer;
    if ~(strcmp(lower(comp(1:2)),'pc')|strcmp(lower(comp(1:3)),'mac')),
      set(StaticButton,'Value',1,'Visible','on');
      set(DynamicButton,'Value',0,'Visible','on');
    end % if ~
    set(PsiText,'Callback','quatdemo(''#Psi'',''E'');');
    set(ThetaText,'Callback','quatdemo(''#Theta'',''E'');');
    set(PhiText,'Callback','quatdemo(''#Phi'',''E'');');
    set(AzimuthText,'Callback','quatdemo(''#Azimuth'',''C'');');
    set(ElevationText,'Callback','quatdemo(''#Elevation'',''C'');');
    set(BetaText,'Callback','quatdemo(''#Beta'',''C'');');
    set(PsiSlide,'Value',str2num(get(PsiText,'String')));
    set(ThetaSlide,'Value',str2num(get(ThetaText,'String')));
    set(PhiSlide,'Value',str2num(get(PhiText,'String')));
    set(AzimuthSlide,'Value',str2num(get(AzimuthText,'String')));
    set(ElevationSlide,'Value',str2num(get(ElevationText,'String')));
    set(BetaSlide,'Value',str2num(get(BetaText,'String')));
  
    quatdemo('#Psi','E');
  end % if ~isempty
  
end; % flag
