function quatdemo(Action,BtnFlag,Theta,Phi)
% QUATDEMO Quaternion demonstration.
%	QUATDEMO runs a demo for quaternions through the use of a 
%	simple aircraft orientation graphical interface.  The aircraft
%	can be rotated using the traditional body rotations Psi, Theta,
%	and Phi.  It can also be rotated using the quaternion 
%	representation.
%

%	Loren Dean  June, 1995.
%	Copyright (c) 1995 by The MathWorks, Inc.

R2D=180/pi;
%%%%%%%%%%%%%%%%%%%%
%%% Nargin Check %%%
%%%%%%%%%%%%%%%%%%%%
if nargin~=0 & nargin~=3,
  if nargin==4,
    QuatFig=Action;Psi=BtnFlag;Action='#PTP';BtnFlag='E';
  else,
    QuatFig=get(0,'CurrentFigure');
  end
  if isempty(QuatFig),return;end

  Data=get(QuatFig,'UserData');
  PlaneHandles=Data(1:2);
  PointerHandle=Data(3);
  QuatAxes=Data(4);
  ResetHandle=Data(5);
  Data(1:5)=[];
  PsiSlide=Data(1)      ;PsiText=Data(2);
  ThetaSlide=Data(7)    ;ThetaText=Data(8);
  PhiSlide=Data(13)      ;PhiText=Data(14);
  AzimuthSlide=Data(19)  ;AzimuthText=Data(20);
  ElevationSlide=Data(25);ElevationText=Data(26);
  BetaSlide=Data(31)    ;BetaText=Data(32);
  PSlide=Data(37);PText=Data(38);
  QSlide=Data(43);QText=Data(44);
  RSlide=Data(49);RText=Data(50);
  QuatText=Data(55);
  StaticButton=Data(56);
  DynamicButton=Data(57);
  EulText=Data(58);
end % if nargin
if nargin==1,
  if strcmp(Action,'#StatDyn'),
    StatHandles=Data(1:18);DynHandles=Data(37:54);
    if strcmp(get(gco,'Tag'),get(StaticButton,'Tag')),
      DynFlag=0;
      set(DynamicButton,'UserData',1);
      set([PSlide,QSlide,RSlide],'Value',0);
      set([PText,QText,RText],'String',num2str(0));
      quatdemo('#Nothing','D');
      drawnow
      set(EulText,'String','Euler Angles');
      set(StatHandles,'Visible','on');
      set(DynHandles,'Visible','off');
      Beta=get(BetaSlide,'Value');
      if Beta~=0,
        set([AzimuthSlide AzimuthText ElevationSlide  ...
             ElevationText BetaSlide BetaText ResetHandle],'Enable','on');
      else,
        set([AzimuthSlide AzimuthText ElevationSlide  ...
             ElevationText BetaSlide BetaText ResetHandle],'Enable','off');
      end % if Beta
    else,
      DynFlag=1;
      set(EulText,'String','Body Rates');
      set(StatHandles,'Visible','off');
      set(DynHandles,'Visible','on');
      set([AzimuthSlide AzimuthText ElevationSlide  ...
           ElevationText BetaSlide BetaText],'Enable','off');
      set([PSlide,QSlide,RSlide],'Value',0);
      set([PText,QText,RText],'String',num2str(0));
      set(ResetHandle,'Enable','off');
    end
    set(StaticButton,'Value',1-DynFlag);
    set(DynamicButton,'Value',DynFlag);
  elseif strcmp(Action,'#Close'),
    set(DynamicButton,'UserData',1);
    close(get(0,'CurrentFigure'));
  elseif strcmp(Action,'#Help'),
    DynFlag=get(DynamicButton,'Value');
    if DynFlag==0,
    HelpText= ...                                       1               
        [' This demonstration shows how three degree of  '
         ' freedom Euler rotations are related to        '
         ' Quaternion rotations (Euler Parameters).      '
         ' Clicking on Yaw, Pitch or Roll rotates the    '
         ' aircraft in heading (Psi), pitch (Theta), and '
         ' roll (Phi), respectively.                     '
         '                                               '
         ' The blue line represents the axis of a single '
         ' simple rotation that brings the aircraft back '
         ' to wings level flying north. The quaternion   '
         ' representation of the aircraft is shown below '
         ' the Euler angles.  Changing Azimuth and       '
         ' Elevation changes the "blue line" axis of     '
         ' rotation and changing Beta changes the amount ' 
         ' the aircraft is rotated about this axis.      '
         ' Azimuth is defined as a rotation about the    '
         ' "down" axis and Elevation is defined as a     '
         ' rotation about the intermediate "east" axis.  '
         ' The "blue line" originates from the "down"    '
         ' axis. Clicking on reset rotates the aircraft  '
         ' through the angle Beta to wings level flying  '
         ' north. It is also possible to change the      '
         ' viewing angle by clicking and dragging the    '
         ' axes.                                         '
         '                                               '];
         
      comp=computer;
      if ~(strcmp(lower(comp(1:2)),'pc')|strcmp(lower(comp(1:3)),'mac')),
        HelpText=[HelpText
         ' The Dynamic radio button changes the Euler    '
         ' angles to body rates of rotation.  Click on   '
         ' Info when the Dynamic button is selected for  '
         ' more detailed information.                    '];
      end % if
    else,
      HelpText= ...
        [' The dynamic rates of rotation (P,Q,R) are body'
         ' fixed rates that take place about the roll,   '
         ' pitch and yaw axes respectively.  The rates   '
         ' are given in Degrees/Frame and can            '
         ' automatically be set to zero using the Reset  '
         ' button.                                       '
         '                                               ' 
         ' The Static button allows you to return to the '
         ' Euler angle display.                          '];
    end % if DynFlag
    helpfun('Quaternion Demonstration Help',HelpText);                                 
  end
elseif nargin==2|nargin==4,

  if nargin==2,
    DynFlag=get(DynamicButton,'Value');
    Psi=get(PsiSlide,'Value');
    Theta=get(ThetaSlide,'Value');
    Phi=get(PhiSlide,'Value');
    Beta=get(BetaSlide,'Value');
    Azimuth=get(AzimuthSlide,'Value'); 
    Elevation=get(ElevationSlide,'Value');
  else,
    DynFlag=0;
  end
  
  if DynFlag==0,
    if BtnFlag=='E',
      %%%%%%%%%%%
      %%% Psi %%%
      %%%%%%%%%%%
      if strcmp(Action,'#Psi'),
        if get(QuatFig,'CurrentObject')==PsiSlide,
          set(PsiText,'String',num2str(Psi));
        else,
          Psi=str2num(get(PsiText,'String'));
          if isempty(Psi),Psi=0;set(PsiText,'String',num2str(Psi));end
          if Psi>180,
            Psi=179.9;set(PsiText,'String',num2str(Psi));
          elseif Psi<-180,
            Psi=-179.9;set(PsiText,'String',num2str(Psi));
          end
          set(PsiSlide,'Value',Psi);
        end
      %%%%%%%%%%%%%
      %%% Theta %%%
      %%%%%%%%%%%%%
      elseif strcmp(Action,'#Theta'),
        if get(QuatFig,'CurrentObject')==ThetaSlide,
          set(ThetaText,'String',num2str(Theta));
        else,
          Theta=str2num(get(ThetaText,'String'));  
          if isempty(Theta),Theta=0;set(ThetaText,'String',num2str(Theta));end
          if Theta>90,
            Theta=89.9;set(ThetaText,'String',num2str(Theta));
          elseif Theta<-90,
            Theta=-89.9;set(ThetaText,'String',num2str(Theta));
          end
          set(ThetaSlide,'Value',Theta);
        end
      %%%%%%%%%%%
      %%% Phi %%%
      %%%%%%%%%%%
      elseif strcmp(Action,'#Phi'),
        if get(QuatFig,'CurrentObject')==PhiSlide,
          set(PhiText,'String',num2str(Phi));
        else,
          Phi=str2num(get(PhiText,'String'));
          if isempty(Phi),Phi=0;set(PhiText,'String',num2str(Phi));end
          if Phi>180,
            Phi=179.9;set(PhiText,'String',num2str(Phi));
          elseif Phi<-180,
            Phi=-179.9;set(PhiText,'String',num2str(Phi));
          end
          set(PhiSlide,'Value',Phi);
        end
        
      elseif strcmp(Action,'#PTP'),
        set(PsiText,'String',num2str(Psi));
        set(ThetaText,'String',num2str(Theta));
        set(PhiText,'String',num2str(Phi));
      end % if strcmp
      
      Psi=Psi/R2D;Theta=Theta/R2D;Phi=Phi/R2D;
  
      Quat=[ ...
         cos(Psi/2)*cos(Theta/2)*sin(Phi/2)-cos(Phi/2)*sin(Psi/2)*sin(Theta/2)
         sin(Psi/2)*cos(Theta/2)*sin(Phi/2)+cos(Phi/2)*cos(Psi/2)*sin(Theta/2)
         sin(Psi/2)*cos(Theta/2)*cos(Phi/2)-sin(Phi/2)*cos(Psi/2)*sin(Theta/2)
         cos(Psi/2)*cos(Theta/2)*cos(Phi/2)+sin(Phi/2)*sin(Psi/2)*sin(Theta/2)
           ]';
        
      Trans=[1           0         0 
             0           cos(Phi)  sin(Phi)
             0          -sin(Phi)  cos(Phi)]  ...
            * ...
            [cos(Theta)  0        -sin(Theta) 
             0           1         0
             sin(Theta)  0         cos(Theta)] ...
            * ...
             [cos(Psi)   sin(Psi)  0
             -sin(Psi)    cos(Psi)  0
             0           0         1         ];
         
      Beta=2*acos(Quat(4))*R2D;
      if Beta==360,
        set([PsiSlide,PhiSlide,BetaSlide],'Value',0);
        set([PsiText,PhiText,ThetaText],'String',num2str(0));
        Beta=0;
      end
     
      if Beta==0,
        Azimuth=0;Elevation=0;
      else,
        CosBetaOver2=Quat(4);
        SinBetaOver2=sqrt(1-CosBetaOver2^2);
        L1=Quat(1)/SinBetaOver2;
        L2=Quat(2)/SinBetaOver2;
        L3=Quat(3)/SinBetaOver2;
        Azimuth=atan2(L2,L1)*R2D;
        Elevation=acos(L3/norm([L1 L2 L3]))*R2D;
      end % if Beta
      
      if nargin==2,
        set(BetaSlide,'Value',Beta);
        set(AzimuthSlide,'Value',Azimuth);
        set(ElevationSlide,'Value',Elevation);
      end
      
      set(BetaText,'String',num2str(Beta));
      set(AzimuthText,'String',num2str(Azimuth));
      set(ElevationText,'String',num2str(Elevation));
      
    elseif BtnFlag=='C',
      %%%%%%%%%%%%%%%
      %%% Azimuth %%%
      %%%%%%%%%%%%%%%
      if strcmp(Action,'#Azimuth'),
        if get(QuatFig,'CurrentObject')==AzimuthSlide,
          set(AzimuthText,'String',num2str(Azimuth));
        else,
          Azimuth=str2num(get(AzimuthText,'String'));
          if isempty(Azimuth), 
            Azimuth=0;set(AzimuthText,'String',num2str(Azimuth));
          end
          if Azimuth>360,
            Azimuth=359.9;set(AzimuthText,'String',num2str(Azimuth));
          elseif Azimuth<-360,
            Azimuth=-359.9;set(AzimuthText,'String',num2str(Azimuth));
          end
          set(AzimuthSlide,'Value',Azimuth);
        end
      %%%%%%%%%%%%%%%%%
      %%% Elevation %%%
      %%%%%%%%%%%%%%%%%
      elseif strcmp(Action,'#Elevation'),
        if get(QuatFig,'CurrentObject')==ElevationSlide,
          set(ElevationText,'String',num2str(Elevation));
        else,
          Elevation=str2num(get(ElevationText,'String'));
          if isempty(Elevation),
            Elevation=0;set(ElevationText,'String',num2str(Elevation));
          end
          if Elevation>180,
            Elevation=180;set(ElevationText,'String',num2str(Elevation));
          elseif Elevation<-180,
            Elevation=-180;set(ElevationText,'String',num2str(Elevation));
          end
          set(ElevationSlide,'Value',Elevation);
        end
      end % if strcmp
      
      
      TransAz=[cos(Azimuth/R2D) -sin(Azimuth/R2D) 0
               sin(Azimuth/R2D)  cos(Azimuth/R2D) 0
               0                    0                   1];
      TransEl=[cos(Elevation/R2D) 0  sin(Elevation/R2D)
               0                  1  0              
              -sin(Elevation/R2D) 0  cos(Elevation/R2D)];
      Trans=TransAz*TransEl;
      
      Quat=[(Trans*[0;0;1])'*sin(Beta/R2D/2) cos(Beta/2/R2D)];
           
    elseif BtnFlag=='B',
      %%%%%%%%%%
      %%% Beta %%%
      %%%%%%%%%%
      if get(QuatFig,'CurrentObject')==BetaSlide,
        set(BetaText,'String',num2str(Beta));
      else,
        Beta=str2num(get(BetaText,'String'));
        if isempty(Beta),Beta=0;set(BetaText,'String',num2str(Beta));end
        if Beta>360,
          Beta=359.9;set(BetaText,'String',num2str(Beta));
        elseif Beta<0,
          Beta=0;set(BetaText,'String',num2str(Beta));
        end % if >360
        set(BetaSlide,'Value',Beta);
      end % if get
      
      if Beta==360,Beta=0;end
      if Beta==0,Azimuth=0;Elevation=0;end
      LTemp=[get(PointerHandle,'XData')
             get(PointerHandle,'YData')
             get(PointerHandle,'ZData')];
             
      TransE2S=[0 1 0;1 0 0;0 0 -1];
      L=LTemp(:,2);L=TransE2S*L/norm(L);
      Quat=[L'*sin(Beta/R2D/2) cos(Beta/R2D/2)];

    elseif BtnFlag=='R',
      %%%%%%%%%%%%%
      %%% Reset %%%
      %%%%%%%%%%%%%
      if rem(Beta,5)==0,
        Beta=Beta-5;
      else,
        Beta=Beta-rem(Beta,5);
      end
      set(BetaSlide,'Value',Beta);
      set(BetaText,'String',num2str(Beta));
      if Beta==0,Azimuth=0;Elevation=0;end
      
      LTemp=[get(PointerHandle,'XData')
             get(PointerHandle,'YData')
             get(PointerHandle,'ZData')];
             
      TransE2S=[0 1 0;1 0 0;0 0 -1];
      L=LTemp(:,2);L=TransE2S*L/norm(L);
      Quat=[L'*sin(Beta/R2D/2) cos(Beta/R2D/2)];
    end % if BtnFlag
    
    if BtnFlag~='E',
      Trans=[                                    ...
             1-2*Quat(2)^2-2*Quat(3)^2           ...
             2*(Quat(1)*Quat(2)+Quat(3)*Quat(4)) ...
             2*(Quat(3)*Quat(1)-Quat(2)*Quat(4))
             2*(Quat(1)*Quat(2)-Quat(3)*Quat(4)) ...
             1-2*Quat(3)^2-2*Quat(1)^2           ...
             2*(Quat(2)*Quat(3)+Quat(1)*Quat(4))
             2*(Quat(3)*Quat(1)+Quat(2)*Quat(4)) ...
             2*(Quat(2)*Quat(3)-Quat(1)*Quat(4)) ...
             1-2*Quat(1)^2-2*Quat(2)^2 
            ];


      Phi=atan2(Trans(2,3),Trans(3,3))*R2D;
      Psi=atan2(Trans(1,2),Trans(1,1))*R2D;
      Theta=atan2(-Trans(1,3),norm([Trans(1,1) Trans(1,2)]))*R2D;

      set(PsiSlide,'Value',Psi);
      set(PsiText,'String',num2str(Psi));
      
      set(PhiSlide,'Value',Phi);
      set(PhiText,'String',num2str(Phi));

      set(ThetaSlide,'Value',Theta);
      set(ThetaText,'String',num2str(Theta));

    end % if ~e
    
  elseif DynFlag==1,
    
    P=get(PSlide,'Value');
    Q=get(QSlide,'Value');
    R=get(RSlide,'Value');
    
    %%%%%%%%%
    %%% P %%%
    %%%%%%%%%
    if BtnFlag=='P',
      if get(QuatFig,'CurrentObject')==PSlide,
        set(PText,'String',num2str(P));
      else,
        P=str2num(get(PText,'String'));
        if isempty(P),P=0;set(PText,'String',num2str(P));end
        if P>10,
          P=10;set(PText,'String',num2str(P));
        elseif P<-10,
          P=-10;set(PText,'String',num2str(P));
        end % if >10
        set(PSlide,'Value',P);
      end % if get
    
    %%%%%%%%%
    %%% Q %%%
    %%%%%%%%% 
    elseif BtnFlag=='Q',
      if get(QuatFig,'CurrentObject')==QSlide,
        set(QText,'String',num2str(Q));
      else,
        Q=str2num(get(QText,'String'));
        if isempty(Q),Q=0;set(QText,'String',num2str(Q));end
        if Q>10,
          Q=10;set(QText,'String',num2str(Q));
        elseif Q<-10,
          Q=-10;set(QText,'String',num2str(Q));
        end % if >10
        set(QSlide,'Value',Q);
      end % if get
    
    %%%%%%%%%
    %%% R %%%
    %%%%%%%%%
    elseif BtnFlag=='S',
      if get(QuatFig,'CurrentObject')==RSlide,
        set(RText,'String',num2str(R));
      else,
        R=str2num(get(RText,'String'));
        if isempty(R),R=0;set(RText,'String',num2str(R));end
        if R>10,
          R=10;set(RText,'String',num2str(R));
        elseif R<-10,
          R=-10;set(RText,'String',num2str(R));
        end % if >10
        set(RSlide,'Value',R);
      end % if get
    
    %%%%%%%%%%%%%
    %%% Reset %%%
    %%%%%%%%%%%%%
    elseif BtnFlag=='R',
      if rem(P*10,2)==0,P=P-sign(P)*0.2;else,P=P-rem(P*10,2)/10;end
      if rem(Q*10,2)==0,Q=Q-sign(Q)*0.2;else,Q=Q-rem(Q*10,2)/10;end
      if rem(R*10,2)==0,R=R-sign(R)*0.2;else,R=R-rem(R*10,2)/10;end
      set(PSlide,'Value',P);set(PText,'String',num2str(P));
      set(QSlide,'Value',Q);set(QText,'String',num2str(Q));
      set(RSlide,'Value',R);set(RText,'String',num2str(R));
    end % if strcmp
    
    P=P/R2D;Q=Q/R2D;R=R/R2D;
    Psi=Psi/R2D;Theta=Theta/R2D;Phi=Phi/R2D;
         
    Quat=get(QuatText,'UserData');
    QuatRates=[-Q*Quat(3)+P*Quat(4)+R*Quat(2) ...
                P*Quat(3)+Q*Quat(4)-R*Quat(1) ...
                Q*Quat(1)-P*Quat(2)+R*Quat(4) ...
               -P*Quat(1)-Q*Quat(2)-R*Quat(3)
              ]/2;
                
    Quat=Quat+QuatRates;Quat=Quat/norm(Quat);
    Trans=[                                    ...
           1-2*Quat(2)^2-2*Quat(3)^2           ...
           2*(Quat(1)*Quat(2)+Quat(3)*Quat(4)) ...
           2*(Quat(3)*Quat(1)-Quat(2)*Quat(4))
                                               ...
           2*(Quat(1)*Quat(2)-Quat(3)*Quat(4)) ...
           1-2*Quat(3)^2-2*Quat(1)^2           ...
           2*(Quat(2)*Quat(3)+Quat(1)*Quat(4))
                                               ...
           2*(Quat(3)*Quat(1)+Quat(2)*Quat(4)) ...
           2*(Quat(2)*Quat(3)-Quat(1)*Quat(4)) ...
           1-2*Quat(1)^2-2*Quat(2)^2 
          ];

    Phi=atan2(Trans(2,3),Trans(3,3))*R2D;
    Psi=atan2(Trans(1,2),Trans(1,1))*R2D;
    Theta=atan2(-Trans(1,3),norm([Trans(1,1) Trans(1,2)]))*R2D;

    set(PsiSlide,'Value',Psi);
    set(PsiText,'String',num2str(Psi));
      
    set(PhiSlide,'Value',Phi);
    set(PhiText,'String',num2str(Phi));

    set(ThetaSlide,'Value',Theta);
    set(ThetaText,'String',num2str(Theta));
    
    Beta=2*acos(Quat(4))*R2D;
    if Beta==360,
      set([PsiSlide,PhiSlide,BetaSlide],'Value',0);
      set([PsiText,PhiText,ThetaText],'String',num2str(0));
      Beta=0;
    end
     
    if Beta==0,
      Azimuth=0;Elevation=0;
    else,
      CosBetaOver2=Quat(4);
      SinBetaOver2=sqrt(1-CosBetaOver2^2);
      L1=Quat(1)/SinBetaOver2;
      L2=Quat(2)/SinBetaOver2;
      L3=Quat(3)/SinBetaOver2;
      Azimuth=atan2(L2,L1)*R2D;
      Elevation=acos(L3/norm([L1 L2 L3]))*R2D;
    end % if Beta
    set(BetaSlide,'Value',Beta);set(BetaText,'String',num2str(Beta));
    set(AzimuthSlide,'Value',Azimuth);
    set(AzimuthText,'String',num2str(Azimuth));
    set(ElevationSlide,'Value',Elevation);
    set(ElevationText,'String',num2str(Elevation));

    if P==0 & Q==0 & R==0,
      set(ResetHandle,'Enable','off');
    else,
      set(ResetHandle,'Enable','on');
    end % if P
  end % if DynFlag

  set(QuatText,'UserData',Quat);
  set(ResetHandle,'UserData',BtnFlag);
  
  %%%%%%%%%%%%%%%%%%%%%%%%%%
  %%% Begin Drawing Loop %%%
  %%%%%%%%%%%%%%%%%%%%%%%%%%
  DrawFlag=get(DynamicButton,'UserData');
  
  if DrawFlag~=1,return;end
  DrawFlag=0;
  
  while ~DrawFlag,
  
    BtnFlag=get(ResetHandle,'UserData');
    
    Psi=get(PsiSlide,'Value');
    Theta=get(ThetaSlide,'Value');
    Phi=get(PhiSlide,'Value');
    
    Beta=get(BetaSlide,'Value');
    Azimuth=get(AzimuthSlide,'Value'); 
    Elevation=get(ElevationSlide,'Value');
    
    P=get(PSlide,'Value');
    Q=get(QSlide,'Value');
    R=get(RSlide,'Value');
    
    Quat=get(QuatText,'UserData');
    set(QuatText,'String',mat2str(Quat,2));
    set(DynamicButton,'UserData',1);
  
    %%%%%%%%%%%%%% The majority of the following code takes care of the
    %%%%%%%%%%%%%% Painter's bug
    PlaneBodyHandle=PlaneHandles(1);
    BodyData=get(PlaneBodyHandle,'UserData');
    Nose=BodyData(:,1);
    RightTail=BodyData(:,2);
    LeftTail=BodyData(:,3);
    BodyNorm=cross(LeftTail-RightTail,Nose-LeftTail);
    BodyUnitNorm=BodyNorm/norm(BodyNorm);
    %%% Convert BodyUnitNorm to Screen Coordinates
  
    %%% Determine the unit normal direction to the screen of the body unit norm
    %%% i.e. Transform the body to boresight coords and determine if above or
    %%% below
    ViewAngles=get(QuatAxes,'View');
    ViewAzimuth=ViewAngles(1)/R2D;ViewElevation=ViewAngles(2)/R2D;
    TransE2S=[0 1 0;1 0 0;0 0 -1];
    ScreenUnitNorm=TransE2S*Trans'*BodyUnitNorm;
  
    ViewNorm=[cos(ViewElevation)*sin(ViewAzimuth) 
             -cos(ViewElevation)*cos(ViewAzimuth) 
              sin(ViewElevation)];

    [BodyUnitNorm ScreenUnitNorm ViewNorm [dot(ScreenUnitNorm,ViewNorm);0;0]];
    
    DrawnPlaneHandles=findobj(QuatAxes,'Type','patch');
    if dot(ScreenUnitNorm,ViewNorm)>0,
      DrawOrder=PlaneHandles([2 1]);
    else,
      DrawOrder=PlaneHandles;
    end
    
    % Do a check to see if the drawn plane handles stacking order gets changed
    if all(DrawnPlaneHandles==PlaneHandles'),
      DrawOrder=DrawOrder([2 1]);%disp('Restacking')
    end
    %%% Draw Everything
    CosBetaOver2=Quat(4);
    SinBetaOver2=sqrt(1-CosBetaOver2^2);
    if SinBetaOver2==0,SinBetaOver2=1;end
    L1=Quat(1)/SinBetaOver2;
    L2=Quat(2)/SinBetaOver2;
    L3=Quat(3)/SinBetaOver2;
    set(PointerHandle,'XData',[0  L2*80],'YData',[0  L1*80],'ZData',[0 -L3*80]);

    for lp=1:length(PlaneHandles),
      NewData=TransE2S'*Trans'*get(DrawOrder(lp),'UserData');
      set(PlaneHandles(lp), ...
         'XData',NewData(1,:), ...
         'YData',NewData(2,:), ...
         'ZData',NewData(3,:)  ...
         );
    end % for lp
  
    %%%%%%%%%%%%%%
    %%% Static %%%
    %%%%%%%%%%%%%%
    if nargin~=4,
      if DynFlag==0,
        if Beta==0|Beta==360,
          set([AzimuthSlide ElevationSlide BetaSlide],'Value',0,'Enable','off');
          set([AzimuthText ElevationText BetaText], ...
             'String',num2str(0),'Enable','off');
          set(ResetHandle,'Enable','off');
          set([PsiSlide,PhiSlide,BetaSlide],'Value',0);
          set([PsiText,PhiText,ThetaText],'String',num2str(0));
        else,
          set([AzimuthSlide AzimuthText ElevationSlide ElevationText ...
               BetaSlide BetaText ResetHandle],'Enable','on');
        end % if Beta
      
        if strcmp(Action,'#Reset'),
          if Beta~=0,
            if rem(Beta,5)==0,
              Beta=Beta-5;
            else,
              Beta=Beta-rem(Beta,5);
            end
            set(BetaSlide,'Value',Beta);
            set(BetaText,'String',num2str(Beta));
            if Beta==0,Azimuth=0;Elevation=0;end
      
            LTemp=[get(PointerHandle,'XData')
                   get(PointerHandle,'YData')
                   get(PointerHandle,'ZData')];
               
            TransE2S=[0 1 0;1 0 0;0 0 -1];
            L=LTemp(:,2);L=TransE2S*L/norm(L);
            Quat=[L'*sin(Beta/R2D/2) cos(Beta/R2D/2)];
            Trans=[                                    ...
                   1-2*Quat(2)^2-2*Quat(3)^2           ...
                   2*(Quat(1)*Quat(2)+Quat(3)*Quat(4)) ...
                   2*(Quat(3)*Quat(1)-Quat(2)*Quat(4))
                   2*(Quat(1)*Quat(2)-Quat(3)*Quat(4)) ...
                   1-2*Quat(3)^2-2*Quat(1)^2           ...
                   2*(Quat(2)*Quat(3)+Quat(1)*Quat(4))
                   2*(Quat(3)*Quat(1)+Quat(2)*Quat(4)) ...
                   2*(Quat(2)*Quat(3)-Quat(1)*Quat(4)) ...
                   1-2*Quat(1)^2-2*Quat(2)^2 
                  ];

            Phi=atan2(Trans(2,3),Trans(3,3))*R2D;
            Psi=atan2(Trans(1,2),Trans(1,1))*R2D;
            Theta=atan2(-Trans(1,3),norm([Trans(1,1) Trans(1,2)]))*R2D;
      
            set(PsiSlide,'Value',Psi);
            set(PsiText,'String',num2str(Psi));
        
            set(PhiSlide,'Value',Phi);
            set(PhiText,'String',num2str(Phi));

            set(ThetaSlide,'Value',Theta);
            set(ThetaText,'String',num2str(Theta));
            set(QuatText,'UserData',Quat);
          
            set(DynamicButton,'UserData',0);
          end % if Beta ~=0
        end % if strcmp
      %%%%%%%%%%%%%%%
      %%% Dynamic %%%
      %%%%%%%%%%%%%%%
      elseif DynFlag==1,
        if ~(P==0 & Q==0 & R==0),
          set(DynamicButton,'UserData',0);
          
          if BtnFlag=='R',
            if rem(P*10,2)==0,P=P-sign(P)*0.2;else,P=P-rem(P*10,2)/10;end
            if rem(Q*10,2)==0,Q=Q-sign(Q)*0.2;else,Q=Q-rem(Q*10,2)/10;end
            if rem(R*10,2)==0,R=R-sign(R)*0.2;else,R=R-rem(R*10,2)/10;end
            set(PSlide,'Value',P);set(PText,'String',num2str(P));
            set(QSlide,'Value',Q);set(QText,'String',num2str(Q));
            set(RSlide,'Value',R);set(RText,'String',num2str(R));
          end % if BtnFlag
        
          P=P/R2D;Q=Q/R2D;R=R/R2D;
          Psi=Psi/R2D;Theta=Theta/R2D;Phi=Phi/R2D;
          Quat=get(QuatText,'UserData');
          QuatRates=[-Q*Quat(3)+P*Quat(4)+R*Quat(2) ...
                      P*Quat(3)+Q*Quat(4)-R*Quat(1) ...
                      Q*Quat(1)-P*Quat(2)+R*Quat(4) ...
                     -P*Quat(1)-Q*Quat(2)-R*Quat(3)
                    ]/2;
                
          Quat=Quat+QuatRates;Quat=Quat/norm(Quat);
          Trans=[                                    ...
                 1-2*Quat(2)^2-2*Quat(3)^2           ...
                 2*(Quat(1)*Quat(2)+Quat(3)*Quat(4)) ...
                 2*(Quat(3)*Quat(1)-Quat(2)*Quat(4))
                 2*(Quat(1)*Quat(2)-Quat(3)*Quat(4)) ...
                 1-2*Quat(3)^2-2*Quat(1)^2           ...
                 2*(Quat(2)*Quat(3)+Quat(1)*Quat(4))
                 2*(Quat(3)*Quat(1)+Quat(2)*Quat(4)) ...
                 2*(Quat(2)*Quat(3)-Quat(1)*Quat(4)) ...
                 1-2*Quat(1)^2-2*Quat(2)^2 
                ];  

 
          Phi=atan2(Trans(2,3),Trans(3,3))*R2D;
          Psi=atan2(Trans(1,2),Trans(1,1))*R2D;
          Theta=atan2(-Trans(1,3),norm([Trans(1,1) Trans(1,2)]))*R2D;
      
          set(PsiSlide,'Value',Psi);
          set(PsiText,'String',num2str(Psi));
      
          set(PhiSlide,'Value',Phi);
          set(PhiText,'String',num2str(Phi));

          set(ThetaSlide,'Value',Theta);
          set(ThetaText,'String',num2str(Theta));
    
          Beta=2*acos(Quat(4))*R2D;
          if Beta==360,
            set([PsiSlide,PhiSlide,BetaSlide],'Value',0);
            set([PsiText,PhiText,ThetaText],'String',num2str(0));
            Beta=0;
          end
     
          if Beta==0,
            Azimuth=0;Elevation=0;
          else,
            CosBetaOver2=Quat(4);
            SinBetaOver2=sqrt(1-CosBetaOver2^2);
            L1=Quat(1)/SinBetaOver2;
            L2=Quat(2)/SinBetaOver2;
            L3=Quat(3)/SinBetaOver2;
            Azimuth=atan2(L2,L1)*R2D;
            Elevation=acos(L3/norm([L1 L2 L3]))*R2D;
          end % if Beta
          set(BetaSlide,'Value',Beta);set(BetaText,'String',num2str(Beta));
          set(AzimuthSlide,'Value',Azimuth);
          set(AzimuthText,'String',num2str(Azimuth));
          set(ElevationSlide,'Value',Elevation);
          set(ElevationText,'String',num2str(Elevation));

          if P==0 & Q==0 & R==0,
            set(ResetHandle,'Enable','off');
            set(DynamicButton,'UserData',1);
          else,
            set(ResetHandle,'Enable','on');
          end % if P
          set(QuatText,'UserData',Quat);
        end % if P
      end % if DynFlag
    
      drawnow;
      if ~ishandle(QuatFig),return;end
      DrawFlag=get(DynamicButton,'UserData');
    else,
      DrawFlag=1;
    end % if nargin~=4
  end % while ~DrawFlag
  set(DynamicButton,'UserData',1);

%%%%%%%%%%%%%%%%%%
%%% Initialize %%%
%%%%%%%%%%%%%%%%%%
elseif nargin==0|nargin==3,
  if nargin==3,
    SimHandle=get_param(gcb,'Handle');
    SimHandleNest=get_param([gcb,'/eulrotds'],'Handle');
    FigHandles=get(0,'Children');
    NumFigHandles=length(FigHandles);
    QuatFig=[];
    for lp=1:NumFigHandles,
      if strcmp(get(FigHandles(lp),'Tag'),'QuatWorkingFig'), 
        QuatFig=FigHandles(lp);
        set_param(SimHandleNest,'Parameters',num2str(QuatFig));
        return;
      end %if any
    end %for lp
  end % if nargin
  
  %%% General Info. 
  Black      =[0       0        0      ]/255;
  LightGray  =[192     192      192    ]/255;
  LightGray2 =[160     160      164    ]/255;
  MediumGray =[128     128      128    ]/255;
  White      =[255     255      255    ]/255;

  %%% Set Positions
  FigPos=get(0,'DefaultFigurePosition');
  FigWidth=600;
  FigHeight=500;
  FigPos(1:2)=FigPos(1:2)-[FigWidth FigHeight]/4;
  FigPos(3:4)=[FigWidth FigHeight];

  DefOffset=8;
  SmallOffset=2;

  SliderWidth=120;
  TextWidth=30;
  NameWidth=65;
  UIHeight=20;
  FigColor=LightGray2;
  UIBackColor=LightGray;
  UIForeColor=Black;
  
  RotCallback=str2mat('#Psi','#Theta','#Phi','#Azimuth','#Elevation', ...
                      '#Beta','#P','#Q','#R');
  RotUnit=str2mat('Deg','Deg','Deg','Deg','Deg','Deg','Deg/Frm', ...
                  'Deg/Frm','Deg/Frm');
  RotMin=[-180 -90 -180 -360 -180   0   -10 -10 -10];
  RotMax=[ 180  90  180  360  180   360  10  10  10];
  RotVal=[   0    0    0  0    0     0     0   0   0];
  RotType=str2mat('Yaw','Pitch','Roll','Azimuth','Elevation', ...
                  'Beta','P (Roll)','Q (Pitch)','R (Yaw)');
  RotFlag=['E';'E';'E';'C';'C';'B';'P';'Q';'S'];
  
  NumInputs=size(RotType,1);
  InputPos=zeros(NumInputs,4);
  CombHeight=2*UIHeight+DefOffset;
  
  InputPos(NumInputs,1:2)=[0 ...
                       FigHeight-NumInputs*CombHeight-2*UIHeight-2*DefOffset];
  for lp=NumInputs-1:-1:1,
    InputPos(lp,:)=InputPos(lp+1,:)+[0 CombHeight 0 0];
  end
  
  InputPos(1:3,2)=InputPos(1:3,2)+UIHeight;

  InputPos(4:6,2)=InputPos(4:6,2)-2*UIHeight-DefOffset;
  InputPos(6,2)=InputPos(6,2)-DefOffset-UIHeight;

  InputPos(7:9,:)=InputPos(1:3,:);
  
  InPos=zeros(6,4);
  InPos(1,:)=[TextWidth 0 SliderWidth UIHeight];
  InPos(2,:)=[InPos(1,1)+2*DefOffset UIHeight SliderWidth-6*DefOffset UIHeight];
  InPos(3,:)=[InPos(1,1)-NameWidth-SmallOffset UIHeight NameWidth UIHeight];
  InPos(4,:)=[InPos(2,1)+InPos(2,3)+SmallOffset UIHeight NameWidth UIHeight];
  InPos(5,:)=[InPos(1,1)-TextWidth-SmallOffset 0 TextWidth UIHeight];%Low
  InPos(6,:)=[InPos(1,1)+InPos(1,3)+SmallOffset 0 TextWidth UIHeight];% High
  
  CombWidth=sum(InPos([2 3 4],3));
  InputPos(:,1)=ones(size(InputPos,1),1)*FigWidth-CombWidth-DefOffset;

  QPos=zeros(2,4);
  QPos(1,:)=[InputPos(1,1) InputPos(4,2)+2*InPos(4,4)+DefOffset ...
             InPos(6,1)+InPos(6,3)-DefOffset UIHeight];
  QPos(2,:)=[QPos(1,1)-TextWidth QPos(1,2) TextWidth UIHeight];

  FramePos=zeros(4,4);
  FramePos(1,1)=InputPos(6,1)+InPos(3,1)-SmallOffset;
  FramePos(1,2)=InputPos(6,2)-DefOffset;
  FramePos(1,3)=CombWidth+2*SmallOffset+3*DefOffset;
  FramePos(1,4)=CombHeight*3+2*UIHeight+3*DefOffset+QPos(1,4);
  FramePos(2,1)=FramePos(1,1);
  FramePos(2,2)=InputPos(3,2)-DefOffset;
  FramePos(2,3)=FramePos(1,3);
  FramePos(2,4)=3*CombHeight+2*DefOffset+UIHeight;

  TextPos=zeros(2,4);
  TextPos(1,:)=[FramePos(1,1)+DefOffset                          ...
                FramePos(1,2)+FramePos(1,4)-UIHeight-SmallOffset ...
                FramePos(1,3)-2*DefOffset                        ...
                UIHeight];
  TextPos(2,:)=[FramePos(2,1)+DefOffset                          ...
                FramePos(2,2)+FramePos(2,4)-UIHeight-SmallOffset ...
                FramePos(2,3)-2*DefOffset                        ...
                UIHeight];
  
  UIWidth=80;UIHeight=30;
  
  FramePos(3,:)=[FramePos(1,1) DefOffset FramePos(1,3) UIHeight+2*DefOffset];
  FramePos(4,:)=[2*DefOffset FramePos(3,2) ...
                 FramePos(1,1)-4*DefOffset FramePos(3,4)]; 
  ResetPos=[FramePos(4,1)+DefOffset FramePos(4,2)+DefOffset ...
            UIWidth UIHeight];
  DynamicPos=[FramePos(4,1)+FramePos(4,3)-2*(UIWidth+DefOffset) FramePos(4,2)+DefOffset ...
              UIWidth UIHeight];
  StaticPos=DynamicPos+[DynamicPos(3)+DefOffset 0 0 0];
   
  HelpPos=[FramePos(3,1)+(FramePos(3,3)-2*UIWidth-2*DefOffset)/2 ...
           FramePos(3,2)+DefOffset UIWidth UIHeight];
  ClosePos=[HelpPos(1)+HelpPos(3)+2*DefOffset HelpPos(2) UIWidth UIHeight];
  
  AxesPos(1:2)=[FramePos(4,1) sum(FramePos(4,[2 4]))+DefOffset];
  AxesPos(3:4)=[FramePos(4,3) FigHeight-3*DefOffset-AxesPos(2)];
               
  %%% Create InputFig 
  Title='Quaternion Demonstration';
  QuatFig=figure( ...
                'BackingStore','off'           , ...
                'Color'       , FigColor       , ...
                'MenuBar'     ,'none'          , ...
                'Name'        ,Title           , ...
                'NumberTitle' ,'off'           , ...
                'Pointer'     ,'arrow'         , ...
                'Units'       ,'pixels'        , ...
                'Position'    ,FigPos          , ...
                'Tag'         ,'QuatWorkingFig', ...
                'Visible'     ,'off'             ...
                ); 
                 
  %%% Create axes
  QuatAxes=axes( ...
               'AspectRatio',[1 NaN]          , ...
               'Box'        ,'on'             , ...
               'Color'      ,Black            , ...
               'DrawMode'   ,'fast'           , ...
               'NextPlot'   ,'add'            , ...
               'Units'      ,'pixels'         , ...
               'Position'   ,AxesPos          , ...
               'Visible'    ,'on'             , ...
               'XLim'       ,[-100 100]       , ...
               'XTick'      ,[]               , ...
               'YLim'       ,[-100 100]       , ...
               'YTick'      ,[]               , ...
               'ZLim'       ,[-100 100]       , ...
               'ZTick'      ,[]               , ...
               'View'       ,[10 10  ]        , ...
               'Tag'        ,'Quaternion Axes'  ...
               );
  
  frot3d
 
  Frames=zeros(1,4);
  for lp=1:size(FramePos,1),
     Frames(lp)=uicontrol(QuatFig             , ...
                         'BackGroundColor'    ,UIBackColor           , ...
                         'ForeGroundColor'    ,UIForeColor           , ...
                         'Units'              ,'pixels'              , ...
                         'Position'           ,FramePos(lp,:)        , ...
                         'Style'              ,'frame'               , ...
                         'Visible'            ,'on'                  , ...
                         'Tag'                ,['Frame ' num2str(lp)]  ...
                         );
  end % for lp

  CBString='quatdemo #Help';
  HelpHandle=uicontrol(QuatFig             , ...
                      'BackGroundColor'    ,UIBackColor   , ...
                      'Callback'           ,CBString      , ...
                      'ForeGroundColor'    ,UIForeColor   , ...
                      'Units'              ,'pixels'      , ...
                      'Position'           ,HelpPos       , ...
                      'Enable'             ,'on'          , ...
                      'Style'              ,'pushbutton'  , ...
                      'String'             ,'Info'        , ...
                      'HorizontalAlignment','center'      , ...
                      'Visible'            ,'on'          , ...
                      'Tag'                ,'Help Button'   ...
                      );
  CBString='quatdemo(''#Close'')';
  CloseHandle=uicontrol(QuatFig             , ...
                       'BackGroundColor'    ,UIBackColor   , ...
                       'Callback'           ,CBString      , ...
                       'ForeGroundColor'    ,UIForeColor   , ...
                       'Units'              ,'pixels'      , ...
                       'Position'           ,ClosePos      , ...
                       'Enable'             ,'on'          , ...
                       'Style'              ,'pushbutton'  , ...
                       'String'             ,'Close'       , ...
                       'HorizontalAlignment','center'      , ...
                       'Visible'            ,'on'          , ...
                       'Tag'                ,'Close Button'  ...
                       );
  CBString='quatdemo(''#Reset'',''R'')';
  ResetHandle=uicontrol(QuatFig             , ...
                       'BackGroundColor'    ,UIBackColor   , ...
                       'Callback'           ,CBString      , ...
                       'ForeGroundColor'    ,UIForeColor   , ...
                       'Units'              ,'pixels'      , ...
                       'Position'           ,ResetPos      , ...
                       'Enable'             ,'off'         , ...
                       'Style'              ,'pushbutton'  , ...
                       'String'             ,'Reset'       , ...
                       'HorizontalAlignment','center'      , ...
                       'Visible'            ,'on'          , ...
                       'Tag'                ,'Reset Button'  ...
                       );
  CBString='quatdemo #StatDyn';
  DynHandle=uicontrol(QuatFig             , ...
                     'BackGroundColor'    ,UIBackColor     , ...
                     'Callback'           ,CBString        , ...
                     'ForeGroundColor'    ,UIForeColor     , ...
                     'Units'              ,'pixels'        , ...
                     'Position'           ,DynamicPos      , ...
                     'Enable'             ,'on'            , ...
                     'Style'              ,'radiobutton'   , ...
                     'String'             ,'Dynamic'       , ...
                     'HorizontalAlignment','center'        , ...
                     'UserData'           ,1               , ...
                     'Value'              ,0               , ...
                     'Visible'            ,'on'            , ...
                     'Tag'                ,'Dynamic Button'  ...
                     );
  StatHandle=uicontrol(QuatFig             , ...
                      'BackGroundColor'    ,UIBackColor     , ...
                      'Callback'           ,CBString        , ...
                      'ForeGroundColor'    ,UIForeColor     , ...
                      'Units'              ,'pixels'        , ...
                      'Position'           ,StaticPos       , ...
                      'Enable'             ,'on'            , ...
                      'Style'              ,'radiobutton'   , ...
                      'String'             ,'Static'        , ...
                      'HorizontalAlignment','center'        , ...
                      'Value'              ,1               , ...
                      'Visible'            ,'on'            , ...
                      'Tag'                ,'Static Button'   ...
                      );

  comp=computer;
  if strcmp(lower(comp(1:2)),'pc')|strcmp(lower(comp(1:3)),'mac'),
    set([DynHandle,StatHandle],'Visible','off');
  end % if ~

  InHandle=zeros(1,NumInputs*2);
  for lp=1:NumInputs,
    CBString=['quatdemo(''' deblank(RotCallback(lp,:)) ...
              ''',''' RotFlag(lp) ''');'];
    Base=(lp-1)*6;
    InHandle(Base+1)=uicontrol(QuatFig         , ...
                              'BackGroundColor',UIBackColor              , ...
                              'Callback'       ,CBString                 , ...
                              'ForeGroundColor',UIForeColor              , ...
                              'Max'            ,RotMax(lp)               , ...
                              'Min'            ,RotMin(lp)               , ...
                              'Units'          ,'pixels'                 , ...
                              'Position'       ,InputPos(lp,:)+InPos(1,:), ...
                              'Enable'         ,'on'                     , ...
                              'Style'          ,'slider'                 , ...
                              'Value'          ,RotVal(lp)               , ...
                              'Visible'        ,'on'                     , ...
                              'Tag'            ,[RotType(lp,:) ' Slider']  ...
                              );
                              
    InHandle(Base+2)=uicontrol(QuatFig         , ...
                              'BackGroundColor',White                    , ...
                              'Callback'       ,CBString                 , ...
                              'ForeGroundColor',UIForeColor              , ...
                              'HorizontalAlignment','left'               , ...
                              'Units'          ,'pixels'                 , ...
                              'Position'       ,InputPos(lp,:)+InPos(2,:), ...
                              'Enable'         ,'on'                     , ...
                              'Style'          ,'edit'                   , ...
                              'String'         ,num2str(RotVal(lp))      , ...
                              'Visible'        ,'on'                     , ...
                              'Tag'            ,[RotType(lp,:) ' Edit']    ...
                              );
                              
   InHandle(Base+3)=uicontrol(QuatFig         , ...
                             'BackGroundColor',UIBackColor              , ...
                             'ForeGroundColor',UIForeColor              , ...
                             'HorizontalAlignment','right'              , ...
                             'Units'          ,'pixels'                 , ...
                             'Position'       ,InputPos(lp,:)+InPos(3,:), ...
                             'Enable'         ,'on'                     , ...
                             'String'         ,deblank(RotType(lp,:))   , ...
                             'Style'          ,'text'                   , ...
                             'Visible'        ,'on'                     , ...
                             'Tag'            ,[RotType(lp,:) ' Text']    ...
                             );
                 
   InHandle(Base+4)=uicontrol(QuatFig         , ...
                             'BackGroundColor',UIBackColor              , ...
                             'ForeGroundColor',UIForeColor              , ...
                             'HorizontalAlignment','left'               , ...
                             'Units'          ,'pixels'                 , ...
                             'Position'       ,InputPos(lp,:)+InPos(4,:), ...
                             'Enable'         ,'on'                     , ...
                             'String'         ,deblank(RotUnit(lp,:))   , ...
                             'Style'          ,'text'                   , ...
                             'Visible'        ,'on'                     , ...
                             'Tag'            ,[RotType(lp,:) 'Unit'   ]  ...
                             );
   InHandle(Base+5)=uicontrol(QuatFig         , ...
                 'BackGroundColor',UIBackColor              , ...
                 'ForeGroundColor',UIForeColor              , ...
                 'HorizontalAlignment','right'              , ...
                 'Units'          ,'pixels'                 , ...
                 'Position'       ,InputPos(lp,:)+InPos(5,:), ...
                 'Enable'         ,'on'                     , ...
                 'String'         ,num2str(RotMin(lp))      , ...
                 'Style'          ,'text'                   , ...
                 'Visible'        ,'on'                     , ...
                 'Tag'            ,[RotType(lp,:) '-360']     ...
                 );
   InHandle(Base+6)=uicontrol(QuatFig         , ...
                             'BackGroundColor',UIBackColor              , ...
                             'ForeGroundColor',UIForeColor              , ...
                             'HorizontalAlignment','left'               , ...
                             'Units'          ,'pixels'                 , ...
                             'Position'       ,InputPos(lp,:)+InPos(6,:), ...
                             'Enable'         ,'on'                     , ...
                             'String'         ,num2str(RotMax(lp))      , ...
                             'Style'          ,'text'                   , ...
                             'Visible'        ,'on'                     , ...
                             'Tag'            ,[RotType(lp,:) ' 360']     ...
                             );
 
  end % for lp
  
  set(InHandle([19 20 25 26 31 32]),'Enable','off');
  set(InHandle(37:54),'Visible','off');
  QuatHandle=uicontrol(QuatFig         , ...
                      'BackGroundColor',UIBackColor         , ...
                      'ForeGroundColor',UIForeColor         , ...
                      'HorizontalAlignment','left'          , ...
                      'Units'          ,'pixels'            , ...
                      'Position'       ,QPos(1,:)           , ...
                      'Enable'         ,'on'                , ...
                      'String'         ,mat2str([0 0 0 1],2), ...
                      'Style'          ,'text'              , ...
                      'UserData'       ,[0 0 0 1]           , ...
                      'Visible'        ,'on'                , ...
                      'Tag'            ,'QuatVals'            ...
                      );
   Junk=uicontrol(QuatFig         , ...
                 'BackGroundColor',UIBackColor, ...
                 'ForeGroundColor',UIForeColor, ...
                 'HorizontalAlignment','right', ...
                 'Units'          ,'pixels'   , ...
                 'Position'       ,QPos(2,:)  , ...
                 'Enable'         ,'on'       , ...
                 'String'         ,'Q = '     , ...
                 'Style'          ,'text'     , ...
                 'Visible'        ,'on'       , ...
                 'Tag'            ,'QuatText'   ...
                 );

   Junk=uicontrol(QuatFig         , ...
                 'BackGroundColor',UIBackColor                , ...
                 'ForeGroundColor',UIForeColor                , ...
                 'HorizontalAlignment','center'               , ...
                 'Units'          ,'pixels'                   , ...
                 'Position'       ,TextPos(1,:)               , ...
                 'String'         ,'Quaternion Representation', ...
                 'Style'          ,'text'                     , ...
                 'Visible'        ,'on'                       , ...
                 'Tag'            ,'Quaternion Text'            ...
                 );
   EulText=uicontrol(QuatFig         , ...
                    'BackGroundColor',UIBackColor   , ...
                    'ForeGroundColor',UIForeColor   , ...
                    'HorizontalAlignment','center'  , ...
                    'Units'          ,'pixels'      , ...
                    'Position'       ,TextPos(2,:)  , ...
                    'String'         ,'Euler Angles', ...
                    'Style'          ,'text'        , ...
                    'Visible'        ,'on'          , ...
                    'Tag'            ,'Euler Text'    ...
                    );

  set(findobj(QuatFig),'Units','normalized');
  
  ArrowLineX=[ 0 90  80 90 80 
               0  0   0  0  0
               0  0  -5  0  5
             ]';
  ArrowLineY=[ 0  0  -5  0  5 
               0 90  80 90 80
               0  0   0  0  0
             ]';
  ArrowLineZ=[ 0   0   0   0   0
               0   0  -5   0   5
               0  90  80  90  80
             ]';

  LineHandles=plot3(ArrowLineY,ArrowLineX,-ArrowLineZ,'w','LineWidth',2);
  LineText(1)=text(0,100,0,'North','Color',[1 1 1]);
  LineText(2)=text(92,0,0,'East','Color',[1 1 1]);
  LineText(3)=text(0,0,-100,'Down','Color',[1 1 1]);

  PointerHandle=plot3(0,0,0,'b' , ...
                     'LineWidth',3                                        , ...
                     'UserData' , ...
                     [ArrowLineX(:,3)';ArrowLineY(:,3)';ArrowLineZ(:,3)']   ...
                     );
  PlaneX=[75  40
           0   0 
           0   0
         ];
  PlaneY=[ 0   0 
          30   0 
         -30   0
         ];
  PlaneZ=[ 0   0
           0   0
           0 -20
         ];
  
  for lp=1:size(PlaneX,2),
    PlaneHandles(lp)=patch(PlaneY(:,lp),PlaneX(:,lp),-PlaneZ(:,lp),[1 0 0], ...
                           'LineWidth',1      , ...
                           'EdgeColor',[0 0 0]  ...
                           );
    set(PlaneHandles(lp), ...
       'UserData',[PlaneX(:,lp)';PlaneY(:,lp)';PlaneZ(:,lp)'] ...
       )
  end
  
  UsData=[PlaneHandles PointerHandle QuatAxes ResetHandle ...
          InHandle QuatHandle StatHandle DynHandle EulText Frames];
          
  if nargin==3,    
    set_param(SimHandleNest,'parameters',num2str(QuatFig));
    UsData=[UsData SimHandle];
  end
  
  set(QuatFig,'Visible','on','UserData',UsData);
    
  set(findobj(QuatFig),'Interruptible','yes');
end % if nargin
