function [ret,x0,str,ts,xts]=simquat(t,x,u,flag);
%SIMQUAT	is the M-file description of the SIMULINK system named SIMQUAT.
%	The block-diagram can be displayed by typing: SIMQUAT.
%
%	SYS=SIMQUAT(T,X,U,FLAG) returns depending on FLAG certain
%	system values given time point, T, current state vector, X,
%	and input vector, U.
%	FLAG is used to indicate the type of output to be returned in SYS.
%
%	Setting FLAG=1 causes SIMQUAT to return state derivatives, FLAG=2
%	discrete states, FLAG=3 system outputs and FLAG=4 next sample
%	time. For more information and other options see SFUNC.
%
%	Calling SIMQUAT with a FLAG of zero:
%	[SIZES]=SIMQUAT([],[],[],0),  returns a vector, SIZES, which
%	contains the sizes of the state vector and other parameters.
%		SIZES(1) number of states
%		SIZES(2) number of discrete states
%		SIZES(3) number of outputs
%		SIZES(4) number of inputs
%		SIZES(5) number of roots (currently unsupported)
%		SIZES(6) direct feedthrough flag
%		SIZES(7) number of sample times
%
%	For the definition of other parameters in SIZES, see SFUNC.
%	See also, TRIM, LINMOD, LINSIM, EULER, RK23, RK45, ADAMS, GEAR.

% Note: This M-file is only used for saving graphical information;
%       after the model is loaded into memory an internal model
%       representation is used.

% the system will take on the name of this mfile:
sys = mfilename;
new_system(sys)
simver(1.3)
if (0 == (nargin + nargout))
     set_param(sys,'Location',[19,55,636,339])
     open_system(sys)
end;
set_param(sys,'algorithm',     'RK-45')
set_param(sys,'Start time',    '0.0')
set_param(sys,'Stop time',     '999999')
set_param(sys,'Min step size', '0.1')
set_param(sys,'Max step size', '1')
set_param(sys,'Relative error','1e-3')
set_param(sys,'Return vars',   '')
set_param(sys,'AssignWideVectorLines','on');

add_block('built-in/Note',[sys,'/',['Units:',13,'Degrees//Second']])
set_param([sys,'/',['Units:',13,'Degrees//Second']],...
		'Font Weight','bold',...
		'position',[85,30,90,35])

add_block('built-in/Constant',[sys,'/','Q (Pitch Rate)'])
set_param([sys,'/','Q (Pitch Rate)'],...
		'Value','0',...
		'position',[80,130,100,150])

add_block('built-in/Constant',[sys,'/','P (Roll Rate)'])
set_param([sys,'/','P (Roll Rate)'],...
		'Value','18',...
		'position',[80,85,100,105])

add_block('built-in/Constant',[sys,'/','R (Yaw Rate)'])
set_param([sys,'/','R (Yaw Rate)'],...
		'Value','0',...
		'position',[80,175,100,195])


%     Subsystem  ['Quaternion',13,'Calculation'].

new_system([sys,'/',['Quaternion',13,'Calculation']])
set_param([sys,'/',['Quaternion',13,'Calculation']],'Location',[67,512,552,748])

add_block('built-in/Mux',[sys,'/',['Quaternion',13,'Calculation/Mux']])
set_param([sys,'/',['Quaternion',13,'Calculation/Mux']],...
		'hide name',0,...
		'inputs','3',...
		'position',[140,63,170,177])

add_block('built-in/Inport',[sys,'/',['Quaternion',13,'Calculation/P (Roll Rate)']])
set_param([sys,'/',['Quaternion',13,'Calculation/P (Roll Rate)']],...
		'Drop Shadow',4,...
		'position',[75,70,95,90])

add_block('built-in/Inport',[sys,'/',['Quaternion',13,'Calculation/R (Yaw Rate)']])
set_param([sys,'/',['Quaternion',13,'Calculation/R (Yaw Rate)']],...
		'Drop Shadow',4,...
		'Port','3',...
		'position',[75,150,95,170])

add_block('built-in/Inport',[sys,'/',['Quaternion',13,'Calculation/Q Pitch Rate)']])
set_param([sys,'/',['Quaternion',13,'Calculation/Q Pitch Rate)']],...
		'Drop Shadow',4,...
		'Port','2',...
		'position',[75,110,95,130])

add_block('built-in/Note',[sys,'/',['Quaternion',13,'Calculation/Units:',13,'Degrees//Second']])
set_param([sys,'/',['Quaternion',13,'Calculation/Units:',13,'Degrees//Second']],...
		'Font Weight','bold',...
		'position',[90,25,95,30])

add_block('built-in/Note',[sys,'/',['Quaternion',13,'Calculation/Units:',13,'Degrees']])
set_param([sys,'/',['Quaternion',13,'Calculation/Units:',13,'Degrees']],...
		'Font Weight','bold',...
		'position',[400,20,405,25])

add_block('built-in/Demux',[sys,'/',['Quaternion',13,'Calculation/Demux']])
set_param([sys,'/',['Quaternion',13,'Calculation/Demux']],...
		'hide name',0,...
		'outputs','3',...
		'position',[300,60,350,180])

add_block('built-in/S-Function',[sys,'/',['Quaternion',13,'Calculation/Initial Conditions:',13,'Psi,Theta, Phi']])
set_param([sys,'/',['Quaternion',13,'Calculation/Initial Conditions:',13,'Psi,Theta, Phi']],...
		'function name','eulrot',...
		'parameters','Psi,Theta,Phi',...
		'position',[210,110,260,130])

add_block('built-in/Outport',[sys,'/',['Quaternion',13,'Calculation/Psi (Heading)']])
set_param([sys,'/',['Quaternion',13,'Calculation/Psi (Heading)']],...
		'Drop Shadow',4,...
		'position',[395,70,415,90])

add_block('built-in/Outport',[sys,'/',['Quaternion',13,'Calculation/Theta (Pitch)']])
set_param([sys,'/',['Quaternion',13,'Calculation/Theta (Pitch)']],...
		'Drop Shadow',4,...
		'Port','2',...
		'position',[395,110,415,130])

add_block('built-in/Outport',[sys,'/',['Quaternion',13,'Calculation/Phi (Roll)']])
set_param([sys,'/',['Quaternion',13,'Calculation/Phi (Roll)']],...
		'Drop Shadow',4,...
		'Port','3',...
		'position',[395,150,415,170])
add_line([sys,'/',['Quaternion',13,'Calculation']],[265,120;295,120])
add_line([sys,'/',['Quaternion',13,'Calculation']],[175,120;205,120])
add_line([sys,'/',['Quaternion',13,'Calculation']],[355,80;390,80])
add_line([sys,'/',['Quaternion',13,'Calculation']],[100,80;135,80])
add_line([sys,'/',['Quaternion',13,'Calculation']],[355,120;390,120])
add_line([sys,'/',['Quaternion',13,'Calculation']],[100,120;135,120])
add_line([sys,'/',['Quaternion',13,'Calculation']],[355,160;390,160])
add_line([sys,'/',['Quaternion',13,'Calculation']],[100,160;135,160])
set_param([sys,'/',['Quaternion',13,'Calculation']],...
		'Mask Display','Quaternion\nCalculation',...
		'Mask Type','Quaternion Calculation')
set_param([sys,'/',['Quaternion',13,'Calculation']],...
		'Mask Dialogue','Calculate Psi, Theta and Phi based on P,Q,R|Initial Psi Value (Deg.)|Initial Theta Value (Deg.):|Initial Phi Value (Deg.):',...
		'Mask Translate','Psi=@1;Theta=@2;Phi=@3;')
set_param([sys,'/',['Quaternion',13,'Calculation']],...
		'Mask Help','This block calculates the Yaw (Psi), Pitch (Theta) and Roll (Phi) of an aircraft using quaternion rotation calculations.  The inputs to the block are P (Roll rate), Q(Pitch rate) and R(Yaw rate).  All input units are Degrees per second.  The outputs of the block are Psi, Theta and Phi all given in Degrees.')
set_param([sys,'/',['Quaternion',13,'Calculation']],...
		'Mask Entries','0\/0\/0\/')


%     Finished composite block ['Quaternion',13,'Calculation'].

set_param([sys,'/',['Quaternion',13,'Calculation']],...
		'hide name',0,...
		'position',[205,120,285,160])

add_block('built-in/Scope',[sys,'/','Theta (Pitch)'])
set_param([sys,'/','Theta (Pitch)'],...
		'Vgain','180.000000',...
		'Hgain','20.000000',...
		'Vmax','360.000000',...
		'Hmax','40.000000',...
		'Window',[383,484,655,670])
open_system([sys,'/','Theta (Pitch)'])
set_param([sys,'/','Theta (Pitch)'],...
		'position',[495,90,525,120])

add_block('built-in/Scope',[sys,'/','Phi (Roll)'])
set_param([sys,'/','Phi (Roll)'],...
		'Vgain','180.000000',...
		'Hgain','20.000000',...
		'Vmax','360.000000',...
		'Hmax','40.000000',...
		'Window',[671,484,940,669])
open_system([sys,'/','Phi (Roll)'])
set_param([sys,'/','Phi (Roll)'],...
		'position',[495,140,525,170])

add_block('built-in/Scope',[sys,'/','Psi (Heading)'])
set_param([sys,'/','Psi (Heading)'],...
		'Vgain','180.000000',...
		'Hgain','20.000000',...
		'Vmax','360.000000',...
		'Hmax','40.000000',...
		'Window',[96,485,368,670])
open_system([sys,'/','Psi (Heading)'])
set_param([sys,'/','Psi (Heading)'],...
		'position',[495,40,525,70])

add_block('built-in/Note',[sys,'/',['Units:',13,'Degrees']])
set_param([sys,'/',['Units:',13,'Degrees']],...
		'Font Weight','bold',...
		'position',[510,0,515,5])


%     Subsystem  ['Rotation',13,'Demo'].

new_system([sys,'/',['Rotation',13,'Demo']])
set_param([sys,'/',['Rotation',13,'Demo']],'Location',[79,402,355,609])

add_block('built-in/Note',[sys,'/',['Rotation',13,'Demo/Units:',13,'Degrees']])
set_param([sys,'/',['Rotation',13,'Demo/Units:',13,'Degrees']],...
		'Font Weight','bold',...
		'position',[60,5,65,10])

add_block('built-in/S-Function',[sys,'/',['Rotation',13,'Demo/eulrotds']])
set_param([sys,'/',['Rotation',13,'Demo/eulrotds']],...
		'function name','eulrotds',...
		'parameters','1',...
		'position',[165,88,240,112])

add_block('built-in/Mux',[sys,'/',['Rotation',13,'Demo/Mux']])
set_param([sys,'/',['Rotation',13,'Demo/Mux']],...
		'hide name',0,...
		'inputs','3',...
		'position',[105,43,135,157])

add_block('built-in/Inport',[sys,'/',['Rotation',13,'Demo/Psi (Heading)']])
set_param([sys,'/',['Rotation',13,'Demo/Psi (Heading)']],...
		'Drop Shadow',4,...
		'position',[40,50,60,70])

add_block('built-in/Inport',[sys,'/',['Rotation',13,'Demo/Phi (Roll)']])
set_param([sys,'/',['Rotation',13,'Demo/Phi (Roll)']],...
		'Drop Shadow',4,...
		'Port','3',...
		'position',[40,130,60,150])

add_block('built-in/Inport',[sys,'/',['Rotation',13,'Demo/Theta (Pitch)']])
set_param([sys,'/',['Rotation',13,'Demo/Theta (Pitch)']],...
		'Drop Shadow',4,...
		'Port','2',...
		'position',[40,90,60,110])
add_line([sys,'/',['Rotation',13,'Demo']],[65,140;100,140])
add_line([sys,'/',['Rotation',13,'Demo']],[65,100;100,100])
add_line([sys,'/',['Rotation',13,'Demo']],[65,60;100,60])
add_line([sys,'/',['Rotation',13,'Demo']],[140,100;160,100])
set_param([sys,'/',['Rotation',13,'Demo']],...
		'Mask Display','Euler\nRotation',...
		'Mask Type','Euler Rotation',...
		'Mask Dialogue','eval(''quatdemo(1,2,3)'');')


%     Finished composite block ['Rotation',13,'Demo'].

set_param([sys,'/',['Rotation',13,'Demo']],...
		'hide name',0,...
		'position',[465,195,545,235])
add_line(sys,[105,95;160,95;160,125;200,125])
add_line(sys,[105,140;200,140])
add_line(sys,[105,185;160,185;160,155;200,155])
add_line(sys,[290,125;365,125;365,200;460,200])
add_line(sys,[290,140;340,140;340,215;460,215])
add_line(sys,[290,155;320,155;320,230;460,230])
add_line(sys,[310,125;310,55;490,55])
add_line(sys,[340,140;340,105;490,105])
add_line(sys,[320,155;490,155])

drawnow

% Return any arguments.
if (nargin | nargout)
	% Must use feval here to access system in memory
	if (nargin > 3)
		if (flag == 0)
			eval(['[ret,x0,str,ts,xts]=',sys,'(t,x,u,flag);'])
		else
			eval(['ret =', sys,'(t,x,u,flag);'])
		end
	else
		[ret,x0,str,ts,xts] = feval(sys);
	end
else
	drawnow % Flash up the model and execute load callback
end
