function qdat = scqdata(beta,nqpts);
%	Gauss-Jacobi quadrature data.
%	SCQDATA(BETA,NQPTS) returns a matrix of quadrature data suitable
%	for other SCM routines.  BETA is a vector of turning angles
%	corresponding to *finite* singularities (prevertices and, for
%	exterior map, the origin).  NQPTS is the number of quadrature
%	points per subinterval, roughly equal to -log10(error).

%	By Toby Driscoll.  Last updated 1/18/94.

n = length(beta);
qnode = zeros(nqpts,n+1);
qwght = zeros(nqpts,n+1);
for j = find(beta(:)>-1)'
  [qnode(:,j),qwght(:,j)] = gaussj(nqpts,0,beta(j));
end
[qnode(:,n+1),qwght(:,n+1)] = gaussj(nqpts,0,0);
qdat = [qnode,qwght];
