function fprime = stderiv(zp,z,beta,nb,j)
%	Evaluates the integrand of the strip map.

%	zp is a vector of points at which to evaluate the derivative.  z,
%	beta, and nb are as in STQUAD.  If j is supplied, the terms
%	corresponding to z(j) are normalized by abs(zp-z(j)).  This is for
%	Gauss-Jacobi quadrature.

%	By Toby Driscoll.  Last updated 2/9/94.

log2 = 0.69314718055994531;
fprime = zeros(size(zp));
zp = zp(:).';
npts = length(zp);
n = length(z);
terms = -pi/2*(zp(ones(n,1),:) - z(:,ones(npts,1)));
terms(1:nb,:) = -terms(1:nb,:);
rt = real(terms);
big = abs(rt) > 40;
if any(any(~big))
  terms(~big) = log(-i*sinh(terms(~big)));
end
terms(big) = sign(rt(big)).*(terms(big)-i*pi/2) - log2;
if nargin==5
  if j > 0
    terms(j,:) = terms(j,:)-log(abs(zp-z(j)));
  end
end
theta = beta(1)-beta(nb+2);
beta([1,nb+2]) = [];
fprime(:) = exp(pi/2*theta*zp + sum(terms.*beta(:,ones(npts,1))));
