function whs(first_let1, first_let2,first_let3, first_let4,first_let5)
% This file is a filter for the 'whos' function.
% It can be used to display only files starting with user specified beginning letter(s)
% At most, five different specifications can be given.
% The file was written for PCs. I do not know if it works on any other system.
%
% Example:  If you type
%
%                         whs a kk x
%
%           all variables beginning with a or kk or x will be displayed

% Comments to: David Pommerenke, Technical University Berlin, pomme@ee.tu-berlin.de

 if (nargin == 0)
    disp('  At least one starting letter must be specified')
    disp(' ')
    disp(' ')
    help whs
    break
 end

 if (exist('first_let2') ==0)  % Sorry, I could not think of a better method to avoid
    first_let2 = first_let1;   % problems with missing input arguments.
 end

 if (exist('first_let3') ==0)
    first_let3 = first_let2;
 end

 if (exist('first_let4') ==0)
    first_let4 = first_let3;
 end

 if (exist('first_let5') ==0)
    first_let5 = first_let3;
 end

oldfile=get(0,'DiaryFile'); % get current DiaryFile to restore it later

% empty needed temporary files
   [fid] = fopen('filter.tmp','w');
   fprintf(fid,'%s');
   fclose(fid);

   [fid2] = fopen('filter2.tmp','w');
   fprintf(fid2,'%s');
   fclose(fid2);


% put the information provided by 'whos' into a diary file filter.tmp
   dbup
      diary filter.tmp;
      whos;
      diary off;
      clc
   dbdown
   set(0,'DiaryFile',oldfile)

% read the whos-information, check if it should be displayed and, if yes, put the information in filter2.tmp

   [fid ] = fopen('filter.tmp' , 'r' );
   [fid2] = fopen('filter2.tmp', 'w' );

% a header to be displayed
   fprintf(fid2,'%s', ['Variables starting with: ']);
   for n=1:nargin
       fprintf(fid2,'%s', [' ' eval(['first_let' num2str(n) ]) ] );
   end
   fprintf(fid2,'%s \n\n', [' ']);

% some varibles
   line = 1;
   line_no = 0;

% filter.tmp will be read line by line till EOF
   while (line ~= -1)
      print = 0;
      line_no = line_no + 1;
      line = fgets(fid);

      % The next 3 lines are used to determine the position of the first letter of each variablename
      pos_let = 0;
      dummy = diff(findstr(' ',line)) - 1;
      dummy = find(dummy);

      if (dummy ~= [])
          pos_let = dummy(1) + 1;
      end

% Now comes the filterfunction
      if (pos_let ~= 0)

         if (  ( strcmp(line(pos_let:pos_let+length(first_let1)-1), first_let1)    ) | ...
               ( strcmp(line(pos_let:pos_let+length(first_let2)-1), first_let2)    ) | ...
               ( strcmp(line(pos_let:pos_let+length(first_let3)-1), first_let3)    ) | ...
               ( strcmp(line(pos_let:pos_let+length(first_let4)-1), first_let4)    ) | ...
               ( strcmp(line(pos_let:pos_let+length(first_let5)-1), first_let5)    ) ...
            )

            print = 1;
         end
      end

% next 3 lines used to copy the header into the filtered file
      if (line_no < 3),
          print = 1;
      end

% all filtered information will be put into filter2.tmp
      if (print == 1)
          fprintf (fid2, '%s ',line);
      end
   end          

   fclose(fid);
   fclose(fid2);
  clc

  type filter2.tmp
  delete filter.tmp
  delete filter2.tmp

 % Nice code, isn't it ?  (pomme@ee.tu-berlin.de)