% General Recognition Theory Toolbox
% Version 1.3	18-July-96
% by Leola A. Alfonso-Reese
% Copyright (c) 1995,1996
%
% For designing and analyzing data for GRT experiments using 2 categories.
%   Based on General Recognition Theory (see Ashby, 1992)
%   Note:  Some analysis routines depend on the Optimization Toolbox for MATLAB.
%
% General Functions
%   bnd2slint          - convert linear bnds to slope & y-intercept pairs (2D)
%   fastnormalcdf      - compute normal cumulative distribution function quickly
%   lindecisbnd        - compute ideal linear decision bound coefficients (nD)
%   linprobcorr        - compute probability correct for optimal linear bound (nD)
%   normalcdf          - compute normal cumulative distribution function
%   normalcdfinv       - compute inverse of normal cumulative distribution
%   normalpdf          - compute normal probability density function
%   quaddecisbnd       - compute ideal quadratic decision bound coefficients (nD)
%
% Stimulus Generation Functions
%   clip_vals          - clip values that are outside of specified range (nD)
%   gensample          - generate normally distributed data points (nD)
%   randrows           - randomize order of rows in a matrix
%   transample         - transform sample params to match desired params (nD)
%
% Subject Simulation Functions
%   lindiscrim2dvals   - compute linear discriminant values (2D)
%   sim2dlin           - simulate observer's response data using linear bnd (2D)
%
% Data Analysis Functions
%   angvec2xymat       - convert vector of angles to x,y coordinate matrix 
%   dprime             - compute d-prime from data (nD)
%   dprimef            - compute d-prime from population parameters (nD)
%   fisherdiscrim2d    - compute coefficients of Fisher's discriminant fcn (2D)
%   fit_2dGLC          - set up and begin search for the GLC (2D)
%   fit_2dGQC          - set up and begin search for the GQC (2D)
%   negloglike_2dGLC   - compute -loglikelihood of the data for GLC model (2D)
%   negloglike_2dGQC   - compute -loglikelihood of the data for GQC model (2D)
%   new2old_2dparams   - convert new format of search parameters to old (2D)
%   norm_old_2dparams  - normalize the old parameters:  [noise a1 a2 b] (2D)
%   old2new_2dparams   - convert old format of search parameters to new (2D)
%   percorr            - determine percent of responses correctly categorized (nD)
%   xymat2angvec       - convert matrix of x,y coordinates to vector of angles
%
% Data Graphing Functions
%   getbndendpts       - return two endpoints of a linear bound (2D)
%   plot2dlinbnd       - plot a linear boundary on the current figure (2D)
%   plot2dquadbnd      - plot a quadratic boundary on the current figure (2D)
%   plot2dresp         - plot response data points (2D)
%   plot2dstim         - plot stimulus data points (2D)
%
% Demonstrations
%   For examples of designing experiments, generating stimuli, simulating
%   subject data, analyzing and graphing data, type 'help GRTdemos.'
%
% GRT Toolbox Information
%   GRT_README         - general information about the GRT toolbox
