function newdata = clip_vals(data,range)
%newdata = clip_vals(data,range)
%  clips values outside of the range for each dimension
%  that has a range specified.
%
%  Parameters:
%    data row format: [var1 var2 ... varn]
%    range = [minvar1 maxvar1
%             minvar2 maxvar2
%             ...
%             minvarn maxvarn]
%    To avoid clipping along any of the dimensions, specify
%    NaN entries for the minimum or maximum range values.

% Created by Leola A. Alfonso-Reese / 7-August-95
% Copyright (c) 1995
% $Revisions:$
%   Date           Modification and Name
%   ----           ---------------------


[dims,m] = size(range);
newdata = data;

for i = 1:dims
	minval = range(i,1);
	maxval = range(i,2);
	if ~isnan(minval)
		lessthanmin = find(data(:,i) < minval);
		if ~isempty(lessthanmin)
		  newdata(lessthanmin,i) = minval*ones(length(lessthanmin),1);
			fprintf('Clipped %i values less than %6.4f.\n',length(lessthanmin),minval);
		else
			fprintf('No values found less than %6.4f.\n',minval);		  
		end
	end
	if ~isnan(maxval)
		exceedmax = find(data(:,i) > maxval);
		if ~isempty(exceedmax)
		  newdata(exceedmax,i) = maxval*ones(length(exceedmax),1);
			fprintf('Clipped %i values greater than %6.4f.\n',length(exceedmax),maxval);
		else
			fprintf('No values found greater than %6.4f.\n',maxval);		  
		end
	end
end
