function [out_params, neglikelihood] = fit_2dGLC(in_params, data, z_limit)
%[out_params, neglikelihood] = fit_2dGLC(in_params, data, z_limit)
%  sets up the parameter search range, sets up the search options, and
%  calls the search function, "constr", found in the optimization toolbox
%  for MATLAB.  The function being minimized is the negative log
%  likelihood of the 2 dimensional data, negloglike_2dGLC.
%
%  Parameters:
%    in_params format:  [noise a1 a2 bias]
%    data row format:  [response x y ... 1]
%    z_limit is the z-score value beyond which one should truncate

% Created by Leola A. Alfonso-Reese / 18-April-95
% Copyright (c) 1995
% $Revisions:$
%   Date           Modification and Name
%   ----           ---------------------
%  5/4/96          Modified help text
%                  by Leola


% Set contraints on parameters
vlb = [ .001 ];
vub = [ 500 ];

% Convert params to search format.  
% Search format: [noise angle bias]
start_params = old2new_2dparams(in_params);

% Set search options
options = foptions;
options(1) = 1;			% Spit out progress info
options(2) = 0.001;	% Termination size for f
options(3) = 0;			% Termination for constraint g
%options(14) = 100; % Max iterations

% Search!
[final_params] = constr('negloglike_2dGLC',start_params,options,vlb,vub,[],data,z_limit);

% Report results
out_params = new2old_2dparams(final_params);
neglikelihood = negloglike_2dGLC(final_params,data,z_limit);
