function [out_params, likelihood] = fit_2dGQC(in_params, data, z_limit)
%[out_params, neglikelihood] = fit_2dGQC(in_params, data, z_limit)
%  sets up the parameter search range, sets up the search options, and
%  calls the search function, "constr", found in the optimization toolbox
%  for MATLAB.  The function being minimized is the negative log
%  likelihood of the 2 dimensional data, negloglike_2dGQC.
%
%  Parameters:
%    in_params format: [pnoise cnoise Amat_entries(1:3) b_entries(1:2) c_bias]
%    data row format:  [correct_response x y ... 1]
%    z_limit is the z-score value beyond which one should truncate

% Created by Leola A. Alfonso-Reese / 25-March-96
% Copyright (c) 1996
% $Revisions:$
%   Date           Modification and Name
%   ----           ---------------------

% Set contraints on parameters
vlb = [ .001   .001];
vub = [ 500^2 500^2];

% No conversion for search format.  
% Search format: [pnoise cnoise Amat_entries(1:3) b_entries(1:2) c_bias]
start_params = in_params;

% Set search options
options = foptions;
options(1) = 1;			% Spit out progress info
options(2) = 0.001;	% Termination size for f
options(3) = 0;			% Termination for constraint g
%options(14) = 100;	% Max iterations

% Search!
[final_params] = constr('negloglike_2dGQC',start_params,options,vlb,vub,[],data,z_limit);

% Report results
out_params = final_params;
likelihood = negloglike_2dGQC(final_params,data,z_limit);
