function prc = linprobcorr(K,uA,uB)
%prc = linprobcorr(K,uA,uB)
%  returns the probability correct using the optimal boundary to
%  categorize the data from categories having means uA, uB and
%  a common covariance matrix, K.
%
%  Parameters:
%    K  is the common covariance matrix
%    uA is a column vector containing the mean of category A
%    uB is a column vector containing the mean of category B

% Created by Leola A. Alfonso-Reese / 12-April-94
% Copyright (c) 1995
% $Revisions:$
%   Date           Modification and Name
%   ----           ---------------------


invK = inv(K);
uhx = (uB-uA)'*invK*uA + .5*(uA'*invK*uA-uB'*invK*uB);
varhx = (uB-uA)'*invK*(uB-uA);
z = (0-uhx)/sqrt(varhx);
prc = normalcdf(z,0,1);
