function  ratio = ames(typ,Mach,gamma);   %version 10-1-87 by Kevin J. Melcher%
%
%IMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMM;
%:                                AMES Tables                                :
%LMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMM9
%: FUNCTION:    Function AMES calculates requested ratios as a function      :
%:              of mach number.  These are the equations used to calculate   :
%:              values for (ames) tables in NASA TN-1428, NASA Report 1135.  :
%GDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDD6
%: SYNTAX:      ratio = ames(type,Mach);                                     :
%:              ratio = ames(type,Mach,gamma);                               :
%GDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDD6
%: PARAMETERS:  type  =  'T/Tt' ... static/total temperature                 :
%:                       'p/pt' ... static/total pressure                    :
%:                       'd/dt' ... local/stagnation density                 :
%:                       'a/at' ... local/stagnation speed of sound          :
%:                       'q/p'  ... velocity head / static pressure          :
%:                       'q/pt' ... velocity head / total  pressure          :
%:                                                                           :
%:              Mach  =  mach number(s) at which to compute specified ratio  :
%:                                                                           :
%:  (optional)  gamma =  Cp/Cv, default = 7/5 = 1.4                          :
%HMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMM<
%

if nargin < 3;  gamma = 7.0/5.0;  end;

%make sure type is four (4) characters in length
 typ =  [abs(typ),32,32,32,32];
 typ =  setstr(typ(1:4));


%calculate common factor:  1 + M^2*(gamma-1)/2
 factor =  1 + (Mach.*Mach)*(gamma-1.0)/2.0;


%static to total temperature ratio
 if typ == 'T/Tt';
    power =  -1;
    ratio =  factor.^power;

%static to total pressure ratio
 elseif typ == 'p/pt';
    power =  -gamma/(gamma-1.0);
    ratio =  factor.^power;

%local to stagnation density ratio
 elseif typ == 'd/dt';
    power =  -1.0/(gamma-1.0);
    ratio =  factor.^power;

%local to stagnation speed of sound
 elseif typ == 'a/at';
    power =  -0.5;
    ratio =  factor.^power;

%velocity head to static pressure ratio
 elseif typ == 'q/p ';
    ratio =  (Mach.*Mach) * gamma/2.0;

%velocity head to total pressure ratio
 elseif typ == 'q/pt';
    power =  -gamma/(gamma-1.0);
    ratio =  (Mach.^2.0)*(gamma/2.0) * factor.^power;

%unrecognized typ
 else
    disp('ERROR:  unrecognized value for parameter TYPE.')
 end;

