function [x,y]=naca4(naca,n)
% naca4(naca,n) generates coordinates for NACA 4 digit profiles
% naca the 4 digit NACA designation
% n    number of segments around profile
%
% Copyright (C) 1994 Anders Lennartsson, abel@mech.kth.se
% revision 1994-10-29
%
% cord assumed to be 1
% maximum camber ratio epsilon is the first digit divided by 100
% coordwise position of maximum camber ratio p, is the second
% digit times 10
% the thickness ratio tau, is the two last digits divided by 100
% the first point is the trailing edge, following points are
% situated forward on the upper side, around the leading
% edge and then backwards on the lower side
epsilon=floor(naca/1000);
p=floor(naca/100);
tau=(naca-p*100)/100;
p=p/10-epsilon;
epsilon=epsilon/100;
p2=p*p;
p12=(1-p)*(1-p);
% first extracting profile characteristics
% esilon 
% p      position for max camber
% tau    max thicknes to cord ratio
% p2 and p12 help variables
% then analyzing n
if (n/2)==round(n/2)
  n2=n/2+1;
else
  n2=(n+1)/2;
end
% starting to make coordinates
% coordinates along cord approximately
% at porjections onto axis of equal circle segments
phiv=0:(2*pi/n):2*pi;
phiv(n+1)=0;
phiv2=phiv(1:n2);
parx=(1+cos(phiv2))/2;
% t2n thickness distribution (half)
rt=sqrt(parx);
t2n=5*tau*(0.2969*rt-parx.*(0.126+parx.*(0.3537-parx.*(0.2843-0.1015*parx))));
% yc  camber curve
% d2n derivative of camber curve
% xu  xcoordinates of upper points
% yu  ycoordinates of upper points
% xl  xcoordinates of lower points
% yl  ycoordinates of lower points
xu=zeros(size(parx));
xl=zeros(size(parx));
yu=zeros(size(parx));
yl=zeros(size(parx));
xu(1)=1;
xl(1)=1;
yu(1)=0;
yl(1)=0;
for ii=2:n2,
  if parx(ii)<p,
	yc=epsilon*parx(ii)*(2*p-parx(ii))/p2;
    d2n=2*epsilon*(p-parx(ii))/p2;
  else
	yc=epsilon*(1-parx(ii))*(1+parx(ii)-2*p)/p12;
    d2n=2*epsilon*(p-parx(ii))/p12;
  end
  td=tan(d2n);
  std=sin(td);
  ctd=cos(td);
  xu(ii)=parx(ii)-t2n(ii)*std;
  xl(ii)=parx(ii)+t2n(ii)*std;
  yu(ii)=yc+t2n(ii)*ctd;
  yl(ii)=yc-t2n(ii)*ctd;
end
% results
if n/2==round(n/2)
  x=[xu,xl(1,(n2-1):-1:1)];
  y=[yu,yl(1,(n2-1):-1:1)];
else
  x=[xu,xl(1,n2:-1:1)];
  y=[yu,yl(1,n2:-1:1)];
end
