function [t,x,u]=barimpac(fend,a,e,rho,len,xmin,xmax,nx,...
                          tmin,tmax,nt,ntrms)
% [t,x,u]=barimapc(fend,a,e,rho,len,xmin,xmax,nx,...
%                  tmin,tmax,nt,ntrms)
% This function computes the longitudinal displacement in
% an elastic bar which is initially at rest with the left
% end fixed. A constant load suddenly applied to the right end
% causes waves to propogate along the bar and continually
% reflect back and forth from the ends. The resulting time
% response is evaluated from a Fourier series solution.
%
% fend = (end force)   a=area   e = (modulus of elasticity)
% rho = (mass per unit volume)  len = (bar length)
% (xmin,xmax,nx) => evaluate at nx points between xmin and xmax
% (tmin,tmax,nt) => evaluate for nt times between tmin and tmax
% nt = (number of terms summed in the series solution)
% t = (output times)  x = (output positions)
% u = (displacement history stored in an nt by nx array)

%    by Howard Wilson, U. of Alabama, Spring 1990

x = xmin+(0:nx-1)*((xmax-xmin)/(nx-1));  xol=x/len;
t = tmin+(0:nt-1)'*((tmax-tmin)/(nt-1));
alpha = sqrt(e/rho);  atl = (alpha/len)*t;
beta = pi*((1:ntrms)-.5); enddfl = fend*len/(a*e);
gamma = (2*enddfl)*((-1).^(1:ntrms))./beta.^2;
u = ones(nt,1)*(enddfl*xol);
u = u+((ones(nt,1)*gamma).*cos(atl*beta))*sin(beta'*xol);
