% Program Barimpac
%
% This program computes the longitudinal displacement history
% for an elastic bar fixed at one end and free at the other end.
% The bar is initially at rest when a constant impact load is
% applied to the right end. The resulting motion consists of
% a series of waves traveling at constant velocity along the
% bar. These waves continually reflect back and forth from both
% ends of the bar resulting in motion which is periodic in time.
% For a constant value of x the displacement is a piecewise
% linear function of time. Similarly, for a particular time, the
% displacement is a piecewise linear function of x. The program
% describes the solution by plotting the displacement for two
% positions, and the deflection pattern for two times. The total
% displacement surface u(x,t) for a range of t and x is also shown.

%    by Howard Wilson, U. of Alabama, Spring 1990

help barimpac
fend=1; a=1; e=1; rho=1; len=1; xmin=0; xmax=1; nx=26;
tmin=0; tmax=12; nt=121; ntrms=50;
% [t,x,u]=barimpac(1,1,1,1,1,0,1,nx,0,12,nt,50);
[t,x,u]=barimpac(fend,a,e,rho,len,xmin,xmax,nx,...
                 tmin,tmax,nt,ntrms);

plot(t,u(:,nx),'-',t,u(:,nx/2),'--')
xlabel('dimensionless time')
ylabel('dimensionless displacement')
title('DISPLACEMENT FOR RIGHT END AND MIDDLE')
text(3,1.75,'solid => right end')
text(3,1.50,'dash  => midpoint')
pause
%!del barhist.met
%meta barhist.met
idpt5=sum(t<=.5); id2pt5=sum(t<=2.5);
clg; plot(x,u(idpt5,:),'-',x,u(id2pt5,:),'--')
xlabel('position divided by length')
ylabel('dimensionless displacement')
title('DEFLECTION PATTERN FOR TWO SELECTED TIMES')
text(.1,1.4,'solid = > dimensionless time = 0.5')
text(.1,1.2,'dash  = > dimensionless time = 2.5')
pause
%!del barhist.met
%meta barhist.met
horzangl=-110; vertangl=30;
barsurf(u,horzangl,vertangl); pause
%!del barsurf.met
%meta barsurf.met
