function [x,t,disp,mom]=bemimpac(e,i,a,rho,len,m0,...
                        tmin,tmax,nt,xmin,xmax,nx,ntrms)
% [x,t,disp,mom]=bemimpac(e,i,a,rho,len,m0,...
%                tmin,tmax,nt,xmin,xmax,nx,ntrms)
% This function evaluates the time dependent displacement
% and moment in a constant cross-section simply-supported
% beam which is initially at rest when a constant moment
% is suddenly applied at the right end. The resulting time
% history is computed.
%
%   t        vector of nt equally spaced time values
%            varying from tmin to tmax
%   x        vector of nx equally spaced position values
%            varying from xmin to xmax
%   ntrms    number of series terms used in the Fourier
%            series solution
%   e,i      elastic modulus and moment of inertia
%   a,rho    cross section area and mass per unit volume
%   len,m0   beam length and end moment value
%   u        matrix of displacements with time varying
%            from row to row, and position varying from
%            column to column
%   mom      matrix of bending moments with time varying
%            from row to row, and position varying from
%            column to column

%     by Howard B. Wilson, Fall 1989
%
pl=pi/len; beta=sqrt(e*i/(a*rho))*pl*pl; c1=12/pi^3;
k=1:ntrms; k2=k.*k; k3=k2.*k;
t=tmin+(0:nt-1)'*((tmax-tmin)/(nt-1));
x=xmin+(0:nx-1)*((xmax-xmin)/(nx-1));
ck=(c1*(-1).^k)./k3; ckm=2/pi*(-1).^k./k;
skx=sin((pl*k)'*x); stk=cos((beta*t)*k2);
disp=(stk.*(ones(nt,1)*ck))*skx;
mom=(stk.*(ones(nt,1)*ckm))*skx;  xol=x/len;
disp=((m0*len*len)/(6*e*i))*(ones(nt,1)*(xol.^3-xol)-disp);
mom=m0*(ones(nt,1)*xol+mom);
