% This program analyzes an impact dynamics problem for an
% elastic Euler beam of constant cross section which is
% simply supported at each end. The beam is initially at
% rest when a constant couple M0 is suddenly applied to
% the right end. The resulting displacement and moment
% are computed by using the following Fourier series:
%
%  Deflection(x,t) = ( M0*L*L/(6*E*I) )*( (x/L)^3 - x/L
%                      - Sum[ Dcof(x,t,n),{n,1,Inf} ] )
%  Moment(x,t) = M0*( - x/L
%                      + Sum[ Mcof(x,t,n),{n,1,Inf} ] )
%  where
%          Dcof(x,t,n) = (12*(-1)^n)/(n*pi)^3)*...
%                      Cos(beta*n*n*t)*Sin(n*pi*x/L)
%          Mcof(x,t,n) = (2*(-1)^n/(n*pi))*...
%                      Cos(beta*n*n*t)*Sin(n*pi*x/L)
%          beta = Sqrt(E*I/(A*Rho))*(pi/L)^2
%
% The displacement and moment are plotted as functions of
% x for the first several successive time steps. Animated
% plots of the entire displacement and moment history are
% also given.

%      Howard Wilson, U. of Alabama, Fall 1989
%

!rm -f  bemimpac.met
clc; help bemimpac
e=1; i=1; a=1; rho=1; len=1; m0=1; tmin=0; tmax=1; nt=101;
xmin=0; xmax=1; nx= 151; ntrms=200;
[x,t,disp,mom]=bemimp(e,i,a,rho,len,m0,...
                  tmin,tmax,nt,xmin,xmax,nx,ntrms);
np=10:12:42;
clg;
plot(x,disp(np,:));
xlabel('x axis'); ylabel('displacement')
title('DISPLACEMENT DUE TO IMPACT MOMENT AT RIGHT END');
text(.3,-.05,['Number of series terms used = ',int2str(ntrms)])
pause, meta bemimpac.met
clg; plot(x,mom(np,:));
xlabel('x axis'); ylabel('moment');
title('BENDING MOMENT IN THE BEAM'); pause
%meta bemimpac.met
animate(x,disp);
animate(x,mom);
