function [masselt,massmat,stifelt,stifmat,frqs,pcter]=...
                                     bmfrqfem(ei,l,mas,n)
% function [masselt,massmat,stifelt,stifmat,frqs,pcter]=...
%                                    bmfrqfem(ei,l,mas,n)
% Determine the natural freqencies of a simply supported
% beam by the Finite Element Method.
%

le=l/n; me=mas/n;c1=6/le^2; c2=3/le; c3=2*ei/le;
% element mass matrix
masselt=le/420*[   156,   22*le,     54,  -13*le
                22*le,  4*le^2,  13*le, -3*le^2
                   54,   13*le,    156,  -22*le
               -13*le, -3*le^2, -22*le,  4*le^2];
% element stiffness matrix
stifelt=c3*[ c1,  c2,  -c1,  c2
            c2,   2,  -c2,   1
           -c1, -c2,   c1, -c2
            c2,   1 , -c2,   2];
ndof=2*(n+1); jj=0:3; mm=zeros(ndof);  kk=zeros(ndof);
% assemble equations
for i=1:n, j=2*i-1+jj;
   mm(j,j)=mm(j,j)+masselt;
   kk(j,j)=kk(j,j)+stifelt; end
massmat=mm; stifmat=kk;
% remove degrees of freedom for zero end deflections
id=[2:ndof-2,ndof]; mm=mm(id,id); kk=kk(id,id);
c=sqrt(mas*l^3/ei);
% compute frequencies
frqs=c*sqrt(sort(eig(kk,mm)));
fexac=c*pi^2*(1:length(frqs))'.^2;
% percentage error in frequencies
pcter=100*(frqs-fexac)./fexac;
