function animate(x,u,tpause,titl)
% This function draws an animated plot of data values stored
% in array u. The different columns of u correspond to position
% values in vector x. The successive rows of u correspond to
% different times. Parameter tpause controls the speed of animation.
%  u       matrix of values to be animate plots of u versus x
%  x       spatial positions for different columns of u
%  tpause  clock seconds between  output of frames. The default is
%          .1 secs when tpause is left out. When tpause=0, then
%          a new frame appears when the user presses any key.

%               by Howard B. Wilson, Fall 1989
%
if nargin < 4, titl=''; end
if nargin < 3, tpause=.1; end
[ntime,nxpts]=size(u);
umin=min(u(:)); umax=max(u(:)); udif=umax-umin; uavg=.5*(umin+umax);
xmin=min(x); xmax=max(x); xdif=xmax-xmin; xavg=.5*(xmin+xmax);
xwmin=xavg-.55*xdif; xwmax=xavg+.55*xdif;
uwmin=uavg-.55*udif; uwmax=uavg+.55*udif;
hold off; clg; ex=0; eu=0;
axis([xwmin,xwmax,uwmin,uwmax]); hold on
title(titl)
plot([xwmin,xwmax,xwmax,xwmin,xwmin],...
     [uwmin,uwmin,uwmax,uwmax,uwmin])
for j=1:ntime
  ut=u(j,:); plot(x,ut);
  if tpause==0, pause, else, pause(tpause); end
  if j==ntime, break, else, plot(x,ut,'i'); end
end
pause; hold off; clg;
