function [c,phi,stres,z]=rector(a,nsega,b,nsegb,ntrms,nxout,nyout)
% [c,phi,stres,z]=rector(a,nsega,b,nsegb,ntrms,nxout,nyout)
% This function employs point matching to obtain an approximate
% solution for torsional stresses in a Saint Venant beam of rectang-
% ular cross section. The complex stress function is analytic inside
% the rectangle and has its real part equal to abs(z*z)/2 on the
% boundary. The problem is solved approximately using a polynomial
% stress function which fits the boundary condition in the least
% square sense. The beam is 2*a wide along the x axis and 2*b high
% along the y axis. The shear stresses in the beam are given by the
% complex stress formula:
%
%     (tauzx-i*tauzy)/(mu*alpha) = -i*conj(z)+f'(z)  where
%
%         f(z)=sum( c(j)*z^(2*j-2), j=1:ntrms );

%       by  H. B. Wilson, U. of Alabama, Fall 1989

% First form a vector zbdry of boundary points for point matching.

db=b/nsegb; i=sqrt(-1); zbdry=cgrid(a,a,1,0,b-db,nsegb);
ztmp=cgrid(a,0,nsega+1,b,b,1);  zbdry=[zbdry(:);ztmp(:)];
% neq=length(zbdry); zbdry=[conj(zbdry(neq:-1:2));zbdry];

% Then form the least square equations to impose the boundary
% conditions.

neq=length(zbdry); amat=ones(neq,ntrms);
ztmp=zbdry.*zbdry; bvec=.5*abs(ztmp);
for j=2:ntrms, amat(:,j)=amat(:,j-1).*ztmp; end

% Solve the least square equations.

amat=real(amat); c=amat\bvec;

% Generate a interior grid to evaluate the solution.

z=cgrid(-a,a,nxout,-b,b,nyout); zz=z.*z;

% Evaluate the membrane function on a grid network

phi=real(polyval(flipud(c),zz))-.5*abs(zz);
cc=(2*(1:ntrms)-2)'.*c;

% Evaluate the membrane deflection and the resultant stresses.
% Plot the results.

ysid=imag(cgrid(a,a,1,-b,b,nyout));
am=num2str(-a);ap=num2str(a); bm=num2str(-b);bp=num2str(b);
stres=-i*conj(z)+i*polyval(flipud(cc),zz)./(z+eps);
subplot(221); mesh(phi); title('MEMBRANE DEFLECTION SHAPE')
subplot(222); mesh(abs(stres)); title('TOTAL STRESS SURFACE')
xlabel([am,'<X<',ap,'    ',bm,'<Y<',bp])
subplot(223); contour(abs(stres')); title('TOTAL STRESS CONTOURS')
xlabel([am,'<x<',ap])
ylabel([bm,'<y<',bp])
subplot(224); plot(ysid,imag(stres(1,:)))
ylabel('tangential stress');xlabel('position on vertical side')
title('STRESS FOR X = A');% !del rector.met DT
%meta rector.met; %DT
subplot



