function [dif_out] = cal_err(desired, actual, hyper)
% CAL_ERR quickprop error function using atanh
%
%     CAL_ERR(DESIRED, ACTUAL, HYPER)
%         DESIRED - target outputs
%         ACTUAL  - actual outputs of last layer
%         HYPER   - 1 => use atanh error
%
%     Ray Byler, 24 Nov 1995, byler@cs.utk.edu.

if nargin ~= 3
  error('Wrong number of arguments.')
end

dif = desired - actual;

[nrows,ncols] = size(desired);

for i =1:ncols
  if hyper == 0 % not using atanh for error
    if dif(i) > -0.1 & dif(i) < 0.1
      dif_out(i) = 0;
    else
      dif_out(i) = dif(i);
    end
  else
    if dif(i) < -0.9999999
      dif_out(i) = -17.0;
    elseif dif(i) > 0.999999
      dif_out(i) = 17.0;
    else
      % Matlab's atanh function isn't very good
      dif_out(i) = log ( (1.0 + dif(i)) ./ (1.0 - dif(i)) );
    end
  end
end

