% QuickProp Addition to Neural Network Toolbox.
%
% Ray Byler, 15 Dec 95, byler@cs.utk.edu
%
% QuickProp   is   a   variant  of  the  back-propagation  learning
% algorithm  like   trainbp,   trainbpx,   and   trainlm.   It   is
% considerably  faster  than  trainbp  and trainbpx and faster than
% trainlm on large problems. It scales up as well  as  trainbp  and
% trainbpx and much better than trainlm.
%
% It  is  designed  to be incorporated into Matlab's Neural Network
% Toolbox, and works with "initff", "simuff",  etc.  Functions  are
% named  and  used  in the same way as the other bp variants in the
% Toolbox.
%
% NEURAL LAYER LEARNING RULES.
% --------------------------------
% Backpropagation learning rules.
%   learnqp  - Scott Fahlman's QuickProp learning rule.
%
% NEURAL NETWORK TRAINING FUNCTIONS.
% --------------------------------
% Backpropagation network training functions.
%   trainqp  - Train feed-forward network with QuickProp.
%              calls tqp1.m, tqp2.m, and tqp3.m.
%
% NEURAL LAYER TRANSFER FUNCTIONS.
% --------------------------------
% Sigmoid transfer functions.
%   sigmoid  - logistic sigmoid transfer function variant, -.5 to +.5 output.
%   asigmoid - logistic sigmoid transfer function variant, 0 to 1 output.
%
% Delta functions for calculating derivatives of error.
%   deltasig - Delta function for sigmoid neurons.
%   deltaasi - Delta function for asigmoid neurons.
%
% OTHER
%   cal_err  - calculates standard error or error with atanh
%
% MISC
%   Makefile - Unix Makefile for quickpro.c
%
%   tst_sine, tst_sqr, tst_xor
%     test  programs  to  verify  that the Matlab version produces
%     output identical to the C version.   Matlab  uses  sine.mat,
%     square.mat,    xor.mat.     C   uses   sine.net,   sine.wts;
%     square.net, square.wts; xor.net, xor.wts.
%
%   tst_iris - QuickProp iris flower classification
%     using 4-6-6-1 size net - loads iris.mat,
%     allows comparisons with BP, BPX, and LM

%   tst_ir - QuickProp iris flower classification
%     using 4-20-20-1 size net - loads ir.mat,
%     allows comparisons with BP, BPX, and LM
%
%   makenice - mean-centered unit variance (MCUV) scaling program
%     useful for scaling inputs and outputs
%
%   scale - linear scaling program
%     useful for scaling inputs and outputs
%
%   quickpro.lsp - Fahlman's original Lisp code
%
%   quickpro.c - Regier's translation of Fahlman's code
%
%   byler_qp.ps - explanation of Matlab translation
%
%   quickpro.exe - DOS executable for running
%     square.net,square.wts; sine.net,sine.wts;
%     xor.net,xor.wts.

