function d_out = deltasig(sig_prime_off, a, d_in, w)
% DELTASIG Delta function for QuickProp symmetrical sigmoid.
%
%     DELTASIG(A,E)
%       A - S1xQ matrix of output vectors
%       E - S1xQ matrix of associated errors
%     Returns an SxQ matrix of output layer derivatives.
%
%     DELTASIG(A,D,W)
%       D - S2xQ matrix of next layer delta vectors
%       W - S2xS1 weight matrix between layers.
%     Returns an SxQ matrix of hidden layer derivatives.
%
%     Ray Byler, 24 Nov 1995, byler@cs.utk.edu.

if nargin ~= 3 & nargin ~= 4
  error('Wrong number of arguments')
end

d_part = sig_prime_off + 0.25*(a .* a);

if nargin == 3
  d_out = d_part .* d_in;
else
  d_out = d_part .* (w' * d_in);
end

