function [a,b,c,d,e,f,g,h] = trainqp(i,j,k,l,m,n,o,p,q,r,s,t)
% TRAINQP Train feed-forward network with quickpropagation.
%
%     TRAINQP can be called with 1, 2, or 3 sets of weights
%     and biases to train up to 3 layer feed-forward networks.
%
%     [W1,B1,W2,B2,...,TE,TR] = TRAINQP(W1,B1,F1,W2,B2,F2,...,P,T,TP)
%       Wi - SixR weight matrix for the ith layer.
%       Bi - S1x1 bias vector for the ith layer.
%       Fi - Transfer function (string) for the ith layer.
%            only sigmoid and asigmoid supported
%       P  - RxQ matrix of input vectors.
%       T  - SxQ matrix of target vectors.
%       TP - Training parameters (optional).
%     Returns new weights and biases and
%       Wi - new weights.
%       Bi - new biases.
%       TE - the actual number of epochs trained.
%       TR - training record: [row of errors]
%
%     Training parameters are:
%       TP(1)  - df, display frequency, default = 1,
%                epochs between updating display
%       TP(2)  - me, max epochs, default = 1000,
%                maximum number of epochs to train
%       TP(3)  - eg, error goal, default = 0.2,
%                sum-squared error goal
%       TP(4)  - lr, learning rate, default = 0.01, NOT USED AT PRESENT.
%       TP(5)  - decay, default = -0.0001, weight decay
%       TP(6)  - split_epsilon, default = 0,
%                1 => divide epsilon by fan-in before use
%       TP(7)  - epsilon, default = 0.00012,
%                for gradient descent if last step was (almost) 0
%       TP(8)  - max_factor, default = 1.75,
%                don't jump more than this times last step
%       TP(9)  - mode_thresh, default = 0.0001,
%                inside thresh, do grad descent; outside, jump
%       TP(10) - momentum, default = 0.9,
%                normal momentum term used in bpm
%       TP(11) - sig_prime_off, sigmoid_prime_offset, default 0.1
%                add to sigmoid to kill flat spots
%       TP(12) - hyper_err, error function type, default = 1.0
%                1 => use atanh error function
%
%     Missing parameters and NaN's are replaced with defaults.
%
%     QUICKPROP IS SENSITIVE TO CHANGES IN EPSILON, MAX_FACTOR,
%     ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
%     AND MODE_THRESH.
%     ~~~~~~~~~~~~~~~
%     If these values are too large the algorithm may thrash about
%     in an unstable manner.
%
%     Ray Byler, 24 Nov 1995, byler@cs.utk.edu.
%
%     This is Scott Fahlman's quickprop program  which  was  translated
%     from  Common  Lisp  into  C  by Terry Regier at the University of
%     California, Berkeley.   email:  regier@cogsci.berkeley.edu,  then
%     translated   into   Matlab  by  Ray  Byler,  24  Nov  95,  email:
%     byler@cs.utk.edu.
%
%     One weakness of all  Matlab  nnet  training  algorithms  is  that
%     connections  are  only  allowed between adjacent layers. The Lisp
%     and  C  versions   of   Quickprop   allow   connections   between
%     non-adjacent  layers. Moreover, the C version is compiled, hence,
%     faster.  However, the C and Lisp versions of quickprop only allow
%     one type of transfer function to  be  used  throughout  the  net,
%     normally hardcoded to ASIGMOID type, whereas Matlab allows you to
%     specify a different transfer function for each layer.
%
%     The  algorithm  and  some test results are described in Fahlman's
%     paper,  "Faster-Learning  Variations  on   Back-Propagation:   An
%     Empirical  Study"  in  Proceedings  of  1988 Connectionist Models
%     Summer School, published by Morgan Kaufmann.
%
%     Note:  the  parameter  called  "mu"  in  the  paper   is   called
%     "max_factor" here.

if all([5 6 8 9 11 12] ~= nargin),error('Wrong number of input arguments');end

if nargin == 5
  [a,b,c,d] = tqp1(i,j,k,l,m);
elseif nargin == 6
  [a,b,c,d] = tqp1(i,j,k,l,m,n);
elseif nargin == 8
  [a,b,c,d,e,f] = tqp2(i,j,k,l,m,n,o,p);
elseif nargin == 9
  [a,b,c,d,e,f] = tqp2(i,j,k,l,m,n,o,p,q);
elseif nargin == 11
  [a,b,c,d,e,f,g,h] = tqp3(i,j,k,l,m,n,o,p,q,r,s);
elseif nargin == 12
  [a,b,c,d,e,f,g,h] = tqp3(i,j,k,l,m,n,o,p,q,r,s,t);
end


