
% M-file "polyfit2dtest"
disp('A Test of ''polyfit2d'' and ''polyval2d.''')
disp(' ')
disp('POLYFIT2D and POLYVAL2D are used to form polynomial data fits to')
disp('functions of two variables, and compute the outputs of the resulting')
disp('polynomial forms.')
disp(' ')
disp('We will use the PEAKS function as the source of our data. Since this')
disp('function is composed of both polynomial and exponential terms, we are')
disp('assured this a ''reasonable'' test--That is, the polynomial can never')
disp('match the output exactly, and consequently there will always be some')
disp('mismatch between PEAKS and the fitting polynomial.')
disp(' ')
disp('Get enough points from PEAKS to define a smooth surface.')
disp('Concentrate on the area near the origin, before PEAKS dies out.')
disp(' ')
echo on
[xs,ys]=meshgrid(-2:.2:2,-2:.2:2);
z=peaks(xs,ys);
echo off
disp(' ')
disp('Plot this section of peaks:')
disp(' ')
figure(1)
clf
echo on
surf(xs,ys,z)
echo off
disp(' ')
disp('Now use POLYFIT2D to form a 5th order polynomial in both x and y,')
disp('using the ordered triples xs, ys, z. Note that POLYFIT2D automatically')
disp('''unwraps'' the matrices xs, ys, and z and forms appropriate vectors')
disp('for the least squares computation--you don''t have to do it yourself.')
disp(' ')
echo on
p=polyfit2d(xs,ys,z,5,5)
echo off
disp(' ')
disp('Now check the fit, using a grid twice as dense as the one used to sample PEAKS:')
disp(' ')
figure(2)
clf
echo on
[xp,yp]=meshgrid(-2:.1:2,-2:.1:2);
zp=polyval2d(p,xp,yp);
surf(xp,yp,zp)
echo off
