function efit(datax, datay, action)
%EFIT	General multiple exponential fit of data
%
%Syntax	gefit(DATAX, DATAY)
%
%Input	DATAX, DATAY
%
%Output	Parameter in global variable G1
%
%	(c) A.K. 16.7.1996
%	last modified 28.7.1996

global G1 G2 G3 G4
global HFUNC HAMP HTAU HCONST HITER HMVAR HTX1 HTX2 HTX3 HTX4 HTX5 HTX6
global G1BOX G2BOX G3BOX G4BOX G5BOX HDONE HRANGE HCURVE HSTAU HFIT
global FUNC PARAM RANGE HL1 HL2 HPL XDATA YDATA HLOGX HLOGY HXTRANS HPLOT

if nargin<3, action='init'; end
   
if strcmp(action, 'init'),
   G1=datax; G2=datay;
   HPLOT=plot(G1, G2, '.', 'EraseMode', 'xor', 'MarkerSize', 8); set(gca, 'Position', [0.3 0.2 0.67 0.77]); hold on;
   ylim=get(gca, 'YLim'); set(gca, 'YLim', [ylim(1)-.05*(ylim(2)-ylim(1)) ylim(2)]);
   set(gcf, 'backingstore', 'off', 'WindowButtonDownfcn', 'efit(G1, G2, ''buttondown'')');
   HFUNC=uicontrol('Style', 'popup', 'Units', 'normalized', 'String', 'Exp 1|Exp 2|Exp 3|Exp 4|Exp 5', ...
                   'Position', [.01 0.89 .15 .1], 'BackgroundColor', [0.702 0.702 0.702], ...
                   'Callback', 'efit(G1, G2, ''func'')'); 
   HAMP=uicontrol('Style', 'edit', 'Units', 'normalized', 'Position', [0 0.77 .14 0.04], 'BackgroundColor', [0.702 0.702 0.702], ...
                     'Callback', 'efit(G1, G2, ''amp'')'); 
   HTAU=uicontrol('Style', 'edit', 'Units', 'normalized', 'Position', [0 0.68 .14 0.04], 'BackgroundColor', [0.702 0.702 0.702], ...
                   'Callback', 'efit(G1, G2, ''tau'')'); 
   HCONST=uicontrol('Style', 'edit', 'Units', 'normalized', 'Position', [0 0.58 .14 0.04], 'String', '0', 'BackgroundColor', [0.702 0.702 0.702]);
   HITER=uicontrol('Style', 'edit', 'Units', 'normalized', 'Position', [0 0.43 .14 0.04], 'BackgroundColor', [0.702 0.702 0.702], ...
                   'String', '200', 'Callback', 'efit(G1, G2, ''iter'')');
   HMVAR=uicontrol('Style', 'edit', 'Units', 'normalized', 'Position', [0 0.33 .14 0.04], 'BackgroundColor', [0.702 0.702 0.702], ...
                   'String', '0.1', 'Callback', 'efit(G1, G2, ''mvar'')');                     
   HTX1=uicontrol('Style', 'text', 'Units', 'normalized', 'String', 'Amp:', 'Position', [0.01 0.8125 .1 0.04], 'BackgroundColor', [0.702 0.702 0.702]);
   HTX2=uicontrol('Style', 'text', 'Units', 'normalized', 'String', 'Tau:', 'Position', [0.01 0.723 .1 0.04], 'BackgroundColor', [0.702 0.702 0.702]);
   HTX3=uicontrol('Style', 'text', 'Units', 'normalized', 'String', 'Const:', 'Position', [0.01 0.622 .1 0.04], 'BackgroundColor', [0.702 0.702 0.702]);
   HTX4=uicontrol('Style', 'text', 'Units', 'normalized', 'String', 'MaxIter:', 'Position', [0.01 0.472 .1 0.04], 'BackgroundColor', [0.702 0.702 0.702]);
   HTX5=uicontrol('Style', 'text', 'Units', 'normalized', 'String', 'MinChange:', 'Position', [0.01 0.372 .13 0.04], 'BackgroundColor', [0.702 0.702 0.702]);
   % Text header for checkboxes
   HTX6=uicontrol('Style', 'text', 'Units', 'normalized', 'String', 'Fit simultaneous', 'Position', [0.01 0.25 .18 0.04], 'BackgroundColor', [0.702 0.702 0.702]);
   G1BOX=uicontrol('Style', 'checkbox', 'Units', 'normalized', 'Position', [0.01 0.21 .18 0.04], 'String', 'Exp 1', 'BackgroundColor', [0.702 0.702 0.702]);                     
   G2BOX=uicontrol('Style', 'checkbox', 'Units', 'normalized', 'Position', [0.01 0.17 .18 0.04], 'String', 'Exp 2', 'BackgroundColor', [0.702 0.702 0.702]);
   G3BOX=uicontrol('Style', 'checkbox', 'Units', 'normalized', 'Position', [0.01 0.13 .18 0.04], 'String', 'Exp 3', 'BackgroundColor', [0.702 0.702 0.702]);
   G4BOX=uicontrol('Style', 'checkbox', 'Units', 'normalized', 'Position', [0.01 0.09 .18 0.04], 'String', 'Exp 4', 'BackgroundColor', [0.702 0.702 0.702]);
   G5BOX=uicontrol('Style', 'checkbox', 'Units', 'normalized', 'Position', [0.01 0.05 .18 0.04], 'String', 'Exp 5', 'BackgroundColor', [0.702 0.702 0.702]);
   HDONE=uicontrol('Style', 'pushbutton', 'Units', 'normalized', 'String', 'Done', 'Position', [0.83 0.01 .1 0.08], ...
                  'callback', 'efit(G1, G2, ''done'')');
   HRANGE=uicontrol('Style', 'pushbutton', 'Units', 'normalized', 'String', 'Set Range', 'Position', [0.2 0.01 .13 0.06], ...
                  'callback', 'efit(G1, G2, ''range'')');
   HSTAU=uicontrol('Style', 'pushbutton', 'Units', 'normalized', 'String', 'Set Tau', 'Position', [0.345 0.01 .18 0.06], ...
                  'callback', 'efit(G1, G2, ''stau'')');
   HCURVE=uicontrol('Style', 'pushbutton', 'Units', 'normalized', 'String', 'Disp Curve', 'Position', [0.54 0.01 .13 0.06], ...
                  'callback', 'efit(G1, G2, ''curve'')');
   HFIT=uicontrol('Style', 'pushbutton', 'Units', 'normalized', 'String', 'Do Fit', 'Position', [0.69 0.01 .13 0.06], ...
                  'callback', 'efit(G1, G2, ''fit'')');
   HLOGY=uicontrol('Style', 'pushbutton', 'Units', 'normalized', 'String', 'LogY', 'Position', [0.12 0.82 .06 0.06], ...
                  'callback', 'efit(G1, G2, ''logy'')');
   HLOGX=uicontrol('Style', 'pushbutton', 'Units', 'normalized', 'String', 'LogX', 'Position', [0.94 0.01 .06 0.06], ...
                  'callback', 'efit(G1, G2, ''logx'')');
   HXTRANS=uicontrol('Style', 'pushbutton', 'Units', 'normalized', 'String', 'xTransf', 'Position', [0.2 0.07 .13 0.06], ...
                  'callback', 'efit(G1, G2, ''xtransf'')');
   HL1=line([0 0], [0 0], 'EraseMode', 'xor'); HL2=line([0 0], [0 0], 'EraseMode', 'xor');
   PARAM=zeros(5,2); PARAM(:,1)=ones(5,1)*max(G2./3);
   RANGE=get(gca, 'XLim');
   HPL=plot([0], [0]);
elseif strcmp(action, 'func'),
   func=get(HFUNC, 'Value');
   set(HAMP, 'String', num2str(PARAM(func,1)));
   set(HTAU, 'String', num2str(PARAM(func,2)));
elseif strcmp(action, 'amp'),
   PARAM(get(HFUNC, 'Value'), 1)=str2num(get(HAMP, 'String'));
elseif strcmp(action, 'tau'),
   PARAM(get(HFUNC, 'Value'), 2)=str2num(get(HTAU, 'String'));
elseif strcmp(action, 'range'),
   set(HSTAU, 'String', 'Set Tau');
   h1=get(HRANGE, 'String');
   if h1=='Set Range', 
      set(HRANGE, 'String', 'Left     ');
   elseif h1=='Left     ',
      set(HRANGE, 'String', 'Right    ');
   elseif h1=='Right    ',
      set(HRANGE, 'String', 'Set Range');
   end %if
elseif strcmp(action, 'buttondown'),
   h2=get(gca, 'CurrentPoint');
   ylim=get(gca, 'YLim'); 
   if get(HSTAU, 'String')=='Tau Off',
      func=get(HFUNC, 'Value');
      set(HTAU, 'String', num2str(h2(1,1)));
      PARAM(get(HFUNC, 'Value'),2)=h2(1,1);
   else
      h1=get(HRANGE, 'String');
      if h1=='Left     ',
         set(HL1, 'Visible', 'off');
         HL1=line([h2(1,1) h2(1,1)], [ylim(1) ylim(2)], 'LineStyle', ':', 'Color', [0 1 0], 'EraseMode', 'xor');
         RANGE(1,1)=h2(1,1);
      elseif h1=='Right    ',
         set(HL2, 'Visible', 'off');
         HL2=line([h2(1,1) h2(1,1)], [ylim(1) ylim(2)], 'LineStyle', ':', 'Color', [0 1 0], 'EraseMode', 'xor');
         RANGE(1,2)=h2(1,1);
      end %if
   end %if
elseif strcmp(action, 'fit'),
   n=zeros(1,5);
   n(1,1)=get(G1BOX,'Value');n(1,2)=get(G2BOX,'Value');n(1,3)=get(G3BOX,'Value');
   n(1,4)=get(G4BOX,'Value');n(1,5)=get(G5BOX,'Value');
   ns=sum(n);
   % Startvector
   x0=PARAM(n,:);
   x0=reshape(x0', 1, ns*2); %Create row vector
   const=str2num(get(HCONST, 'String')); x0=[x0 const];
   % Fitting options
   options=zeros(1,14);
   options(2)=1e-4; options(3)=str2num(get(HMVAR, 'String')); options(14)=str2num(get(HITER, 'String'));
   XDATA=G1(find(G1>=RANGE(1,1) & G1<=RANGE(1,2)));
   YDATA=G2(find(G1>=RANGE(1,1) & G1<=RANGE(1,2)));
   if ns>=1,
      [x, options]=fmins('expfun', x0, options, [], ns);
      disp(['fmin: ' num2str(options(8))]);
   end %if
   %Create new parameter matrix
   if ns>0, 
      set(HCONST, 'String', num2str(x(length(x))));
      x=x(1:length(x)-1);
      x=reshape(x, 2, ns)';
      PARAM(n,:)=x;
   end %if
   func=get(HFUNC, 'Value');
   set(HAMP, 'String', num2str(PARAM(func,1)));
   set(HTAU, 'String', num2str(PARAM(func,2)));
elseif strcmp(action, 'curve'),
   n=zeros(1,5);
   n(1,1)=get(G1BOX,'Value');n(1,2)=get(G2BOX,'Value');n(1,3)=get(G3BOX,'Value');
   n(1,4)=get(G4BOX,'Value');n(1,5)=get(G5BOX,'Value');
   ns=sum(n);
   if ns>=1, 
      p=PARAM(n,:);
      p=reshape(p', 1, ns*2); %Create row vector
      const=str2num(get(HCONST, 'String'));
      x=min(G1):(max(G1)-min(G1))/200:max(G1);
      if ns==1,
         y=p(1)*exp(-x/p(2))+const;
      elseif ns==2,
         y=p(1)*exp(-x/p(2))+p(3)*exp(-x/p(4))+const;
      elseif ns==3,
         y=p(1)*exp(-x/p(2))+p(3)*exp(-x/p(4))+p(5)*exp(-x/p(6))+const;
      elseif ns==4,
         y=p(1)*exp(-x/p(2))+p(3)*exp(-x/p(4))+p(5)*exp(-x/p(6))+p(7)*exp(-x/p(8))+const;
      elseif ns==5,
         y=p(1)*exp(-x/p(2))+p(3)*exp(-x/p(4))+p(5)*exp(-x/p(6))+p(7)*exp(-x/p(8))+p(9)*exp(-x/p(10))+const;
      end %if
      delete(HPL);
      if get(HXTRANS, 'String')=='Normal ', y=y.*x;end
      HPL=plot(x,y, 'g', 'EraseMode', 'xor');
   end %if
elseif strcmp(action, 'stau'),
   if get(HSTAU, 'String')=='Set Tau', 
      set(HSTAU, 'String', 'Tau Off');
   else
      set(HSTAU, 'String', 'Set Tau');
   end %if
elseif strcmp(action, 'logx'),
   if get(HLOGX, 'String')=='LogX',
      set(gca, 'XScale', 'log');
      set(HLOGX, 'String', 'LinX');
   else
      set(gca, 'XScale', 'linear');
      set(HLOGX, 'String', 'LogX');
   end %if
elseif strcmp(action, 'logy'),
   if get(HLOGY, 'String')=='LogY',
      set(gca, 'YScale', 'log');
      set(HLOGY, 'String', 'LinY');
   else
      set(gca, 'YScale', 'linear');
      set(HLOGY, 'String', 'LogY');
   end %if
elseif strcmp(action, 'xtransf'),
  if get(HXTRANS, 'String')=='xTransf',
     ylim=get(gca, 'YLim');
     ycurve=get(HPL, 'YData'); xcurve=get(HPL, 'XData');
     delete(HPLOT); 
     HPLOT=plot(G1, G2.*G1, '.', 'EraseMode', 'xor', 'MarkerSize', 8); set(gca, 'YLim', [ylim(1) max(G1.*G2)]);
     set(HPL, 'YData', ycurve.*xcurve);
     set(HXTRANS, 'String', 'Normal ');
  elseif get(HXTRANS, 'String')=='Normal ',
     delete(HPLOT);
     h2=max(G2); h1=min(G2);
     HPLOT=plot(G1, G2, '.', 'EraseMode', 'xor', 'MarkerSize', 8); set(gca, 'YLim', [h1-.05*(h2-h1) h2]);
     set(HXTRANS, 'String', 'xTransf');
  end %if
elseif strcmp(action, 'done'),
   const=get(HCONST, 'String');
   G1=[]; G2=[];
   disp('   Amplitude   Tau');
   format short e;
   disp(PARAM);
   disp(['Constant:  ' num2str(const)]);
   format short;
   G1=[]; G2=[]; G3=[]; G4=[];
   n=zeros(1,5);
   n(1,1)=get(G1BOX,'Value');n(1,2)=get(G2BOX,'Value');n(1,3)=get(G3BOX,'Value');
   n(1,4)=get(G4BOX,'Value');n(1,5)=get(G5BOX,'Value');
   ns=sum(n);
   G1=PARAM(n,:);
   G1=reshape(G1', 1, ns*2); %Create row vector
   const=str2num(get(HCONST, 'String')); G1=[G1 const];
   close(gcf);
   clear global HFUNC Hamp HTAU HCONST HITER HMVAR HTX1 HTX2 HTX3 HTX4 HTX5 HTX6
   clear global G1BOX G2BOX G3BOX G4BOX G5BOX HDONE HRANGE HCURVE HSTAU HFIT
   clear global FUNC PARAM RANGE HL1 HL2 HPL XDATA YDATA HLOGX HLOGY HTRANS HPLOT
end %if

