function [y, x]=logdist(data, nbins, lower, upper)
%LOGHIST	Data distribution with logarithmically spaced
%		bins
%
%Syntax		[Y, X] = logdist(DATA, NBINS[, LOWER[, UPPER]]);
%Input		DATA	data vector
%		NBINS	number of bins
%		LOWER	lower limit for bins	[min(DATA)]
%		UPPER	upper limit for bins	[max(DATA)]
%Output		Y	distribution
%		X	lower limit of bins
%
%Comment	If Y is multiexpontentially distributed the command
%		semilogx(x, y) gives a peaked histogramm, where
%		the center of each peak gives the time constant
%		of one component of the distribution.
%		The theoretical pdf is given by
%		exp(x-log10(taui)-exp(x-log10(taui)),
%		where taui is ith time constant.
%		Caution: data from eventlist with integer dwell times
%		gives distributions with many erratic peaks
%		(Sigworth, Sine, Biophys.J., 52, 1987, 1047-54)
%		(test data is in lgdist.mat)
%
%	(c) A.K. 4.7.1996

if nargin<4, upper=max(data); end
if nargin<3, lower=min(data); end

[y, x]=hist(data, logspace(log10(lower), log10(upper), nbins));

