%RANDMIN1  Minimization of a function by random search where the random numbers
%	   are equally distributed
%
%Syntax	[x, iter, fmin]=randmin1(func, x0, ranges, options)
%
%Input	func		name of function to minimize (as string)
%	x0		starting parameters
%	ranges		matrix of ranges for the parameters (one column for
%			for each parameter, first row lower limit second row
%			upper limit)
%	options(1)	max interations [200]
%	options(2)	stop criterion [.1]
%	options(3)	=1 : output of intermediate steps  [0]
%
%Output	x		parameter vector which minimizes func
%	iter		needed iterations
%	fmin		minimum of func
%
%	(c) A.K. 12.8.1995

function [x, iter, fmin]=randmin1(func, x0, ranges, options)

if nargin<4, 
   options(1)=200; options(2)=.1; options(3)=0;
end %if
fminalt=0;

str=[func '(x0)'];
del=ranges(2,:)-ranges(1,:);

n=1;
fmin=eval(str); x=x0;
while n<options(1) & fmin>options(2),
      xn=rand(size(x0)).*del+ranges(1,:);
      str=[func '(xn)'];
      fn=eval(str);
      n=n+1;
      if fn<fmin
         fminalt=fmin;fmin=fn; x=xn;
         if options(3)==1, disp(['Iteration:' num2str(n) ' fmin:' num2str(fmin) ' x:' num2str(xn)]); end
      end %if
end %while
iter=n;
