function uijcorr(action, data, points, vscale, pos)
%JCORRECT Correction of patch-clamp data for baseline jumps
%
%	Aufruf:	jcorrect(DATA[, POINTS[ ,VSCALE[, POS]]])
%
%	Graphische Anzeige und Messen von Daten
%
%	Eingabe	DATA	Datenvektor
%		POINTS	Anzahl der darzustellenden Punkte
%		VSCALE  Vertikaler Skalierungfaktor (0<VSCALE<100)
%		POS	Anfangsposition des darzustellenden Bereichs
%
%	Bemerkung: Die globalen Variablen G1, G2, G3, G4 muessen vor dem Aufruf
%		   als global definiert werden. Dies geschieht am besten
%		   standardmaessig in der Datei MATLABRC.M
%		   Wird nur mit Cursor 1 gearbeitet wird ueber folgende
%		   Datenbereiche gemittelt:
%		   Vertikal-Modus  : von Anfang bis Cursor 1
%		   Horizontal-Modus: von Cursor 1 bis oben
%
%	(c) A.K. 14.8.1995
%	last modified 24.7.1996

global P HPOI HPOIVAL HPOS HVSC HSCVAL HOK HPVAL YLIM HZOOM HMODE HC1 HC2 HC3 HAV POS HVR HDIF
global G1 G2 G3 G4 HL1 HL2 HL3 HDO HQUIT HTRPVAL HDISP

if nargin<2, data=action; action='init'; end
if nargin<3, points=round(length(data)/8); end
if nargin<4, vscale=1; end
if nargin<5, pos=1; end
   
if strcmp(action, 'init'),
   POS=[0 0];
   G1=data; G2=points; G3=vscale; G4=pos;
   YLIM=[min(G1)-.05*min(G1) max(G1)+0.05*max(G1)];
   YLIM=YLIM/G3; 
   plot((G4:G4+G2), data(G4:G4+G2), 'EraseMode', 'xor'); h=gca; set(h, 'XLim', [G4 G4+G2], 'YLim', YLIM, 'Position', [0.2 0.11 0.7 0.815]); 
   HL1=line([0 0], [0 0], 'EraseMode', 'xor'); HL2=line([0 0], [0 0], 'EraseMode', 'xor');
   set(gcf, 'backingstore', 'off', 'WindowButtonDownfcn', 'uijcorr(''buttondown'', G1, G2, G3, G4)');
   HPOI=uicontrol('Style', 'slider', 'Units', 'normalized', 'Value', G2, 'Position', [.3 0.93 0.4 0.04], ...
                  'Min', 3, 'Max', length(G1)-1, 'Callback', 'uijcorr(''numpoints'', G1, G2, G3, G4)');
   HPOIVAL=uicontrol('Style', 'edit', 'Units', 'normalized', 'String', num2str(G2), 'Position', [0.7 0.93 0.1 0.033], 'BackgroundColor', [0.702 0.702 0.702], ...
                     'Callback', 'uijcorr(''poival'', G1, G2, G3, G4)'); 
   HPOS=uicontrol('Style', 'slider', 'Units', 'normalized', 'Value', G4, 'Position', [0 0.97 1 0.04], ...
                  'Min', 1, 'Max', length(G1), 'Callback', 'uijcorr(''position'', G1, G2, G3, G4)');
   HPVAL=uicontrol('Style', 'edit', 'Units', 'normalized', 'String', '1', 'Position', [0.9 0.94 0.1 0.03], 'BackgroundColor', [0.702 0.702 0.702], ...
                   'Max', 1, 'Callback', 'uijcorr(''posval'', G1, G2, G3, G4)'); 
   HVSC=uicontrol('Style', 'slider', 'Units', 'normalized', 'Value', 1, 'Position', [.94 0.62 .03 0.3], ...
                  'Min', .1, 'Max', 10, 'Callback', 'uijcorr(''vscale'', G1, G2, G3, G4)');
   HSCVAL=uicontrol('Style', 'edit', 'Units', 'normalized', 'String', '1', 'Position', [0.93 0.58 0.05 0.03], 'BackgroundColor', [0.702 0.702 0.702], ...
                   'Max', 1, 'Callback', 'uijcorr(''scval'', G1, G2, G3, G4)');                   
   HOK=uicontrol('Style', 'pushbutton', 'Units', 'normalized', 'String', 'OK', 'Position', [0.92 0.11 .08 0.06], ...
                  'callback', 'uijcorr(''ok'', G1, G2, G3, G4)');
   HQUIT=uicontrol('Style', 'pushbutton', 'Units', 'normalized', 'String', 'Quit', 'Position', [0.92 0.19 .08 0.05], ...
                  'callback', 'uijcorr(''quit'', G1, G2, G3, G4)');
   HZOOM=uicontrol('Style', 'pushbutton', 'Units', 'normalized', 'String', 'Zoom on', 'Position', [0.02 0.01 .12 0.05], ...
                   'callback', 'uijcorr(''zoom'', G1, G2, G3, G4)');
   HTXTRP=uicontrol('Style', 'text', 'Units', 'normalized', 'String', 'Number of Transitionpoints:', 'Position', [0.2 0.005 .3 0.038], 'BackgroundColor', [0.702 0.702 0.702]);
   HTRPVAL=uicontrol('Style', 'edit', 'Units', 'normalized', 'String', '7' , 'Position', [0.52 0.005 0.1 0.038], 'BackgroundColor', [0.702 0.702 0.702], ...
                     'Callback', 'uijcorr(''trpval'', G1, G2, G3, G4)'); 
   HMODE=uicontrol('Style', 'pushbutton', 'Units', 'normalized', 'String', 'Baseline 1', 'Position', [0.02 0.08 .12 0.05], ...
                  'callback', 'uijcorr(''mode'', G1, G2, G3, G4)');
   HDISP=uicontrol('Style', 'pushbutton', 'Units', 'normalized', 'String', 'Display Points', 'Position', [0.85 0.002 .16 0.05], ...
                   'callback', 'uijcorr(''disp'', G1, G2, G3, G4)');
   HDO=uicontrol('Style', 'pushbutton', 'Units', 'normalized', 'String', 'Do Correction', 'Position', [0.01 0.15 .15 0.07], ...
                  'callback', 'uijcorr(''correct'', G1, G2, G3, G4)');
   HTX1=uicontrol('Style', 'text', 'Units', 'normalized', 'String', 'Cursor 1:', 'Position', [0.01 0.83 .12 0.04], 'BackgroundColor', [0.702 0.702 0.702]);
   HTX2=uicontrol('Style', 'text', 'Units', 'normalized', 'String', 'Cursor 2:', 'Position', [0.01 0.71 .12 0.04], 'BackgroundColor', [0.702 0.702 0.702]);
   HTX3=uicontrol('Style', 'text', 'Units', 'normalized', 'String', 'TransitionP', 'Position', [0.01 0.59 .12 0.04], 'BackgroundColor', [0.702 0.702 0.702]);
   HC1=uicontrol('Style', 'text', 'Units', 'normalized', 'String', '         ', 'Position', [0 0.79 .14 0.04], 'BackgroundColor', [0.702 0.702 0.702]);
   HC2=uicontrol('Style', 'text', 'Units', 'normalized', 'String', '         ', 'Position', [0 0.669 .14 0.04],'BackgroundColor', [0.702 0.702 0.702]);
   HC3=uicontrol('Style', 'text', 'Units', 'normalized', 'String', '        ', 'Position', [0 0.55 .14 0.04], 'BackgroundColor', [0.702 0.702 0.702]);
elseif strcmp(action, 'position'),
   G4=round(get(HPOS, 'Value'));
   if G4>length(G1)-G2,
      G4=length(G1)-G2; set(HPOS, 'Value', G4);
   end %if
   plot((G4:G4+G2), G1(G4:G4+G2), 'EraseMode', 'xor'); h=gca; set(h, 'XLim', [G4 G4+G2], 'YLim', YLIM/G3);
   HL1=line([0 0], [0 0], 'EraseMode', 'xor'); HL2=line([0 0], [0 0], 'EraseMode', 'xor'); HL3=line([0 0], [0 0], 'EraseMode', 'xor');
   set(HPVAL, 'String', num2str(G4));
elseif strcmp(action, 'posval'),
   G4=str2num(get(HPVAL, 'String'));
   if G4>length(G1)-G2,
      G4=length(G1)-G2; set(HPOS, 'Value', G4); set(HPVAL, 'String', num2str(G4));
   end %if
   plot((G4:G4+G2), G1(G4:G4+G2), 'EraseMode', 'xor'); h=gca; set(h, 'XLim', [G4 G4+G2], 'YLim', YLIM/G3);
   HL1=line([0 0], [0 0], 'EraseMode', 'xor'); HL2=line([0 0], [0 0], 'EraseMode', 'xor');HL3=line([0 0], [0 0], 'EraseMode', 'xor');
   set(HPOS, 'Value', G4);
elseif strcmp(action, 'numpoints'),
   G2=round(get(HPOI, 'Value'));
   if G2>length(G1)-G4,
      G2=length(G1)-G4; 
      set(HPOI, 'Value', G2);
   end %if     
   plot((G4:G4+G2), G1(G4:G4+G2), 'EraseMode', 'xor'); h=gca; set(h, 'XLim', [G4 G4+G2], 'YLim', YLIM/G3);
   HL1=line([0 0], [0 0], 'EraseMode', 'xor'); HL2=line([0 0], [0 0], 'EraseMode', 'xor');HL3=line([0 0], [0 0], 'EraseMode', 'xor');
   set(HPOIVAL, 'String', num2str(G2));
elseif strcmp(action, 'poival'),
   G2=str2num(get(HPOIVAL, 'String'));
   if G2>length(G1)-G4,
      G2=length(G1)-G4; 
      set(HPOIVAL, 'String', num2str(G2));
   end %if     
   plot((G4:G4+G2), G1(G4:G4+G2), 'EraseMode', 'xor'); h=gca; set(h, 'XLim', [G4 G4+G2], 'YLim', YLIM/G3);
   HL1=line([0 0], [0 0], 'EraseMode', 'xor'); HL2=line([0 0], [0 0], 'EraseMode', 'xor');HL3=line([0 0], [0 0], 'EraseMode', 'xor');
   set(HPOI, 'Value', G2);
elseif strcmp(action, 'vscale'),
   G3=get(HVSC, 'Value');
   set(gca, 'YLim', YLIM/G3);
   set(HSCVAL, 'String', num2str(G3));
elseif strcmp(action, 'scval'),
   G3=str2num(get(HSCVAL, 'String'));
   if G3>10, G3=10; end
   if G3<.1, G3=.1; end
   set(HVSC, 'Value', G3);
   set(gca, 'YLim', YLIM/G3);
elseif strcmp(action, 'buttondown'),
   h1=get(gca, 'CurrentPoint');
   h2=get(HMODE, 'String');
   y0 = YLIM(1); ym = YLIM(2);
   xlim=get(gca, 'XLim');
   if h2=='Baseline 1'
      set(HL1, 'Visible', 'off');
      POS(1)=h1(1,2);
      HL1=line([xlim(1) xlim(2)], [POS(1) POS(1)], 'LineStyle', ':', 'Color', [0 1 0], 'EraseMode', 'xor');
      set(HC1, 'String', num2str(POS(1)));
   elseif h2=='Baseline 2'
      set(HL2, 'Visible', 'off');
      POS(2)=h1(1,2);
      HL2=line([xlim(1) xlim(2)], [POS(2) POS(2)], 'LineStyle', ':', 'Color', [0 1 0], 'EraseMode', 'xor');
      set(HC2, 'String', num2str(POS(2)));
   elseif h2=='TransPoint',
      set(HL3, 'Visible', 'off');
      POS(1)=h1(1,1);
      HL3=line([POS(1) POS(1)], [y0 ym], 'LineStyle', ':', 'Color', [0 1 0], 'EraseMode', 'xor');
      set(HC3, 'String', num2str(POS(1)));
   end %if
elseif strcmp(action, 'trpval'),
      trp=str2num(get(HTRPVAL, 'String'));
      if rem(trp,2)==0, set(HTRPVAL, 'String', num2str(trp+1)); end
      if trp<=3, set(HTRPVAL, 'String', num2str(5)); end
elseif strcmp(action, 'disp'),
   plot((G4:G4+G2), G1(G4:G4+G2), 'EraseMode', 'xor', 'LineStyle', '.'); h=gca; set(h, 'XLim', [G4 G4+G2], 'YLim', YLIM/G3);
   HL1=line([0 0], [0 0], 'EraseMode', 'xor'); HL2=line([0 0], [0 0], 'EraseMode', 'xor');HL3=line([0 0], [0 0], 'EraseMode', 'xor');
elseif strcmp(action, 'mode'),
   h=get(HMODE, 'String');
   if h=='Baseline 1',
      set(HMODE, 'String', 'Baseline 2');
   elseif h=='Baseline 2',
      set(HMODE, 'String', 'TransPoint');
   elseif h=='TransPoint',
      set(HMODE, 'String', 'Baseline 1');
   end %if
elseif strcmp(action, 'zoom'),
   s=get(HZOOM, 'String');
   if strcmp(s, 'Zoom on'), 
      set(HZOOM, 'String', 'Zoom off'); zoom on
   else
      set(HZOOM, 'String', 'Zoom on'); zoom off
      set(gcf, 'WindowButtonDownfcn', 'uijcorr(''buttondown'', G1, G2, G3, G4)');
   end %if
elseif strcmp(action, 'correct'),
   bl1=str2num(get(HC1, 'String'));
   bl2=str2num(get(HC2, 'String'));
   trp=round(str2num(get(HC3, 'String')));
   trange=str2num(get(HTRPVAL, 'String')); h=floor(trange/2);
   p=polyfit(trp-2*h-2:trp+2*h+2, [bl1 bl1 G1(trp-2*h:trp+2*h) bl2 bl2], 5);
   if trp~=0,
      G1(trp-h:trp+h)=G1(trp-h:trp+h)-polyval(p, trp-h:trp+h)+bl1;
      G1(trp+h+1:length(G1))=G1(trp+h+1:length(G1))-(bl2-bl1);
      plot((G4:G4+G2), G1(G4:G4+G2), 'EraseMode', 'xor'); h=gca; set(h, 'XLim', [G4 G4+G2], 'YLim', YLIM/G3);
      HL1=line([0 0], [0 0], 'EraseMode', 'xor'); HL2=line([0 0], [0 0], 'EraseMode', 'xor');HL3=line([0 0], [0 0], 'EraseMode', 'xor');
   end %if
elseif strcmp(action, 'quit'),
   G3=0;
   close(gcf);
   clear global P; clear global HPOI; clear global HPOS; clear global P;
   clear global HVSC; clear global HUNDO; clear global HOK; clear global HQUIT;
   clear global HPVAL; clear global HPOIVAL; clear global YLIM;
   clear global HZOOM; clear global HMODE;
   clear global HC1; clear global HC2; clear global HAV; clear global HL1; clear global HL2;
   clear global HVR; clear global HDO; clear global HQUIT; clear global HTRPVAL; clear global HDISP;
elseif strcmp(action, 'ok'),
   G3=1;
   close(gcf);
   clear global P; clear global HPOI; clear global HPOS; clear global P;
   clear global HVSC; clear global HUNDO; clear global HOK; clear global HQUIT;
   clear global HPVAL; clear global HPOIVAL; clear global YLIM;
   clear global HZOOM; clear global HMODE;
   clear global HC1; clear global HC2; clear global HAV; clear global HL1; clear global HL2;
   clear global HVR; clear global HDO; clear global HQUIT; clear global HTRPVAL; clear global HDISP;
end %if

