function acr = autocorr(data, n)
%AUTOCORR  Calculates the Autocorrelation function by use of fourier transform
%
%Syntax	ACR = autocorr(DATA[, N])
%
%Input	DATA	
%	N	Number of points for Fourier-Transformation (power of two)
%		(acr contains N/2 points)
%	
%Output	ACR	Autocorrelation function
%
%Remark	(see e.g. Castro I.P., An Introduction to the digital analysis
%	of stationary signals, 1989)
%
%	(c) A.K. 28.10.1995

if nargin<2, n=length(data); end
len=length(data); k=len/n;
h=n/2;
acr=zeros(h,1);

for i=0:k-1
    df=ft(data((i*n+1):(i+1)*n));
    df=df.*conj(df)./n;
    df(1)=df(1)+i*df(h+1);
    temp=ift(df);
    acr=acr+temp(1:h);
end % for i
acr=acr./k;
