function pds = powers2(data, n, dt)
%POWERS2	Calculates the power spectral density
%
%Syntax	PDS = powers2(DATA[, N,[ DT]])
%
%Input	DATA	
%	N	Number of points for one FT [length(data)]
%	DT	Sampling interval   [1]
%	
%Output	PDS	Power density spectrum
%
%Remark	Yields the minimum spectral variance by subdivision of data in
%	k segments (see Numerical Recipes), additionally the mean of each
%	segment is set to zero before FT
%	Uses the triangular window.
%	The pds is finally multiplied by DT to assure correct amplitude for
%	fluctuation analysis e.g. for ion channel data the amplitude is given
%	by: S(0)=2*sigma^2 / (pi*fc)
%
%	(c) A.K. 4.11.1995

if nargin<3, dt=1; end
if nargin<2, n=length(data); end
len = length(data); m = n/2;
k=len/m-1; %Anzahl Unterteilungen
pds=zeros(m, 1); den = 0;

% Usage of triangular window
sumw = sum(wtri(ones(n,1)).^2);

for kk=0:k-1,
    data(kk*m+1:kk*m+n)=data(kk*m+1:kk*m+n)-mean(data(kk*m+1:kk*m+n)); 
%   Usage of triangular window
    fdata = fft(wtri(data(kk*m+1:kk*m+n)));
    pds = pds + 2*abs(fdata(1:m)).^2;
    den = den + sumw;
end %for kk
pds=pds./den*dt;
