function data = signal(time, sampl, freq, amps, phase, noise)
%SIGNAL	Generation of a time domain signal by superposition of cosine-functions and white noise
%
%Syntax	DATA = signal(TIME, SAMPL, FREQ[, AMPS[, PHASE[, NOISE]]])
%
%       Erzeugt einen Spaltenvektor DATA der Lnge TIME/SAMPL durch
%	berlagerung von cos(2*Pi*FREQ*t + PHASE)-Funktionen mit 
%	weiem Rauschen der Varianz NOISE
%
%Input	TIME	Total time in s
%	SAMPL	Sampling interval in s
%	FREQ	Row vector of frequencies in Hz (min. 2)
%	AMPS		      Amplitudes
%	PHASE		      Phases
%	NOISE	Noise-amplitude (variance)
%	
%Output	DATA	Column vector
%
%Usage	Creates a vector of length TIME/SAMPL by superposition of 
%	cos(2*Pi*FREQ*t + PHASE)-function and wihte noise.
%	Should be used as testing utility
%
%	(c) A.K. 9.7.1994

if nargin<6, noise=0; end
if nargin<5, phase=zeros(1,size(freq,2)); end
if nargin<4, amps=ones(1, size(freq,2)); end
t = (sampl:sampl:time)'*2*pi;
vec = ones(size(t,1),1);
% Erzeugung einer Matrix mit Spalten fr jede Frequenz bzw. Phase
% Elementweise Multiplikation mit den Amplituden
% und Summierung ber jede Zeile
data = sum((sin(t * freq + vec*phase) .* (vec*amps))')';


