%^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
%                orbit program: compute position and                  *
%          velocity (eci) of a satellite from its kepler              *
%                            elements                                 *
%                                                                     *
%          input:a,e,i,om,w1,tp,time                                  *
%                                                                     *
%          output: f,e,r,h,fd,rd,torbit                               *
%                                                                     *
%          files called: kepler,gauss,are,aorb,amgmo,fdot,rdot        *
%                                                                     *
%          math routines required: dot, rot, cross, tilde             *
%                                                                     *
%          [f,e,r,h,fd,rd,torbit] = orbit(a,ee,fin,om,wp,tp,t,const)        *
%                                                                     *
%                                                                     *
%^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

function [f,e,r,h,fd,rd,torbit] = orbit(a,ee,fin,om,wp,tp,t,const)
 rpd = const(1);
 dpr= const(2);
 gm = const(3);

%     compute mean anomaly
      n = sqrt(gm/a^3);
      m=n*(t-tp);

%     solve kepler's equation for the eccentric anomaly
      [e] = kepler(m,ee);

%     solve gauss's equation for the true anomaly
      [f] = gauss(e,ee);

%     compute the radius vector
      [r] = are(a,ee,f);

%     compute the orbit matrix
      [torbit] = aorb(om,wp,f,fin);


%     compute the orbital angular momentum, h
      [h] = angmo(a,ee,const);


%     compute the time derivative of the true anomaly, fd
      [fd] =  fdot(h,r);

%     compute the time derivative of the radius vector
      [rd] = rdot(a,ee,f,fd);

%======================================================================



