function [OutPt,OutDir,ElemPoints] = roapertr(InPt,InDir,FCenter,Normal, ...
                                              Thickness,Radius)
%ROAPERTR aperture
%
%         InPt      : last intersection of incoming rays
%         InDir     : direction of incoming rays
%         FCenter   : center position of aperture
%         Normal    : normal vector at center
%         Thickness : thickness of aperture
%         Radius    : [inner radius, outer radius]
%

% Version 0.4  February 1996
% Part of the RayOptik toolbox
% Copyright 1996 by Georg Beyerle.  All rights reserved.
% beyerle@tmf.jpl.nasa.gov

  OutPt  = InPt;
  OutDir = InDir;

  NofRays = length(InPt(1,:));

  One = ones(1,NofRays);

%
%  front surface
%
  [FPt,FDir,FHit,FFct] = rosrfrfl(InPt,InDir,FCenter,Normal,Radius,[0,0,0]);

  Idx = FHit(2,:);
  OutPt(:,Idx)  = FPt(:,Idx);
  OutDir(:,Idx) = FDir(:,Idx) * NaN; 

%
%  aperture opening
%
  if (Radius(1) > 0),
    Idx = find(FHit(1,:));
    if length(Idx) > 0,

      [Pt,Hit] = rocylind(InPt(:,Idx),InDir(:,Idx),FCenter,Normal, ...
                                Radius(1),1,0,Thickness);

      OutPt(:,Idx(Hit))  = Pt(:,Hit);
      OutDir(:,Idx(Hit)) = Pt(:,Hit) * NaN; 

    end
  end
    
%
%  check if rays hit cylindrical out side
%
  Idx = find(FHit(3,:));
  if length(Idx) > 0,

    [Pt,Hit] = rocylind(InPt(:,Idx),InDir(:,Idx),FCenter,Normal, ...
                                Radius(2),-1,0,Thickness);

    OutPt(:,Idx(Hit))  = Pt(:,Hit);
    OutDir(:,Idx(Hit)) = Pt(:,Hit) * NaN;

  end

%
%  optical axis
%
  OutPt(:,1)  = FCenter;
  OutDir(:,1) = InDir(:,1);

%
%  graphics
%  
  ElemPoints = roelepts(FCenter,Normal,Radius,Thickness,[0,0,0],[0,0,0]);

end
