function [OutPt,Hit] = rocylind(InPt,InDir,Center,Normal,Radius,PMFlag,From,To)
%ROCYLIND rays intersecting a cylinder of radius 'Radius'
%
%           [OutPt,OutDir,Hit] = rocylind(InPt,InDir,Center,Normal,
%                                         Radius,PMFlag)
%
%         InPt     : starting point
%         InDir    : starting direction
%

% Version 0.4  February 1996
% Part of the RayOptik toolbox
% Copyright 1996 by Georg Beyerle.  All rights reserved.
% beyerle@tmf.jpl.nasa.gov

  NofRays = length(InPt(1,:));
  One = ones(1,NofRays);

  if length(PMFlag) == 1,
    PMFlag = PMFlag * One;
  end

  PMinVert = InPt - Center * One;
    
  PMinVertXNormal   = cross(PMinVert, Normal * One);   
  DirXNormal        = cross(InDir, Normal * One);     
  PMinVertDotNormal = Normal' * PMinVert;
  DirDotNormal      = Normal' * InDir;


%
%  intersecting point is   Fct * InDir + InPt, 
%  where  Fct^2 + Num1/Den*Fct + Num2/Den = 0
%
  Num1 = 2 * sum(DirXNormal .* PMinVertXNormal);

  Num2 = -Radius.^2 + sum(PMinVertXNormal.^2);

  Den = sum(DirXNormal.^2);

  Fct = One * NaN;

  Idx = find( Num1.^2/4 >= Num2.*Den & Den ~= 0);

  Fct(Idx) = -Num1(Idx)./Den(Idx)/2 + ...
       sqrt((Num1(Idx)./Den(Idx)/2).^2 - Num2(Idx)./Den(Idx)) .* PMFlag(Idx);

  Idx = (Den == 0 & Num1 ~= 0);
  Fct(Idx) = -Num2(Idx) ./ Num1(Idx);

%
%  we only look forwards
%
  Idx = find( Fct < 0);
  Fct(Idx) = NaN * Idx;

  OutPt = InPt + ([1;1;1] * Fct) .* InDir;

  Dsp = -sum((OutPt-Center*One) .* (Normal*One));

  Hit = (Dsp >= From & Dsp <= To) & ~isnan(OutPt(1,:));

end

