function [Elem, Rays, Wvl, Units] = roexpl02
%ROEXPL02 Example input file for RayOptik
%
%         Newton telescope
%

% Version 0.4  February 1996
% Part of the RayOptik toolbox
% Copyright 1996 by Georg Beyerle.  All rights reserved.
% beyerle@tmf.jpl.nasa.gov

%
%  units : mm
%
  Units = 'mm';

%
%  rays (start points & directions)
%
  M    = 50;
  Max  = 295;
  Step = 2*Max/(M-1);
  Pt            = [0;0;0] * ones(1,2*M);
  Pt(2,1:M)     = (-Max:Step:Max);
  Pt(3,M+1:2*M) = (-Max:Step:Max);

  LenPt = length(Pt(1,:));
  Dir   = [1;0;0] * ones(1,LenPt);

%
%  wavelength in m
%
  Wvl = 632.8e-9 * ones(1,LenPt+1);

%
%  element description
%
  Elem = [...
          'screen    ', ...
          1,[NaN,NaN,NaN],0,[NaN,NaN,NaN], ...
          NaN,NaN,NaN, ...
          NaN,[NaN,NaN,NaN],NaN,[NaN,NaN,NaN], ...
          '          ', ...
          '          ',[NaN,NaN], ...
          '          ',[NaN,NaN]; ...
%
          'aperture  ', ...
          100,[NaN,NaN,NaN],0,[NaN,NaN,NaN], ...
          0,130,20, ...
          NaN,[NaN,NaN,NaN],NaN,[NaN,NaN,NaN], ...
          '          ', ...
          '          ',[NaN,NaN], ...
          '          ',[NaN,NaN]; ...
%
          'mirror    ', ...
          1100,[NaN,NaN,NaN],0,[NaN,NaN,NaN], ...
          0,300,60, ...
          NaN,[NaN,NaN,NaN],NaN,[NaN,NaN,NaN], ...
          '          ', ...
          'spherical ',[-2400,NaN], ...
          '          ',[NaN,NaN]; ...
%
          'mirror    ', ...
          900,[NaN,NaN,NaN],45,[NaN,NaN,NaN], ...
          0,150,30, ...
          NaN,[NaN,NaN,NaN],NaN,[NaN,NaN,NaN], ...
          '          ', ...
          'plane     ',[NaN,NaN], ...
          '          ',[NaN,NaN]; ...
%
          'screen    ', ...
          500,[NaN,NaN,NaN],0,[NaN,NaN,NaN], ...
          NaN,NaN,NaN, ...
          NaN,[NaN,NaN,NaN],NaN,[NaN,NaN,NaN], ...
          '          ', ...
          '          ',[NaN,NaN], ...
          '          ',[NaN,NaN]; ...
];

%
%  optical axis
%
  OAPt  = [0,0,0];
  OADir = [1,0,0];

  Rays  = [OAPt(:) Pt; OADir(:) Dir];

end



