function [Elem, Rays, Wvl, Units] = roexpl01
%ROEXPL01 Example input file for RayOptik
%
%         spherical mirror, multiple reflections
%

% Version 0.4  February 1996
% Part of the RayOptik toolbox
% Copyright 1996 by Georg Beyerle.  All rights reserved.
% beyerle@tmf.jpl.nasa.gov

%
%  units : mm
%
  Units = 'mm';

%
%  rays (start points & directions)
%
  M    = 5;
  Max  = 24;
  Min  = 20;
  Step      = (Max-Min)/(M-1);
  Pt        = [0;0;0] * ones(1,M);
  Pt(2,1:M) = (Min:Step:Max);

  LenPt = length(Pt(1,:));
  Dir   = [1;0;0] * ones(1,LenPt);

%
%  wavelength in m
%
  Wvl = 632.8e-9 * ones(1,LenPt + 1);

%
%  element description
%
  Elem = [...
          'screen    ', ...
          1,[NaN,NaN,NaN],0,[NaN,NaN,NaN], ...
          NaN,NaN,NaN, ...
          NaN,[NaN,NaN,NaN],NaN,[NaN,NaN,NaN], ...
          '          ', ...
          '          ',[NaN,NaN], ...
          '          ',[NaN,NaN]; ...
%
          'mirror    ', ...
          100,[NaN,NaN,NaN],0,[NaN,NaN,NaN], ...
          0,25,5, ...
          NaN,[NaN,NaN,NaN],NaN,[NaN,NaN,NaN], ...
          '          ', ...
          'spherical ',[-25,NaN], ...
          '          ',[NaN,NaN]; ...
%
          'screen    ', ...
          100,[NaN,NaN,NaN],0,[NaN,NaN,NaN], ...
          NaN,NaN,NaN, ...
          NaN,[NaN,NaN,NaN],NaN,[NaN,NaN,NaN], ...
          '          ', ...
          '          ',[NaN,NaN], ...
          '          ',[NaN,NaN]; ...
];

%
%  optical axis
%
  OAPt  = [0,0,0];
  OADir = [1,0,0];

  Rays  = [OAPt(:) Pt; OADir(:) Dir];

end



