function RI = rorfridx(Wvl, Material)
%RORFRIDX  refractive index of material 'Material' at wavelength 'Wvl'
%
%            RI = rorfridx(Wavelength, Material)
%
%          Following materials are implemented:
%
%            'quarz' (205 - 2000 nm)
%            'bk7'   (365 - 2300 nm)
%            'f2'    (365 - 2300 nm)

% Version 0.4  February 1996
% Part of the RayOptik toolbox
% Copyright 1996 by Georg Beyerle. All rights reserved.
% beyerle@tmf.jpl.nasa.gov

  WvlRange = [205 2000;
              365 2300;
              365 2300;] * 1e-9;

  RIData = [ ...
%
%  synthetic quartz
%
  3.5533743e-025 -3.3761341e-021  1.3594359e-017 ...
 -3.0214587e-014  4.0442017e-011 -3.3338059e-008 ...
  1.6555903e-005 -4.5768251e-003  2.0082663e+000;
%
% BK7
%
  2.3516278e-026 -2.6877207e-022  1.3136880e-018 ...
 -3.5857372e-015  5.9837827e-012 -6.2717517e-009 ...
  4.0598480e-006 -1.5141273e-003  1.7670866e+000;
%
% F2
%
  7.2052735e-026 -8.2205449e-022  4.0059404e-018 ...
 -1.0882194e-014  1.8027131e-011 -1.8685109e-008 ...
  1.1897728e-005 -4.3170032e-003  2.3066832e+000
 ];

  if findstr(lower(Material),'qua') == 1
    SelIdx = 1;
  elseif findstr(lower(Material),'bk7') == 1
    SelIdx = 2;
  elseif findstr(lower(Material),'f2') == 1
    SelIdx = 3;
  else
    error([mfilename ': material >' setstr(Material) '< not yet in library.']);
  end

%
% data is fitted with polynomial of degree 8
%
  RI = polyval(RIData(SelIdx,:),Wvl*1e9);

  Idx = find(Wvl < WvlRange(SelIdx,1) | Wvl > WvlRange(SelIdx,2));
  if length(Idx) > 0,
    error([upper(mfilename) ': wavelength (' int2str(Wvl(Idx(1))*1e9) ' nm) outside range ' ...
       '[' int2str(WvlRange(SelIdx,1)*1e9) ',' int2str(WvlRange(SelIdx,2)*1e9) '] nm']);
  end

end
