function spect = opCache(ch, x1, x2, fftSize, y1, y2)
% spect = opCache(ch, x1, x2, fftSize, y1, y2)
% Return spect frames from x1 to x2 inclusive.
% Calculate which ones need computing and which to retrieve from
% the cache.
% y1 and y2 specify the frequency bin numbers to use.

global opCacheIndex opTimeStamp opSpectParams

maxCache = 5e6;			% max number of cells (roughly) in cache
maxBlock = round(maxCache/10);

if (~exist('opTimeStamp')), opTimeStamp = 0; end

opCacheIndex = opCacheData(ch, 'iget');
if (any(size(opCacheIndex)))
  if (any(opCacheIndex(1,:) ~= sort(opCacheIndex(1,:))))
    [dummy,ix] = sort(opCacheIndex(1,:));		% sort the index
    opCacheIndex = opCacheIndex(:, ix);
    disp('WARNING: opCacheIndex not sorted upon entry to opCache. Sorting...');
  end
end

% figure out which frames need computing and make space for them
[fr0,fr1] = opCacheWhich(x1, x2, opTimeStamp);		% which to compute?
[fr0,fr1] = opCacheSplitSegs(fr0, fr1, floor(maxBlock/fftSize)); % split 'em up
space = floor(maxCache/fftSize) - opCacheData(ch, 'ncols');
if (length(fr0))
  opCacheFlushOld(ch, sum(fr1 - fr0 + 1) - space, opTimeStamp);
end

% get new spect blocks, add to cache
loadp = all(opSpectParams(ch, 1:5) == opCurParams(ch));
for i = 1:length(fr0)
  where = opCacheData(ch, 'ncols')+1;
  if (loadp)
    opCacheData(ch, 'append', opLoadSpect(ch, fr0(i), fr1(i), fftSize/2));
  else
    opCacheData(ch, 'append', opComputeSpect(ch, fr0(i), fr1(i)));
  end
  opCacheIndex = [opCacheIndex, [fr0(i); fr1(i); opTimeStamp; where]];
end

% finish up
opTimeStamp = opTimeStamp + 1;
[dummy,ix] = sort(opCacheIndex(1,:));		% sort the index
opCacheIndex = opCacheIndex(:, ix);		% NB: sorting happens above too
opCacheData(ch, 'iset', opCacheIndex);
spect = opCacheMakeSpect(ch,x1,x2,y1,y2);	% final result
