function opCacheFlushOld(ch, n, tNow)
% opFlushOldCache(ch, n, tNow)
% Clear out space in the channel ch's cache for n more frames, 
% tossing least-recently-used slots.  Don't toss any frame with 
% timestamp tNow or later.

% Terminology:
%   "frame" is a column of opCacheData.
%   "slot" is a column in opCacheIndex.

global opCacheIndex

if (n <= 0 | size(opCacheIndex) == [0 0]), return; end

% calculate which slots to keep
sizes = opCacheIndex(2,:) - opCacheIndex(1,:) + 1;
freemark = (opCacheIndex(3,:) < tNow);		% 0's: keep; 1's: freeable
ifree = find(freemark);				% possibly freeable slots
[dummy, ix] = sort(opCacheIndex(3,ifree));	% ix is index into ifree
ixkeep = find(cumsum(sizes(ifree(ix))) > n);	% index into ix
% keepslots = [find(~freemark), ifree(ix(ixkeep))];   this, or next 2 lines
freemark(ifree(ix(ixkeep))) = zeros(1,length(ixkeep));
keepslots = find(~freemark);

% assemble the slots to keep
x = [];  y = [];
for i = keepslots
  x = [x, length(y)+1];				% new index into cache
  y = [y, opCacheIndex(4,i) : opCacheIndex(4,i)+sizes(i)-1];
end
opCacheIndex = [opCacheIndex(1:3,keepslots); x];
opCacheData(ch, 'setcols', y);			% whew!
