function [fr0,fr1] = opCacheWhich(n1, n2, tNow)
% [fr0,fr1] = opCacheWhich(n1, n2)
% Given a start frame n1 and end frame n2, figure out which frames aren't
% in the cache, returning two vectors of start- and end-frames that
% need computing.  Also, time-stamp the frames that ARE in the cache 
% as being used at time tNow.

global opCacheIndex

if (nCols(opCacheIndex) < 1)			% handle empty cache
  x0 = [];
else						% find empty columns
  x0 = find(opCacheIndex(1,:) <= n2 & opCacheIndex(2,:) >= n1);
  if (length(x0))
    opCacheIndex(3,x0) = tNow*ones(1,length(x0)); % mark slots to keep
  end
end
x1 = opCacheIndex(:, x0); 			% pick out relevant columns
x2 = [([0 n1-1 0 0].'), x1, ([n2+1 0 0 0].')];	% add start and end marks
x3 = x2(1, 2:nCols(x2));
x4 = x2(2, 1:nCols(x2)-1);
fr0 = reduce(x4, x3 - x4 > 1) + 1;
fr1 = reduce(x3, x3 - x4 > 1) - 1;
