function [lolim,hilim,n] = opColorMap(ch, bright, contr, dummy)
% opColorMap(chan, bright, contr, 'setlimits')
% Set colormap limits when drawing a new image.
%
% [lolim,hilim,n] = opColorMap(chan, 'getlimits')
% Return the range of values which should be converted to pixel-values
% ranging from 1 to n.
%
% repaint = opColorMap(chan, bright, contrast)
% If possible, install a colormap for the given brightness and 
% contrast values and return 1.  If not possible, return 0 to indicate
% that the pixels must be repainted.

global opLoLimit opHiLimit opColor opColorDepth

n = 48;					% number of grays
minnie = log(1e-5);			% min displayable value
maxie  = log(1e10);			% max displayable value

if (nargin == 2)			% return limits
  lolim = opLoLimit(ch);
  hilim = opHiLimit(ch);
  return

elseif (nargin == 4)			% set limits
  opLoLimit(ch) = (maxie - minnie) * (bright - contr) + minnie;
  opHiLimit(ch) = (maxie - minnie) * (bright + contr) + minnie;
  %printf('Setting limits: lo %g, hi %g', opLoLimit, opHiLimit);
  return
end

% Construct colormap.
blackval = (maxie - minnie) * (bright - contr/2) + minnie;
whiteval = (maxie - minnie) * (bright + contr/2) + minnie;

range = opHiLimit(ch) - opLoLimit(ch);
c0 = round((blackval-opLoLimit(ch))/range * (n-1) + 1); % black before here
c1 = round((whiteval-opLoLimit(ch))/range * (n-1) + 1); %  white after here

if (c0 < 1 | c1 > n | c1-c0+1 < n/3)
  lolim = 0;			% can't do it; have to repaint pixels
else
  %printf('lolim %g, hilim %g, c0 %g, c1 %g', opLoLimit, opHiLimit, c0, c1);
  map = [ones(c0-1,3); linspace(1,0,c1-c0+1).' * [1 1 1]; zeros(n-c1,3)];
  map = [map; ones(c0-1,1) * (opColor + (1-opColorDepth) * (1-opColor));...
      linspace(1, opColorDepth, c1-c0+1).' * opColor ...
	  + linspace(1-opColorDepth, 0, c1-c0+1).' * (1-opColor); ...
      ones(n-c1,1) * opColor * opColorDepth];
  colormap(map);
  lolim = 1;
end
