function spect = opComputeSpect(ch, fr0, fr1)
% spect = opComputeSpect(ch, fr0, fr1)
% Compute spectrogram frames fr0 to fr1 and add them to the cache.
% Reads the sound file and returns a block of the spectrogram.
% Assumes the cache already has enough space in it to hold the new frames.

global opSrate opDataSize opHopSize opZeroPad opWinType

printf('Computing spect frames %g to %g.', fr0, fr1);

srate   = opSrate(ch);
data    = opDataSize(ch);
hop     = round(opHopSize(ch) * data);
fRate   = srate / hop;
pad     = opZeroPad(ch) * data;
win     = opWinTypeF(data, ch).';

sams = soundIn(opFileName(ch,'getsound'), (fr0-1)*hop, data + (fr1-fr0)*hop).';
height = (data + pad) / 2;
spect = zeros(height, fr1-fr0+1);		% for speed
for f = 0:fr1-fr0
  res = fft([sams(f*hop + 1 : f*hop + data) .* win, zeros(1,pad)]);
  spect(:,f+1) = res(1:height).';
end
spect = log(abs(spect));	% do log here to avoid multiple 'log of 0' msgs
