function spect = opLoadSpect(ch, x1, x2, frameSize)
% Load frames x1 through x2 inclusive from the spectrogram file.
%
% SPECTROGRAM FILE FORMAT
%
% Spect files start with these 4-byte integers:
%	version		
%	srate		sampling rate (opSrate)
%	dataSize	samples per fft frame (opDataSize)
%	hopSize		hop size, in samples (opHopSize * opDataSize)
%	zeroPad		zero pad size, in multiples of dataSize (opZeroPad)
%	winType		window type (opWinType)
%	brightness	0-1000
%	contrast	0-1000
% Then comes zero-padding out to the fft size (i.e. fftSize*2 bytes).
% This makes the spect readable as a binary file, with only the first 
% column messed up.
%
% Then comes the spect data, column-wise, lowest freq first, 4-byte floats.
%
% See also opSaveSpect, opSetFileInfo.
%
% Version history:  
% Version(header size)
% 0(5): srate, datasize, hopsize, zeropad, wintype
% 1(8): version number prepended; brightness, contrast appended

n = x2 - x1 + 1;
printf('Loading spect frames %g to %g', x1, x2);
skip = frameSize * ceil(length(opCurParams(ch,1))/frameSize);	% header info
spect = reshape(readBinary(opFileName(ch, 'getspect'), ...
                           (skip + frameSize*(x1-1))*4, n*frameSize, 'f'), ...
		frameSize, n);
