function opMeasure(cmd, x0, x1)
% opMeasure('init', chan)
%     Initialize for a given channel.
%
% opMeasure('click', pt)
%     Display the measures for a given mouse click.
%
% opMeasure('newmenu', chan, menu)
%     Set up the menu for display.
%
% opMeasure('checkmenu')
%     Set up the check-marks onthe menu appropriately.
%
% opMeasure('flip', n)
%     Flip measure #n from on to off or vice versa.
%
% opMeasure('painttext', chan)
%     Display the names of the various measures at location opMeasurePos.
%
% opMeasure('newpt', chan, pt)
%     Display the values of the various measures for the given [t f] point.
%
% opMeasure('newsel', chan)
%     Display the values of the various measures for the current selection.

global opc opMeasures opMeasureNames opMeasureMenus opMeasureTexts 
global opMeasureNums opMeasurePos opNsamp opSrate opHopSize opZeroPad
global opSelT0 opSelT1 opSelF0 opSelF1 opWindowAxes opMeasureGram opMeasureSel

if (strcmp(cmd, 'init'))
  opMeasureNames = ...
    str2mat(...
       str2mat(...
          'total length',...
	  'sample rate',...
	  'time',...
	  'frequency',...
	  'amplitude',...
	  'sample #'),...
       str2mat(...
          'start time',...
	  'end time',...
	  'duration',...
          'low freq',...
	  'high freq',...
	  'bandwidth',...
	  'energy',...
	  'peak freq',...
	  'peak time'));
  if (x0 == 1)
    opMeasures(x0,:) = [0 0 1 1 1 0 0 0 0 0 0 0 1 0 0]; % initial set
    opMeasureSel     = [0 0 0 0 0 0 1 1 1 1 1 1 1 1 1]; % selection measures
    opMeasureGram    = [0 0 0 0 0 0 0 0 0 0 0 0 1 1 1]; % need gram for these
  else opMeasures(x0,:) = opMeasures(1,:);
  end
  opMeasureTexts(x0,:) = zeros(1,length(opMeasures));
  opMeasureNums (x0,:) = zeros(1,length(opMeasures));

elseif (strcmp(cmd, 'newmenu'))
  set(x1, 'Callback', 'opMeasure(''checkmenu'');');
  for i = 1:nRows(opMeasureNames)
    opMeasureMenus(x0, i) = uimenu(x1,'Label', opMeasureNames(i,:), ...
	'Callback', ['opMeasure(''flip'', ',num2str(i),')']);
  end

elseif (strcmp(cmd, 'checkmenu'))
  for i = 1:nCols(opMeasureMenus)
    if (opMeasures(opc,i))
      set(opMeasureMenus(opc,i), 'Checked', 'on')
    else
      set(opMeasureMenus(opc,i), 'Checked', 'off')
    end
  end
  
elseif (strcmp(cmd, 'flip'))
  opMeasures(opc,x0) = ~opMeasures(opc,x0);
  opMeasure('painttext', opc);
  
elseif (strcmp(cmd, 'painttext'))
  xoff = 65;
  axes(opWindowAxes);
  delete(opMeasureTexts(x0, find(opMeasureTexts(x0,:))));
  delete(opMeasureNums (x0, find(opMeasureNums (x0,:))));
  x = find(opMeasures(opc,:));
  t = []; n = [];
  if (length(x))
    names = sub([opMeasureNames(x,:), 10*ones(length(x),1)].',0).';
    t = uiMultiText(opMeasurePos(x0,1), opMeasurePos(x0,2), ...
	names(1:length(names)-1), -7, 'FontSize', 10, 'Units','pixels');
    n = uiMultiText(opMeasurePos(x0,1)+xoff, opMeasurePos(x0,2), ...
	setstr(10 * ones(1,length(x)-1)), -7, 'FontSize',10, 'Units','pixels');
  end
  opMeasureTexts(x0,:) = [t, zeros(1, nCols(opMeasures) - length(t))];
  opMeasureNums (x0,:) = [n, zeros(1, nCols(opMeasures) - length(n))];
  opMeasure('newsel',x0);

elseif (strcmp(cmd, 'newpt') | strcmp(cmd, 'newsel'))
  sel = [];
  if (opSelect(x0)), sel=[opSelT0(x0) opSelF0(x0) opSelT1(x0) opSelF1(x0)]; end

  axes(opWindowAxes);
  k = 0;
  p = strcmp(cmd, 'newpt');			% show point values?
  s = strcmp(cmd, 'newsel') & length(sel);	% show selection values?
  if (s & any(opMeasures(x0,:) & opMeasureGram))
    [spect,p,bx] = opGetSpect(x0, sel(1), sel(3), sel(2), sel(4));
    [nr,nc] = size(spect);
  end
  for i = find(opMeasures(x0,:))
    v = [];
    if     i==1     , v = opNsamp(x0) / opSrate(x0);	suf = 's'; % total len
    elseif i==2     , v = opSrate(x0);			suf = 'Hz';% samp. rate
    elseif i==3  & p, v = x1(1);			suf = 's'; % time
    elseif i==4  & p, v = x1(2);			suf = 'Hz';% frequency
    elseif i==5  & p,
      v = exp(opGetSpect(x0, x1(1),x1(1),x1(2),x1(2))) / 100;	suf = '';% ampl
      if (~length(v)), v = 0; end
    elseif i==6  & p, v = round(x1(1)*opSrate(x0));	suf = '';  % sample no.
    elseif i==7  & s, v = sel(1);			suf = 's'; % start time
    elseif i==8  & s, v = sel(3);			suf = 's'; % end time
    elseif i==9  & s, v = sel(3)-sel(1);		suf = 's'; % duration
    elseif i==10 & s, v = sel(2);			suf = 'Hz';% low freq
    elseif i==11 & s, v = sel(4);			suf = 'Hz';% high freq
    elseif i==12 & s, v = sel(4)-sel(2);		suf = 'Hz';% bandwidth
    elseif i==13 & s,						   % energy
      v = sum(sum(exp(spect)))/100*opHopSize(x0)/(1+opZeroPad(x0)); suf = '';
    elseif i==14 & s,						   % freq peak
      [dummy,v] = max(spect(:));
      v = (rem(v-1,nr)       + 0.5) / nr * (bx(4)-bx(2)) + bx(2); suf = 'Hz';
    elseif i==15 & s,						   % time peak
      [dummy,v] = max(spect(:));
      v = (floor((v-1) / nr) + 0.5) / nc * (bx(3)-bx(1)) + bx(1); suf = 's';
    end
    k = k+1;
    if (length(v))
      if (~v), str = ['0 ', suf];
      else
	y = floor(log10(abs(v)));
	if (-3 < y & y < 5), str = sprintf('%-6.*f %s', 4 - y, v, suf);
	else                 str = sprintf('%-.5ge%+d %s', v/10^y, y,suf);
	end
      end
      set(opMeasureNums(x0,k), 'String', str);
    elseif (strcmp(cmd, 'newsel') & opMeasureSel(i))
      % no v and it's a selectino-display ==> erase selection measures
      set(opMeasureNums(x0,k), 'String', '');
    end
  end
else
  error(['Osprey internal error: Unknown command: ', cmd]);
end
