function str = opPlay(cmd, ch)
% opPlay('button')
% Play the selection (if there is one) or the screen (if not).
% This is called when the user clicks on the button.
%
% opPlay('all')
% Play the whole sound.
%
% opPlay('disptext', ch)
% Display the popup text according whether there's a selection or not.
%
% opPlay('ratetext', ch)
% Return a string to use on the popup play-rate menu.
%
% opPlay('setrate')
% Set the rate to the given value.  This is the menu callback.
%
% opPlay('getrate', ch)
% Return the current playback rate factor.

global opc opNsamp opSrate opT0 opT1 opSelT0 opSelT1 opSelF0 opSelF1
global opPlayBut opFig opTMax opPlayRateMenu opPlayRate

if (nargin < 2), ch = opc; end
issel = opSelect(ch);

if (strcmp(cmd, 'disptext'))
  if (issel), set(opPlayBut(ch), 'String', 'Play Selection');
  else        set(opPlayBut(ch), 'String', 'Play Screen');
  end
  return

elseif (strindex(cmd, 'rate') > 0)
  x = defaultsrate / opSrate(ch);
  x = uniq(round(x ./ 2.^(0:round(log2(x)))));
  if (strcmp(cmd, 'ratetext'))
    str = ['Playback rate', sprintf('|    %gx', x)];
  elseif (strcmp(cmd, 'setrate'))
    x = get(opPlayRateMenu, 'value') - 1;
    if (x > 0), opPlayRate(ch) = x; 
    else set(opPlayRateMenu, 'value', opPlayRate(ch)+1);
    end
  elseif (strcmp(cmd, 'getrate'))
    str = round(max(x) / x(opPlayRate(ch)));
  else 
    error(['Internal error: Bad command ''', cmd, '''.']); 
  end
  return

elseif (strcmp(cmd, 'all'))
  t0 = 0; t1 = opTMax(opc);		% whole sound

elseif (strcmp(cmd, 'button'))
  if (issel), t0 = opSelT0(opc); t1 = opSelT1(opc);	% selection
  else        t0 = opT0(opc);    t1 = opT1(opc);	% screen
  end
else
  error(['Unknown command in opPlay: ', cmd]);
end

s0 = max(round(t0 * opSrate(opc)), 0);
s1 = min(round(t1 * opSrate(opc)), opNsamp(opc));
if (s1 > s0)
  set(opFig, 'Pointer', 'watch');
  soundPlay(soundIn(opFileName(opc,'getsound'), s0, s1-s0), ...
      opPlay('getrate', opc));
  set(opFig, 'Pointer', 'crosshair');
end
