function opRedraw(cmd, filename)
% opRedraw('redraw', filename)
%    Remove everything from the current figure and repaint it.
%
% opRedraw('manualscale')
%    Ask user for scaling values, then rescale image.
%
% opRedraw('manualsize')
%    Ask user for window-size values, then rescale image.
%
% opRedraw('scalecallback')
%    This is used in the manscale code for handling user input.
%
% opRedraw('sizecallback')
%    This is used in the mansize code for handling user input.


% N.B. opAxes object does not necessarily exist yet.

global opc opT0 opT1 opF0 opF1 opTMax opSrate opAxes opFig
global uiInput1 uiInput2 uiInputButton

if (nargin < 1), cmd = 'redraw'; end

if (strcmp(cmd, 'manscale') | strcmp(cmd,'scalecallback'))
  set(opAxes(opc), 'Units', 'inches');  
  pos = get(opAxes(opc), 'Position');
  cur = [opT1(opc)-opT0(opc), opF1(opc)-opF0(opc)] ./ pos(3:4);
  if (strcmp(cmd, 'manscale'))
    uiInput('Manual scaling','OK|Cancel','opRedraw(''scalecallback'')',...
	[0 0], 'X-axis seconds per inch', num2str(cur(1)), ...
	'Y-axis Hertz per inch', num2str(cur(2)))
    return;	% execution continues immediately below upon user input
  end
  if (uiInputButton ~= 1), return; end
  x = str2num(uiInput1);
  y = str2num(uiInput2);
  if (length(x) ~= 1 | any(x<=0)), x=cur(1); end
  if (length(y) ~= 1 | any(y<=0)), y=cur(2); end

  [opT0(opc),opT1(opc),a1] = opRescale(opT0(opc),opT1(opc),opTMax(opc),   x,1);
  [opF0(opc),opF1(opc),a2] = opRescale(opF0(opc),opF1(opc),opSrate(opc)/2,y,2);
  if (a1 | a2), cmd = 'redraw';		% fall through
  else opRefresh(opc); end

elseif (strcmp(cmd, 'mansize') | strcmp(cmd, 'sizecallback'))
  set(opAxes(opc), 'Units', 'inches');  pos = get(opAxes(opc), 'Position');
  set(opFig,       'Units', 'inches'); fpos = get(opFig,       'Position');
  if (strcmp(cmd, 'mansize'))
    uiInput('Manual sizing','OK|Cancel', 'opRedraw(''sizecallback'')',[0 0],...
	'Image width, inches', num2str(pos(3)), ...
	'Image height, inches',num2str(pos(4)));
    return;	% execution continues immediately below upon user input
  end
  if (uiInputButton ~= 1), return; end
  x = str2num(uiInput1);
  y = str2num(uiInput2);
  if (length(x) ~= 1 | any(x<=0)), x=pos(3); end
  if (length(y) ~= 1 | any(y<=0)), y=pos(4); end
  set(opFig, 'Position', [fpos(1:2), [x y] + (fpos(3:4) - pos(3:4))]); drawnow;
  cmd = 'redraw';			% fall through
end


if (strcmp(cmd,'redraw'))	% may get executed after manscale or mansize
  if (nargin < 2), filename = ''; end
  if (~length(filename))
    filename = opFileName(opc, 'getsound');
    if (length(filename) == 0), filename = opFileName(opc, 'getspect'); end
  end
  opInitFigure(filename);
  opRepaintControls(opc);
  opRefresh(opc);
end
