function [x0,x1,repaint] = opRescale(x0, x1, xMax, new, dim)
% [x0,x1,repaint] = opRescale(x0, x1, xMax, new, dim)
% Rescale the dimensions of opAxes to fit the given size.
% If the sound is too short for the new size, force it --
% resize window to make it fit.
%
% 'repaint' is 1 if the window was resized and therefore needs repainting.
%
% x0	old (and new returned value) start
% x1	old ( " ) end
% xMax	maximum along this dimension; minimum is assumed to be 0
% new	new s/in or Hz/in
% dim	1 for x-dim or 2 for y-dim

global opAxes opFig opc

set(opAxes(opc), 'Units', 'inches');  pos = get(opAxes(opc), 'Position');
set(opFig,       'Units', 'inches'); fpos = get(opFig, 'Position');

scale = new / ((x1 - x0) / pos(dim+2));
x1 = x0 + pos(dim+2)*new;
repaint = 0;
if (x1 > xMax)
  x0 = x0 - (x1 - xMax);
  x1 = xMax;
  if (x0 < 0)
    % image is too big at new scale; have to resize the window
    z = fpos(dim+2) - pos(dim+2);	% size of non-image part of window
    if (dim == 1)
      set(opFig, 'Position', [fpos(1:2) ((fpos(3)-z)*(x1/(x1-x0))+z) fpos(4)]);
    else
      set(opFig, 'Position', [fpos(1:2) fpos(3) ((fpos(4)-z)*(x1/(x1-x0))+z)]);
    end
    x0 = 0;
    repaint = 1;
  end
end
