function opSaveSpect
% Compute an entire spectrogram with the current settings and save
% it in a file.
% Calls opCache, which does the computing.  To prevent loading from
% the spect file (which is being written), the sampling rate of the
% spect file is arbitrarily set to 0; presumably no real file will
% will have this sampling rate.
%
% See also opLoadSpect, opSetFileInfo.

global opc opDataSize opHopSize opNsamp opZeroPad opSpectParams opFig

set(opFig, 'Pointer', 'watch');

data      = opDataSize(opc);
hop       = round(opHopSize(opc) * data);
nframe    = floor((opNsamp(opc) - data) / hop + 1);
fftSize   = (data * (1+opZeroPad(opc)));
frameSize = fftSize / 2;

spectfile = opFileName(opc, 'getspect');
cur = opCurParams(opc, 1);
fill = frameSize * ceil(length(cur)/frameSize) - length(cur);
writeBinary(spectfile, 0, [cur, zeros(1, fill)], 'l', 1);
off = (length(cur) + fill) * 4;

opSpectParams(opc, 1) = 0;		% this is a hack!
chunk = round(262144 / frameSize);
for i = 0:chunk:nframe
  spect = opCache(opc, i+1, min(i+chunk, nframe), fftSize, 1, frameSize);
  printf('Writing spect frames %g to %g', i+1, i+nCols(spect));
  writeBinary(spectfile, off, spect, 'f');
  off = off + prod(size(spect))*4;
end

opSetFileInfo(opc, opFileName(opc, 'getsound'));
set(opFig, 'Pointer', 'crosshair');
