function x = opSelect(typ)
% bool = opSelect(chan)
% Return 1 if the given channel has a selection, 0 otherwise.
%
% opSelect('win-h')
% Extend selection to the current window in the time direction.
%
% opSelect('win-v')
% Extend selection to the current window in the frequency direction.
%
% opSelect('all-h')
% Extend selection to the whole sound in the time direction.
%
% opSelect('all-v')
% Extend selection to the whole sound in the frequency direction.

global opc opT0 opT1 opF0 opF1 opSelT0 opSelT1 opSelF0 opSelF1 opSrate opTMax

if (~isstr(typ))
  x = (opSelT0(typ) < opSelT1(opc)) & (opSelF0(opc) < opSelF1(opc));

else
  if (strcmp(typ, 'win-h'))
    opSelT0(opc) = opT0(opc);
    opSelT1(opc) = opT1(opc);
  end
  if (strcmp(typ, 'win-v'))
    opSelF0(opc) = opF0(opc);
    opSelF1(opc) = opF1(opc);
  end
  if (strcmp(typ, 'all-h') | strcmp(typ, 'all'))
    opSelT0(opc) = 0;
    opSelT1(opc) = opTMax(opc);
  end
  if (strcmp(typ, 'all-v') | strcmp(typ, 'all'))
    opSelF0(opc) = 0;
    opSelF1(opc) = opSrate(opc) / 2;
  end
  if (strcmp(typ, 'none'))
    opEraseSelection(opc);
  end
  
  opMeasure('newsel', opc);
  opRefresh(opc);
end
