function opSetFileInfo(ch, filename)
% [srate,nsamp,typ] = opSetFileInfo(ch, filename)
% For the given file, find out the sampling rate, the number of samples,
% and the file type.  If there is a .spec file, set up the spectrogram
% parameters for that spectrogram.
%
% The type is one of
%   1	sound file exists
%   2	spectrogram file exists
%   3	both sound and spectrogram files exist
%
% See also opCurParams, opLoadSpect, opSaveSpect.

global opSrate opNsamp opDataSize opHopSize opZeroPad opWinType opSpectParams 
global opFileType opBrightness opContrast opTMax

[dummy,opSrate(ch),opNsamp(ch)] = soundIn(filename,0,0);
opTMax(ch) = opNsamp(ch) / opSrate(ch);
typ = (opSrate(ch) > 0);
if (typ),
  opFileName(ch, 'setsound', filename);
else
  opFileName(ch, 'setsound', '');
end

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Now look for a spect file and set things up if it's there.

spectname = [filename(1:length(filename)-length(pathExt(filename))), 'spec'];
opFileName(ch, 'setspect', spectname);
fid = fopen(spectname, 'r');
if (fid >= 0),
  fclose(fid);
  info = readBinary(spectname, 0, 8, 'l');
  opSpectVer(ch)   = info(1);
  % don't set srate; it has to match for spect-file reading to work
  opDataSize(ch)   = info(3);
  opHopSize(ch)    = info(4) / info(3);
  opZeroPad(ch)    = info(5);
  opWinType(ch)    = info(6);
  opBrightness(ch) = info(7) / 1000;
  opContrast(ch)   = info(8) / 1000;
  opSpectParams(ch, 1:5) = info(2:6).';
  frameSize = (opDataSize(ch) * (1+opZeroPad(ch))) / 2;		% == fftSize/2
  [dummy,nnum] = readBinary(spectname, frameSize*4, 0, 'f');
  opNsamp(ch) = (nnum/frameSize - 1) * info(4) + opDataSize(ch);
  opTMax(ch) = opNsamp(ch) / opSrate(ch);
  typ = typ + 2;
end

if (typ == 0)
  error(['Can''t find sound or spect file ', filename]);
end

opFileType(ch) = typ;
