function opSlider(which)
% opSlider(which)
% Read a value from a slider and repaint accordingly.  The arg 'which'
% is either b, c, h, or v, depending on the slider that was changed.
% 
% If the user clicks on the H or V scroll bar either outside the button or
% on the arrow, detect that and scroll by the appropriate amount rather
% than the amount MATLAB wants to move the slider.

global opc opBrightness opContrast opBrightnessSlider opContrastSlider
global opHScrollBar opVScrollBar opHScrollSkip opVScrollSkip opFig
global opTMax opSrate opT0 opT1 opF0 opF1 uiSliderClick uiSliderPrev

obj = get(opFig, 'CurrentObject');
if (which == 'b' | which == 'c')
  opBrightness(opc) = get(opBrightnessSlider, 'Value');
  opContrast(opc)   = get(opContrastSlider,   'Value');
  if (opColorMap(opc, opBrightness(opc), 1-opContrast(opc)))
    return;
  end
  % otherwise fall through and repaint the image

else
  % Figure out previous and current scrollbar values, and how far to scroll.
  if (which == 'h')
    x0 = opT0(opc);
    x1 = opT1(opc);
    xMax = opTMax(opc);
    skip = opHScrollSkip;
    obj = opHScrollBar;
  elseif (which == 'v')
    x0 = opF0(opc);
    x1 = opF1(opc);
    xMax = opSrate(opc) / 2;
    skip = opVScrollSkip;
    obj = opVScrollBar;
  else
    error(['Internal error: Impossible slider type ''', which, '''.']);
  end
  
  now = get(obj, 'Value');
  prev = uiSliderPrev;

  len = x1 - x0;
  long = opSliderSetting(xMax, len * skip, len * skip + len);
  short = long / 10;
  if     (strcmp(uiSliderClick, 'upsmall')),   now = prev + short;
  elseif (strcmp(uiSliderClick, 'downsmall')), now = prev - short;
  elseif (strcmp(uiSliderClick, 'upbig')),     now = prev + long;
  elseif (strcmp(uiSliderClick, 'downbig')),   now = prev - long;
  else   % leave 'now' alone
  end
  
  now = min(1, max(0, now));
  
  if (len < xMax)
    if (which == 'h')
      opT0(opc) = (xMax - len) * now;
      opT1(opc) = opT0(opc) + len;
    else
      opF0(opc) = (xMax - len) * now;
      opF1(opc) = opF0(opc) + len;
    end
  end
end

opRefresh(opc);
