function x = loadascii(filename)
%LOADASCII   Load an ascii file, returns its contents as a matrix.
%
% x = loadascii(filename)
% Return the contents of the file as a numeric array.  This allows
% you to name the result whatever you like, instead of having to
% hack around with the name MATLAB chooses.
%
% This routine currently works fully only on unix machines, partly only
% on Macs, and not at all of PC's or other machines.  If you can
% add your machine type, please do so, then send the changes to 
% dkm1@cornell.edu.
%
% See also mlFileNameFilter.

if (isunix)
  % first quote shell special characters with '\'
  special = ' $''"`!\^(){}&*?><;:|~';
  p = any(   ones(length(special), 1) * filename...  % places that need quoting
          == special.' * ones(1, length(filename)));
  filename = [p*'\'; filename];
  filename = reduce(filename(:), filename(:)).';

  temp = tempname;
  eval(['!ln -s ',filename,' ', temp]);
  load(temp);
  eval(['!/bin/rm ', temp]);		% use /bin/rm to avoid 'rm -i' alias
  eval(['x = ', mlFileNameFilter(temp), ';']);
else
  c = computer;
  if (strcmp(c(1:3), 'MAC'))
    % Doesn't always work.
    load(filename);
    eval(['x = ', mlFileNameFilter(filename), ';']);
  elseif (strcmp(c(1:2), 'PC'))
    error('Please write code in loadascii.m for PC''s, ',...
	  'then send it to dkm1@cornell.edu.');
  else
    error(['Please write code for your computer type, ', c, ...
	      ', then send it to dkm1@cornell.edu.']);
  end
end
