function y = percentile(x, pct)
% y = PERCENTILE(x, pct)
% Example: percentile(x, 0.10) is the value that is higher than 10%
% of the elements of x, and less than the remaining 90%.
% If the length of x is such that there is no element of x exactly
% corresponding to the 'pct' position, a weighted average of the two
% adjacent values is used.  For this computation, the smallest element
% of x corresponds to pct=0, and the largest to pct=1. This convention
% can lead to some unexpected answers; try  percentile(1:10,1/3)  .
%
% percentile(x, 0.5) is the median of x.
%
% If x is a matrix, percentile operates on columns, returning a row vector.

if (nRows(x) == 1), x = x.'; end
x = sort(x);
n = (nRows(x) - 1) * pct + 1;
r = rem(n, 1);
if (r > 0)
  y = x(n,:) * r + x(n+1,:) * (1-r);
else
  y = x(n,:);
end
