function soundPlay(snd, f)
%soundPlay    Play a sound with interpolated samples.
%
% soundPlay(x)
% Play vector x at the default sampling rate of the machine.  On the 
% Sun, this is 8192 Hz; on the Mac, 22254.54 Hz.
%
% soundPlay(x, f)
% Play x, but slowed down by a factor of f.  f must be an integer.
% This is done by linearly interpolating samples.
%
% See also sound, soundIn, and the lower-level routines
% auwrite (Sun), playsound (Mac, Next, SGI), wavwrite (PC).

if (nargin < 2), f = 1; end
if (f ~= round(f)), error('Playback factor must be an integer.'); end

if (f == 1)
  sound(snd);
else
  snd = snd(:).';
  y = ((f:-1:1) / f).';
  n = length(snd);
  sound(reshape(y*snd(1:n-1) + (1-y)*snd(2:n), length(snd)*f-f, 1));
end
