function [out1,out2] = ginp(arg1)
%GINP	Graphical input from a mouse.
% 	[X,Y] = GINP gets 1 point from the current axes and returns 
% 	the instant X- and Y-coordinates in X and Y.  The cursor
% 	can be positioned using a mouse. 
% 
%	Adapted by G. Evangelista 1995 from 
%	GINPUT.M (Copyright (c) 1984-93 by The MathWorks, Inc).

    fig = gcf;
    ax = gca;
    fig_units = get(fig,'units');
    set(fig,'units','normalized');
    axu = get(ax,'units');
    set(ax,'units','normalized')
    xlin = strcmp('linear',get(ax,'xscale'));
    ylin = strcmp('linear',get(ax,'yscale'));
    if nargin > 0
        norm_rect = [0 0 1 1];
    else
        norm_rect = get(ax,'Position');
	AR=get(ax,'AspectRatio');
	if ~isnan(AR(1))	% Handle Axis "square" or "image"
		set(gcf,'units','pixels');
		fp=get(fig,'position');
		set(gcf,'units','normalized');
		R=AR(1)*fp(4)/fp(3);
		if R<1
			norm_rect(1)=norm_rect(1)+norm_rect(4)*(1-R)/2;
			norm_rect(3)=norm_rect(4)*R;
		else
			norm_rect(2)=norm_rect(2)+norm_rect(3)*(1-1/R)/2;
			norm_rect(4)=norm_rect(3)/R;
		end
	end	
        ydir = get(ax,'ydir');
        ax_lim  = axis;
        if ~xlin, ax_lim(1:2) = log(ax_lim(1:2)); end
        if ~ylin, ax_lim(3:4) = log(ax_lim(3:4)); end
        d_h = ax_lim(4) - ax_lim(3);
        if strcmp(ydir,'reverse'), ax_lim(3) = ax_lim(4); d_h = -d_h; end
        d_w = ax_lim(2) - ax_lim(1);
    end
    ptr_fig = -1; ptr_win=-1;
    while(ptr_fig ~= fig)|(ptr_win ~= fig) 
	ptr_fig = get(0,'CurrentFigure'); 
	ptr_win=get(0,'PointerWindow');
    end;
                scrn_pt = get(0, 'PointerLocation');
                set(fig,'units','pixels')
                loc = get(fig, 'Position');
                set(fig,'units','normalized')
                pt = [scrn_pt(1) - loc(1), scrn_pt(2) - loc(2)];
                ax_rect = [fix(norm_rect(1)*loc(3)),fix(norm_rect(2)*loc(4)),...
                    fix(norm_rect(3)*loc(3)),fix(norm_rect(4)*loc(4))];
                pt(1) = (pt(1) - ax_rect(1))/ax_rect(3);
                pt(2) = (pt(2) - ax_rect(2))/ax_rect(4);
                if nargin < 1
                    pt(1) = ax_lim(1) + pt(1) * d_w;
                    pt(2) = ax_lim(3) + pt(2) * d_h;
                    if ~xlin, pt(1) = exp(pt(1)); end
                    if ~ylin, pt(2) = exp(pt(2)); end
                end
                 	
    out1 = [out1;pt(1,1)];
    y = [y;pt(1,2)];
    if nargout > 1
        out2 = y;
    else
        out1 = [out1 y];
    end
    set(fig,'units',fig_units);
    set(ax,'units',axu)

