function zoomplot(s,SR,nme,xlab,ylab,pos,t0,oldf)
%
%ZOOMPLOT user's entry point to Analyze
%
%	  this function may be called with up to 8 parameters:
%
%         zoomplot by itself brings up the Analyze Startup Window
%
%	  zoomplot(s) brings up the Signal Panel window containing the signal s
%	              If s is a matrix, the Signal Panel will contain as many
%		      signals as are the number of columns of s.
%
%	  zoomplot(s,SR) specifies the sampling rate SR (scalar).
%
%	  zoomplot(s,SR,name) also specifies the title of window, where name is a
%			      string. 
%
%	  zoomplot(s,SR,name,xlab) also specifies the x-axis label, where xlab is a 
%			      string.
%
%	  zoomplot(s,SR,name,xlab,ylab) also specifies the y-axis label, where
% 					ylab is a string.
%
%	  zoomplot(s,SR,name,xlab,ylab,pos) also specifies the position of the window,
%					    where pos=[xmin,ymin,width,height] is a 4-vector
%
%	  zoomplot(s,SR,name,xlab,ylab,pos,t0) also specifies the time origin t0 (scalar)
%
%	  zoomplot called with eight parameters replaces the current figure with a Signal Panel;
%	           this parameter is arbitrary.	To work properly, the figure must be created with
%		   the function newfig. Users are not encouraged to use this option.



%         Copyright (c) by G. Evangelista, Universita` "Federico II" di Napoli, Italia, 1994-96   
%
if nargin<7
	t0=0;
	if nargin<6
		pos=maxpos;
		if nargin<5
			ylab='Amplitude';
			if nargin<4
				xlab='Time (sec.)';
				if nargin<3, 
					nme='Signal';
					if nargin<2, SR=1; end
				end
			end
		end
	end
end
if nargin>0
	hlp=ishlp;
	if nargin<8, newfig(0,nme,0); end
	H=gcf; hnd=get(H,'user');
	
	set(H,'Position',pos);
	[L,nsig]=size(s);
	if L==0
		s=zeros(2,nsig); L=2; nsig=1;
	end
	maximag=max(max(abs(imag(s))));
	if maximag>0, sigerr(0,H,maximag); s=real(s); end
	if L==1, s=conj(s'); L=nsig; nsig=1; end
	Ms=max(max(s)); ms=min(min(s)); if abs(Ms-ms)<1e-5, Ms=ms+1e-5; ms=ms-1e-5; end
	zo=L; ofs=1; n=0; endp=L;
	XYc=uimenu(H,'Label','XY'); 
	uimenu(XYc,'Label','Unselect','Enable','off','Tag','Unsel','Callback','selframe(''Unselect'');');
	An=uimenu(H,'Label','More...'); drawnow;
	F=int2str(H);
	set(An,'Callback',['chkhelp(''More''); An=getanhan(',F,'); zpmore(An);']);
	Cz=uicontrol(H,'Position',[1,44,19,500],'Style','slider');						
	Cb=uicontrol(H,'Position',[20,44,16,16],'Style','pushbutton','String','O');					
	Cb1=uicontrol(H,'Position',[1,21,19,19],'Style','pushbutton','String','<');				
	Cb2=uicontrol(H,'Position',[21,21,19,19],'Style','pushbutton','String','>');				
	Rb=uicontrol(H,'Position',[20,61,16,16],'Style','pushbutton','String','R');				
	[CT,CTS,SSR,HHxy(1),HHxy(2),ext]=sigbar(H);
	p=get(HHxy(2),'pos'); p=p(1)+p(3)+2;
	pm=maxpos; pm=pm(3)-p-120; 
	C=uicontrol(H,'Position',[p,1,pm,19],'Style','slider');
	p=p+pm;
	hH=uicontrol(H,'Position',[p,1,120,19],'Style','pushbutton','back',[.75 .75 .75]);	
	set(hH,'String',get(hnd,'user'));
	set(hH,'Callback','t=get(gco,''String''); helpon(t,0);');			
	set(CT,'String',int2str(zo));
	set(CTS,'String',int2str(ofs));
	set(SSR,'String',num2str(SR));
	set(C,'CallBack','selframe(''TimeShiftSli'');');
	set(CTS,'CallBack','selframe(''TimeShiftEd'');');
	set(Cz,'CallBack','selframe(''ZoomSli'');');
	set(Cb,'CallBack','selframe(''Samples'');');
	set(Rb,'CallBack','selframe(''Reset'')');
	set(Cb1,'CallBack','selframe(''LeftShift'');','user',[hnd hH]);
	set(Cb2,'CallBack','selframe(''RightShift'');');
	set(CT,'CallBack','selframe(''ZoomEd'')');
	set(SSR,'CallBack','selframe(''SR'')');
	if hlp, sethelp; end
	plot(t0+(0:L-1)'/SR,s);				
	axis([t0,t0+max([(L-1)/SR,1/SR]),ms,Ms]);
	set(gca,'position',[.13,.14,.77,.78]);
	xlabel(xlab);
	ylabel(ylab);
	XS=0; YS=0; 
	hand=[C; Cz; Cb; Cb1; Cb2; CT; XYc; An; 0; Rb; CTS; HHxy(1); HHxy(2); SSR; ext];
	vars=[nsig; t0; ofs; zo; endp; SR; ms; Ms; 0; XS; YS];
	putdata(s,vars,hand);

	xycodis([HHxy(1),HHxy(2)]);
	selframe(' '); selectw3(0);
else
	figure;	H=gcf; set(H,'Tag','Analyze_Startup');
	set(H,'Name','Analyze Rel. 6.0d - Copyright  1994-96 by Gianpaolo Evangelista');
	set(H,'Position',pos,'NumberTitle','off');
	LDN=uimenu(H,'Label','New');
		LD=uimenu(LDN,'Label','Signal');
			uimenu(LD,'Label','Load .mat','Callback','chkhelp(''Load_mat''); [HH,Nme,fid,typ,fn]=ldmathd(''Signal''); selsig(HH,Nme,fid,typ,fn);');
			uimenu(LD,'Label','Load .wav','Callback','chkhelp(''Load_wav''); ldwav;','Enable','off');
			uimenu(LD,'Label','Load Int','Callback','chkhelp(''Load_Int''); freadint;','Enable','off');
			siggen(0,LD);
		LD=uimenu(LDN,'Label','Image','Enable','off');
			uimenu(LD,'Label','Load .mat','Callback','[HH,Nme,fid,typ]=ldmathd(''Image''); selsig2(HH,Nme,fid,typ);');
			uimenu(LD,'Label','Load BMP','Callback','freadint(3);');drawnow;
			uimenu(LD,'Label','Load Int','Callback','freadint(0);');
		filtdes('DesignMenu',LDN);
	hm=uimenu(gcf,'Label','?');
	uimenu(hm,'Label','Help Topics','CallBack','helpon(''Contents'',0);');
	hnd=uimenu(hm,'Label','Help Agent','CallBack','sethelp(1)');
	uimenu(hm,'Label','About Analyze','CallBack','about');
	uimenu(hm,'Label','How to Register','CallBack','regist');
	uimenu(gcf,'Label','Analyze_Demo','Callback','anademo');
	reginfo
	set(H,'user',hnd,'visible','on');
end