function ATT = atten(attenuation)

%  atten.m  calculates the optimal standard 1% resistors of a simple voltage divider.
%  The input is 'attenuation' which is a number between  0.001 and 1.
%  ATT is returned and contains three columns.    [ att  r1   r2 ]
%      where att is the actual attenuation,  and att = r1/(r1+r2)
%        written by John A.M. Petersen  12-Sept-96

if ((attenuation >= 1))
	error('Duh!  Attenuation means an number less than 1.0. ')
 elseif (attenuation < .001)
   error('This program does not calculate attenuations < .001')
end

rev = 1;
if attenuation < .01
	K = 100;                      % calculate guess for starting resistor index
  N = round((attenuation + .00023)/.00009);
elseif attenuation < .093
	K = 10;
  N = round((attenuation + .0015)/.0008);
elseif attenuation < .500
  K = 1;
  N = round((attenuation - .05)/.004);
else   %  attenuation > .500
  K = 1;
  rev = -1;
  N =  round((1-attenuation)/.004);
end
if (N < 1)
     N = 1;
elseif (N > 96)
     N = 96;
end
r2 = resistor;
r1 = r2;
m = length(r2);
meanerr = 1e6;
BEST = 0;
att = attenuation;
while (~BEST)
   r1last = r1;
   attlast = att;
  if ((N < 1)|(N > 96))
       break;
   end
  if (N < 2)
      r1 = r2/10/K;
  elseif (N > 95)
      r1 =  r2/K;
  else
     r1 = r2(N:m)/10;
     r1 = [r1' r2(1:N-1)']'/K;    % shift resistors to prepare to calculate attenuation.
  end   
   att = r1./(r1 + r2);
   if (rev == -1)  
       att = 1 - (r1./(r1 + r2));
   end
   meanerrlast = meanerr; %  cost function; determines how close we are to the best
	 meanerr = mean((att - attenuation).^2);    %      set of resistors
	if ((meanerr < meanerrlast) & (mean(att) > attenuation))
			bestguess = N;
			N = N - rev;
	elseif((meanerr < meanerrlast) & (mean(att) < attenuation))
			bestguess = N;
			N = N + rev;
	elseif(meanerr > meanerrlast)
			BEST =  bestguess;
  end
end
if (rev==1)
    ATT = [attlast r1last r2];
else
     ATT = [attlast r2  r1last];
end
err = abs(attenuation - ATT(:,1));
[x,i] = sort(err);    % Order ATT from smallest error to largest error
ATT = ATT(i,:);
plot(x*100,ATT(:,1),'x',x*100,attenuation*ones(m,1),'g')
title(' ATTENUATION  =  R1/(R1 + R2)')
xlabel('Percent Error')
ylabel('Attenuation')
