function x=fconv2(y, h, shape);

% FCONV2	Two dimensional convolution.
% 		C = FCONV2(A, B) performs the 2-D convolution of matrices
% 		A and B.   Fast Version Using FT. 
%		If [ma,na] = size(A) and [mb,nb] = size(B), then 
% 		size(C) = [ma+mb-1,na+nb-1]. 
%		If input real then so is Output.
%
%		C = FCONV2(A,B,'shape') returns a subsection of the 2-D
%		convolution with size specified by 'shape':
%		  'full'  - (default) returns the full 2-D convolution, 
%		  'same'  - returns the central part of the convolution 
%		            that is the same size as A.
%		  'valid' - returns only those parts of the convolution
%		            that are computed without the zero-padded
%		            edges, size(C) = [ma-mb+1,na-nb+1] when
%	       		    size(A) > size(B).
%
%		David Lopes - 26/11/96 - ISVR, University of Southampton, England.

error(nargchk(2,3,nargin));
if nargin<3, shape = '!'; end

%Check Input Arguements

code = [shape,' ']; code = code(1);
if isempty(find(code=='svf')), error('Shape Parameter Not Known'); end

%Zero Pad Data
yt=[y, zeros(size(y,1),size(h,2)-1)];	yt=[yt; zeros(size(h,1)-1, size(yt,2))];
ht=[h, zeros(size(h,1),size(y,2)-1)];	ht=[ht; zeros(size(y,1)-1, size(ht,2))];

%2D Ft and IFt
Y=fft(fft(yt).').';	H=fft(fft(ht).').';	
t=Y.*H;			x=conj(fft(fft(conj(t)).')).';	x = x/prod(size(x));

% Return Real Output if Real Input
if (all(all(~imag(y)))) & (all(all(~imag(h))))
	x=real(x);
end;

% Put into the same format as matlab - conv2 routine. 
[xy,yy] = size(y);	[xh,yh] = size(h);

if (code =='s')
    	x = x((floor(xy/2) + (1:xh)),(floor(yy/2) + (1:yh)));
elseif (code == 'v')
  	x = x((xh-1 + (1:xy-xh+1)),(yh-1 + (1:yy-yh+1)));
end
