function filterfile(B,A,filefrom,fileto,precin,size,precout)
% Out of core filtering routine.
%
% filterfile(B,A,filefrom,fileto,precin,size,precout)
%
% Compute fileto=filter(B,A,filefrom)
%
% where the data in filefrom are in precision precin (see help fread) and in
% fileto are given in precision precout and each chunk read is of size size.
% 
% The files should be filenames.
%
% Defaults are: precin='double'
%               size  =16384
%               precout=precin
%
% Written by Hans Olsson, Hans.Olsson@dna.lth.se,1996-12-06.

if(nargin<5) precin='double';end;
if(nargin<6) size=16384;end;
if(nargin<7) precout=precin;end;

fidfrom=fopen(filefrom,'r');
if (fidfrom==-1) error(['Could not open ',filefrom]);end;
fidto=fopen(fileto,'w');
if (fidto==-1) error(['Could not open ',fileto]);end;

[x,cnt]=fread(fidfrom,size,precin);
[y,z]=filter(B,A,x);
fwrite(fidto,y,precout);
while cnt>0
  [x,cnt]=fread(fidfrom,size,precin);
  [y,z]=filter(B,A,x,z);
  fwrite(fidto,y,precout);
end

fclose(fidfrom);
fclose(fidto);
