function GAINANDR = gain( G )    

%  gain.m  searches for the best resistor ratio for the desired gain, G, 
%         using standard 1% resistors         
%  GAINANDR is a 3 column matrix of the form [gain  r1 r2]
%  The best gains are plotted wrt the error compaired to G.
%   Written by John A.M. Petersen    9 Sept 1996

if ((G >= 10) | (G<= 1))
	error('Gain must be between 1 and 10.  Just scale the resistors for your actual gain.')
end
r2 = resistor;                              
r1 = r2;
m = length(r2);
if (G>9.53)
     N = 1;
else                                                            %initial guess for which resistors to ratio
     N = m - min(find(r2 > G*100));  %      see the while loop.
end
BEST = 0;
GAIN = G;
meanerr = 1e6;
while(~BEST)
  r1last = r1;
	GAINlast = GAIN;
  r1 = r2(N:m)/10;
	r1 = [r1' r2(1:N-1)']';           % shift resistors to prepare to calculate GAIN.
	GAIN = r2./r1;
	meanerrlast = meanerr; %  cost function; determines how close we are to the best
	meanerr = mean((GAIN - G).^2);    %      set of resistors
	if ((meanerr < meanerrlast) & (mean(GAIN) > G))
			bestguess = N;
			N = N + 1;
	elseif((meanerr < meanerrlast) & (mean(GAIN) < G))
			bestguess = N;
			N = N - 1;
	elseif(meanerr > meanerrlast)
			BEST =  bestguess;
	end
end
GAINANDR = [GAINlast r1last r2];              
x=[1:m]'; 
err = abs(G - GAINANDR(:,1));
[x,i] = sort(err);    % Sort from smallest error to largest error
GAINANDR = GAINANDR(i,:);
plot(100*x,GAINANDR(:,1),'x',100*x,G*ones(m,1),'g')
title('GAIN = R2/R1')
xlabel('Percent Error')
ylabel('GAIN')
