%GUI to visually analyse fft plots, and display Harmonics
%within the CURRENT figure window.
%
%Duncan Allison, Auto Studies Group, Cranfield University,
%BEDS, MK43 0AL. E-Mail me066r@cranfield.ac.uk -- 3/1/96
%
%Select "CHOOSE" and use crosshair to select point within the plot area.
%The x-axis (frequency) value is displayed in the text box.
%
%Select "DISPLAY" to draw lines at the harmonics of this frequency
%
%Use the "BASEBAND" slider to reduce the frequency displayed.
%Note - YLimMode should be set to 'auto' in axes properties.

%reset current figure axes to allow positioning of buttons
% and set default values
fighndl=gcf;
zoom off;
axeshndl=gca;
axislims=axis;		%for number of lines and reset to full scale display
fhz=[0 0];		%initial harmonic frequency (not plotted)
oldlinhndl=[];		%line handle matrix

%will use the default position for axes on EXIT
defaultaxes=get(axeshndl,'position');

%size plot axes for space on figure for addition of buttons
set(axeshndl,'units','normalized',...
		'position',[0.13,0.11,0.65,0.815]);


%=====================================
 
%setup buttons

%check box to toggle Zoom
hndl1=uicontrol(fighndl,'style','checkbox','string','Zoom On','units',...
		'normalized',...
		'position',[0.8 0.875 0.18 0.05],...
		'callback','zoom');

%push button to choose frequency to plot
hndl2=uicontrol(fighndl,'style','pushbutton','string','Choose','units',...
		'normalized',...
		'foregroundcolor',[0 1 0],...
		'position',[0.8 0.795 0.18 0.07],...
		'callback',['fhz=ginput(1);',...
			'set(hndl3,''visible'',''on''),',...
			'set(hndl6,''string'',num2str(fhz(1)))']);

%push button to plot lines
hndl3=uicontrol(fighndl,'style','pushbutton','string','Display','units',...
		'normalized','visible','off',...
		'foregroundcolor',[0 1 0],...
		'position',[0.8 0.72 0.18 0.07],...
		'callback',['data=[fhz(1),axislims,oldlinhndl];',...
				'if data(1)==0,','return,',...
				  'else,',...
				    'if size(data,2) >5,',...
				      	'delete(data(6:size(data,2))),',...
					'oldlinhndl=[];',...
				    'end,',...
				  'for n=1:1:fix(data(3)/data(1)),',...
				    'oldlinhndl(n)=line([n*data(1),n*data(1)],[data(4),data(5)]);',...
				  'end,',...
				'set(oldlinhndl,''color'',''red''),',...
			    	'end']);

%push button to end harmonic & reset plot size
hndl4=uicontrol(fighndl,'style','pushbutton','string','Exit','units',...
		'normalized',...
		'foregroundcolor',[1 0 0],...
		'position',[0.8 0.11 0.18 0.07],...
		'callback',['hndllist=[hndl1,hndl2,hndl3,hndl4,hndl5,hndl6,hndl7,hndl8,hndl9];',...
			'axis(axislims),',...
			'zoom off,',...
			'set(axeshndl,''position'',defaultaxes),',...
			'delete(hndllist(:)),',...
			'delete(oldlinhndl)']);

%fundamental harmonic frequency text box
hndl5=uicontrol(fighndl,'style','text','units',...
		'normalized',...
		'position',[0.8 0.28 0.18 0.08],...
		'string','Fundamental Harmonic(Hz)');

%Value of fundamental text box
hndl6=uicontrol(fighndl,'style','text','units',...
		'normalized',...
		'position',[0.8 0.235 0.18 0.04],...
		'string',num2str(fhz(1)));

%slider for baseband to display
hndl7=uicontrol(fighndl,'style','slider','units',...
		'normalized',...
		'position',[0.8 0.57 0.18 0.06],...
		'min',axislims(1),'max',axislims(2),...
		'value',axislims(2),...
		'callback',[...
		  'set(gca,''xlim'',',...
		  '[0 get(hndl7,''value'')]),',...
		  'set(hndl9,''string'',num2str(get(hndl7,''value'')))']);

%text box for baseband max frequency
hndl8=uicontrol(fighndl,'style','text','units',...
		'normalized',...
		'position',[0.8 0.49 0.18 0.08],...
		'string','Baseband Plot(Hz)');

%value of baseband text box
hndl9=uicontrol(fighndl,'style','text','units',...
		'normalized',...
		'position',[0.8 0.448 0.18 0.04],...
		'string',num2str(get(hndl7,'value')));
%============================================
figure(fighndl);

