function spect = opCache(ch, x1, x2, fftSize, y1, y2)
% spect = opCache(ch, x1, x2, fftSize, y1, y2)
%
%   Return spect frames from x1 to x2 inclusive.  Calculate which
%   ones need computing and which to retrieve from the cache.  y1 and
%   y2 specify the frequency bin numbers to use.

global opCacheIndex opTimeStamp opSpectParams

maxCache  = 1000000;			% max number of cells (roughly) in cache
%maxCache =  500000;			% use this for small-memory machines
%maxCache = 5000000; disp('huge cache!')% 40 MB size
maxBlock  = round(maxCache/10);		% maximum cache block size

if (~exist('opTimeStamp')), opTimeStamp = 0; end

if (opCacheData(ch, 'nrows') ~= fftSize/2)
  % Create new cache.
  n = round(maxCache / fftSize * 2);
  opCacheData(ch, 'replace', zeros(fftSize/2, n));
  opCacheData(ch', 'iset', [-1;-1] * ones(1,n));
end

% This is a temp variable used by many subfunctions (Which, FindRoom, etc.).
opCacheIndex = opCacheData(ch, 'iget');

% Figure out which frames need computing and make space for them.
[fr0,fr1] = opCacheWhich(x1, x2, opTimeStamp); % also stamps existing w/time now
if (length(fr0))
  slotnums = opCacheFindRoom(ch, sum(fr1 - fr0 + 1), opTimeStamp);
end

% Split up large blocks, so we don't make any huge spectrograms.
[fr0,fr1] = opCacheSplitSegs(fr0, fr1, floor(maxBlock/fftSize*2));% split 'em up

% get new spect blocks, add to cache
loadp = all(opSpectParams(ch, 1:5) == opCurParams(ch));
j = 1;
for i = 1:length(fr0)
  ss = slotnums(j : j + fr1(i) - fr0(i));
  if (loadp)
    opCacheData(ch, 'colset', ss, opLoadSpect(ch, fr0(i), fr1(i), fftSize/2));
  else
    opCacheData(ch, 'colset', ss, opComputeSpect(ch, fr0(i), fr1(i)));
  end
  opCacheIndex(:,ss) = [fr0(i):fr1(i); opTimeStamp * ones(1,length(ss))];
  j = j + length(ss);
end

% finish up
opTimeStamp = opTimeStamp + 1;
opCacheData(ch, 'iset', opCacheIndex);
spect = opCacheMakeSpect(ch,x1,x2,y1,y2);	% final result
