function spect = opComputeSpect(ch, fr0, fr1)
% spect = opComputeSpect(ch, fr0, fr1)
% Compute spectrogram frames fr0 to fr1 inclusive.
% If fr0=0, this computes the first vertical strip in the spectrogram.
% The channel number is ch; usually this is 0.
%
% Reads the sound file and returns a block (rectangular array) of the 
% spectrogram.

global opSrate opDataSize opHopSize opZeroPad opWinType opChannelNum opFig

%printf('Computing spect frames %g to %g.', fr0, fr1);

sRate   = opSrate(ch);			% sampling rate
data    = opDataSize(ch);		% number of samples in each frame
hop     = round(opHopSize(ch) * data);	% hop size, in samples, between frames
fRate   = sRate / hop;			% frame rate
pad     = opZeroPad(ch) * data;		% number of zeros to append before FFT
height	= (data + pad) / 2;		% number of cells in returned array
win     = opWinTypeF(data, ch).';	% window function

% Figure out which samples to get from the sound file: s0 is the starting
% sample number, n is the total number of samples.
s0	= round((fr0-1)*hop - data/2 + hop/2);	% adjust for warm-up time
n	= data + (fr1 - fr0) * hop;

% Read the sound samples.
sams = opSoundIn(ch, max(s0,0), n, opChannelNum).';

% Adjust for warm-up time at the start of the sound file.
if (s0 < 0), sams = [zeros(1,-s0), sams]; end	% adjust for warm-up time

% Compute the spectrogram.  
% First make an empty array for MATLAB speed.
spect = zeros(height, fr1-fr0+1);

for f = 0:fr1-fr0
  res = fft([sams(f*hop + 1 : f*hop + data) .* win, zeros(1,pad)]);
  spect(:,f+1) = res(1:height).';
end
spect = log(abs(spect));	% do log here to avoid multiple 'log of 0' msgs

% Spectrogram normalization.
global opNP opNorm
if (~exist('opNorm')), opNorm = 0; end
if (opNorm)

  infilename = opFileName(ch);
  %outsuffix = 'fin-Q';  singerParams	% get freqs, normp (=decay time)
  outsuffix = 'blue-C'; singerParams	% get freqs, normp (=decay time)
  %outsuffix = 'blue-I'; singerParams	% get freqs, normp (=decay time)
  %outsuffix = 'blue-N'; singerParams	% get freqs, normp (=decay time)
  %outsuffix = 'minke-C'; singerParams	% get freqs, normp (=decay time)

  % Hide stuff inside 'eval' so the compiler won't complain about not 
  % seeing normSpect.
  clear normSpect findetect
  %normp = 200; disp('Using special minke normp.');
  eval('[spect1,opNP] = normSpect(spect, freqs, sRate, normp, fRate, opNP);')

  if (bitand(opNorm,1))		% '1' bit means display normalized spect
    spect = spect1;
  end
  if (bitand(opNorm,2))		% '2' bit means call findetect
    eval('findetect(spect1, freqs, sRate, fRate);')
    figure(opFig);
  end

end
