function opDataLog(cmd, ch, pt)
% opDataLog('click')
%	User did a right-mouse-click.  Log a point in the data log.
%
% opDataLog('clear')
%	Check if okay to clear the data log, then clear it with 'clear!'.
%
% opDataLog('clear!')
%       Really clear the data log.
%
% opDataLog('callback')
%       Utility function for 'clear'.
%
% opDataLog('save')   or   opDataLog('saveASCII')
%	Open up a save dialog box for the data log.
%
% opDataLog('truncate')
%       Remove a point from the end of the data log.

global opc opLog opLogP opLogPrev opMeas opMeasureNames opDataLogMenu
global opLogChanged opFig uiInputButton opTempTime

if (strcmp(cmd, 'clear!'))
  opLog = [];
  opLogChanged = 0;
  
elseif (strcmp(cmd, 'clear'))
  if (opLogChanged)
    uiInput(['Data log has unsaved data in it;', 10, 'OK to clear?'], ...
	'OK|Cancel', 'opDataLog(''callback'')');
  else
    opDataLog('clear!');
  end
  
elseif (strcmp(cmd, 'callback'))
  if (uiInputButton == 1)
    opDataLog('clear!');
  end

elseif (strcmp(cmd, 'click'))				% right mouse click
  if (~exist('opLogPrev'))
    opLogPrev = opMeas(opc,:); 
    opLog = [];
  end
  if (any(opLogPrev ~= opMeas(opc,:)))
    if (any(size(opLog)))
      opTempMsg(opc, ['The set of measurements has changed;', 10,...
			    			'clearing data log...'], 4);
      opDataLog('clear!');
    end
    opLogPrev = opMeas(opc,:);
  end
  
  line = opMeasure('logpt', opc, pt);			% log a point
  opLog = [opLog; line];
  opLogChanged = 1;

elseif (strcmp(cmd, 'save') | strcmp(cmd, 'saveASCII'))
  datalog = opLog;
  initfile = [pathRoot(opFileName(opc, 'getsound')), '.log'];
  pos = get(0, 'screensize');
  opPointer('watch');
  str = 'Save Data Log';
  if (strcmp(cmd, 'saveASCII')), str = 'Save Data Log (ASCII)'; end
  [f,d] = uiputfile(initfile, str,  pos(3)/2-150, pos(4)/2-200);
  opPointer('crosshair');
  if ((~isstr(f)) | ~min(size(f))), return; end		% Cancel
  
  if (strcmp(cmd, 'save'))
    datacolumns = opMeasureNames(find(opMeas(opc,:)),:);
    eval(['save ', d, pathSep, f, ' datalog datacolumns -mat']);
  else
    eval(['save ', d, pathSep, f, ' datalog -ascii']);
  end
  opLogChanged = 0;

elseif (strcmp(cmd, 'switch'))
  if (~exist('opTempTime')), opTempTime = 4; end
  if (opLogP)
    opLogP = 0;
    set(opDataLogMenu, 'Label', 'Enable');
    opTempMsg(opc, ['''alt'' mouse clicks (right button)', 10, ...
	    'will now extend the selection.'], opTempTime);
  else
    opLogP = 1;
    set(opDataLogMenu, 'Label', 'Disable');
    opTempMsg(opc, ['''alt'' mouse clicks (right button)', 10, ...
	    'will now add to the data log.'], opTempTime);
  end
  opTempTime = max(0, opTempTime - 1);

elseif (strcmp(cmd, 'truncate'))
  if (nRows(opLog) > 0)
    opLog(length(opLog),:) = [];
  end

else
  error(['Osprey internal error: Unknown command ''', cmd, '''.']);

end
