function data = opDataSizeF(ch, len)
% opDataSizeF
% Set the data size of the current channel to whatever the popup
% says.  This is called when the user changes the popup value.
%
% opDataSizeF(ch)
% Set the displayed popup to the correct value for channel ch.
% 
% opDataSizeF('default', chan)
% Set the data size to the default value (256).
% 
% string = opDataSize('string')
% Return the popup string with the |-separated list of names.
 
global opDataSizePopup opDataSize opc

if (nargin < 1)
  x = get(opDataSizePopup, 'Value');		% returns line number on popup
  if (x > 1)
    prev = opDataSize(opc);
    opDataSize(opc) = 2 ^ (x+1);
    if (opDataSize(opc) ~= prev), opRefresh(opc,1); end
  else
    opDataSizeF(opc);		% reset popup to correct value
  end
else
  if (isstr(ch))
    if (strcmp(ch, 'default'))
      opDataSize(len) = 256; 			% default
    elseif (strcmp(ch, 'string'))
      data = ['Samples/frame|           8|         16|         32',...
	  '|         64|       128|       256|       512|     1024',...
	  '|     2048|     4096|     8192|   16384|   32768'];
    end
  else
    set(opDataSizePopup, 'Value', round(log(opDataSize(ch)) / log(2) - 1));
  end
end
