function z = opFileName(ch, cmd, x)
% opFileName(ch, 'setsound', name)
%    Set the sound file name for the given channel.  If name is '', it
%    means either that we're still in the initialization stage and no
%    file name has been set yet, or that the user started up with a sound
%    signal instead of a sound file name.
%
% name = opFileName(ch, 'getsound')
%    Return the sound file name.  This does NOT include the optional
%    second line containing the sampling rate.  If the 
%
% name = opFileName(ch, 'getsound', 1)
%    Return the sound file name set by opFileName(ch, 'setsound', ...).
%    This includes both lines of the file name, if present (see osprey.m
%    or soundIn.m).
%
% opFileName(ch, 'setspect', name)
%    Set the spectrogram file name for the given channel.
%
% name = opFileName(ch, 'getspect')
%    Return the spectrogram file name set by opFileName(ch, 'setspect', ...).

global opc
global opSoundFile1 opSoundFile2 opSoundFile3 opSoundFile4
global opSoundFile5 opSoundFile6 opSoundFile7 opSoundFile8

global opSpectFile1 opSpectFile2 opSpectFile3 opSpectFile4
global opSpectFile5 opSpectFile6 opSpectFile7 opSpectFile8

if (nargin < 2), cmd = 'getsound'; end
if (nargin < 1), ch = opc; end

nm = ['File', num2str(ch)];
if (strcmp(cmd, 'setsound'))
  eval(['opSound', nm, ' = x;']);

elseif (strcmp(cmd, 'getsound'))
  if (nargin < 3), x = 0; end

  eval(['z = opSound', nm, ';']);
  if (length(z) & x)			% watch out for empty z
    z = z(1,:);				% first line only
  end

elseif (strcmp(cmd, 'setspect'))
  eval(['opSpect', nm, ' = x;']);

elseif (strcmp(cmd, 'getspect'))
  eval(['z = opSpect', nm, ';']);

else
  error(['Unknown command: ', cmd]);
end
