function [spect, pixbox, realbox] = opGetSpect(ch, t0, t1, f0, f1, selbox)
% spect = opGetSpect(ch, t0, t1, f0, f1)
% Get a spectrogram of the relevant section of sound, and return it.
% This is done by getting the gram from a cache, reading it from a 
% file, or computing it.
%
% [spect,pixbox] = opGetSpect(ch, t0, t1, f0, f1, selbox)
% As above, but also compute pixel coordinates of a box specified in
% time and frequency.  selbox and pixbox are [t0 f0 t1 f1].
% 
% [spect,pixbox,realbox] = opGetSpect(ch, t0, t1, f0, f1, selbox)
% As above, but return a box representing the true bounds of the spect
% that is returned.  This may be different than [t0 f0 t1 f1] because of
% roundoff error, as the dimensions of spect are necessarily integers.

global opDataSize opHopSize opZeroPad opSrate opFig opNsamp

data    = opDataSize(ch);
hop     = round(opHopSize(ch) * data);
pad     = opZeroPad(ch) * data;
srate   = opSrate(ch);
fftSize = data + pad;
fRate   = srate / hop;
binSize = (srate / 2) / (fftSize / 2);
nframe  = floor((opNsamp(ch) - data) / hop + 1);

x1 = max(1,         1 + floor(t0 * fRate));
x2 = min(nframe,         ceil(t1 * fRate));
y1 = max(1,         1 + floor(f0 / binSize));
y2 = min(fftSize/2,      ceil(f1 / binSize));

x2 = max(x1, x2);
y2 = max(y1, y2);

realbox = [(x1-1)/fRate  (y1-1)*binSize  x2/fRate  y2*binSize];

% Compute any spectrogram frames that aren't there yet.
opPointer('watch');
spect = opCache(ch, x1, x2, fftSize, y1, y2);
opPointer('crosshair');

if (nargin > 5)
  pixbox = [max(1,            floor(selbox(1) * fRate)   - (x1-1) + 1), ...
	    max(1,            floor(selbox(2) / binSize) - (y1-1) + 1), ...
            min(nCols(spect),  ceil(selbox(3) * fRate)   - (x1-1)), ...
	    min(nRows(spect),  ceil(selbox(4) / binSize) - (y1-1))];
end
