function opMouseClick
% opMouseClick
% This gets called when the user clicks in the window.
% Left-clicks start a selection, and middle-clicks end it.
% Right-clicks extend the selection or add to the datalog according to opLogP.
% Double clicks (typ = 'open') don't do anything.

global opMousePos opc opSelT0 opSelT1 opSelF0 opSelF1 opAxes opSrate opTMax
global opFig opLogP opNonSelCount

pt = sub(get(opAxes(opc), 'CurrentPoint'),1,1:2);
typ = get(opFig,'SelectionType');
redraw = 0;

if (strcmp(typ, 'normal') | strcmp(typ, 'extend'))	% left, middle mouse
  if (strcmp(typ, 'normal'))
    opMousePos(opc,1:2) = pt(1,1:2);
  else
    opMousePos(opc,3:4) = pt(1,1:2);
  end
  if (all(finite(opMousePos)))
    opSelT0(opc) = min(opMousePos(opc,[1 3]));
    opSelT1(opc) = max(opMousePos(opc,[1 3]));
    opSelF0(opc) = min(opMousePos(opc,[2 4]));
    opSelF1(opc) = max(opMousePos(opc,[2 4]));
    redraw = 1;
  end

elseif (strcmp(typ,'alt')) 				% right mouse click
  if (opLogP)
    opDataLog('click', opc, pt);
  else
    % extend selection
    if (opSelect(opc))
      opNonSelCount = 0;
      t = pt(1,1);
      f = pt(1,2);
      if (abs(opSelT0(opc) - t) < abs(opSelT1(opc) - t))
	opSelT0(opc) = t;
      else
	opSelT1(opc) = t;
      end
      if (abs(opSelF0(opc) - f) < abs(opSelF1(opc) - f))
	opSelF0(opc) = f;
      else
	opSelF1(opc) = f;
      end
      redraw = 1;
    else
      if (~exist('opNonSelCount')), opNonSelCount = 0; end
      opNonSelCount = rem(opNonSelCount + 1, 6);
      if (opNonSelCount == 5)
	opTempMsg(opc, 'Warning: The data log is not enabled.', 3);
      end
    end
  end
end
  
if (redraw)
  opSelT0(opc) = max(opSelT0(opc), 0);
  opSelT1(opc) = min(opSelT1(opc), opTMax(opc));
  opSelF0(opc) = max(opSelF0(opc), 0);
  opSelF1(opc) = min(opSelF1(opc), opSrate(opc)/2);
  opMousePos(opc,:) = [Inf Inf Inf Inf];	% flag value: 'no selection'
  opMeasure('newsel', opc, pt);
end

opMeasure('newpt', opc, pt);
if (redraw)
  opRefresh(opc); 
end
