function opPositionControls(ch)
% opPositionControls(ch)
% (Re-)position the buttons, sliders, text boxes, and so on in the 
% Osprey window.
%
% This function assumes that the controls already exist; see opMakeControls
% for the order of elements in the vector.

global opFig opContrastSlider opBrightnessSlider opPlayRateMenu opPlayRate
global opDataSizePopup opHopSizePopup opZeroPadPopup opHScrollBar opVScrollBar
global opWinTypePopup opPlayBut opContrastText opBrightnessText opAxes
global opMeasurePos opWindowAxes opHScrollMenu opVScrollMenu opShareColors
global opDataLogMenu opChannelMenu

set(opFig, 'Units', 'pixels');

% Create menus if necessary.
opMenus(ch);

% Create controls (in the wrong positions) if necessary.
controls = opMakeControls(ch);

% The rest of this file positions the controls.
xywh = get(opFig, 'Position');
set(controls(1), 'Units', 'pixels', 'Position', [0 0 xywh(3) xywh(4)]);

% Zoom/crunch buttons.
left = 16;
wide = 39;
hinc = wide + 8;
top  = xywh(4) - 12;
high = 39;
set(controls(2), 'Position', [left      top-high wide high]);  
set(controls(3), 'Position', [left+hinc top-high wide high]);
top = top - high - 8;

set(controls(4), 'Position', [left      top-high wide high]);
set(controls(5), 'Position', [left+hinc top-high wide high]);
bBot   = top - high;
bRight = left + hinc + wide;

% Brightness and contrast sliders.
left = bRight + 40;
wide = 200;
bot = 10;
high = 16;
inc = high + 8;
set(controls(6), 'Position', [left bot wide high]);       % contrast slider
set(controls(7), 'Position', [left+wide+5 bot+8]);        % contrast text
set(controls(8), 'Position', [left+wide+67 bot+2 25 15]); % 'Set' button
bot = bot + inc;
set(controls(9), 'Position', [left bot wide high]);       % brightness slider
set(controls(10), 'Position',[left+wide+5 bot+8]);        % brightness text
sTop   = bot + high;
sRight = left + wide + 90;

% Play button
left = sRight + 20;
wide = 100;
bot = 10;
high = 40;
set(controls(11), 'Position', [left bot wide high]);
pRight = left + wide;

% Play rate button.
left = pRight + 10;
wide = 90;
bot = 10;
high = 40;
set(controls(12), 'Position', [left bot wide high]);
rRight = left + wide;

% Popup menus.
left = 10;
wide = 100;
top  = bBot - 12;
high = 18;
inc  = high + 6;
set(controls(13), 'Position', [left top-high wide high]);  top = top - inc;
set(controls(14), 'Position', [left top-high wide high]);  top = top - inc;
set(controls(15), 'Position', [left top-high wide high]);  top = top - inc;
set(controls(16), 'Position', [left top-high wide high]);
pBot   = top - high;
pRight = left + wide;

% Measures
top = pBot - 20;
left = 6;
opMeasurePos = [left top];
opMeasure('painttext', ch);

% Scrollbars.
thick   = 15;
left    = 10;			% space beside vertical scrollbar.
right   = 10;
top     = 10;			% space above horizontal scrollbar.
bot     = 10;
imLeft  = 60 + bRight;
imWide  = xywh(3) - imLeft - left - right - thick;
imBot   = 30 + sTop;
imHigh  = xywh(4) - imBot - bot - top - thick;
set(controls(17), 'Position', [imLeft  (xywh(4)-top-thick)  imWide  thick]);
set(controls(18), 'Position', [(xywh(3)-right-thick)  imBot  thick  imHigh]);

% main axes object
set(controls(19), 'Units', 'pixels', 'Position', [imLeft imBot imWide imHigh]);

%opDataSizeF(ch);		                % set to default value
%opZeroPadF(ch);			                % set to default value
%opHopSizeF(ch);			                % set to default value
%opWinTypeF('disp', ch);		                % set to default value
