function opPrefSave(cmd, x0, x1);
% opPrefs('save', chan)
% Put up a dialog box for saving preferences.  When done, call 
% with 'save-file'.
%
% opPrefs('save-file', okay)
% Read the check-boxes from the dialog box.  Get a file name to save
% the preferences in, and save them.
%
% opPrefs('load', chan)
% Ask the user for a file to load, call load-file.
%
% opPrefs('load-file', chan, filename)
% Load preferences from the specified file.
%
% opPrefs('click', okay)
% Process a user click.  This is necessary only for interaction between
% window size, start/end time/freq, and window time/freq scaling.

% Version history:
%    1	 9/14/94  first version created
%    2	10/??/94  opMeas changed (added #datalogs and maybe more)
%    3  11/10/94  datasize_ changed from samples to seconds
%    4  11/17/94  added channel number to opMeas
%    5  12/13/94  added centroid time, centroid freq

global opc opBrightness opContrast opDataSize opF0 opF1 opFig
global opHScrollSkip opHopSize opMeas
global opPsButton opPsChan opPsName opPsValue opPsWin opPsWinPos opPsType
global opSrate opT0 opT1 opTMax opVScrollSkip opWinType opZeroPad
global opPrefDir opColorMapName

version = 5;	% FIX opMeasure('setmeasures') WHEN THIS IS CHANGED!!!!!!!!!!!!

if (~exist('opPsName'))
  opPsName = str2mat(str2mat(...
      '-Window information',...
      'sound file name',...
      'window size/position',...		% type 1; see 'click'
      'window start/end time', ...		% type 2
      'time scaling (sec/cm)',...		% type 3
      'window low/high frequency',...		% type 4
      'frequency scaling (Hz/cm)',...		% type 5
      '-Spectrogram computation',...
      'samples per frame',...
      'zero padding'),...
      str2mat(...
      'hop size',...
      'window type',...
      '-Display information',...
      'brightness and contrast',...
      'measurements',...
      'h/v slider scroll amount',...
      'color map'...
  ));
  opPsValue = [0 0 0 0 0 0 1 1 1 1 1 0 0 0];	% initially checked?
  opPsType  = [0 1 2 3 4 5 0 0 0 0 0 0 0 0];	% see above; also 'click'
  opPsWin = [];
  opPsWinPos = [];
end

if (strcmp(cmd, 'save'))
  if (nargin < 2), x0 = opc; end
  opPsChan = x0;
  color = [1 1 1] * 0.702;		% about 3/4 grey

  % remove any existing Prefs window
  if (length(opPsWin)), if (any(get(0, 'Children') == opPsWin)),
    delete(opPsWin); 
  end; end
  
  x1 = 0.2;				% left margin: "Choose Preferences..."
  x2 = 0.3;				% left margin: section titles
  x3 = 0.5;				% left margin: checkboxes
  high = 0.25;				% inter-checkbox vertical increment
  if (~length(opPsWinPos))
    set(0, 'Units', 'inches');
    p = get(0, 'ScreenSize');
    w = 3.3;
    h = nRows(opPsName) * (high + 0.2) - length(opPsValue) * 0.1 + 1.2;
    opPsWinPos = [(p(3)-w)/2 (p(4)-h)/2 w h];
  end
  opPsWin = figure('Units', 'inch', 'Pos', opPsWinPos, 'Color', color,...
      'Resize', 'off', 'NumberTitle', 'off', 'Name', 'Save Preferences');
  fpos = get(gcf, 'pos');
  y    = fpos(4) - 0.4;
  wide = fpos(3) - x3 - x2;
  opPsButton = [];
  j = 0;
  set(gca,'Units','inches','Pos', [0 0 fpos(3:4)], 'Visible', 'off');
  text(x1, y, 'Choose preferences to save:', 'FontWeight', 'bold', ...
      'Color', [0 0 0], 'FontSize', 14, 'Units', 'inches', 'Pos', [x1 y]);
  y = y - 0.35;
  for i = 1:nRows(opPsName)
    if (opPsName(i,1) == '-')
      text(x2, y, opPsName(i,2:nCols(opPsName)), 'FontWeight', 'bold', ...
	  'Color', [0 0 0], 'Units', 'inches', 'Pos', [x2 y]);
      y = y - high - 0.2;
    else
      j = j + 1;
      opPsButton(j) = uicontrol('Style','checkbox', 'String', opPsName(i,:),...
	  'Units', 'inches', 'Pos', [x3 y wide high],...
	  'Value',opPsValue(j), 'Background', color, 'Horiz', 'left', ...
	  'Callback', 'opPrefSave(''click'');');
      y = y - high - 0.1;
    end
  end
  y = y - 0.2;
  uicontrol('Style', 'pushb', 'String', 'OK...',     'Units', 'inches', ...
      'Pos', [x3      y 1 0.3], 'Callback', 'opPrefSave(''save-file'', 1)');
  uicontrol('Style', 'pushb', 'String', 'Cancel', 'Units', 'inches',...
      'Pos', [x3+1.25 y 1 0.3], 'Callback', 'opPrefSave(''save-file'', 0)');

elseif (strcmp(cmd, 'click'))
  % User clicked a button; see if we need to un-click any other buttons.
  % This is for handling window size/duration/scaling interactions.
  winsize   = opPsButton(find(opPsType == 1));
  startend  = opPsButton(find(opPsType == 2));
  timescale = opPsButton(find(opPsType == 3));
  lowhigh   = opPsButton(find(opPsType == 4));
  freqscale = opPsButton(find(opPsType == 5));

  o = gco;				% handle of button that was clicked
  if (get(winsize, 'Value') & get(startend, 'Value') & get(timescale, 'Value'))
    if (o == startend)
      set(timescale, 'Value', 0);
    else
      set(startend, 'Value', 0);
    end
  end
  if (get(winsize, 'Value') & get(lowhigh, 'Value') & get(freqscale, 'Value'))
    if (o == lowhigh)
      set(freqscale, 'Value', 0);
    else
      set(lowhigh, 'Value', 0);
    end
  end

elseif (strcmp(cmd, 'save-file'))
  opPsWinPos = get(opPsWin, 'Position');
  if (x0)
    for i = 1:length(opPsButton)
      opPsValue(i) = get(opPsButton(i), 'Value');
    end
  end
  delete(opPsWin);
  opPsWin = [];
  if (~x0), return; end
  set(0, 'Units', 'pixels');
  opPointer('watch');
  if (~exist('opPrefDir')), opPrefDir = pathDir(opFileName(opc)); end
  [f,d] = uiputfile1([opPrefDir, pathSep, '*.opref'],'Save preferences as...');
  opPointer('crosshair');
  if (~isstr(f)), return; end
  opPrefDir = d;
  
  filename = [d,f];
  [fd,msg] = fopen(filename, 'wt+');
  if (fd < 0)
    error(sprintf('Osprey: Can''t open file ''%s'', %s \n     ''%s''',...
       filename, 'error message was', msg));
  end

  % write header
  d = clock;
  fprintf(fd, '%% Osprey preferences file, created %s %g:%02g:%02g.\n\n', ...
      date, d(4), d(5), floor(d(6)));
  fprintf(fd, 'prefversion_ = %g;\n', version);

  v = opPsValue;
  ch = opPsChan;
  n = 0;
  n=n+1; if v(n),					% file name
    fprintf(fd,'filename_ = ''%s'';\n', opFileName(ch));
  end; n=n+1; if v(n)					% window size/pos
    set(opFig, 'Units', 'inches');
    fprintf(fd, 'pos_ = [%s];        %% inches\n', ...
	sprintf('%g ', get(opFig, 'Pos')));
  end; n=n+1; if v(n)					% window start/end time
    if (v(n+1))
      dopos = 1;
    else
      fprintf(fd, 't0_ = %g;              %% s\n', opT0(ch));
      fprintf(fd, 't1_ = %g;              %% s\n', opT1(ch));
    end
  end; n=n+1; if v(n)					% time scaling (s/pix)
    fprintf(fd, 'timescale_ = %g;       %% s/inch\n', ...
	sub(opRedraw('curscale', ch), 1));
  end; n=n+1; if v(n)					% window low/high freq
    fprintf(fd, 'f0_ = %g;              %% Hz\n', opF0(ch));
    fprintf(fd, 'f1_ = %g;              %% Hz\n', opF1(ch));
  end; n=n+1; if v(n)					% freq scaling (Hz/pix)
    fprintf(fd, 'freqscale_ = %g;       %% Hz/inch\n', ...
	sub(opRedraw('curscale', ch), 2));
  end; n=n+1; if v(n)					% samples per frame
    fprintf(fd, 'datasize_ = %g;        %% s\n', opDataSize(ch) / opSrate(ch));
  end; n=n+1; if v(n)					% zero padding
    fprintf(fd, 'zeropad_ = %g;\n', opZeroPad(ch));
  end; n=n+1; if v(n)					% hop size
    fprintf(fd, 'hopsize_ = %g;\n', opHopSize(ch));
  end; n=n+1; if v(n)					% window type
    fprintf(fd, 'wintype_ = %g;\n', opWinType(ch));
  end; n=n+1; if v(n)					% brightness/contrast
    fprintf(fd, 'brightness_ = %g;\n', opBrightness(ch));
    fprintf(fd, 'contrast_ = %g;\n', opContrast(ch));
  end; n=n+1; if v(n)					% measurements
    fprintf(fd, 'measures_ = [%s];\n', sprintf('%g ', opMeas(ch,:)));
  end; n=n+1; if v(n)					% h/v slider scroll
    fprintf(fd, 'hscrollskip_ = %g;\n', opHScrollSkip);
    fprintf(fd, 'vscrollskip_ = %g;\n', opVScrollSkip);
  end; n=n+1; if v(n)					% h/v slider scroll
    fprintf(fd, 'colormap_ = ''%s'';\n', opColorMapName);
  end
  fclose(fd);

elseif (strcmp(cmd, 'load'))
  if (nargin < 2), x0 = opc; end
  opPointer('watch');
  if (~exist('opPrefDir')), opPrefDir = pathDir(opFileName(opc)); end
  [f,d] = uigetfile1([opPrefDir, pathSep, '*.opref'], 'Load preferences...');
  opPointer('crosshair');
  if (~isstr(f) | nCols(f) == 0), return; end	% f can be size [1 0]!
  opPrefDir = d;
  opPrefSave('load-file', x0, [d,f]);
  
elseif (strcmp(cmd, 'load-file'))
  ch = x0;
  eval_file_name = x1;
  evalfile;
  
  % Parse the variable values stored in the file; figure out along the
  % way how much re-computing and re-displaying is necessary.

  repaint   = 0;				% repaint whole window?
  flush     = 0;				% flush cache and reimage?
  reimage   = 0;				% redisplay gram?
  remeasure = 0;				% redisplay measurements?

  if (exist('filename_')), if (strcmp(filename_, opFileName(ch)))
    opSetFileInfo(ch, filename_);	% set Srate, Nsamp, TMax, FileName
    opInitialFrame(ch);			% set up opT0/1, opF0/1
    repaint = 1; flush = 1;
  end; end

  % oldpos is the original figure position, and newpos where it should move to.
  % newpos can get changed by both pos_ and timescale_/freqscale_ .
  set(opFig, 'Units', 'inches');
  oldpos = get(opFig, 'pos');
  newpos = oldpos;

  if (exist('pos_'))
    newpos = pos_;			% repainting taken care of below
  end

  if (exist('t0_')), if (t0_ ~= opT0(ch) | t1_ ~= opT1(ch))
    opT0(ch) = max(0, min(min(t0_,t1_), opTMax(ch)));
    opT1(ch) = max(0, min(max(t0_,t1_), opTMax(ch)));
    reimage = 1;
  end; end
  if (exist('f0_')), if (f0_ ~= opF0(ch) | f1_ ~= opF1(ch))
    opF0(ch) = max(0, min(min(f0_,f1_), opSrate(ch)/2));
    opF1(ch) = max(0, min(max(f0_,f1_), opSrate(ch)/2));
    reimage = 1;
  end; end

  if (exist('timescale_') | exist('freqscale_'))
    cur = opRedraw('curscale', ch);		% get current scaling
    if (exist('timescale_')), if (timescale_ ~= cur(1))
      [opT0(ch),opT1(ch),x] = opRescale(opT0(ch), opT1(ch), opTMax(ch), ...
                                                 timescale_, 1, newpos(3:4));
      if (x), newpos(3) = x; end
    end; end
    if (exist('freqscale_')), if (freqscale_ ~= cur(2))
      [opF0(ch),opF1(ch),x] = opRescale(opF0(ch), opF1(ch), opSrate(ch)/2, ...
                                                 freqscale_, 2, newpos(3:4));
      if (x), newpos(4) = x; end
    end; end
    reimage = 1;			% below, might decide to repaint too
    end
  end

  if (exist('datasize_'))
    if (prefversion_ >= 3)
      datasize_ = 2 ^ round(log2(datasize_ * opSrate(ch)));
    end
    if (datasize_ ~= opDataSize(ch))
      opDataSize(ch) = datasize_;
      flush = 1;
    end
  end; end

  if (exist('zeropad_')), if (zeropad_ ~= opZeroPad(ch))
    opZeroPad(ch) = zeropad_;
    flush = 1;
  end; end
  if (exist('hopsize_')), if (hopsize_ ~= opHopSize(ch))
    opHopSize(ch) = hopsize_;
    flush = 1;
  end; end
  if (exist('wintype_')), if (wintype_ ~= opWinType(ch))
    opWinType(ch) = wintype_;
    flush = 1;
  end; end
  if (exist('brightness_')), if (brightness_ ~= opBrightness(ch))
    opBrightness(ch) = min(1, max(0, brightness_));
    reimage = 1;
  end; end
  if (exist('contrast_')), if (contrast_ ~= opContrast(ch))
    opContrast(ch) = min(1, max(0, contrast_));
    reimage = 1;
  end; end
  if (exist('measures_')),
    opMeasure('setmeasures', ch, measures_, prefversion_);
    remeasure = 1;
  end
  if (exist('hscrollskip_')),
    opHScrollSkip = hscrollskip_;
  end
  if (exist('vscrollskip_')),
    opVScrollSkip = vscrollskip_;
  end
  if (exist('colormap_')),
    opColorMapName = colormap_;
    reimage = 1;
  end
  
  % Do any redrawing necessary.
  if (any(oldpos ~= newpos))
    if (any(1e-4 < abs(oldpos(3:4) - newpos(3:4))))
      opInitFigure(opFileName(ch));	% get rid of menus before re-sizing
      set(opFig, 'Units', 'inch', 'Pos', newpos);
      repaint = 1;
    else
      set(opFig, 'Pos', newpos);
      reimage = 1;
    end
  end
  if (flush)
    opCacheData(ch, 'iclear');
  end
  if (repaint)
    opEraseSelection(ch);
    opRedraw('repaint');
    flush = 0; reimage = 0; remeasure = 0;
  end
  if (flush)
    opEraseSelection(ch);
    opRefresh(ch, 1);
    opDataSizeF(ch);
    opZeroPadF(ch);
    opHopSizeF(ch);
    opWinTypeF(ch);
    reimage = 0;
  end
  if (reimage)
    opRefresh(ch, 0);
  end
  if (remeasure)
    opMeasure('painttext', ch);
  end

end
