function opRefChan(ch, setbc)
% opRefChan(ch)
% Repaint a channel image and its axes.
%
% % opRefChan(ch, setbc)
% As above, but calculate brightness and contrast values from the gram
% and set the sliders.

% Note that this is also called from opPrint, which messes with opAxes.
% opPrint depends on this guy not changing the axes.

global opAxes opT0 opT1 opF0 opF1 opSelT0 opSelT1 opSelF0 opSelF1
global opBrightnessSlider opContrastSlider opBrightness opContrast
global opSrate opTMax opHScrollBar opVScrollBar opSliderValues
global opFig opImages

if (nargin < 2), setbc = 0; end

t0 = opT0(ch);  t1 = opT1(ch);
f0 = opF0(ch);  f1 = opF1(ch);

selbox = [opSelT0(ch)  opSelF0(ch)  opSelT1(ch)  opSelF1(ch)];
[bits, pixbox, realbox] = opGetSpect(ch, t0, t1, f0, f1, selbox);
i = find(isnan(bits) | bits <= 0);
bits(i) = 1e-35 * ones(1,length(i));

if (setbc)
  [b,c] = opColorMap('setbc', ch, bits);
  opBrightness(ch) = b;
  opContrast(ch)   = c;
end
x = get(opAxes(ch),'children');
if (length(x)), delete(x); drawnow; end
set(opAxes(ch), 'XLim', [t0 t1], 'YLim', [f0 f1]);
pix = opBitsToPix(ch, bits, opBrightness(ch), opContrast(ch), pixbox);
set(opFig, 'NextPlot', 'add');
axes(opAxes);
opImages(ch) = image(realbox([1 3]), realbox([2 4]), pix, ...
    					'ButtonDownFcn','opMouseClick');
set(opFig, 'NextPlot', 'new');

% Have to redraw axes (matlab bug, I think).
set(opAxes(ch), 'XLim', [t0 t1], 'YLim', realbox([2 4]), 'YDir', 'normal',...
    'TickDir', 'out', 'Box', 'off');

% Set scroll bars and play-button.
uiSlider(opHScrollBar, 'Value', opSlideSetting(opTMax(ch), t0, t1));
uiSlider(opVScrollBar, 'Value', opSlideSetting(opSrate(ch)/2, f0, f1));
uiSlider(opBrightnessSlider, 'Value', opBrightness(ch));
uiSlider(opContrastSlider,   'Value', opContrast(ch));
opPlay('disptext', ch);
