function opSlider(which)
% opSlider(which)
% Read a value from a slider and repaint accordingly.  The arg 'which'
% is either b, c, h, or v, depending on the slider that was changed 
% (brightness, contrast, horizontal scroll, vertical scroll).
% 
% If the user clicks on the H or V scroll bar either outside the button or
% on the arrow, detect that and scroll by the appropriate amount rather
% than the amount MATLAB wants to move the slider.

global opc opBrightness opContrast opBrightnessSlider opContrastSlider
global opHScrollBar opVScrollBar opHScrollSkip opVScrollSkip opFig
global opTMax opSrate opT0 opT1 opF0 opF1 uiSliderClick uiSliderPrev

drawnow;				% repaint slider in correct position
obj = get(opFig, 'CurrentObject');

% Figure out previous scrollbar values, and long and short scroll sizes.
if (which == 'b' | which == 'c')	% brightness and contrast sliders
  if (which == 'b')
    prev = opBrightness(opc);
  else               
    prev = opContrast(opc);
  end
  long = 0.1;				% amount to move on click in bar
  short = 0.005;			% amount to move on click on arrow

else					% h and v scrollbars
  if (which == 'h')			% h scrollbar
    x0 = opT0(opc);
    x1 = opT1(opc);
    xMax = opTMax(opc);
    skip = opHScrollSkip;
    
  elseif (which == 'v')			% v scrollbar
    x0 = opF0(opc);
    x1 = opF1(opc);
    xMax = opSrate(opc) / 2;
    skip = opVScrollSkip;
  else
    error(['Internal error: Impossible slider type ''', which, '''.']);
  end
  
  prev = opSlideSetting(xMax, x0, x1);
  len = x1 - x0;
  long = opSlideSetting(xMax, len * skip, len * skip + len);
  short = long / 10;
end

if     (strcmp(uiSliderClick, 'upsmall')),   now = prev + short;
elseif (strcmp(uiSliderClick, 'downsmall')), now = prev - short;
elseif (strcmp(uiSliderClick, 'upbig')),     now = prev + long;
elseif (strcmp(uiSliderClick, 'downbig')),   now = prev - long;
else                                         now = get(obj,'Value'); %no change
end

now = min(1, max(0, now));

if (which == 'b' | which == 'c')
  if (which == 'b'), opBrightness(opc) = now;
  else               opContrast(opc)   = now;
  end

  % Try diddling the colormap; if it works, just return.
  if (opColorMap('install', opc, opBrightness(opc), opContrast(opc)))
    if   (which == 'b'), uiSlider(opBrightnessSlider, 'Value', now);
    else                 uiSlider(opContrastSlider,   'Value', now);
    end
    return;
  end
  % otherwise fall through and repaint the image
  
else					% h or v scrollbar
  if (len < xMax)
    if (which == 'h')
      opT0(opc) = (xMax - len) * now;
      opT1(opc) = opT0(opc) + len;
    else
      opF0(opc) = (xMax - len) * now;
      opF1(opc) = opF0(opc) + len;
    end
  end
end

opRefresh(opc);		% fixes scrollbars and brightness and contrast sliders
