function pad = opZeroPadF(ch, len)
% opZeroPadF
% Set the zero pad size of the current channel to whatever the popup
% says.  This is called when the user changes the popup value.
%
% opZeroPadF(ch)
% Set the displayed popup to the correct value for channel ch.
% 
% opZeroPadF('default', chan)
% Set the zero pad size to the default value (0).
% 
% string = opZeroPadF('string')
% Return the popup string with the |-separated list of names.
 
global opZeroPadPopup opZeroPad opc

if (nargin < 1)
  x = get(opZeroPadPopup, 'Value');
  if (x > 1)
    prev = opZeroPad(opc);
    opZeroPad(opc) = 2 ^ (x-2) - 1;
    if (opZeroPad(opc) ~= prev), opRefresh(opc,1); end
  else
    opZeroPadF(opc);		% reset popup to correct value
  end
else
  if (isstr(ch))
    if (strcmp(ch, 'default'))
      opZeroPad(len) = 0; 			% default
    elseif (strcmp(ch, 'string'))
      pad = 'Zero Padding|    None|     1x|     3x|     7x|    15x|    31x';
    end
  else
    set(opZeroPadPopup, 'Value', round(log(opZeroPad(ch)+1) / log(2) + 2));
  end
end
