function y = bitxor(x1, x2)
%BITXOR		Bitwise logical XOR operator.
%
% y = bitxor(x1,x2)
% Return the bitwise XOR of x1 and x2.  This is the value that has 1 bits
% at positions where x1 and x2, but not both, have 1 bits.  Does not work
% when one of the numbers is negative.
%
% Note that this routine will work only up to 32 bits, or to the precision 
% of your machine's double-precision float representation, whichever
% is smaller.
%
% See also bitand, bitor, any, all, |, &, xor.

% Dave Mellinger
% 27 May 1995

global bit_vals
if (~exist('bit_vals'))	
  % using a global is slightly faster than recomputing bit_vals every time (Sun)
  bit_vals = 2 .^ (0:31);
end

x1 = rem(floor(x1 ./ bit_vals), 2);
x2 = rem(floor(x2 ./ bit_vals), 2);

y = sum(bit_vals .* xor(x1, x2));
