function [x,y] = fitpeaks(seq, pks, nbd)
%FITPEAKS    Do parabolic fits to points near peaks.
%
% [x,y] = fitpeaks(x, peaks)
%    Fit quadratics to the curve x at the points x(peaks) using the 5 points
%    around each peak, then find the extremum of each quadratic and return it.
%    peaks may be a vector or matrix; x and y are the same shape upon return.
%
% [x,y] = fitpeaks(x, peaks, nbd)
%    As above, but use the given neighborhood size.  Default is 2, meaning
%    to use the 5 indices (peak-2 : peak+2).

if (nargin < 3)
  nbd = 2;
end

n = prod(size(pks));
x = zeros(1,n);
y = zeros(1,n);

% Should vectorize this.
for i = 1:n
  % Find appropriate indices to fit parabola to.
  ix = [pks(i)-nbd  pks(i)+nbd];
  while (min(ix) < 1)
    if (diff(ix) > 3), ix(1) = [];
    else ix = ix + 1;
    end
  end
  while (max(ix) > length(seq))
    if (diff(ix) > 3), ix(length(ix)) = [];
    else ix = ix - 1;
    end
  end
  idx = ix(1) : ix(2);

  % Fit it.
  quadFit = polyfit(idx, seq(idx), 2);
  x(i) = roots(polyder(quadFit));
  y(i) = polyval(quadFit, x(i));
end

x = reshape(x, size(pks));
y = reshape(y, size(pks));
