function x = loadascii(filename, commentchar)
%LOADASCII   Load an ascii file (w/comments), return its contents as a matrix.
%
% x = loadascii(filename)
%    Return the contents of the file as a numeric array.  This allows
%    you to name the result whatever you like, instead of having to
%    hack around with the name MATLAB chooses with the 'load' command.
%
%    Comments are allowed in files.  As in MATLAB .m files, comments 
%    begin with the '%' character and end at the end of the line.
%
% x = loadascii(filename, commentchar)
%    As above, but comments begin with the given character instead of '%'.
%    A typical commentchar is '#'.
%
% See also load, mlFileNameFilter, readBinary, fread, fgetl, fgets.

if (nargin < 2)
  commentchar = '%';
end

fd = fopen(filename, 'r');
if (fd < 0)
  error(['Can''t open the file "' filename '".']);
end

x = [];
nr = 0;				% number of rows of good data in x
lineno = 0;
while (1)
  str = fgetl(fd);
  if (~isstr(str))		% EOF?
    x = x(1:nr,:);
    fclose(fd);
    return
  end
  lineno = lineno + 1;
  
  y = find(str == commentchar);
  if (~length(y))
    y = length(str) + 1;
  end
  num = sscanf(str(1:y(1)-1), '%g').';

  if (length(num))
    nr = nr + 1;
    
    if (nCols(x) ~= 0 & length(num) ~= nCols(x))
      fclose(fd);
      error(sprintf('File %s, line %d: %s.', filename, lineno, ...
	  'All lines in file must have same number of elements'));
    end

    % If x is too small, add more rows on the bottom.
    if (nr > nRows(x))
      x = [x; zeros(500, length(num))];
    end
    x(nr,:) = num;
  end
end
