function zlims = zlim(lo, hi)
%ZLIM		set z-limits of the current plot
%
% zlim(lo,hi)
%   This is shorthand for set(gca, 'ZLimits', [lo hi]),
%   except that it does the right thing if lo > hi.
%
% zlim([lo hi])
%   Same as above.
%
% zlim(vec)
%   This is shorthand for set(gca, 'Zlimits', [min(vec) max(vec)]).
%
% zlim('auto')
%   Set the z-axis limits so the endpoints are nice round numbers.
%   MATLAB does the work.
%
% zlim('manual')
%   Freezes the limits so MATLAB will not change them upon, say, printing.
%
% zlim('fit')
%   Set the z-axis limits so the first and last data points in the plot are
%   at the ends of the displayed range.
%
%
% zl = zlim(...)
%   All of the above forms return the new z-limits.

if (nargin < 2)
  if (nargin > 0)
    if (strcmp(lo, 'auto') | strcmp(lo, 'manual'))
      set(gca, 'ZlimMode', lo);
    elseif (strcmp(lo, 'fit'))		% fit axis limits to data
      m = Inf;
      M = -Inf;
      for ch = get(gca, 'Children').'
	tt = get(ch, 'Type');
	%if (any(strmatch(tt, 'line','image','patch','surface')))
	if (any(strmatch(tt, str2mat('line','image','patch','surface'))))
	  d = get(ch, 'ZData');
	  d(isnan(d) | isinf(d)) = [];
	  m = min(m, min(min(d)));
	  M = max(M, max(max(d)));
	end
      end
      if (~isinf(m) & ~isinf(M))
	set(gca, 'ZLim', [m M]);
      end
    else
      if (length(lo) == 2), zlim(lo(1), lo(2));
      else zlim(min(lo), max(lo));
      end
    end
  end
else
  zl = get(gca, 'ZLim');
  if (strcmp(get(gca, 'ZDir'), 'reverse'))
    zl = fliplr(zl);
  end
  if (isnan(lo)), lo = zl(1); end
  if (isnan(hi)), hi = zl(2); end
  if (lo < hi)
    set(gca, 'ZLim', [lo hi], 'ZDir', 'normal');
  else
    set(gca, 'ZLim', [hi lo], 'ZDir', 'reverse')
  end
end

if (nargout > 0)
  zlims = get(gca, 'ZLim');
end
