% CEPF0	- Cepstral pitch estimation
% Usage: [f01,f02]=cepf0(y,rate,twin,thop,nfft,plotflag,flo,fhi);
% computes nfft-pt real cepstrum of waveform (y) at sample freq of (rate)
% on frames of length twin [ms] advanced by thop [ms]; 
% A peak-picking routine (t0pkr) generates 2 f0 estimates per frame.
% plotflag: set to 1 to view individual cepstral plots
% Peter Assmann - June 30, 1991
function [f01,f02]=cepf0(y,rate,twin,thop,nfft,plotflag,flo,fhi);
n = max(size(y));
if(~exist('rate')) rate=10000; end;    % default sample rate is 20 kHz
if(~exist('twin')) twin=25; end;       % default frame size is 25 ms
if(~exist('thop')) thop=twin/2; end;   % default frame hop is twin/2
if(~exist('nfft')) nfft=512; end;      % default 512-point FFT
if(~exist('plotflag')) plotflag=0; end;% defaults: no plot
if(~exist('flo')) flo=80; end;         % default min F0
if(~exist('fhi')) fhi=350; end;        % default max F0
xl=rate/fhi+1; xh=rate/flo+1; yl=-1; yh=3; % x,y ranges for plots
nwin=rate/1000*twin;
nhop=rate/1000*thop;
i1=1; iframe=0;
while i1<=n
 i2=min(i1+nwin-1,n); npts=i2-i1+1; iframe=iframe+1;
 x=[y(i1:i2).*hanning(length(y(i1:i2)));zeros(nfft-npts,1)];
 [f01(iframe),f02(iframe)]=t0pkr(real(ifft(log(abs(fft(x))))),flo,fhi,rate);
 if f01(iframe)==0 & iframe>1, f01(iframe)=f01(iframe-1); end;
 if f02(iframe)==0 & iframe>1, f02(iframe)=f02(iframe-1); end;
 if plotflag==1,
  it01=round(1/f01(iframe)*rate)+1;
  it02=round(1/f02(iframe)*rate)+1;
  c=rceps(x);
  clg; hold off; axis([xl xh yl yh]);
  subplot(211); plot(x); title(['Frame: ' int2str(iframe)]);
  subplot(212); plot(c); hold on; 
  plot([it01 it01],[yl yh],':');
  if nargout==2, plot([it02 it02],[yl yh],':'); end;
  hold off; 
  pause(.3);
 end
 i1=i1+nhop;
end
f01=f01';f02=f02';
if plotflag==1,
 plot(f01,'o'); xlabel('Frame number'); ylabel('Fundamental Frequency (Hz)');
 if nargout==2,
  plot(f01,'+'); xlabel('Frame number'); ylabel('Fundamental Frequency (Hz)');
 end;
end;
