% cvst_synth.m - synthesis routine
% Peter Assmann - July 26, 1993
% plots schematic spectrogram + waveform
s=get(0,'ScreenSize');
P=get(1,'Pos');
P=[P(1)+s(3)*.1 P(2)+s(4)*.03 P(3) P(4)];
if P(1)<=5, P(1)=5; end;
if P(2)<=5, P(2)=5; end;
if P(1)+s(3)*.1 +P(3) > s(3),
 P(3) = P(3) - (P(1)+P(3) - s(3)) - 5;
end;
if P(2)+s(4)*.03 +P(4) > s(4),
 P(4) = P(4) - (P(2)+P(4) - s(4)) - 5;
end;
if max(get(0,'Children'))<5,
 figure('Pos',P,'NumberTitle','Off',...
'Name','Synthesis Window');
end;
figure(5); clf; 
subplot(211); hold on;
t=((1:nframes)/nframes*dur)';
for i=1:nframes,
 if F1(i)>30, plot(t(i),F1(i)/1000,'o','EraseMode','Back'); end;
 if F2(i)>30, plot(t(i),F2(i)/1000,'o','EraseMode','Back'); end;
 if F3(i)>30, plot(t(i),F3(i)/1000,'o','EraseMode','Back'); end;
 if F4(i)>30, plot(t(i),F4(i)/1000,'o','EraseMode','Back'); end;
 if rate>=10000 & F5(i)>30, plot(t(i),F5(i)/1000,'o','EraseMode','Back'); end;
end;
axis([0 dur 0 rate/2/1000]);grid;
ylabel('Frequency (kHz)');
title('Schematic spectrogram');
drawnow;
% synthesize waveform
y=zeros(npts,1);           % initialize waveform to zero
T=1/rate;                  % reciprocal of sample frequency
o=ones(nsampf,1);          % matrix of ones
ps=zeros(nsampf,(rate/2)/min(F0)+1);
psi=zeros(1,(rate/2)/min(F0)+1);
subplot(211); hold on;
for iframe=1:nframes
 if(F1(iframe)>30) 
  text((iframe/nframes*dur)-1, ...
  (F1(iframe)/1000)-.1,'*','EraseMode','Back'); end;
 if(F2(iframe)>30) 
  text((iframe/nframes*dur)-1, ...
  (F2(iframe)/1000)-.1,'*','EraseMode','Back'); end;
 if(F3(iframe)>30) 
  text((iframe/nframes*dur)-1, ...
  (F3(iframe)/1000)-.1,'*','EraseMode','Back'); end;
 if(F4(iframe)>30) 
  text((iframe/nframes*dur)-1, ...
  (F4(iframe)/1000)-.1,'*','EraseMode','Back'); end;
 if(rate>=10000) 
  text((iframe/nframes*dur)-1, ...
  (F5(iframe)/1000)-.1,'*','EraseMode','Back'); end;
 drawnow;
 ft=[F1(iframe) F2(iframe) F3(iframe) F4(iframe) F5(iframe)];
 bt=[B1(iframe) B2(iframe) B3(iframe) B4(iframe) B5(iframe)];
 f0=F0(iframe);
% set number of formants based on sample rate
% (Note: nft must be set within frame loop!)
 if(rate>=8000) nft=4; end;
 if(rate>=10000) nft=5; end;
% whenever the frequency of any formant is set to <30 Hz,
% it is excluded from the synthesis and nft is reduced by 1.
 i=find(ft(1:nft)<30); nft=nft-length(i); bt(i)=[]; ft(i)=[];
 n1=(iframe-1)*nsampf; n2=n1+nsampf-1; % frame sample indices
 if nft>0,  % if there is at least one formant > 30 Hz
  [amp,ph]=get_vspect(f0,ft,bt,nft,rate,0); % compute spectrum
  nh=length(amp);  % number of harmonics to be synthesized
  k=(o*(0:nh-1))*2*pi*f0*T;
  ps=cumsum(k);
  y(n1+1:n2+1)=sum((o*amp'.*cos(ps-k+o*ph'+o*psi(1:nh)))')'...
  *10.^(AV(iframe)/20)*scale_factor;
 else,  % no formants > 30 Hz
  y(n1+1:n2+1)=zeros(size(n1+1:n2+1)); % generate silence
 end;
 psi(1,1:nh)=psi(1,1:nh)+(ps(nsampf,1:nh)); 
end; 
% if last frame exceeds npts, trim off any extra samples:
if n2+1>npts, y(npts+1:n2+1)=[]; end;
hold off;
subplot(212);hold off;
t=((1:npts)/npts*dur)';
plot(t,y/1000);
axis([0 dur min(y)/1000 max(y)/1000]);
title('Waveform');
xlabel('Time (ms)');
ylabel('Amplitude');
grid;
figure(1);
