% FFTPSD - function to compute a sequence of spectra
%        - spectral stored as a matrix of nframes x nfilts
% Usage: y=fftpsd(wave,rate,nfilt,nsampf,nhop,pre,plotflag);
% Peter Assmann - June 29 1992
function y=fftpsd(wave,rate,nfilt,nsampf,nhop,pre,plotflag);
if(~exist('rate')) rate=10000; end;
if(~exist('nfilt')) nfilt=256; end;
if(~exist('nsampf')) nsampf=256; end;
if(~exist('nhop')) nhop=40; end;
if(~exist('pre')) pre=0; end;
if(~exist('plotflag')) plotflag=0; end;
nframes=fix(((length(wave)-1)-(nsampf-nhop))/nhop);
nfft=nfilt*2;
delf=rate/(2*(nfilt-1));
y=zeros(nfilt,nframes);
freq=(1:nfilt)/nfilt*(rate/2);
maxw=max(wave);
minw=min(wave);
for iframe=1:nframes
 s1=((iframe-1)*nhop)+1; s2=s1+nsampf-1;
 w=(wave(s1+1:s2+1)-(pre*(wave(s1:s2)))).*hanning(nsampf);
 f=fft(w,nfft);
 pow=(f(1:nfilt).*conj(f(1:nfilt)))./(nfilt-1);
 y(:,iframe)=pow(1:nfilt);
 if plotflag==1,
  clg;subplot(211);hold off;
  axis([(s1)/rate*1000 (s2)/rate*1000 minw maxw]);
  x=s1/rate*1000:1/rate*1000:s2/rate*1000;
  if (length(x)==length(w)) plot(x,w); else plot(w); end
  xlabel('Time (ms)');title(sprintf('Frame %g',iframe));
  hold off;axis([0 5000 -70 20]);
  plot((1:nfilt)/nfilt*(rate/2),10*log10(max(pow,eps))-70,'-');hold on;
  hold off;title(sprintf('Frame %g',iframe));
  xlabel('Frequency (Hz)');ylabel('Amplitude (dB)');
  pause(1);
 end
end
y=y';
