% specsynth: script to control cascade formant synthesizer
% Peter Assmann / Will Ballard - June 30, 1993
% Updated to add formant bandwidth changes 03-03-94.
%  dur: duration of signal in ms
%  nmspf: number of ms per frame
%  rate: sample rate in Hz
% [parameter vectors, each of dimension 1 x round(dur/nmspf)]:
%  F1-F5: Frequencies of formants 1-5 in Hz
%  AV: amplitude of voicing in dB
%  F0: Fundamental frequency in Hz
%  B1-B5: Bandwidths of formants 1-5 in Hz
more off;
% if there is no vector "y", synthesize 200-ms, 4-formant 
% 'neutral' vowel at 8000 samples/sec
if ~exist('y'), 
 y=track_synth;
end;
% save original waveform if it exists
if ~exist('original'), 
 original = y;
end;

if ~exist('rate'),  rate=8000; end;
if ~exist('dur'),   dur=length(original)/(rate/1000); end;
if ~exist('nmspf'), nmspf=5; end;
if ~exist('scale_factor'), scale_factor=30; end;
if ~exist('AVmin'), AVmin=50; end;  % AV plot range
if ~exist('AVmax'), AVmax=120; end;
if ~exist('F0min'), F0min=50; end;  % F0 plot range
if ~exist('F0max'), F0max=350; end;
if ~exist('BWmin'), BWmin=50; end;  % BW plot range
if ~exist('BWmax'), BWmax=350; end;
npts=dur*(rate/1000);
nsampf=nmspf*(rate/1000);
nframes=round(dur/nmspf);
o=ones(1,nframes);
if ~exist('F1') F1=[o*500]; end;
if ~exist('F2') F2=[o*1500]; end;
if ~exist('F3') F3=[o*2500]; end;
if ~exist('F4') F4=[o*3500]; end;
if ~exist('F5') F5=[o*4500]; end;
% Estimate F0 and AV from original:
if ~exist('AV'), 
 AV=avtrack(original,rate,25,nmspf,0); 
end;
if ~exist('F0'),
 F0=cepf0(original,rate,25,nmspf,512,0)';
end;

if ~exist('B1') B1=[o*90]; end;
if ~exist('B2') B2=[o*110]; end;
if ~exist('B3') B3=[o*170]; end;
if ~exist('B4') B4=[o*250]; end;
if ~exist('B5') B5=[o*300]; end;
if(~exist('nfft')) nfft=64; end;
if(~exist('nsampf')) nsampf=60; end;
if(~exist('nhop')) nhop=5; end;
if(~exist('pre')) pre=1; end;
if(~exist('drng')) drng=80; end;
msg='Please wait ... interpolating existing tracks';
if length(F1)~=nframes, disp(msg); F1=splint(F1,nframes);end;
if length(F2)~=nframes, F2=splint(F2,nframes);end;
if length(F3)~=nframes, F3=splint(F3,nframes);end;
if length(F4)~=nframes, F4=splint(F4,nframes);end;
if length(F5)~=nframes, F5=splint(F5,nframes);end;
if length(AV)~=nframes, AV=splint(AV,nframes);end;
if length(F0)~=nframes, F0=splint(F0,nframes);end;
if length(B1)~=nframes, B1=splint(B1,nframes);end;
if length(B2)~=nframes, B2=splint(B2,nframes);end;
if length(B3)~=nframes, B3=splint(B3,nframes);end;
if length(B4)~=nframes, B4=splint(B4,nframes);end;
if length(B5)~=nframes, B5=splint(B5,nframes);end;

delete(get(0,'children'));
figure('Name','Main Window','NumberTitle','Off'); 
% spectrogram
t=(1:length(original))'/(rate/1000);
b=20.*log10(fftpsd(original/3276.8,rate,nfft,nsampf,nhop,pre)+eps)';
b=(b-max(max(b)))+drng;
b(find(b<0))=zeros(size(find(b<0)))+eps;
imagesc([0 max(t)],[0 rate/2000],b);
colormap(gray(64));
axis manual on xy;
set(gca,'YTick',[],'XTick',[],'Position',[.1 .1 .65 .75]);
axes('XLim',[0 max(t)],'YLim',[0 rate/2000],'Position',[.1 .1 .65 .75],...
'YTick',0:.1:rate/2000,'XTickLabels',[],'YTickLabels',[],...
'TickLength',[0.005 0.025],'TickDir','Out','Box','On'); 

% callbacks
parameter =[];

hmenu=uicontrol('Style','Popup','String',...
'F1|F2|F3|F4|F5|AV|F0|B1|B2|B3|B4|B5','Callback','parameter=get(hmenu,''Value'');get_track;',...
 'Position',[0.82 0.84 0.13 0.07],'Units','Normalized');
text(.9,1.02,'Track','Units','Normalized');

hsynthesize=uicontrol('Style','Pushbutton','Callback','cvst_synth;',...
 'Position',[0.82 0.76 0.13 0.06],'Units','Normalized',...
 'String','Synthesize');

hplay=uicontrol('Style','Pushbutton','Callback','sound(y,rate);',...
 'Position',[0.82 0.69 0.13 0.06],'Units','Normalized',...
 'String','Play');

hplayoriginal=uicontrol('Style','Pushbutton','Callback',...
'sound(original,rate);','Position',[0.82 0.62 0.13 0.06],...
'Units','Normalized','String','Play Original');

hexit=uicontrol('Style','Pushbutton','Callback',...
 'h=get(0,''Child'');for i=1:length(h),reset(figure(h(i)));close;end;',...
 'Position',[0.82 0.55 0.13 0.06],'Units','Normalized',...
 'String','Exit');

hrestart=uicontrol('Style','Pushbutton','Callback',...
 'h=get(0,''Child'');for i=1:length(h),reset(figure(h(i)));close;end;specsynth;',...
 'Position',[0.82 0.48 0.13 0.06],...
 'Units','Normalized','String','Restart');

hfigure=axes('Position',[.1 .1 .65 .75],...
 'Units','Normalized','XMinorGrid','On','Box','On',...
 'XLim',[0 dur],'YLim',[0 rate/2000]); 
title('Left-point draw,  Middle-quit draw,  Right-line draw');
xlabel('Time  (ms)');
ylabel('Frequency  (kHz)');
hfigure1=axes('Position',[.1 .1 .65 .75],...
 'XTick',[],'YTick',[],'XLim',[0 dur],'YLim',[0 rate/2]); 
hold on;
x = ((1:nframes)/nframes*dur);
p1 = plot(x,F1,'o',x,F1,'-y','EraseMode','Back');
text(dur+nmspf,F1(nframes),'F1'); 
p2 = plot(x,F2,'o',x,F2,'-y','EraseMode','Back');
text(dur+nmspf,F2(nframes),'F2');
p3 = plot(x,F3,'o',x,F3,'-y','EraseMode','Back');
text(dur+nmspf,F3(nframes),'F3');   
p4 = plot(x,F4,'o',x,F4,'-y','EraseMode','Back');
text(dur+nmspf,F4(nframes),'F4');	 
if(rate>=10000), 
  p5=plot(x,F5,'o',x,F5,'-y','EraseMode','Back');
  text(dur+nmspf,F5(nframes),'F5');
end;

% Amplitude of Voicing window
figure('Visible','off','Name','Amplitude Window',...
'NumberTitle','Off'); 
hfigure2=axes('Position',[.12 .1 .8 .8],...
'Units','Normalized','XMinorGrid','On','Box','On',...
'XLim',[0 dur],'YLim',[AVmin AVmax]);
xlabel('Time (ms)');
ylabel('Amplitude of Voicing (dB)');
title('Left-point draw,  Middle-quit draw,  Right-line draw');
hold on;
p6=plot(x,AV,'o',x,AV,'-y','Vis','off','EraseMode','Back');

% F0 Track window
figure('Visible','off','Name','F0 Window',...
'NumberTitle','Off'); 
hfigure3=axes('Position',[.12 .1 .8 .8],...
 'Units','Normalized','XMinorGrid','On','Box','On',...
 'XLim',[0 dur],'YLim',[F0min F0max]);
xlabel('Time (ms)');
ylabel('Fundamental Frequency (Hz)');
title('Left-point draw,  Middle-quit draw,  Right-line draw');
hold on;
p7=plot(x,F0,'o',x,F0,'-y','Vis','off','EraseMode','Back');

% Formant Bandwidth Track window
figure('Visible','off','Name','Formant Bandwidth Window',...
'NumberTitle','Off'); 
hfigure4=axes('Position',[.12 .1 .8 .8],...
 'Units','Normalized','XMinorGrid','On','Box','On',...
 'XLim',[0 dur],'YLim',[BWmin BWmax]);
xlabel('Time (ms)');
ylabel('Formant Bandwidth (Hz)');
title('Left-point draw,  Middle-quit draw,  Right-line draw');
hold on;
p8=plot(x,B1,'o',x,B1,'-y','Vis','off','EraseMode','Back');
p9=plot(x,B2,'o',x,B2,'-y','Vis','off','EraseMode','Back');
p10=plot(x,B3,'o',x,B3,'-y','Vis','off','EraseMode','Back');
p11=plot(x,B4,'o',x,B4,'-y','Vis','off','EraseMode','Back');
p12=plot(x,B5,'o',x,B5,'-y','Vis','off','EraseMode','Back');

