% sw_synth.m - sine-wave track synthesis  
% Peter Assmann - June 30, 1993
% plots schematic spectrogram + waveform
s=get(0,'ScreenSize');
P=get(1,'Pos');
P=[P(1)+s(3)*.1 P(2)+s(4)*.03 P(3) P(4)];
if P(1)<=5, P(1)=5; end;
if P(2)<=5, P(2)=5; end;
if P(1)+s(3)*.1 +P(3) > s(3),
 P(3) = P(3) - (P(1)+P(3) - s(3)) - 5;
end;
if P(2)+s(4)*.03 +P(4) > s(4),
 P(4) = P(4) - (P(2)+P(4) - s(4)) - 5;
end;
if max(get(0,'Children'))<5,
 figure('Pos',P,'NumberTitle','Off',...
'Name','Synthesis Window');
end;
figure(3); clf; 
subplot(211); hold on;
t=((1:nframes)/nframes*dur)';
for i=1:nframes,
 if F1(i)>30, plot(t(i),F1(i)/1000,'o','EraseMode','Back'); end;
 if F2(i)>30, plot(t(i),F2(i)/1000,'o','EraseMode','Back'); end;
 if F3(i)>30, plot(t(i),F3(i)/1000,'o','EraseMode','Back'); end;
 if F4(i)>30, plot(t(i),F4(i)/1000,'o','EraseMode','Back'); end;
 if rate>=10000 & F5(i)>30, plot(t(i),F5(i)/1000,'o','EraseMode','Back'); end;
end;
axis([0 dur 0 rate/2/1000]);grid;
% xlabel('Time (ms)');
ylabel('Frequency (kHz)');
title('Schematic spectrogram');
drawnow;
% synthesize waveform
y=zeros(npts,1);
T=1/rate;
o=ones(nsampf,1);
psi1=0;
psi2=0;
psi3=0;
psi4=0;
psi5=0;
subplot(211); hold on;
for iframe=1:nframes
 if(F1(iframe)>30) 
  text((iframe/nframes*dur)-1, ...
  (F1(iframe)/1000)-.1,'*','EraseMode','Back'); end;
 if(F2(iframe)>30) 
  text((iframe/nframes*dur)-1, ...
  (F2(iframe)/1000)-.1,'*','EraseMode','Back'); end;
 if(F3(iframe)>30) 
  text((iframe/nframes*dur)-1, ...
  (F3(iframe)/1000)-.1,'*','EraseMode','Back'); end;
 if(F4(iframe)>30) 
  text((iframe/nframes*dur)-1, ...
  (F4(iframe)/1000)-.1,'*','EraseMode','Back'); end;
 if(rate>=10000) 
  text((iframe/nframes*dur)-1, ...
  (F5(iframe)/1000)-.1,'*','EraseMode','Back'); end;
 drawnow;
%
 ft=[F1(iframe) F2(iframe) F3(iframe) F4(iframe) F5(iframe)];
 bt=[90 110 170 250 300];
 f0=ft; % frequencies at which to sample speech spectrum
% set number of formants based on sample rate
% (Note: nft must be set within frame loop!)
 if(rate>=8000) nft=4; end;
 if(rate>=10000) nft=5; end;
% whenever the frequency of any formant is set to <30 Hz,
% it is excluded from the synthesis and nft is reduced by 1.
 i=find(ft(1:nft)<30); nft=nft-length(i); bt(i)=[]; ft(i)=[];
 n1=(iframe-1)*nsampf; n2=n1+nsampf-1;
 ps1=(psi1+cumsum(o*2*pi*F1(iframe)*T))'; % update "angle" vector
 ps2=(psi2+cumsum(o*2*pi*F2(iframe)*T))';
 ps3=(psi3+cumsum(o*2*pi*F3(iframe)*T))';
 ps4=(psi4+cumsum(o*2*pi*F4(iframe)*T))';
 ps5=(psi5+cumsum(o*2*pi*F5(iframe)*T))';
 if nft>0,  % if there is at least one formant > 30 Hz
  [amp,ph]=get_vspect(f0,ft,bt,nft,rate,0); % compute spectrum
  nh=length(amp);  % number of harmonics to be synthesized
  amp=amp.*10.^(AV(iframe)/20)*scale_factor;
  if(F1(iframe)>0) x1=amp(1).*cos(ps1)'; else, x1=0; end;
  if(F2(iframe)>0) x2=amp(2).*cos(ps2)'; else, x2=0; end;
  if(F3(iframe)>0) x3=amp(3).*cos(ps3)'; else, x3=0; end;
  if(F4(iframe)>0) x4=amp(4).*cos(ps4)'; else, x4=0; end;
  if(F5(iframe)>0) x5=amp(5).*cos(ps5)'; else, x5=0; end;
  y(n1+1:n2+1)=x1+x2+x3+x4+x5;
 else,  % no formants > 30 Hz
  y(n1+1:n2+1)=zeros(size(n1+1:n2+1)); % generate silence
 end;
 psi1=ps1(nsampf); % retain angle with highest index
 psi2=ps2(nsampf);
 psi3=ps3(nsampf);
 psi4=ps4(nsampf);
 psi5=ps5(nsampf);
end;
% if last frame exceeds npts, trim off any extra samples:
if n2+1>npts, y(npts+1:n2+1)=[]; end;
subplot(212);hold off;
t=((1:npts)/npts*dur)';
plot(t,y/1000);
axis([0 dur min(y)/1000 max(y)/1000]);
title('Waveform');
xlabel('Time (ms)');
ylabel('Amplitude');
grid;
figure(1);
