% swsynth: script to control sine wave synthesis
% Peter Assmann / Will Ballard - June 30, 1993
%  dur: duration of signal in ms
%  nmspf: number of ms per frame
%  rate: sample rate in Hz
% [parameter vectors, each of dimension=round(dur/nmspf)]:
%  F1-F5: Frequencies of formants 1-5 in Hz
%  AV: amplitude of voicing in dB
more off;
if exist('y'),
 if ~any(y), clear y dur; end;
end;
if ~exist('y'), % synthesize 200-ms '4-tone neutral vowel'
 y=1000*cos((1:1600)'*2*pi*500*(1/8000)) + ...
   1000*cos((1:1600)'*2*pi*1500*(1/8000)) + ...
   1000*cos((1:1600)'*2*pi*2500*(1/8000)) + ...
   1000*cos((1:1600)'*2*pi*3500*(1/8000));
end;
%save original waveform
if ~exist('original'), 
 original = y;
end;
if ~exist('rate'),  rate=8000; end;
if ~exist('dur'), dur=length(original)/(rate/1000); end;
if ~exist('nmspf'), nmspf=5; end;
if ~exist('scale_factor'), scale_factor=30; end;
if ~exist('AVmin'), AVmin=50; end;   % AV plot range
if ~exist('AVmax'), AVmax=120; end;
npts=dur*(rate/1000);
nframes=round(dur/nmspf);
o=ones(1,nframes);
if ~exist('F1') F1=[o*500]; end;
if ~exist('F2') F2=[o*1500]; end;
if ~exist('F3') F3=[o*2500]; end;
if ~exist('F4') F4=[o*3500]; end;
if ~exist('F5') F5=[o*4500]; end;
% Estimate AV from waveform:
if ~exist('AV'), 
 AV=avtrack(original,rate,25,12.5,0);
 AV(length(AV))=[]; 
end;
%
if(~exist('nfft')) nfft=64; end;
if(~exist('nsampf')) nsampf=nmspf*(rate/1000); end;
if(~exist('nhop')) nhop=5; end;
if(~exist('pre')) pre=1; end;
if(~exist('drng')) drng=80; end;
msg='Please wait ... interpolating existing tracks';
if length(F1)~=nframes, disp(msg); F1=splint(F1,nframes);end;
if length(F2)~=nframes, F2=splint(F2,nframes);end;
if length(F3)~=nframes, F3=splint(F3,nframes);end;
if length(F4)~=nframes, F4=splint(F4,nframes);end;
if length(F5)~=nframes, F5=splint(F5,nframes);end;
if length(AV)~=nframes, AV=splint(AV,nframes);end;
delete(flipud(sort(get(0,'children'))));
figure(1);
% spectrogram
t=(1:length(original))'/(rate/1000);
b=20.*log10(fftpsd(original/3276.8,rate,nfft,nsampf,nhop,pre)+eps)';
b=(b-max(max(b)))+drng;
b(find(b<0))=zeros(size(find(b<0)))+eps;
imagesc([0 max(t)],[0 rate/2000],b);
colormap(gray(64));
axis manual on xy;
set(gca,'YTick',[],'XTick',[],'Position',[.1 .1 .65 .75]);
axes('XLim',[0 max(t)],'YLim',[0 rate/2000],'Position',[.1 .1 .65 .75],...
'YTick',0:.1:rate/2000,'XTickLabels',[],'YTickLabels',[],...
'TickLength',[0.005 0.025],'TickDir','Out','Box','On'); 

% callbacks
parameter =[];

hmenu=uicontrol('Style','Popup','String',...
'F1|F2|F3|F4|F5|AV','Callback','parameter=get(hmenu,''Value'');get_track;',...
 'Position',[0.82 0.84 0.13 0.07],'Units','Normalized');
text(.9,1.02,'Track','Units','Normalized');

hsynthesize=uicontrol('Style','Pushbutton','Callback','sw_synth;',...
 'Position',[0.82 0.76 0.13 0.06],'Units','Normalized',...
 'String','Synthesize');

hplay=uicontrol('Style','Pushbutton','Callback','sound(y,rate);',...
 'Position',[0.82 0.69 0.13 0.06],'Units','Normalized',...
 'String','Play');

hplayoriginal=uicontrol('Style','Pushbutton','Callback','sound(original,rate);',...
 'Position',[0.82 0.62 0.13 0.06],'Units','Normalized',...
 'String','Play Original');

hexit=uicontrol('Style','Pushbutton','Callback','h=get(0,''Child'');for i=1:length(h),reset(figure(h(i)));close;end;',...
 'Position',[0.82 0.55 0.13 0.06],'Units','Normalized',...
 'String','Exit');

hrestart=uicontrol('Style','Pushbutton','Callback',...
'h=get(0,''Child'');for i=1:length(h),reset(figure(h(i)));close;end;swsynth;','Position',[0.82 0.48 0.13 0.06],...
'Units','Normalized','String','Restart');

hfigure=axes('Position',[.1 .1 .65 .75],...
 'Units','Normalized','XMinorGrid','On','Box','On',...
 'XLim',[0 dur],'YLim',[0 rate/2000]); 
title('Left-point draw,  Middle-quit draw,  Right-line draw');
xlabel('Time  (ms)');
ylabel('Frequency  (kHz)');
hfigure1=axes('Position',[.1 .1 .65 .75],...
 'XTick',[],'YTick',[],'XLim',[0 dur],'YLim',[0 rate/2]); 
hold on;
x = ((1:nframes)/nframes*dur);
p1 = plot(x,F1,'o',x,F1,'-y','EraseMode','Back');
text(dur+nmspf,F1(nframes),'F1'); 
p2 = plot(x,F2,'o',x,F2,'-y','EraseMode','Back');
text(dur+nmspf,F2(nframes),'F2');
p3 = plot(x,F3,'o',x,F3,'-y','EraseMode','Back');
text(dur+nmspf,F3(nframes),'F3');   
p4 = plot(x,F4,'o',x,F4,'-y','EraseMode','Back');
text(dur+nmspf,F4(nframes),'F4');	 
if(rate>=10000), 
  p5=plot(x,F5,'o',x,F5,'-y','EraseMode','Back');
  text(dur+nmspf,F5(nframes),'F5');
end;

% Amplitude of Voicing window
figure('Visible','off','Name','Amplitude Window',...
'NumberTitle','Off');
hfigure2=axes('Position',[.12 .1 .8 .8],...
'Units','Normalized','XMinorGrid','On','Box','On',...
'XLim',[0 dur],'YLim',[AVmin AVmax]);
xlabel('Time (ms)');
ylabel('Amplitude of Voicing (dB)');
title('Left-point draw,  Middle-quit draw,  Right-line draw');
hold on;
p6=plot(x,AV,'o',x,AV,'-y','Vis','off','EraseMode','Back');

