function [ret,x0,str,ts,xts]=VCO_v13(t,x,u,flag);
%VCO_V13	is the M-file description of the SIMULINK system named VCO_V13.
%	The block-diagram can be displayed by typing: VCO_V13.
%
%	SYS=VCO_V13(T,X,U,FLAG) returns depending on FLAG certain
%	system values given time point, T, current state vector, X,
%	and input vector, U.
%	FLAG is used to indicate the type of output to be returned in SYS.
%
%	Setting FLAG=1 causes VCO_V13 to return state derivatives, FLAG=2
%	discrete states, FLAG=3 system outputs and FLAG=4 next sample
%	time. For more information and other options see SFUNC.
%
%	Calling VCO_V13 with a FLAG of zero:
%	[SIZES]=VCO_V13([],[],[],0),  returns a vector, SIZES, which
%	contains the sizes of the state vector and other parameters.
%		SIZES(1) number of states
%		SIZES(2) number of discrete states
%		SIZES(3) number of outputs
%		SIZES(4) number of inputs
%		SIZES(5) number of roots (currently unsupported)
%		SIZES(6) direct feedthrough flag
%		SIZES(7) number of sample times
%
%	For the definition of other parameters in SIZES, see SFUNC.
%	See also, TRIM, LINMOD, LINSIM, EULER, RK23, RK45, ADAMS, GEAR.

% Note: This M-file is only used for saving graphical information;
%       after the model is loaded into memory an internal model
%       representation is used.

% the system will take on the name of this mfile:
sys = mfilename;
new_system(sys)
simver(1.3)
if (0 == (nargin + nargout))
     set_param(sys,'Location',[566,243,903,468])
     open_system(sys)
end;
set_param(sys,'algorithm',     'RK-45')
set_param(sys,'Start time',    '0.0')
set_param(sys,'Stop time',     '999999')
set_param(sys,'Min step size', '0.0001')
set_param(sys,'Max step size', '10')
set_param(sys,'Relative error','1e-3')
set_param(sys,'Return vars',   '')


%     Subsystem  ['Voltage',13,'Controlled',13,'Oscillator'].

new_system([sys,'/',['Voltage',13,'Controlled',13,'Oscillator']])
set_param([sys,'/',['Voltage',13,'Controlled',13,'Oscillator']],'Location',[238,249,1003,686])

add_block('built-in/Note',[sys,'/',['Voltage',13,'Controlled',13,'Oscillator/To solve the equation ',13,'sin((u*alpha+wn)*(t+dt)) = sin((u*alpha+wn)*t + (u*alpha+wn)*dt)',13,'at time t+dt']])
set_param([sys,'/',['Voltage',13,'Controlled',13,'Oscillator/To solve the equation ',13,'sin((u*alpha+wn)*(t+dt)) = sin((u*alpha+wn)*t + (u*alpha+wn)*dt)',13,'at time t+dt']],...
		'position',[215,345,220,350])

add_block('built-in/Note',[sys,'/',['Voltage',13,'Controlled',13,'Oscillator/limit input voltage',13,'to prevent o//p of',13,'negative frequencies']])
set_param([sys,'/',['Voltage',13,'Controlled',13,'Oscillator/limit input voltage',13,'to prevent o//p of',13,'negative frequencies']],...
		'position',[55,25,60,30])

add_block('built-in/Note',[sys,'/',['Voltage',13,'Controlled',13,'Oscillator/Uses the trigonometric identites',13,'sin(A+B) = sin(A)cos(B)+cos(A)sin(B)',13,'cos(A+B) = cos(A)cos(B)-sin(A)sin(B)']])
set_param([sys,'/',['Voltage',13,'Controlled',13,'Oscillator/Uses the trigonometric identites',13,'sin(A+B) = sin(A)cos(B)+cos(A)sin(B)',13,'cos(A+B) = cos(A)cos(B)-sin(A)sin(B)']],...
		'position',[195,280,200,285])

add_block('built-in/Abs',[sys,'/',['Voltage',13,'Controlled',13,'Oscillator/Abs']])
set_param([sys,'/',['Voltage',13,'Controlled',13,'Oscillator/Abs']],...
		'position',[130,118,160,142])

add_block('built-in/Product',[sys,'/',['Voltage',13,'Controlled',13,'Oscillator/Product1']])
set_param([sys,'/',['Voltage',13,'Controlled',13,'Oscillator/Product1']],...
		'position',[395,115,420,135])

add_block('built-in/Sum',[sys,'/',['Voltage',13,'Controlled',13,'Oscillator/dt1']])
set_param([sys,'/',['Voltage',13,'Controlled',13,'Oscillator/dt1']],...
		'position',[500,155,520,175])

add_block('built-in/Sum',[sys,'/',['Voltage',13,'Controlled',13,'Oscillator/dt2']])
set_param([sys,'/',['Voltage',13,'Controlled',13,'Oscillator/dt2']],...
		'inputs','-+',...
		'position',[505,240,525,260])

add_block('built-in/Product',[sys,'/',['Voltage',13,'Controlled',13,'Oscillator/Product4']])
set_param([sys,'/',['Voltage',13,'Controlled',13,'Oscillator/Product4']],...
		'position',[395,265,420,285])

add_block('built-in/Product',[sys,'/',['Voltage',13,'Controlled',13,'Oscillator/Product3']])
set_param([sys,'/',['Voltage',13,'Controlled',13,'Oscillator/Product3']],...
		'position',[395,225,420,245])

add_block('built-in/Product',[sys,'/',['Voltage',13,'Controlled',13,'Oscillator/Product2']])
set_param([sys,'/',['Voltage',13,'Controlled',13,'Oscillator/Product2']],...
		'position',[395,180,420,200])

add_block('built-in/Fcn',[sys,'/',['Voltage',13,'Controlled',13,'Oscillator/cos_h']])
set_param([sys,'/',['Voltage',13,'Controlled',13,'Oscillator/cos_h']],...
		'Expr','cos(u[2]*(u[1]*alpha + wc))',...
		'position',[270,210,310,230])

add_block('built-in/Fcn',[sys,'/',['Voltage',13,'Controlled',13,'Oscillator/sin_h']])
set_param([sys,'/',['Voltage',13,'Controlled',13,'Oscillator/sin_h']],...
		'Expr','sin(u[2]*(u[1]*alpha + wc))',...
		'position',[270,130,310,150])

add_block('built-in/Mux',[sys,'/',['Voltage',13,'Controlled',13,'Oscillator/Mux']])
set_param([sys,'/',['Voltage',13,'Controlled',13,'Oscillator/Mux']],...
		'inputs','2',...
		'position',[205,121,235,154])

add_block('built-in/Sum',[sys,'/',['Voltage',13,'Controlled',13,'Oscillator/dt']])
set_param([sys,'/',['Voltage',13,'Controlled',13,'Oscillator/dt']],...
		'inputs','+-',...
		'position',[160,180,180,200])

add_block('built-in/Clock',[sys,'/',['Voltage',13,'Controlled',13,'Oscillator/Clock']])
set_param([sys,'/',['Voltage',13,'Controlled',13,'Oscillator/Clock']],...
		'position',[35,175,55,195])

add_block('built-in/Outport',[sys,'/',['Voltage',13,'Controlled',13,'Oscillator/sin_out']])
set_param([sys,'/',['Voltage',13,'Controlled',13,'Oscillator/sin_out']],...
		'position',[600,155,620,175])

add_block('built-in/Memory',[sys,'/',['Voltage',13,'Controlled',13,'Oscillator/Memory']])
set_param([sys,'/',['Voltage',13,'Controlled',13,'Oscillator/Memory']],...
		'orientation',2,...
		'position',[480,70,530,100])

add_block('built-in/Memory',[sys,'/',['Voltage',13,'Controlled',13,'Oscillator/Memory1']])
set_param([sys,'/',['Voltage',13,'Controlled',13,'Oscillator/Memory1']],...
		'orientation',2,...
		'x0','1',...
		'position',[475,320,525,350])

add_block('built-in/Memory',[sys,'/',['Voltage',13,'Controlled',13,'Oscillator/Memory2']])
set_param([sys,'/',['Voltage',13,'Controlled',13,'Oscillator/Memory2']],...
		'position',[80,205,130,235])

add_block('built-in/Inport',[sys,'/',['Voltage',13,'Controlled',13,'Oscillator/voltage',13,'in']])
set_param([sys,'/',['Voltage',13,'Controlled',13,'Oscillator/voltage',13,'in']],...
		'position',[60,120,80,140])
add_line([sys,'/',['Voltage',13,'Controlled',13,'Oscillator']],[315,220;340,220;340,130;390,130])
add_line([sys,'/',['Voltage',13,'Controlled',13,'Oscillator']],[340,220;340,280;390,280])
add_line([sys,'/',['Voltage',13,'Controlled',13,'Oscillator']],[315,140;360,140;360,195;390,195])
add_line([sys,'/',['Voltage',13,'Controlled',13,'Oscillator']],[360,195;360,240;390,240])
add_line([sys,'/',['Voltage',13,'Controlled',13,'Oscillator']],[470,335;350,335;350,185;390,185])
add_line([sys,'/',['Voltage',13,'Controlled',13,'Oscillator']],[350,270;390,270])
add_line([sys,'/',['Voltage',13,'Controlled',13,'Oscillator']],[475,85;370,85;370,120;390,120])
add_line([sys,'/',['Voltage',13,'Controlled',13,'Oscillator']],[370,120;370,230;390,230])
add_line([sys,'/',['Voltage',13,'Controlled',13,'Oscillator']],[530,250;560,250;560,335;530,335])
add_line([sys,'/',['Voltage',13,'Controlled',13,'Oscillator']],[525,165;560,165;560,85;535,85])
add_line([sys,'/',['Voltage',13,'Controlled',13,'Oscillator']],[425,190;455,190;455,170;495,170])
add_line([sys,'/',['Voltage',13,'Controlled',13,'Oscillator']],[425,125;455,125;455,160;495,160])
add_line([sys,'/',['Voltage',13,'Controlled',13,'Oscillator']],[425,275;455,275;455,255;500,255])
add_line([sys,'/',['Voltage',13,'Controlled',13,'Oscillator']],[425,235;455,235;455,245;500,245])
add_line([sys,'/',['Voltage',13,'Controlled',13,'Oscillator']],[240,140;265,140])
add_line([sys,'/',['Voltage',13,'Controlled',13,'Oscillator']],[250,140;250,220;265,220])
add_line([sys,'/',['Voltage',13,'Controlled',13,'Oscillator']],[185,190;195,190;195,175;185,175;185,145;200,145])
add_line([sys,'/',['Voltage',13,'Controlled',13,'Oscillator']],[135,220;145,220;155,195])
add_line([sys,'/',['Voltage',13,'Controlled',13,'Oscillator']],[60,185;155,185])
add_line([sys,'/',['Voltage',13,'Controlled',13,'Oscillator']],[60,185;65,185;75,220])
add_line([sys,'/',['Voltage',13,'Controlled',13,'Oscillator']],[525,165;595,165])
add_line([sys,'/',['Voltage',13,'Controlled',13,'Oscillator']],[165,130;200,130])
add_line([sys,'/',['Voltage',13,'Controlled',13,'Oscillator']],[85,130;125,130])
set_param([sys,'/',['Voltage',13,'Controlled',13,'Oscillator']],...
		'Mask Display','VCO',...
		'Mask Dialogue','Voltage Controlled Oscillator|Natural Frequency:|Frequency Multiplier:',...
		'Mask Translate','wc=@1;alpha=@2;')
set_param([sys,'/',['Voltage',13,'Controlled',13,'Oscillator']],...
		'Mask Help','Converts an input value into a frequency output.\n  Y=sin(t*wn+F.M.*u))\nInput values must be >= 0.',...
		'Mask Entries','100\/20\/')


%     Finished composite block ['Voltage',13,'Controlled',13,'Oscillator'].

set_param([sys,'/',['Voltage',13,'Controlled',13,'Oscillator']],...
		'position',[110,40,160,100])

drawnow

% Return any arguments.
if (nargin | nargout)
	% Must use feval here to access system in memory
	if (nargin > 3)
		if (flag == 0)
			eval(['[ret,x0,str,ts,xts]=',sys,'(t,x,u,flag);'])
		else
			eval(['ret =', sys,'(t,x,u,flag);'])
		end
	else
		[ret,x0,str,ts,xts] = feval(sys);
	end
else
	drawnow % Flash up the model and execute load callback
end
