function [ret,x0,str,ts,xts]=pll(t,x,u,flag);
%PLL	is the M-file description of the SIMULINK system named PLL.
%	The block-diagram can be displayed by typing: PLL.
%
%	SYS=PLL(T,X,U,FLAG) returns depending on FLAG certain
%	system values given time point, T, current state vector, X,
%	and input vector, U.
%	FLAG is used to indicate the type of output to be returned in SYS.
%
%	Setting FLAG=1 causes PLL to return state derivatives, FLAG=2
%	discrete states, FLAG=3 system outputs and FLAG=4 next sample
%	time. For more information and other options see SFUNC.
%
%	Calling PLL with a FLAG of zero:
%	[SIZES]=PLL([],[],[],0),  returns a vector, SIZES, which
%	contains the sizes of the state vector and other parameters.
%		SIZES(1) number of states
%		SIZES(2) number of discrete states
%		SIZES(3) number of outputs
%		SIZES(4) number of inputs
%		SIZES(5) number of roots (currently unsupported)
%		SIZES(6) direct feedthrough flag
%		SIZES(7) number of sample times
%
%	For the definition of other parameters in SIZES, see SFUNC.
%	See also, TRIM, LINMOD, LINSIM, EULER, RK23, RK45, ADAMS, GEAR.

% Note: This M-file is only used for saving graphical information;
%       after the model is loaded into memory an internal model
%       representation is used.

% the system will take on the name of this mfile:
sys = mfilename;
new_system(sys)
simver(1.3)
if (0 == (nargin + nargout))
     set_param(sys,'Location',[324,99,763,395])
     open_system(sys)
end;
set_param(sys,'algorithm',     'RK-45')
set_param(sys,'Start time',    '0.0')
set_param(sys,'Stop time',     '19')
set_param(sys,'Min step size', '0.001')
set_param(sys,'Max step size', '.001')
set_param(sys,'Relative error','1e-3')
set_param(sys,'Return vars',   '')

add_block('built-in/Product',[sys,'/','Product'])
set_param([sys,'/','Product'],...
		'position',[110,38,140,62])

add_block('built-in/Mux',[sys,'/','Mux'])
set_param([sys,'/','Mux'],...
		'orientation',1,...
		'inputs','2',...
		'position',[42,210,73,245])

add_block('built-in/Scope',[sys,'/','Scope1'])
set_param([sys,'/','Scope1'],...
		'Vgain','1.000000',...
		'Hgain','0.500000',...
		'Vmax','2.000000',...
		'Hmax','1.000000',...
		'Window',[814,681,1143,857])
open_system([sys,'/','Scope1'])
set_param([sys,'/','Scope1'],...
		'position',[150,250,180,280])

add_block('built-in/Sine Wave',[sys,'/','Sine Wave'])
set_param([sys,'/','Sine Wave'],...
		'frequency','108',...
		'position',[25,35,45,55])

add_block('built-in/Zero-Pole',[sys,'/',['Chebychev Type I',13,'LP Filter']])
set_param([sys,'/',['Chebychev Type I',13,'LP Filter']],...
		'Zeros','z',...
		'Poles','p',...
		'Gain','k',...
		'Mask Display','plot(20*log10(w),20*log10(abs(h)))')
set_param([sys,'/',['Chebychev Type I',13,'LP Filter']],...
		'Mask Dialogue','Chebyshev type I low pass filter.\n\n(Requires Signal Processing Toolbox)|Cutoff frequency (rad/sec):|Order:|Db ripple in passband:')
set_param([sys,'/',['Chebychev Type I',13,'LP Filter']],...
		'Mask Translate','[z,p,k]=cheb1ap(@2,@3); z=@1*z; p=@1*p; k=real(prod(-p)); [num,den]=zp2tf(z,p,k); w=logspace(log10(@1/10),log10(10*@1),50); h=freqs(num,den,w); ')
set_param([sys,'/',['Chebychev Type I',13,'LP Filter']],...
		'Mask Help','Analog Chebychev type I low pass filter using MATLAB''s cheb1ap command.',...
		'Mask Entries','100\/8\/3\/',...
		'position',[190,25,250,75])


%     Subsystem  'VCO1'.

new_system([sys,'/','VCO1'])
set_param([sys,'/','VCO1'],'Location',[14,126,684,386])

add_block('built-in/Inport',[sys,'/','VCO1/VCO_in'])
set_param([sys,'/','VCO1/VCO_in'],...
		'position',[35,40,55,60])

add_block('built-in/Outport',[sys,'/','VCO1/VCO_out'])
set_param([sys,'/','VCO1/VCO_out'],...
		'position',[600,110,620,130])

add_block('built-in/Memory',[sys,'/','VCO1/Memory1'])
set_param([sys,'/','VCO1/Memory1'],...
		'position',[115,177,155,203])

add_block('built-in/Constant',[sys,'/',['VCO1/Center',13,'frequency']])
set_param([sys,'/',['VCO1/Center',13,'frequency']],...
		'Value','F0',...
		'position',[80,98,130,122])

add_block('built-in/Sum',[sys,'/','VCO1/Sum1'])
set_param([sys,'/','VCO1/Sum1'],...
		'position',[165,41,195,79])

add_block('built-in/Gain',[sys,'/',['VCO1/VCO',13,'gain']])
set_param([sys,'/',['VCO1/VCO',13,'gain']],...
		'Gain','K0',...
		'position',[90,35,130,65])

add_block('built-in/Sum',[sys,'/','VCO1/dt'])
set_param([sys,'/','VCO1/dt'],...
		'inputs','+-',...
		'position',[190,157,210,188])

add_block('built-in/Clock',[sys,'/','VCO1/Clock'])
set_param([sys,'/','VCO1/Clock'],...
		'position',[55,155,75,175])

add_block('built-in/Product',[sys,'/','VCO1/Product'])
set_param([sys,'/','VCO1/Product'],...
		'position',[240,86,270,124])

add_block('built-in/Fcn',[sys,'/',['VCO1/Modulo 1',13,'Integrator']])
set_param([sys,'/',['VCO1/Modulo 1',13,'Integrator']],...
		'Expr','rem(u,1)',...
		'position',[370,108,430,132])

add_block('built-in/Memory',[sys,'/','VCO1/Memory2'])
set_param([sys,'/','VCO1/Memory2'],...
		'orientation',2,...
		'x0','Phase',...
		'position',[315,172,355,198])

add_block('built-in/Sum',[sys,'/','VCO1/Sum2'])
set_param([sys,'/','VCO1/Sum2'],...
		'position',[315,94,350,141])

add_block('built-in/Fcn',[sys,'/','VCO1/SIN'])
set_param([sys,'/','VCO1/SIN'],...
		'Expr','sin(2*pi*u)',...
		'position',[480,104,550,136])

add_block('built-in/Note',[sys,'/','VCO1/Phase Integrator'])
set_param([sys,'/','VCO1/Phase Integrator'],...
		'position',[370,55,375,60])
add_line([sys,'/','VCO1'],[275,105;310,105])
add_line([sys,'/','VCO1'],[200,60;215,60;215,95;235,95])
add_line([sys,'/','VCO1'],[215,175;225,175;235,115])
add_line([sys,'/','VCO1'],[135,110;145,110;145,70;160,70])
add_line([sys,'/','VCO1'],[135,50;160,50])
add_line([sys,'/','VCO1'],[80,165;95,165;95,190;110,190])
add_line([sys,'/','VCO1'],[80,165;185,165])
add_line([sys,'/','VCO1'],[160,190;170,190;170,180;185,180])
add_line([sys,'/','VCO1'],[355,120;365,120])
add_line([sys,'/','VCO1'],[310,185;295,185;295,130;310,130])
add_line([sys,'/','VCO1'],[435,120;450,120;450,185;360,185])
add_line([sys,'/','VCO1'],[435,120;475,120])
add_line([sys,'/','VCO1'],[60,50;85,50])
add_line([sys,'/','VCO1'],[555,120;595,120])
set_param([sys,'/','VCO1'],...
		'Mask Display','plot(sin(0:pi/8:2*pi),cos(0:pi/8:2*pi),[-1:1/8:1]*0.75,sin(0:pi/8:2*pi)*0.5)',...
		'Mask Type','VCO')
set_param([sys,'/','VCO1'],...
		'Mask Dialogue','Voltage Controlled Oscillator.|Initial Frequency (Hz):|VCO Gain (Hz/V):|Initial Phase (rad):',...
		'Mask Translate','F0=@1; K0=@2; Phase=@3/2/pi;')
set_param([sys,'/','VCO1'],...
		'Mask Help','Voltage Controlled Oscillator.',...
		'Mask Entries','50/pi\/10/pi\/0\/')


%     Finished composite block 'VCO1'.

set_param([sys,'/','VCO1'],...
		'orientation',2,...
		'position',[150,175,190,215])

add_block('built-in/Scope',[sys,'/','Scope'])
set_param([sys,'/','Scope'],...
		'Vgain','1.000000',...
		'Hgain','10.000000',...
		'Vmax','2.000000',...
		'Hmax','20.000000',...
		'Window',[813,394,1142,570])
open_system([sys,'/','Scope'])
set_param([sys,'/','Scope'],...
		'position',[360,35,390,65])
add_line(sys,[145,50;185,50])
add_line(sys,[50,45;105,45])
add_line(sys,[145,195;65,195;65,55;105,55])
add_line(sys,[255,50;315,50;315,195;195,195])
add_line(sys,[60,250;60,265;145,265])
add_line(sys,[145,195;65,205])
add_line(sys,[50,45;50,205])
add_line(sys,[255,50;355,50])

drawnow

% Return any arguments.
if (nargin | nargout)
	% Must use feval here to access system in memory
	if (nargin > 3)
		if (flag == 0)
			eval(['[ret,x0,str,ts,xts]=',sys,'(t,x,u,flag);'])
		else
			eval(['ret =', sys,'(t,x,u,flag);'])
		end
	else
		[ret,x0,str,ts,xts] = feval(sys);
	end
else
	drawnow % Flash up the model and execute load callback
end
