function [ret,x0,str,ts,xts]=pll_v13(t,x,u,flag);
%PLL_V13	is the M-file description of the SIMULINK system named PLL_V13.
%	The block-diagram can be displayed by typing: PLL_V13.
%
%	SYS=PLL_V13(T,X,U,FLAG) returns depending on FLAG certain
%	system values given time point, T, current state vector, X,
%	and input vector, U.
%	FLAG is used to indicate the type of output to be returned in SYS.
%
%	Setting FLAG=1 causes PLL_V13 to return state derivatives, FLAG=2
%	discrete states, FLAG=3 system outputs and FLAG=4 next sample
%	time. For more information and other options see SFUNC.
%
%	Calling PLL_V13 with a FLAG of zero:
%	[SIZES]=PLL_V13([],[],[],0),  returns a vector, SIZES, which
%	contains the sizes of the state vector and other parameters.
%		SIZES(1) number of states
%		SIZES(2) number of discrete states
%		SIZES(3) number of outputs
%		SIZES(4) number of inputs
%		SIZES(5) number of roots (currently unsupported)
%		SIZES(6) direct feedthrough flag
%		SIZES(7) number of sample times
%
%	For the definition of other parameters in SIZES, see SFUNC.
%	See also, TRIM, LINMOD, LINSIM, EULER, RK23, RK45, ADAMS, GEAR.

% Note: This M-file is only used for saving graphical information;
%       after the model is loaded into memory an internal model
%       representation is used.

% the system will take on the name of this mfile:
sys = mfilename;
new_system(sys)
simver(1.3)
if (0 == (nargin + nargout))
     set_param(sys,'Location',[338,161,838,461])
     open_system(sys)
end;
set_param(sys,'algorithm',     'RK-45')
set_param(sys,'Start time',    '0.0')
set_param(sys,'Stop time',     '19')
set_param(sys,'Min step size', '0.001')
set_param(sys,'Max step size', '.001')
set_param(sys,'Relative error','1e-3')
set_param(sys,'Return vars',   '')

add_block('built-in/Product',[sys,'/','Product'])
set_param([sys,'/','Product'],...
		'position',[110,38,140,62])

add_block('built-in/Scope',[sys,'/','Scope'])
set_param([sys,'/','Scope'],...
		'Vgain','1.000000',...
		'Hgain','10.000000',...
		'Vmax','2.000000',...
		'Hmax','20.000000',...
		'Window',[813,394,1142,570])
open_system([sys,'/','Scope'])
set_param([sys,'/','Scope'],...
		'position',[405,130,435,160])

add_block('built-in/Mux',[sys,'/','Mux'])
set_param([sys,'/','Mux'],...
		'orientation',1,...
		'inputs','2',...
		'position',[42,210,73,245])

add_block('built-in/Scope',[sys,'/','Scope1'])
set_param([sys,'/','Scope1'],...
		'Vgain','1.000000',...
		'Hgain','0.500000',...
		'Vmax','2.000000',...
		'Hmax','1.000000',...
		'Window',[814,681,1143,857])
open_system([sys,'/','Scope1'])
set_param([sys,'/','Scope1'],...
		'position',[150,250,180,280])


%     Subsystem  'VCO'.

new_system([sys,'/','VCO'])
set_param([sys,'/','VCO'],'Location',[238,249,1003,686])

add_block('built-in/Inport',[sys,'/',['VCO/voltage',13,'in']])
set_param([sys,'/',['VCO/voltage',13,'in']],...
		'position',[60,120,80,140])

add_block('built-in/Memory',[sys,'/','VCO/Memory2'])
set_param([sys,'/','VCO/Memory2'],...
		'position',[80,205,130,235])

add_block('built-in/Memory',[sys,'/','VCO/Memory1'])
set_param([sys,'/','VCO/Memory1'],...
		'orientation',2,...
		'x0','1',...
		'position',[475,320,525,350])

add_block('built-in/Memory',[sys,'/','VCO/Memory'])
set_param([sys,'/','VCO/Memory'],...
		'orientation',2,...
		'position',[480,70,530,100])

add_block('built-in/Outport',[sys,'/','VCO/sin_out'])
set_param([sys,'/','VCO/sin_out'],...
		'position',[600,155,620,175])

add_block('built-in/Clock',[sys,'/','VCO/Clock'])
set_param([sys,'/','VCO/Clock'],...
		'position',[35,175,55,195])

add_block('built-in/Sum',[sys,'/','VCO/dt'])
set_param([sys,'/','VCO/dt'],...
		'inputs','+-',...
		'position',[160,180,180,200])

add_block('built-in/Mux',[sys,'/','VCO/Mux'])
set_param([sys,'/','VCO/Mux'],...
		'inputs','2',...
		'position',[205,121,235,154])

add_block('built-in/Fcn',[sys,'/','VCO/sin_h'])
set_param([sys,'/','VCO/sin_h'],...
		'Expr','sin(u[2]*(u[1]*alpha + wc))',...
		'position',[270,130,310,150])

add_block('built-in/Fcn',[sys,'/','VCO/cos_h'])
set_param([sys,'/','VCO/cos_h'],...
		'Expr','cos(u[2]*(u[1]*alpha + wc))',...
		'position',[270,210,310,230])

add_block('built-in/Product',[sys,'/','VCO/Product2'])
set_param([sys,'/','VCO/Product2'],...
		'position',[395,180,420,200])

add_block('built-in/Product',[sys,'/','VCO/Product3'])
set_param([sys,'/','VCO/Product3'],...
		'position',[395,225,420,245])

add_block('built-in/Product',[sys,'/','VCO/Product4'])
set_param([sys,'/','VCO/Product4'],...
		'position',[395,265,420,285])

add_block('built-in/Sum',[sys,'/','VCO/dt2'])
set_param([sys,'/','VCO/dt2'],...
		'inputs','-+',...
		'position',[505,240,525,260])

add_block('built-in/Sum',[sys,'/','VCO/dt1'])
set_param([sys,'/','VCO/dt1'],...
		'position',[500,155,520,175])

add_block('built-in/Product',[sys,'/','VCO/Product1'])
set_param([sys,'/','VCO/Product1'],...
		'position',[395,115,420,135])

add_block('built-in/Abs',[sys,'/','VCO/Abs'])
set_param([sys,'/','VCO/Abs'],...
		'position',[130,118,160,142])

add_block('built-in/Note',[sys,'/',['VCO/Uses the trigonometric identites',13,'sin(A+B) = sin(A)cos(B)+cos(A)sin(B)',13,'cos(A+B) = cos(A)cos(B)-sin(A)sin(B)']])
set_param([sys,'/',['VCO/Uses the trigonometric identites',13,'sin(A+B) = sin(A)cos(B)+cos(A)sin(B)',13,'cos(A+B) = cos(A)cos(B)-sin(A)sin(B)']],...
		'position',[195,280,200,285])

add_block('built-in/Note',[sys,'/',['VCO/limit input voltage',13,'to prevent o//p of',13,'negative frequencies']])
set_param([sys,'/',['VCO/limit input voltage',13,'to prevent o//p of',13,'negative frequencies']],...
		'position',[55,25,60,30])

add_block('built-in/Note',[sys,'/',['VCO/To solve the equation ',13,'sin((u*alpha+wn)*(t+dt)) = sin((u*alpha+wn)*t + (u*alpha+wn)*dt)',13,'at time t+dt']])
set_param([sys,'/',['VCO/To solve the equation ',13,'sin((u*alpha+wn)*(t+dt)) = sin((u*alpha+wn)*t + (u*alpha+wn)*dt)',13,'at time t+dt']],...
		'position',[215,345,220,350])
add_line([sys,'/','VCO'],[85,130;125,130])
add_line([sys,'/','VCO'],[165,130;200,130])
add_line([sys,'/','VCO'],[525,165;595,165])
add_line([sys,'/','VCO'],[60,185;65,185;75,220])
add_line([sys,'/','VCO'],[60,185;155,185])
add_line([sys,'/','VCO'],[135,220;145,220;155,195])
add_line([sys,'/','VCO'],[185,190;195,190;195,175;185,175;185,145;200,145])
add_line([sys,'/','VCO'],[240,140;265,140])
add_line([sys,'/','VCO'],[250,140;250,220;265,220])
add_line([sys,'/','VCO'],[425,235;455,235;455,245;500,245])
add_line([sys,'/','VCO'],[425,275;455,275;455,255;500,255])
add_line([sys,'/','VCO'],[425,125;455,125;455,160;495,160])
add_line([sys,'/','VCO'],[425,190;455,190;455,170;495,170])
add_line([sys,'/','VCO'],[525,165;560,165;560,85;535,85])
add_line([sys,'/','VCO'],[530,250;560,250;560,335;530,335])
add_line([sys,'/','VCO'],[475,85;370,85;370,120;390,120])
add_line([sys,'/','VCO'],[370,120;370,230;390,230])
add_line([sys,'/','VCO'],[470,335;350,335;350,185;390,185])
add_line([sys,'/','VCO'],[350,270;390,270])
add_line([sys,'/','VCO'],[315,140;360,140;360,195;390,195])
add_line([sys,'/','VCO'],[360,195;360,240;390,240])
add_line([sys,'/','VCO'],[315,220;340,220;340,130;390,130])
add_line([sys,'/','VCO'],[340,220;340,280;390,280])
set_param([sys,'/','VCO'],...
		'Mask Display','VCO',...
		'Mask Dialogue','Voltage Control Oscillator|Natural Frequency:|Frequency Multiplier:',...
		'Mask Translate','wc=@1;alpha=@2;')
set_param([sys,'/','VCO'],...
		'Mask Help','Converts an input value into a frequency output.\n  Y=sin(t*wn+F.M.*u))\nInput values must be >= 0.',...
		'Mask Entries','100\/20\/')


%     Finished composite block 'VCO'.

set_param([sys,'/','VCO'],...
		'orientation',2,...
		'position',[140,165,190,225])

add_block('built-in/Sine Wave',[sys,'/','Sine Wave'])
set_param([sys,'/','Sine Wave'],...
		'frequency','108',...
		'position',[25,35,45,55])

add_block('built-in/Zero-Pole',[sys,'/',['Chebychev Type I',13,'LP Filter']])
set_param([sys,'/',['Chebychev Type I',13,'LP Filter']],...
		'Zeros','z',...
		'Poles','p',...
		'Gain','k',...
		'Mask Display','plot(20*log10(w),20*log10(abs(h)))')
set_param([sys,'/',['Chebychev Type I',13,'LP Filter']],...
		'Mask Dialogue','Chebyshev type I low pass filter.\n\n(Requires Signal Processing Toolbox)|Cutoff frequency (rad/sec):|Order:|Db ripple in passband:')
set_param([sys,'/',['Chebychev Type I',13,'LP Filter']],...
		'Mask Translate','[z,p,k]=cheb1ap(@2,@3); z=@1*z; p=@1*p; k=real(prod(-p)); [num,den]=zp2tf(z,p,k); w=logspace(log10(@1/10),log10(10*@1),50); h=freqs(num,den,w); ')
set_param([sys,'/',['Chebychev Type I',13,'LP Filter']],...
		'Mask Help','Analog Chebychev type I low pass filter using MATLAB''s cheb1ap command.',...
		'Mask Entries','100\/8\/3\/',...
		'position',[190,25,250,75])
add_line(sys,[145,50;185,50])
add_line(sys,[50,45;105,45])
add_line(sys,[135,195;85,195;85,55;105,55])
add_line(sys,[255,50;315,50;315,195;195,195])
add_line(sys,[315,145;400,145])
add_line(sys,[60,250;60,265;145,265])
add_line(sys,[135,195;65,205])
add_line(sys,[50,45;50,205])

drawnow

% Return any arguments.
if (nargin | nargout)
	% Must use feval here to access system in memory
	if (nargin > 3)
		if (flag == 0)
			eval(['[ret,x0,str,ts,xts]=',sys,'(t,x,u,flag);'])
		else
			eval(['ret =', sys,'(t,x,u,flag);'])
		end
	else
		[ret,x0,str,ts,xts] = feval(sys);
	end
else
	drawnow % Flash up the model and execute load callback
end
