function anoption(Action,WorkingFig)
%ANOPTION Animation option menu function.
%	ANOPTION(ACTION) is the callback function for the Option menu 
%	on the animation figure window.
%
%	ACTION may be one of 7 strings:
%	          '#Grid'  Toggle the grid on/off.
%	        '#AxisOn'  Toggle the axis on/off
%	           '#Box'  Toggle the axis box on/off.
%	      '#TickMark'  Toggle TickMarks on/off.
%	'#AutoExpandAxis'  Toggle the automatic scaling on/off.
%	       '#SetAxis'  Set axis limits.
%	    '#SquareAxis'  Toggle square axis on/off
%	   'ChangeLabels'  Change axis labels
%	   'UpdateLabels'  Update axis labels
%	   '#FindObjects'  Find all objects.
%	    '#HideStatus'  Toggle status bar display.
%	 '#HideObjectBtn'  Toggle object button icon display
%	   '#FindDiagram'  Find Simulink Diagram
%
%
%	See also ANSIMINI.

%	Loren Dean  March, 1995.
%	Copyright (c) 1995 by The MathWorks, Inc.

if nargin==1,
  WorkingFig=findobj(0,'Type','figure','Tag','WorkingFig');
end  
FigData=get(WorkingFig,'UserData');
WorkingAxes=FigData(2);

%%%%%%%%%%%%
%%% Grid %%%
%%%%%%%%%%%%
if strcmp(Action,'#Grid'),
  HOptnGrid = findobj(WorkingFig, ...
                     'Type'     ,'uimenu'        , ...
                     'Tag'      ,'MenuOptionGrid'  ...
                     );
  if strcmp(get(HOptnGrid,'Checked'),'on'),
    set(HOptnGrid,'Checked','off');
    set(WorkingAxes,'XGrid','off','YGrid','off');
  else,
    set(HOptnGrid,'Checked','on');
    set(WorkingAxes,'XGrid','on','YGrid','on');
  end %if strcmp
  
%%%%%%%%%%%%%%%%%%%
%%% Axis On/Off %%%
%%%%%%%%%%%%%%%%%%%
elseif strcmp(Action,'#AxisOn'),
  AxisOnHandle=findobj(WorkingFig, ...
                   'Type'     ,'uimenu'         , ...
                   'Tag'      ,'MenuOptionAxisOn' ...
                   );
  if strcmp('off',get(AxisOnHandle,'Checked')),
    set(AxisOnHandle,'Checked','on');
    set(WorkingAxes,'Visible','on');
  else,
    set(AxisOnHandle,'Checked','off');
    set(WorkingAxes,'Visible','off')
  end % if strcmp off
    
%%%%%%%%%%%%%%%%
%%% Axis Box %%%
%%%%%%%%%%%%%%%%
elseif strcmp(Action,'#Box'),
  BoxHandle=findobj(WorkingFig, ...
                   'Type'     ,'uimenu'      , ...
                   'Tag'      ,'MenuOptionBox' ...
                   );
  if strcmp('off',get(BoxHandle,'Checked')),
    set(BoxHandle,'Checked','on');
    set(WorkingAxes,'Box','on');
  else,
    set(BoxHandle,'Checked','off');
    set(WorkingAxes,'Box','off');
  end % if strcmp off
  
%%%%%%%%%%%%%%%%%
%%% Tick Mark %%%
%%%%%%%%%%%%%%%%%
elseif strcmp(Action,'#TickMark'),
  TickHandle=findobj(WorkingFig, ...
                    'Type'     ,'uimenu'       , ...
                    'Tag'      ,'MenuOptionTickMark' ...
                    );
  if strcmp('on',get(TickHandle,'Checked')),
    set(TickHandle,'Checked','off');
    set(WorkingAxes,'XTick',[],'YTick',[]);
  else,
    set(TickHandle,'Checked','on');
    set(WorkingAxes,'XTickMode','auto','YTickMode','auto');
  end % if strcmp on
%%%%%%%%%%%%%%%%%%%
%%% Square Axis %%%
%%%%%%%%%%%%%%%%%%%
elseif strcmp(Action,'#SquareAxis'),
  SquareHandle=findobj(WorkingFig, ...
                      'Type'     ,'uimenu'       , ...
                      'Tag'      ,'MenuOptionSquareAxis' ...
                      );
  if strcmp('on',get(SquareHandle,'Checked')),
    set(SquareHandle,'Checked','off');
    set(WorkingAxes,'PlotBoxAspectRatioMode','auto');
  else,
    set(SquareHandle,'Checked','on');
    set(WorkingAxes,'PlotBoxAspectRatio',[1 1 1]);
  end % if strcmp on
                   
  
%%%%%%%%%%%%%%%%%%%%%%%%
%%% Auto Axis Limits %%%
%%%%%%%%%%%%%%%%%%%%%%%%
elseif strcmp(Action,'#AutoExpandAxis'),
    AutoAxisHandle=findobj(WorkingFig, ...
                          'Type'     ,'uimenu'            , ...
                          'Tag'      ,'MenuOptionAxisAuto'  ...
                          );
    if strcmp('off',get(AutoAxisHandle,'Checked')),
      set(AutoAxisHandle,'Checked','on');
    else,
      set(AutoAxisHandle,'Checked','off');
    end % if strcmp off
    
%%%%%%%%%%%%%%%%%%%%%%%
%%% Set Axis Limits %%%
%%%%%%%%%%%%%%%%%%%%%%%
elseif strcmp(Action,'#SetAxis'),
  set(WorkingFig,'CurrentAxes',WorkingAxes);
  AxCall=['axlimdlg(''ApplyCallback'');'              , ...
          'CurFig=get(0,''CurrentFigure'');'          , ...
          'Data=get(CurFig,''UserData'');'            , ...
          'AxHandle=get(Data(1,1),''UserData'');'     , ...
          'FigHandle=get(AxHandle,''Parent'');'       , ...
          'set(0,''CurrentFigure'',FigHandle);'       , ...
          'ansimltn #Reset ;'                         , ...
          'set(0,''CurrentFigure'',CurFig);'            ...
         ];

  Data=get(WorkingFig,'UserData');
  SimHandle=Data(1);
  String=['Axes Limits: ' get_param(SimHandle,'Name')];

  
  axlimdlg(String                                            , ...
           [0 0]                                             , ...
           ['X-Axis Range';'Y-Axis Range']                   , ...
           [WorkingAxes, NaN,WorkingAxes]                    , ...
           ['x';'y']                                         , ...
           [get(WorkingAxes,'XLim');get(WorkingAxes,'YLim')] , ...
           AxCall                                              ...
          );

%%%%%%%%%%%%%%%%%%%%%
%%% Change Labels %%%
%%%%%%%%%%%%%%%%%%%%%
elseif strcmp(Action,'#ChangeLabels'),
  TextStrings=str2mat('X Label:','Y Label:','Title:');
  
  Values=str2mat(get(get(WorkingAxes,'XLabel'),'String'), ...
                 get(get(WorkingAxes,'YLabel'),'String'), ...
                 get(get(WorkingAxes,'Title'),'String')   ...
                );
  Callbacks=setstr(ones(size(Values,1)+1,1)*'anoption #UpdateLabels');

  Tags=['X';'Y';'T'];

  FigTag='PrpDlgFig';
  FigTitle='Axis Label Settings';
  FigHelp='This dialog allows you to set the labels on the current axes.';
  
  set(WorkingFig,'Pointer','watch')  
  Handles = anprpdlg('#Initialize', []    , WorkingFig, ...
                     TextStrings  , Values, Callbacks , ...
                     Tags         , FigTag, FigTitle  , ...
                     FigHelp        ...
                     );
  set(WorkingFig,'Pointer','arrow')
  
%%%%%%%%%%%%%%%%%%%%%
%%% Update Labels %%%
%%%%%%%%%%%%%%%%%%%%%
elseif strcmp(Action,'#UpdateLabels'),
  PrpDlgFig=gcbf;
  
  List=['X';'Y';'T'];
  for lp=1:length(List),
    %%% Get Handles
    eval([ List(lp) 'Handle=findobj(PrpDlgFig,', ...
          ' ''Type'',''uicontrol'',''Tag'',''' List(lp) ''');']);

    %%% Get Strings for Edit Text Blocks
    eval(['Current' List(lp) '=get(' List(lp) 'Handle,''String'');']);

    %%% Remove all leading and trailing spaces from CurrentX and CurrentY
    eval(['Current' List(lp) '=deblank(fliplr(Current' List(lp) '));']);
    eval(['Current' List(lp) '=deblank(fliplr(Current' List(lp) '));']);
  end % for lp
  
  set(get(WorkingAxes,'XLabel'),'String',CurrentX,'Color',[1 1 1])
  set(get(WorkingAxes,'YLabel'),'String',CurrentY,'Color',[1 1 1])
  set(get(WorkingAxes,'Title') ,'String',CurrentT,'Color',[1 1 1])
  
%%%%%%%%%%%%%%%%%%%%
%%% Find Objects %%%
%%%%%%%%%%%%%%%%%%%%
elseif strcmp(Action,'#FindObjects'),
  AutoHandle=FigData(3);
  if strcmp(get(AutoHandle,'Checked'),'on'),
    set(WorkingAxes,'XLimMode','auto','YLimMode','auto');
    drawnow
    set(WorkingAxes,'XLimMode','manual','YLimMode','manual');
  end
          
%%%%%%%%%%%%%%%%%%%%%%%
%%% Hide Status Bar %%%
%%%%%%%%%%%%%%%%%%%%%%%
elseif strcmp(Action,'#HideStatus'),
  HideHandle = findobj(WorkingFig, ...
                      'Type'     ,'uimenu'              , ...
                      'Tag'      ,'MenuOptionHideStatus'  ...
                      );

  GridHandle = findobj(WorkingFig, ...
                      'Type'     ,'uimenu'        , ...
                      'Tag'      ,'MenuOptionGrid'  ...
                      );

  StatusHandles=get(HideHandle,'UserData');

  AxisPos=get(GridHandle,'UserData');
  NewPos=get(WorkingAxes,'Position');
  
  if strcmp(get(HideHandle,'Checked'),'on'),
    set(HideHandle,'Checked','off');
    if strcmp(get(StatusHandles(1),'String'),'Start'),    
      set(StatusHandles([1 3:5]),'Visible','on');
      if strcmp(get(WorkingFig,'KeyPressFcn'),'ansimltn #WarnPress'),
        set(StatusHandles(2),'Visible','on');
      end        
    else,
      set(StatusHandles([1 3:7]),'Visible','on');
    end
    
    NewPos([2 4])=AxisPos(1,[2 4]);
  else,
    set(HideHandle,'Checked','on');
    set(StatusHandles,'Visible','off');
    NewPos([2 4])=AxisPos(2,[2 4]);
  end %if strcmp on
  set(WorkingAxes,'Position',NewPos);
  
%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%% Hide Object Buttons %%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%
elseif strcmp(Action,'#HideObjectBtn'),
  HideHandle = findobj(WorkingFig, ...
                      'Type'     ,'uimenu'               , ...
                      'Tag'      ,'MenuOptionHideButtons'  ...
                      );
  ObjectHandles=get(HideHandle,'UserData');
  
  GridHandle = findobj(WorkingFig, ...
                      'Type'     ,'uimenu'        , ...
                      'Tag'      ,'MenuOptionGrid'  ...
                      );
                      
  AxisPos=get(GridHandle,'UserData');
  NewPos=get(WorkingAxes,'Position');
  
  set(ObjectHandles(2:end),'EraseMode','normal');    
  
  if strcmp(get(HideHandle,'Checked'),'on'),
    set(HideHandle,'Checked','off');
    set(ObjectHandles,'Visible','on');
    NewPos([1 3])=AxisPos(1,[1 3]);
  else,
    set(HideHandle,'Checked','on');
    set(ObjectHandles,'Visible','off');
    NewPos([1 3])=AxisPos(2,[1 3]);
  end %if strcmp on
  set(ObjectHandles(2:end),'EraseMode','none');    
   
  set(WorkingAxes,'Position',NewPos);
  % bug work around  
  set(gcbf,'Color',[0 0 0]);  
  
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%% Find Simulink Diagram %%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
elseif strcmp(Action,'#FindDiagram'),
 SimHandle=FigData(1);
 open_system(get_param(SimHandle,'Parent'));
end % if strcmp Action
