function [sys,x0]=ansim(t,x,u,flag,WorkingFig)
%ANSIM	Simulation animation.
%	[SYS,XO]=ANSIM(T,X,U,FLAG,WORKINGFIG) is the S-Function used
%	for the animation block in Simulink.  
%
%	WORKINGFIG is the handle of the figure that the animation takes
%	place on.
%
%	See also ANSIMINI.

%	Loren Dean  March, 1995.
%	Copyright (c) 1995 by The MathWorks, Inc.

InvalidHandle=0;
eval('InvalidHandle=~strcmp(get(WorkingFig,''Tag''),''WorkingFig'');', ...
     'InvalidHandle=1;'                                                ...
     );

if InvalidHandle,WorkingFig=[];end

if ~isempty(WorkingFig),
  SimFigData=get(WorkingFig,'UserData');
  WorkingAxes=SimFigData(2);
end

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%% Initialize everything %%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
if flag==0, 

  if ~isempty(WorkingFig),
    set(WorkingFig,'Pointer','watch')
    CloseHandle=findobj(WorkingFig,'Type','uimenu','Tag','MenuFileClose');
    InitOnce=get(CloseHandle,'UserData');
    
    if ~InitOnce,
      %%% Determine if a Properties dialog for this figure is already open
      %%% and close it using OK if it is
      Figs=findobj(0,'Type','figure','Tag','PrpDlgFig');
      for lp=1:length(Figs),
        Handle=get(Figs(lp),'UserData');
        if Handle(1)==WorkingFig,
          set(0,'CurrentFigure',Figs(lp));
          anprpdlg #OK
        end
      end % for lp
      
      ansimltn('#MakeStatic',WorkingFig)      

      ansimltn('#Start/Stop',WorkingFig)
      
      ansimltn('#Disable',WorkingFig);
      
      ansetobj(WorkingFig);
 
      anedit('#Deselect',WorkingFig)      
      
    end % if ~InitOnce
    
    set(WorkingFig,'Pointer','arrow')
    
  end % if ~isempty
  drawnow;
  
  sys=[0 0 0 -1 0 0];
  x0=[];

%%%%%%%%%%%%%%%%%%%%%%%%%%
%%% Simulate Everthing %%%
%%%%%%%%%%%%%%%%%%%%%%%%%%
elseif flag==2,
  if ~isempty(WorkingFig),
   
    anreset(WorkingFig,u);
    
  end % WorkingFig
  sys=[];

%%%%%%%%%%%%%%%%%%%%%%
%%% End Simulation %%%
%%%%%%%%%%%%%%%%%%%%%%
elseif flag==9,
  
  if ~isempty(WorkingFig),
    set(WorkingFig,'Pointer','watch')
    CloseHandle=findobj(WorkingFig,'Type','uimenu','Tag','MenuFileClose');
    set(CloseHandle,'UserData',0);

    ansimltn('#MakeStatic',WorkingFig)      
    
    SimData=get(WorkingAxes,'UserData');

    HideHandle = findobj(WorkingFig, ...
                        'Type'     ,'uimenu'              , ...
                        'Tag'      ,'MenuOptionHideStatus'  ...
                        );
    StatusHandles=get(HideHandle,'UserData');                      
    set(StatusHandles(6:7),'Visible','off');        

    if ~isempty(SimData),
      set(SimData(:,1),'EraseMode','normal');
      anedit('#Deselect',WorkingFig)


      if strcmp(get(HideHandle,'Checked'),'off'),
        set(StatusHandles(2),'Visible','on');
      end
      ResetMenuHandle=findobj(WorkingFig, ...
                             'Type'     ,'uimenu'             , ...
                             'Tag'      ,'MenuSimulationReset'  ...
                             );
      set(ResetMenuHandle,'Enable','on');
      
      ansimltn('#WarnBtnPress',WorkingFig)

    else,
      ansimltn('#Enable',WorkingFig);
    end % if ~isempty

    ansimltn('#Start/Stop',WorkingFig)
        
    anedit('#Deselect',WorkingFig)      
    
    set(WorkingFig,'Pointer','arrow')
  end % if WorkingFig

  
  sys=[];
end; % flag


