function andot(Action,Handle,WorkingFig,u)
%ANDOT	Dot creation and display function.
%	ANDOT(ACTION,HANDLE,WORKINGFIG,U) is the creation and display 
%	function for the dot object in the simulation animation block.
%
%	ACTION may be one of four strings:
%	    '#Draw'  Draw dot object.
%	     '#New'  Create new dot object.
%	  '#Modify'  Modify dot object parameters.
%	  '#Update'  Update object paramaters as entered in currently
%	             displayed dialog.
%
%	HANDLE is a vector of dot object handles.
%
%	WORKINGFIG is the handle for the figure that the objects are 
%	drawn on.
%
%	U is the vector of inputs to the animation block.  It is used
%	in the '#Draw' area only.
%
%	See also ANLINE, ANPATHC, ANRECT, ANTEXT, ANOBJ.

%	Loren Dean March, 1995.
%	Copyright (c) 1995 by The MathWorks, Inc.
%

%%%%%%%%%%%
%%% Draw %%%
%%%%%%%%%%%
if strcmp(Action,'#Draw'),

  NumObjs=length(Handle);
  Data=zeros(NumObjs,6);
  
  for lp=1:NumObjs,
    Data(lp,:)=eval(get(Handle(lp),'UserData') ,      ...
                  ['[get(Handle(lp),''XData'') '      ...
                   ' get(Handle(lp),''YData'') '      ...
                   ' get(Handle(lp),''MarkerSize'') ' ...
                   ' get(Handle(lp),''Color'')]'     ] ...
                   );
  end % for lp
    
  FigData=get(WorkingFig,'UserData');
  WorkingAxes=FigData(2);
  
  [Data(:,1),Data(:,2)] = andraw(WorkingFig ,Handle      , ...
                                 Data(:,1)  ,Data(:,2)   , ...
                                 get(WorkingAxes,'XLim') , ...
                                 get(WorkingAxes,'YLim')   ...
                                 );
  for lp=1:NumObjs,
    set(Handle(lp) , ...
       'XData'     ,Data(lp,1)             , ...
       'YData'     ,Data(lp,2)             , ...
       'MarkerSize',max(abs(Data(lp,3)),10), ...
       'Color'     ,abs(Data(lp,4:6))        ...
       );
  end % for lp
  
%%%%%%%%%%%
%%% New %%%
%%%%%%%%%%%
elseif strcmp(Action,'#New'),
  % All Cases except Load from file and double click open
  if nargin==1,
    WorkingFig=findobj(0,'type','figure','Tag','WorkingFig');
    Handle=[];
  end % if
  
  FigData=get(WorkingFig,'UserData');
  WorkingAxes=FigData(2);
  set(WorkingFig,'CurrentAxes',WorkingAxes);
  
  LoadFromFileFlag=length(Handle)>1;

  if LoadFromFileFlag,
    u=angetic(WorkingFig);
    Data=eval(Handle,['[sum(get(WorkingAxes,''XLim''))/2,' , ...
                      ' sum(get(WorkingAxes,''YLim''))/2,' , ...
                      ' 30 1 1 1]'                           ...
                      ]);
    XPos=Data(1);YPos=Data(2);Marker=max(10,abs(Data(3)));Color=Data(4:6);
    
  else,
    if nargin==4,  % Double click open
      [XPos,YPos]=angetpos(WorkingFig,1);
    else,
      [XPos,YPos]=angetpos(WorkingFig);
    end % if nargin
    Marker=30;
    Color=[1 1 1];
  end %if LoadFromFileFlag

  CurrentPt=line(                                       ...
                 XPos          , YPos                 , ...
                'LineStyle'    , '.'                  , ...
                'MarkerSize'   , Marker               , ...
                'Color'        , Color                , ...
                'ButtonDownFcn', 'anedit #ButtonDown' , ...
                'EraseMode'    , 'normal'             , ...
                'Interruptible', 'yes'                , ...
                'Tag'          , 'AnimDot'              ...
                );
 
  if LoadFromFileFlag,
    WorkingData=Handle;
  else,
    WorkingData=['[' num2str(XPos)   ',' num2str(YPos)  ','  ...
                     num2str(Marker) ',' mat2str(Color) ',]' ...
                ];
  end % if LoadFromFileFlag
  
  [SelectColor,DeselectColor]=angetclr('#New',CurrentPt,Color);
  set(CurrentPt,'UserData',WorkingData,'Color',SelectColor);
  
  AxesData=get(WorkingAxes,'UserData');
  set(WorkingAxes,'UserData',[]); %Done for speed purposes (not necessary)
  AxesData=[CurrentPt abs('andot   ');AxesData];
  set(WorkingAxes,'UserData',AxesData);

  
  andraw(WorkingFig             , CurrentPt              , ...
         XPos                   , YPos                   , ...
         get(WorkingAxes,'XLim'), get(WorkingAxes,'YLim')  ...
        );

  if ~LoadFromFileFlag,
    andot('#Modify',CurrentPt,WorkingFig)
  end
  

%%%%%%%%%%%%%%
%%% Modify %%%
%%%%%%%%%%%%%%
elseif strcmp(Action,'#Modify'),

  List='XYRC';
  CurrentData=get(Handle,'UserData');

  CommaLocs=ancomloc(CurrentData);
  CurrentX=CurrentData(1,             2:CommaLocs(1)-1);
  for lp=2:length(List),
    eval(['Current' List(lp) '=CurrentData(1,CommaLocs(' num2str(lp-1) ...
          ')+1:CommaLocs(' num2str(lp) ')-1);']);
  end % for lp

  TextStrings=str2mat('X Coordinate:','Y Coordinate:'  , ...
                      'Marker Size:' ,'Color ([R,G,B]):' ...
                     );
  Values=str2mat(CurrentX,CurrentY,CurrentR,CurrentC);
  Callbacks=setstr(ones(length(Values(:,1))+1,1)*'andot #Update');

  Tags=List';

  FigTag='PrpDlgFig';
  FigData=get(WorkingFig,'UserData');
  SimHandle=FigData(1);
  FigTitle=['Dot Object Properties: ' get_param(SimHandle,'Name')];
  Handles = anprpdlg('#Initialize', Handle, WorkingFig, ...
                     TextStrings  , Values, Callbacks , ...
                     Tags         , FigTag, FigTitle    ...
                    );

%%%%%%%%%%%%%%
%%% Update %%%
%%%%%%%%%%%%%%
elseif strcmp(Action,'#Update'),

  PrpDlgFig=get(0,'CurrentFigure');
  Data=get(PrpDlgFig,'UserData');
  WorkingFig=Data(1);
  WorkingAxes=findobj(WorkingFig,'Type','axes','Tag','WorkingAxes');

  CurrentPt=Data(2);
  
  List='XYRC';
  for lp=1:length(List),
    %%% Get Handles
    eval([ List(lp) 'Handle=findobj(PrpDlgFig,', ...
          ' ''Type'',''uicontrol'',''Tag'',''' List(lp) ''');']);

    %%% Get Strings for Edit Text Blocks
    eval(['Current' List(lp) '=get(' List(lp) 'Handle,''String'');']);

    %%% Remove all leading and trailing spaces from CurrentX and CurrentY
    eval(['Current' List(lp) '=deblank(fliplr(Current' List(lp) '));']);
    eval(['Current' List(lp) '=deblank(fliplr(Current' List(lp) '));']);
  end % for lp
  
  u=angetic(WorkingFig);
  eval(['XFlag=0;CurrentXPos=' CurrentX ';']           , ...
        'XFlag=1;CurrentXPos=get(CurrentPt,''XData'');'  ...
      );
  eval(['YFlag=0;CurrentYPos=' CurrentY ';']           , ...
        'YFlag=1;CurrentYPos=get(CurrentPt,''YData'');'  ...
      );
  eval('RFlag=0;CurrentRVal=max(abs(eval(CurrentR,''30'')),10);', ...
       'RFlag=1;CurrentRVal=10;'                                  ...
      );
  eval(['CFlag=0;CurrentCVal=' CurrentC ';']            , ...
        'CFlag=1;CurrentCVal=get(CurrentPt,''Color'');'  ...
      );
  HCancel=findobj(PrpDlgFig,'Type','uicontrol','Tag','Cancel');
  CurrentData=get(HCancel,'UserData');
  CommaLocs=ancomloc(CurrentData(1,:));
  
  ListLoc=0;
  if XFlag,Low=2;             High=CommaLocs(1)-1;ListLoc=1;end
  if YFlag,Low=CommaLocs(1)+1;High=CommaLocs(2)-1;ListLoc=2;end
  if RFlag,Low=CommaLocs(2)+1;High=CommaLocs(3)-1;ListLoc=3;end
  if CFlag,Low=CommaLocs(3)+1;High=CommaLocs(4)-1;ListLoc=4;end
  
  if ListLoc,
    CurrentString=CurrentData(1,Low:High);
    eval(['Current' List(ListLoc) '=CurrentString;']);
    eval(['set(' List(ListLoc) 'Handle,''String'',CurrentString)']);
    disp([7,7,7 'Last entry was invalid.  Old being used.']);disp(' ');
  end
  
  AllPtData =[ '[' CurrentX ',' CurrentY ',' CurrentR ',' CurrentC ',]' ];

  set(HCancel,'UserData',str2mat(AllPtData,CurrentData(2,:)));
  
  set(CurrentPt  , ...
     'Xdata'     , CurrentXPos, ...
     'Ydata'     , CurrentYPos, ...
     'MarkerSize', CurrentRVal, ...
     'Color'     , CurrentCVal, ...
     'UserData'  , AllPtData    ...
     );

  angetclr('#Modify',CurrentPt,CurrentCVal);
  
  ansimltn('#Reset',WorkingFig);


end % if strcmp action
