function [out1,out2]=andraw(WorkingFig,ObjHandle,arg3,arg4,arg5,arg6)
%ANDRAW	Reset object position.
%	[XPOS,YPOS]=ANDRAW(WORKINGFIG,OBJHANDLE,CURXPOS,CURYPOS,XLIM,YLIM)
%	This function will reset animation object positions based on the 
%	scaling option selected for the axes.  If auto scaling is set, object
%	positions are not changed but the axis limits are.
%
%	Other Calling Syntaxes:
%	  ANDRAW(WORKINGFIG,OBJHANDLE,XLIM,YLIM)
%	  ANDRAW(WORKINGFIG,OBJHANDLE,CURPOSITION,XLIM,YLIM)
%	  ANDRAW(WORKINGFIG,OBJHANDLE,CURXPOS,CURYPOS,XLIM,YLIM)
%	  [POSITION] =ANDRAW(WORKINGFIG,OBJHANDLE,CURPOSITION,XLIM,YLIM)
%	  [XPOS,YPOS]=ANDRAW(WORKINGFIG,OBJHANDLE,CURXPOS,CURYPOS,XLIM,YLIM)
%
%	POSITION,CURPOSITION are nx7 element matrices containing the x,y,z 
%	  position and 4 element extent of text objects.
%
%	XPOS,YPOS,CURXPOS,CURYPOS are nx1 vectors containg the position of 
%	  the objects.
%
%	WORKINGFIG is the handle for the figure the objects are placed on.
%
%	OBJHANDLE is a vector of object handles.  If ObjHandle is a NumPts by
%	2 matrix, the second column contains the number of data points 
%	associated with each handle.
%
%	XLIM,YLIM are the x and y limits of the axes.
%
%	See also ANDOT, ANRECT, ANTEXT.

%	Loren Dean  March, 1995.
%	Copyright (c) 1995 by The MathWorks, Inc.

SimFigData=get(WorkingFig,'UserData');
AutoAxisHandle=SimFigData(3);
WorkingAxes=SimFigData(2);
SimHandle=SimFigData(1);
SimRoot=bdroot(SimHandle);

if nargin==4,
  XLim=arg3;YLim=arg4;
elseif nargin==5,
  Position=arg3;XLim=arg4;YLim=arg5;
elseif nargin==6,
  XPos=arg3;YPos=arg4;XLim=arg5;YLim=arg6;
end % if nargin

NumPts=length(ObjHandle(:,1));

if strcmp('off',get(AutoAxisHandle,'Checked')),

  if strcmp('text',get(ObjHandle(1),'Type')),
    if nargin==4,
      Position=zeros(NumPts,7);
      for lp=1:NumPts,
        Position(lp,:)=[get(ObjHandle(lp),'Position') , ...
                        get(ObjHandle(lp),'Extent')     ...
                       ];
      end % for lp
    end % if nargin

    XLoc=find(Position(:,4)<XLim(1));
    Position(XLoc,1)=Position(XLoc,1) - ...
                     Position(XLoc,4) + ...
                     ones(length(XLoc),1)*XLim(1);
    XLoc=find(Position(:,4)+Position(:,6)>XLim(2));
    Position(XLoc,1)=Position(XLoc,1) - ...
                     (Position(XLoc,4)+Position(XLoc,6)) + ...
                     ones(length(XLoc),1)*XLim(2);

    YLoc=find(Position(:,5)<YLim(1));
    Position(YLoc,2)=Position(YLoc,2) - ...
                     Position(YLoc,5) + ...
                     ones(length(YLoc),1)*YLim(1);
    YLoc=find(Position(:,5)+Position(:,7)>YLim(2));
    Position(YLoc,2)=Position(YLoc,2) - ...
                     (Position(YLoc,5)+Position(YLoc,7)) + ...
                     ones(length(YLoc),1)*YLim(2);
 
   
    if nargout==0,
      for lp=1:NumPts,
        set(ObjHandle(lp),'Position',Position(lp,1:3));
      end % for lp
    else,
      out1=Position;out2=[];        
    end  % if nargout
    
  else,
    if length(ObjHandle(1,:))==1, 
      NumPts=length(ObjHandle);
    else,
      NumPts=length(ObjHandle(:,1));
      NumDataPts=ObjHandle(:,2);
    end % if length
 
    out1=[];out2=[];
    if nargin==6,
      XPosTemp=XPos;
      YPosTemp=YPos;
      if length(ObjHandle(1,:))==1, 
        XLng=length(XPos(:,1));
        NumDataPts=ones(NumPts,1)*XLng/NumPts;
      else,
        NumDataPts=ObjHandle(:,2);
      end % if length
    end % if nargin
    
    for lp=1:NumPts,
      if nargin==4,
        XPos=get(ObjHandle(lp),'XData');
        YPos=get(ObjHandle(lp),'Ydata');
        NumDataPts=length(XPos);
      end % if nargin
  
      LocStart=sum(NumDataPts(1:lp-1))+1;
      LocEnd=sum(NumDataPts(1:lp));
      if nargin==6,
        XPos=XPosTemp(LocStart:LocEnd);
        YPos=YPosTemp(LocStart:LocEnd);
      end % if nargin
      
      CurXPosMin=min(min(XPos));
      CurXPosMax=max(max(XPos));
      CurYPosMin=min(min(YPos));
      CurYPosMax=max(max(YPos));
  
      if CurXPosMin<XLim(1),
        XPos=XPos-CurXPosMin+XLim(1);
      elseif CurXPosMax>XLim(2),
        XPos=XPos-CurXPosMax+XLim(2);
      end %if XPos

      if CurYPosMin<YLim(1),
        YPos=YPos-CurYPosMin+YLim(1);
      elseif CurYPosMax>YLim(2),
        YPos=YPos-CurYPosMax+YLim(2);
      end %if YPos

      if nargout==0,
        set(ObjHandle(lp),'XData',XPos,'YData',YPos);
      else,
        out1=[out1;XPos];out2=[out2;YPos];
      end % if nargout
    end % for lp
  end % if strcmp
  
else, % AutoScale Axes

  if strcmp('text',get(ObjHandle(1),'Type')),
    if nargin==4,
      Position=zeros(NumPts,7);
      for lp=1:NumPts,
        Position(lp,:)=[get(ObjHandle(lp),'Position') , ...
                        get(ObjHandle(lp),'Extent') ...
                       ];
      end % for lp
    end % if nargin
    
    XPos=[Position(:,4) Position(:,4)+Position(:,6)];
    YPos=[Position(:,5) Position(:,5)+Position(:,7)];

    if nargout==0,
      if nargin~=4,
        for lp=1:NumPts,
          set(ObjHandle(lp),'Position',Position(lp,1:3));
        end % for lp
      end % if nargin
    else,     
      out1=Position;out2=[];        
    end  % if nargout
    
  else,
  
    if nargin==4,
      XPos=[];YPos=[]; 
      %Make assumption that all objects have same # of points
      XPosTemp=get(ObjHandle(1),'XData');
      YPosTemp=get(ObjHandle(1),'YData');
      XSize=size(XPosTemp);
      XPos=zeros(XSize(1)*NumPts,XSize(2));
      XPos(1:XSize(1),:)=XPosTemp;
      YPos(1:XSize(1),:)=YPosTemp;

      for lp=2:NumPts,
        XPos((lp-1)*XSize(1)+1:lp*XSize(1),:)=get(ObjHandle(lp),'XData');
        YPos((lp-1)*XSize(1)+1:lp*XSize(1),:)=get(ObjHandle(lp),'YData');
      end % for lp
    end % if nargin
    
    if nargout==0,
      if nargin~=4,
        XSize=length(XPos(:,1))/NumPts;
        for lp=1:NumPts,
          set(ObjHandle(lp), ...
             'XData',XPos((lp-1)*XSize(1)+1:lp*XSize(1),:), ...
             'YData',YPos((lp-1)*XSize(1)+1:lp*XSize(1),:)  ...
             );
        end % for lp
      end % if nargin
    else,
      out1=XPos;out2=YPos;
    end % if nargout

  end % if strcmp
   
  XMin=min(min(XPos));XMax=max(max(XPos));
  YMin=min(min(YPos));YMax=max(max(YPos));
  
  XDist=XLim(2)-XLim(1);
  
  %%%%%%%%%%%%%%%%%%%%
  %%% Outward Scaling
  while XMin<XLim(1)+0.04*XDist,
    XLim(1)=XLim(1)-0.2*XDist;
    set(WorkingAxes,'XLim',XLim);
%   set(WorkingAxes,'XLim',chop(XLim,3));
  end %while XMin
      
  while XMax>XLim(2)-0.04*XDist,
    XLim(2)=XLim(2)+0.2*XDist;
    set(WorkingAxes,'XLim',XLim);
%   set(WorkingAxes,'XLim',chop(XLim,3));
  end %while XMin

 
  YDist=YLim(2)-YLim(1);
  
  while YMin<YLim(1)+0.04*YDist,
    YLim(1)=YLim(1)-0.2*YDist;
    set(WorkingAxes,'YLim',YLim);
%   set(WorkingAxes,'YLim',chop(YLim,3));
  end %while YMin
      
  while YMax>YLim(2)-0.04*YDist,
    YLim(2)=YLim(2)+0.2*YDist;
    set(WorkingAxes,'YLim',YLim);
%   set(WorkingAxes,'YLim',chop(YLim,3));
  end %while YMin
        
  %%%%%%%%%%%%%%%%%%%%
  %%% Inward Scaling
  if ~strcmp(get_param(SimRoot,'Simulation Running'),'off'),
    AData=get(AutoAxisHandle,'UserData');
    set(AutoAxisHandle,'UserData',[]);
    NewAData=[AData(2:100,:);XMin XMax YMin YMax];
    set(AutoAxisHandle,'UserData',NewAData);
 
    %%% DiffLim determines how far the axes scale    
    DiffLim=0.00001; 
    while all(NewAData(:,1)>XLim(1)+0.25*XDist) & ...
          diff(XLim)>DiffLim,
      if diff(XLim)<DiffLim,
        XLim(2)=XLim(1)+DiffLim;
      else,
        XLim(1)=XLim(1)+0.25*XDist;
      end
      if XLim(2)<XLim(1),XLim=XLim([2 1]);end
      set(WorkingAxes,'XLim',XLim);
    end % while all

    while all(NewAData(:,2)<XLim(2)-0.25*XDist) & ...
          diff(XLim)>DiffLim,
      if diff(XLim)<DiffLim,
        XLim(1)=XLim(2)-DiffLim;
      else,
        XLim(2)=XLim(2)-0.25*XDist;
      end
      if XLim(2)<XLim(1),XLim=XLim([2 1]);end
      set(WorkingAxes,'XLim',XLim);
    end % while all

    while (all(NewAData(:,3)>YLim(1)+0.25*YDist) & ...
          diff(YLim)>DiffLim),
      if diff(YLim)<DiffLim,
        YLim(2)=YLim(1)+DiffLim;
      else,
        YLim(1)=YLim(1)+0.25*YDist;
      end
      if YLim(2)<YLim(1),YLim=YLim([2 1]);end
      set(WorkingAxes,'YLim',YLim);
    end % while all

    while all(NewAData(:,4)<YLim(2)-0.25*YDist) & ...
          diff(YLim)>DiffLim,
      if diff(YLim)<DiffLim,
        YLim(1)=YLim(2)-DiffLim;
      else,
        YLim(2)=YLim(2)-0.25*YDist;
      end
      if YLim(2)<YLim(1),YLim=YLim([2 1]);end
      set(WorkingAxes,'YLim',YLim);
    end % while all
  end % if ~strcmp
end % if strcmp
