function anfile(Action,Name)
%ANFILE	Animation file menu function.
%	ANFILE(ACTION) is the callback function for the File menu on 
%	the animation figure window.
%
%	ACTION may be one of 3 strings:
%          '#Load'  Load animation data.
%	   '#Save'  Save animation data.
%	  '#Close'  Close animation window.
%
%	See also ANSIMINI.

%	Loren Dean  March, 1995.
%	Copyright (c) 1995 by The MathWorks, Inc.

WorkingFig=findobj(0,'type','figure','Tag','WorkingFig');
if isempty(WorkingFig),WorkingFig=gcf;end
Data=get(WorkingFig,'UserData');
SimHandle=Data(1);
WorkingAxes=Data(2);

%%%%%%%%%%%%
%%% Load %%%
%%%%%%%%%%%%
if strcmp(Action,'#Load'),
  if nargin==1,
    [FileName,PathName]=uigetfile('*.mat','Load Animation Data');
  else,
    FileName=Name;PathName=[];
  end
  if FileName~=0,
    load([PathName FileName]);
    if ~exist('OnGrid'), % Check for valid data file    
      errordlg('Not a valid animation data file!!!','Wrong Data File');
    else, %Valid File
            
      FigTitle=get(WorkingFig,'Name');
      TitleLoc=findstr(FigTitle,'File: ');
      FigTitle=[FigTitle(1:TitleLoc+5) FileName];
      set(WorkingFig,'Name',FigTitle);
      

      set_param(SimHandle,'Mask Help',FileName);
      set(WorkingFig,'CurrentAxes',WorkingAxes,'Tag','');
    
      OldObjectInfo=get(WorkingAxes,'UserData');
      if ~isempty(OldObjectInfo),
        delete(OldObjectInfo(:,1));
        set(WorkingAxes,'UserData',[]);
        ModifyHandle=findobj(WorkingFig,'Tag','MenuEditModify');
        set(ModifyHandle,'UserData',[]);
      end % if ~isempty

      MenuGridHandle=findobj(WorkingFig, ...
                            'Type'     ,'uimenu'        , ...
                            'Tag'      ,'MenuOptionGrid'  ...
                            );
     
      set(WorkingAxes,'Position',AxisPos);
      set(MenuGridHandle,'UserData',AxisData);
      if strcmp(OnGrid,'off'),OnGrid='on';else;OnGrid='off';end
      set(MenuGridHandle,'Checked',OnGrid);
      anoption('#Grid',WorkingFig)
          
      MenuAxisOnHandle=findobj(WorkingFig, ...
                              'Type'     ,'uimenu'        , ...
                              'Tag'      ,'MenuOptionAxisOn'  ...
                              );
      if strcmp(AxisOn,'off'),AxisOn='on';else;AxisOn='off';end
      set(MenuAxisOnHandle,'Checked',AxisOn);
      anoption('#AxisOn',WorkingFig)
 
      MenuBoxHandle=findobj(WorkingFig, ...
                           'Type'     ,'uimenu'       , ...
                           'Tag'      ,'MenuOptionBox'  ...
                           );
      if strcmp(AxisBox,'off'),AxisBox='on';else;AxisBox='off';end
      set(MenuBoxHandle,'Checked',AxisBox);
      anoption('#Box',WorkingFig)
    
      MenuTickHandle=findobj(WorkingFig, ...
                            'Type'     ,'uimenu'           , ...
                            'Tag'      ,'MenuOptionTickMark' ...
                            );
      if strcmp(TickMark,'off'),TickMark='on';else;TickMark='off';end
      set(MenuTickHandle,'Checked',TickMark);
      anoption('#TickMark',WorkingFig)
    
      MenuAutoHandle=findobj(WorkingFig, ...
                            'Type','uimenu'           , ...
                            'Tag','MenuOptionAxisAuto'  ...
                            );
      if strcmp(AutoScale,'off'),AutoScale='on';else;AutoScale='off';end
      set(MenuAutoHandle,'Checked',AutoScale);
      anoption('#AutoExpandAxis',WorkingFig)
    
      set(WorkingAxes,'XLim',AxisLimit(1:2),'YLim',AxisLimit(3:4));
    
      MenuHideHandle=findobj(WorkingFig, ...
                            'Type'     ,'uimenu'               , ...
                            'Tag'      ,'MenuOptionHideButtons'  ...
                            );
      if strcmp(HideButton,'off'),HideButton='on';else;HideButton='off';end
      set(MenuHideHandle,'Checked',HideButton);
      anoption('#HideObjectBtn',WorkingFig)

      MenuHideStatus=findobj(WorkingFig, ...
                            'Type'     ,'uimenu'               , ...
                            'Tag'      ,'MenuOptionHideStatus'  ...
                            );
      if strcmp(HideStatus,'off'),HideStatus='on';else;HideStatus='off';end
      set(MenuHideStatus,'Checked',HideStatus);
      anoption('#HideStatus',WorkingFig)
      
      SetICHandle=findobj(WorkingFig, ...
                         'Type'     ,'uimenu'             , ...
                         'Tag'      ,'MenuSimulationSetIC'  ...
                         );
      set(SetICHandle,'UserData',ICString);
    
      XLabHandle=get(WorkingAxes,'XLabel');
      if ~exist('XLabel'),XLabel='';end      
      set(XLabHandle,'String',XLabel);

      YLabHandle=get(WorkingAxes,'YLabel');
      if ~exist('YLabel'),YLabel='';end      
      set(YLabHandle,'String',YLabel);

      TitleHandle=get(WorkingAxes,'Title');
      if ~exist('Title'),Title='';end      
      set(TitleHandle,'String',Title);

      SquareHandle=findobj(WorkingFig, ...
                          'Type'     ,'uimenu'              , ...
                          'Tag'      ,'MenuOptionSquareAxis'  ...
                          );
      if ~exist('SquareAxis'),SquareAxis='off';end                      
      if strcmp(SquareAxis,'off'),SquareAxis='on';else;SquareAxis='off';end
      set(SquareHandle,'Checked',SquareAxis);
      anoption('#SquareAxis',WorkingFig)      
      
      if ~isempty(ObjectInfo),      
        NumPts=length(ObjectInfo(:,1));
      else,
        NumPts=0;
      end
      
      for lp=1:NumPts,
        eval(['ObjectData=ObjectInfo' num2str(lp) ';']);
        eval([deblank(setstr(ObjectInfo(lp,2:9))), ...
             '(''#New'',ObjectData,WorkingFig,1);' ...
             ]);
        ansetobj(WorkingFig)
      end % for lp
    
      ansimltn('#Reset',WorkingFig)
      anedit('#Deselect',WorkingFig)

      ObjectInfo=get(WorkingAxes,'UserData');
    
      if strcmp(get_param(bdroot(SimHandle),'Simulation Running'),'on'),
        set(ObjectInfo(:,1), ...
           'EraseMode'    ,'background', ...
           'ButtonDownFcn',''            ...
           );
        drawnow;
      end % if strcmp
    
      set(WorkingFig,'Tag','WorkingFig')
    end % if ~exist
  end % if FileName
  
%%%%%%%%%%%%
%%% Save %%%
%%%%%%%%%%%%
elseif strcmp(Action,'#Save'),
  FileName=get_param(SimHandle,'Mask Help');
%% The following if statement accounts for a MAC specific
%% problem.  When get_param is used with a handle rather
%% than a name, a system call is made and a different 
%% answer is returned.
  if ~isempty(FileName),
    Loc=findstr(FileName,'(Mask)');
    if ~isempty(Loc), FileName(1:Loc+6)=[]; end
    if ~isempty(FileName),
      Loc=findstr(FileName,'No help available.');
      if ~isempty(Loc), FileName(1:Loc+18)=[]; end
    end % if ~isempty
  end % if ~isempty

  if isempty(FileName),FileName='*.mat';end
  [FileName,PathName]=uiputfile(FileName,'Save Animation Data');
  
  if FileName~=0,
  
    FigTitle=get(WorkingFig,'Name');
    TitleLoc=findstr(FigTitle,'File: ');
    FigTitle=[FigTitle(1:TitleLoc+5) FileName];
    set(WorkingFig,'Name',FigTitle);

    set_param(SimHandle,'Mask Help',FileName);
 
    ObjectInfo=get(WorkingAxes,'UserData');
    
    NumPts=size(ObjectInfo);NumPts=NumPts(1);
    
    MenuGridHandle=findobj(WorkingFig, ...
                          'Type'     ,'uimenu'        , ...
                          'Tag'      ,'MenuOptionGrid'  ...
                          );
    OnGrid=get(MenuGridHandle,'Checked');
    AxisData = get(MenuGridHandle,'UserData');

    MenuAxisOnHandle=findobj(WorkingFig, ...
                            'Type'     ,'uimenu'        , ...
                            'Tag'      ,'MenuOptionAxisOn'  ...
                            );
    AxisOn=get(MenuAxisOnHandle,'Checked');
    
    MenuBoxHandle=findobj(WorkingFig, ...
                         'Type'     ,'uimenu'       , ...
                         'Tag'      ,'MenuOptionBox'  ...
                         );
    AxisBox=get(MenuBoxHandle,'Checked');
    
    MenuTickHandle=findobj(WorkingFig, ...
                          'Type'     ,'uimenu'           , ...
                          'Tag'      ,'MenuOptionTickMark' ...
                          );
    TickMark=get(MenuTickHandle,'Checked');
    
    MenuAutoHandle=findobj(WorkingFig, ...
                          'Type','uimenu'           , ...
                          'Tag','MenuOptionAxisAuto'  ...
                          );
    AutoScale=get(MenuAutoHandle,'Checked');
    
    AxisLimit=[get(WorkingAxes,'XLim') get(WorkingAxes,'YLim')];
    
    AxisPos=get(WorkingAxes,'Position');
     
    MenuHideHandle=findobj(WorkingFig, ...
                          'Type'     ,'uimenu'               , ...
                          'Tag'      ,'MenuOptionHideButtons'  ...
                          );
    HideButton=get(MenuHideHandle,'Checked');

    MenuHideStatus=findobj(WorkingFig, ...
                          'Type'     ,'uimenu'        , ...
                          'Tag'      ,'MenuOptionHideStatus'  ...
                          );
    HideStatus=get(MenuHideStatus,'Checked');

    XLabHandle=get(WorkingAxes,'XLabel');
    XLabel=get(XLabHandle,'String');

    YLabHandle=get(WorkingAxes,'YLabel');
    YLabel=get(YLabHandle,'String');

    TitleHandle=get(WorkingAxes,'Title');
    Title=get(TitleHandle,'String');

    SetICHandle=findobj(WorkingFig, ...
                       'Type'     ,'uimenu'             , ...
                       'Tag'      ,'MenuSimulationSetIC'  ...
                       );

    ICString=get(SetICHandle,'UserData');

    SquareHandle=findobj(WorkingFig, ...
                        'Type'     ,'uimenu'              , ...
                        'Tag'      ,'MenuOptionSquareAxis'  ...
                        );
    SquareAxis=get(SquareHandle,'Checked');
    
    VarNames=['''ObjectInfo'',''OnGrid'',''AxisBox'',''TickMark'','  ...
              '''AutoScale'',''AxisLimit'',''AxisPos'',''AxisData'',' ...
              '''HideButton'',''HideStatus'',''AxisOn'',''ICString'',' ...
              '''XLabel'',''YLabel'',''Title'',''SquareAxis'''];
    
    for lp=1:NumPts
      VarNames=[VarNames ',''ObjectInfo' num2str(lp) ''''];
      eval(['ObjectInfo' num2str(lp) '=get(ObjectInfo(lp,1),''UserData'');']);
    end % for lp
    eval(['save(''' PathName FileName ''',' VarNames ')']);
    set_param(SimHandle,'Mask Help',FileName);
    
  end %if FileName
  
%%%%%%%%%%%%%
%%% Close %%%
%%%%%%%%%%%%%
elseif strcmp(Action,'#Close'),

  FileHandle=findobj(WorkingFig,'Type','uimenu','Tag','MenuFile');
  FileVal=get(FileHandle,'UserData');
  if ~FileVal,    
    set(FileHandle,'UserData',1);
    Answer=questdlg('Do you want to save the animation before quitting?', ...
                    'Close','Cancel','Save',3);
    set(FileHandle,'UserData',0);                   
 
    if strcmp(Answer,'Save'),
      anfile #Save
      Answer='Close';
    end
    if strcmp(Answer,'Close'),
      Figs=findobj(0,'Type','figure','Tag','PropertiesDialog');
     
      if ~isempty(Figs),
        for lp=1:length(Figs),
          Info=get(Figs(lp),'UserData');
          if Info(1)==WorkingFig,close(Figs(lp));end
        end % for lp
      end % if ~isempty
    
      if ishandle(WorkingFig),    
        close(WorkingFig);
      end
    end % if strcmp
  end % if ~OpenFlag    
  
end % if strcmp Action






