function [ret,x0,str,ts,xts]=animblk(t,x,u,flag);
%ANIMBLK	is the M-file description of the SIMULINK system named ANIMBLK.
%	The block-diagram can be displayed by typing: ANIMBLK.
%
%	SYS=ANIMBLK(T,X,U,FLAG) returns depending on FLAG certain
%	system values given time point, T, current state vector, X,
%	and input vector, U.
%	FLAG is used to indicate the type of output to be returned in SYS.
%
%	Setting FLAG=1 causes ANIMBLK to return state derivatives, FLAG=2
%	discrete states, FLAG=3 system outputs and FLAG=4 next sample
%	time. For more information and other options see SFUNC.
%
%	Calling ANIMBLK with a FLAG of zero:
%	[SIZES]=ANIMBLK([],[],[],0),  returns a vector, SIZES, which
%	contains the sizes of the state vector and other parameters.
%		SIZES(1) number of states
%		SIZES(2) number of discrete states
%		SIZES(3) number of outputs
%		SIZES(4) number of inputs
%		SIZES(5) number of roots (currently unsupported)
%		SIZES(6) direct feedthrough flag
%		SIZES(7) number of sample times
%
%	For the definition of other parameters in SIZES, see SFUNC.
%	See also, TRIM, LINMOD, LINSIM, EULER, RK23, RK45, ADAMS, GEAR.

% Note: This M-file is only used for saving graphical information;
%       after the model is loaded into memory an internal model
%       representation is used.

% the system will take on the name of this mfile:
sys = mfilename;
new_system(sys)
simver(1.3)
if (0 == (nargin + nargout))
     set_param(sys,'Location',[112,78,320,176])
     open_system(sys)
end;
set_param(sys,'algorithm',     'RK-45')
set_param(sys,'Start time',    '0.0')
set_param(sys,'Stop time',     '999999')
set_param(sys,'Min step size', '0.0001')
set_param(sys,'Max step size', '10')
set_param(sys,'Relative error','1e-3')
set_param(sys,'Return vars',   '')


%     Subsystem  'SimAnim'.

new_system([sys,'/','SimAnim'])
set_param([sys,'/','SimAnim'],'Location',[220,207,417,288])

add_block('built-in/S-Function',[sys,'/','SimAnim/ansim'])
set_param([sys,'/','SimAnim/ansim'],...
		'hide name',0,...
		'function name','ansim',...
		'parameters','1',...
		'position',[105,25,155,45])

add_block('built-in/Inport',[sys,'/','SimAnim/in_1'])
set_param([sys,'/','SimAnim/in_1'],...
		'Drop Shadow',4,...
		'position',[30,25,50,45])
add_line([sys,'/','SimAnim'],[55,35;100,35])
set_param([sys,'/','SimAnim'],...
		'Mask Display','Simulation\nAnimation',...
		'Mask Type','Simulation Animation',...
		'Mask Dialogue','eval(''ansimini #Initialize'');')


%     Finished composite block 'SimAnim'.

set_param([sys,'/','SimAnim'],...
		'position',[60,13,140,57])

drawnow

% Return any arguments.
if (nargin | nargout)
	% Must use feval here to access system in memory
	if (nargin > 3)
		if (flag == 0)
			eval(['[ret,x0,str,ts,xts]=',sys,'(t,x,u,flag);'])
		else
			eval(['ret =', sys,'(t,x,u,flag);'])
		end
	else
		[ret,x0,str,ts,xts] = feval(sys);
	end
else
	drawnow % Flash up the model and execute load callback
end
