function anrect(Action,Handle,WorkingFig,u)
%ANRECT	Rectangle creation and display function.
%	ANRECT(ACTION,HANDLE,WORKINGFIG,U) is the creation and display 
%	function for the rectangle object in the simulation animation block.
%
%	ACTION may be one of four strings:
%	    '#Draw'  Draw rectangle object.
%	     '#New'  Create new rectangle object.
%	  '#Modify'  Modify rectangle object parameters.
%	  '#Update'  Update object paramaters as entered in currently
%	             displayed dialog.
%
%	HANDLE is a vector of rectangle object handles.
%
%	WORKINGFIG is the handle for the figure that the objects are 
%	drawn on.
%
%	U is the vector of inputs to the animation block.  It is used
%	in the '#Draw' area only.
%
%	See also ANLINE, ANPATCH, ANDOT, ANTEXT, ANOBJ.

%	Loren Dean March, 1995.
%	Copyright (c) 1995 by The MathWorks, Inc.

%%%%%%%%%%%
%%% Draw %%%
%%%%%%%%%%%
if strcmp(Action,'#Draw'),

  NumObjs=length(Handle);
  Data=zeros(NumObjs,8);
  XPos=zeros(NumObjs*5,1);
  YPos=zeros(NumObjs*5,1);
  
  for lp=1:NumObjs,
    X=get(Handle(lp),'Xdata');
    Y=get(Handle(lp),'YData');
    Data(lp,:)=eval(get(Handle(lp),'UserData')       , ...
                  ['[X(1) Y(1) X(2)-X(1) Y(3)-Y(1) 0', ...
                   ' get(Handle(lp),''Color'')]']       ...
                   );
    X=Data(lp,1);
    Y=Data(lp,2);
    W=Data(lp,3);
    H=Data(lp,4);
    R=Data(lp,5);
    Pos=[cos(R*pi/180) -sin(R*pi/180);sin(R*pi/180) cos(R*pi/180)]* ...
        [0 W W 0 0;0 0 H H 0];
     
    XPos((lp-1)*5+1:lp*5,1)=(Pos(1,:)+X)';  
    YPos((lp-1)*5+1:lp*5,1)=(Pos(2,:)+Y)'; 

  end % for lp
    
  FigData=get(WorkingFig,'UserData');
  WorkingAxes=FigData(2);
  
  [XPos,YPos] = andraw(WorkingFig ,Handle      , ...
                       XPos       ,YPos        , ...
                       get(WorkingAxes,'XLim') , ...
                       get(WorkingAxes,'YLim')   ...
                      );
  
  for lp=1:NumObjs,
    set(Handle(lp) , ...
       'XData'     ,XPos((lp-1)*5+1:lp*5,1), ...
       'YData'     ,YPos((lp-1)*5+1:lp*5,1), ...
       'Color'     ,abs(Data(lp,6:8))        ...
       );
  end % for lp
  
%%%%%%%%%%%
%%% New %%%
%%%%%%%%%%%
elseif strcmp(Action,'#New'),

  if nargin==1,
    WorkingFig=findobj(0,'type','figure','Tag','WorkingFig');
    Handle=[];
  end % if nargin
  
  FigData=get(WorkingFig,'UserData');
  WorkingAxes=FigData(2);
  set(WorkingFig,'CurrentAxes',WorkingAxes);
  
  LoadFromFileFlag=length(Handle)>1;

  XLim=get(WorkingAxes,'XLim');
  YLim=get(WorkingAxes,'YLim');
  
  if LoadFromFileFlag,
    u=angetic(WorkingFig);
    
    Data=eval(Handle,['[diff(XLim)/2'      , ...
                      ' diff(YLim)/2'      , ...
                      ' abs(diff(XLim)/8)' , ...
                      ' abs(diff(YLim)/8)' , ...
                      ' 0 1 1 1]']           ...
             );
    X=Data(1);Y=Data(2);W=Data(3);H=Data(4);R=Data(5);Color=Data(6:8);
  else,
    if nargin==4,  % Double click open
      [X,Y]=angetpos(WorkingFig,1);
    else,
      [X,Y]=angetpos(WorkingFig);
    end
    W=abs(diff(XLim)/8);H=abs(diff(YLim)/8);R=0;
    Color=[1 1 1];
  end % if LoadFromFileFlag

  Pos=[cos(R*pi/180) -sin(R*pi/180);sin(R*pi/180) cos(R*pi/180)]* ...
      [0 W W 0 0;0 0 H H 0];
  XPos=Pos(1,:)+X;
  YPos=Pos(2,:)+Y;
  
  CurrentPt=line(                                       ...
                 XPos          , YPos                 , ...
                'LineStyle'    , '-'                  , ...
                'Color'        , Color                , ...
                'ButtonDownFcn', 'anedit #ButtonDown' , ...
                'EraseMode'    , 'normal'             , ...
                'Interruptible', 'yes'                , ...
                'Tag'          , 'AnimRect'             ...
                );
     
  if LoadFromFileFlag,
    WorkingData=Handle;
  else,
    WorkingData=[ '[' num2str(X) ',' num2str(Y)     ',' , ...
                      num2str(W) ',' num2str(H)     ',' , ...
                      num2str(R) ',' mat2str(Color) ',]'  ...
                ];
  end % if LoadFromFileFlag
  
  [SelectColor,DeselectColor]=angetclr('#New',CurrentPt,Color);
  set(CurrentPt,'UserData',WorkingData,'Color',SelectColor);
  
  AxesData=get(WorkingAxes,'UserData');
  set(WorkingAxes,'UserData',[]); %Done for speed purposes (not necessary)
  AxesData=[CurrentPt abs('anrect  ');AxesData];
  set(WorkingAxes,'UserData',AxesData);
  
  andraw(WorkingFig             , CurrentPt              , ...
         XPos                   , YPos                   , ...
         get(WorkingAxes,'XLim'), get(WorkingAxes,'YLim')  ...
        );
    
  if ~LoadFromFileFlag,
    anrect('#Modify',CurrentPt,WorkingFig)
  end
  

%%%%%%%%%%%%%%
%%% Modify %%%
%%%%%%%%%%%%%%
elseif strcmp(Action,'#Modify'),
  
  List='XYWHRC';
  CurrentData=get(Handle,'UserData');

  CommaLocs=ancomloc(CurrentData);
  
  CurrentX=CurrentData(1,             2:CommaLocs(1)-1);
  for lp=2:length(List),
    eval(['Current' List(lp) '=CurrentData(1,CommaLocs(' num2str(lp-1) ...
          ')+1:CommaLocs(' num2str(lp) ')-1);']);
  end % for lp

  TextStrings=str2mat('X Coordinate:'      , ...
                      'Y Coordinate:'      , ...
                      'Width:'             , ...
                      'Height:'            , ...
                      'Rotation (Degrees):', ...
                      'Color ([R G B]):'     ...
                      );
  Values=str2mat(CurrentX,CurrentY,CurrentW,CurrentH,CurrentR,CurrentC);
  Callbacks=setstr(ones(length(Values(:,1))+1,1)*'anrect #Update');

  Tags=List';

  FigTag='PrpDlgFig';
  FigData=get(WorkingFig,'UserData');
  SimHandle=FigData(1);
  FigTitle=['Rectangle Object Properties: ' get_param(SimHandle,'Name')];
  
  Handles = anprpdlg('#Initialize', Handle, WorkingFig, ...
                     TextStrings  , Values, Callbacks , ...
                     Tags         , FigTag, FigTitle    ...
                     );
%%%%%%%%%%%%%%
%%% Update %%%
%%%%%%%%%%%%%%
elseif strcmp(Action,'#Update'),

  PrpDlgFig=get(0,'CurrentFigure');
  Data=get(PrpDlgFig,'UserData');
  WorkingFig=Data(1);
  WorkingAxes=findobj(WorkingFig,'Type','axes','Tag','WorkingAxes');


  CurrentPt=Data(2);
  
  List='XYWHRC';
  for lp=1:length(List),
    %%% Get Handles
    eval([ List(lp) 'Handle=findobj(PrpDlgFig,', ...
          ' ''Type'',''uicontrol'',''Tag'',''' List(lp) ''');']);

    %%% Get Strings for Edit Text Blocks
    eval(['Current' List(lp) '=get(' List(lp) 'Handle,''String'');']);

    %%% Remove all leading and trailing spaces from CurrentX and CurrentY
    eval(['Current' List(lp) '=deblank(fliplr(Current' List(lp) '));']);
    eval(['Current' List(lp) '=deblank(fliplr(Current' List(lp) '));']);
  end % for lp

  u=angetic(WorkingFig);
  X=get(CurrentPt,'Xdata');
  Y=get(CurrentPt,'YData');
  Data=eval(get(CurrentPt,'UserData')          , ...
          ['[X(1) Y(1) X(2)-X(1) Y(3)-Y(1) 0 ' , ...
           'get(CurrentPt,''Color'')]']          ...
           );
           
  eval(['XFlag=0;X=' CurrentX ';'],'XFlag=1;X=Data(1);');
  eval(['YFlag=0;Y=' CurrentY ';'],'YFlag=1;Y=Data(2);');
  eval(['WFlag=0;W=' CurrentW ';'],'WFlag=1;W=Data(3);');
  eval(['HFlag=0;H=' CurrentH ';'],'HFlag=1;H=Data(4);');
  eval(['RFlag=0;R=' CurrentR ';'],'RFlag=1;R=Data(5);');
  eval(['CFlag=0;CurrentColor=' CurrentC ';'], ...
        'CFlag=1;CurrentColor=Data(6:8);'      ...
      );
  
  HCancel=findobj(PrpDlgFig,'Type','uicontrol','Tag','Cancel');
  CurrentData=get(HCancel,'UserData');
  CommaLocs=ancomloc(CurrentData(1,:));
  
  ListLoc=0;
  if XFlag,Low=2;             High=CommaLocs(1)-1;ListLoc=1;end
  if YFlag,Low=CommaLocs(1)+1;High=CommaLocs(2)-1;ListLoc=2;end
  if WFlag,Low=CommaLocs(2)+1;High=CommaLocs(3)-1;ListLoc=3;end
  if HFlag,Low=CommaLocs(3)+1;High=CommaLocs(4)-1;ListLoc=4;end
  if RFlag,Low=CommaLocs(4)+1;High=CommaLocs(5)-1;ListLoc=5;end
  if CFlag,Low=CommaLocs(5)+1;High=CommaLocs(6)-1;ListLoc=6;end
  
  if ListLoc,
    eval(['set(' List(ListLoc) 'Handle,''String'',CurrentData(1,Low:High))']);
    disp([7,7,7 'Last entry was invalid.  Old being used.']);disp(' ');
  end
  
  AllPtData =[ '[' CurrentX ',' CurrentY ',' , ... 
                   CurrentW ',' CurrentH ',' , ...
                   CurrentR ',' CurrentC ',]'  ...
             ];
  
  set(HCancel,'UserData',str2mat(AllPtData,CurrentData(2,:)));
  
  
  Pos=[cos(R*pi/180) -sin(R*pi/180);sin(R*pi/180) cos(R*pi/180)]* ...
      [0 W W 0 0;0 0 H H 0];
  CurrentXPos=Pos(1,:)+X;
  CurrentYPos=Pos(2,:)+Y;
  
  set(CurrentPt  , ...
     'Xdata'     , CurrentXPos , ...
     'Ydata'     , CurrentYPos , ...
     'Color'     , CurrentColor, ...
     'UserData'  , AllPtData     ...
     );

  angetclr('#Modify',CurrentPt,CurrentColor);
  
  ansimltn('#Reset',WorkingFig)
  
end % if strcmp    
