function ansimini(Action)
%ANSIMINI Initialize figure for SIMULINK animations.
%	ANSIMINI(ACTION) is the initialization function for SIMULINK
%	animations.  
%
%	ACTION may be one string:
%	   '#Initialize'  Initialize the figure window.
%
%	The following information is stored in UserData:
%	Location                       Data                      Size
%	                                               (E = After Evaluation)
%	---------------------------------------------------------------------
%	SimulinkAnimationMaskParameter WorkingFig               1
%
%	SimulinkAnimationMaskHelp      FileName                 Variable Size
%
%	WorkingFigure                  SimulinkTopBlockHandle   1
%	                               WorkingAxesHandle        1
%	                               AutoAxisHandle           1
%	                               MenuSim...StartHandle    1
%
%	WorkingAxes                    [Handle1 FunctionCall1   1,8
%	                                Handlen FunctionCalln]  1,8
%
%       StartButton                    Static Info              Variable
%
%       ResetButton                    Static Color Info        Variable
%
%	ANLINEObject                   XText                    100
%	                               YText                    100
%	                               Color                    100
%
%	ANDOTObject                    XPosition                E 1
%	                               YPosition                E 1
%	                               MarkerSize               E 1
%	                               Color                    E 3
%
%	ANRECTObject                   XPosition                E 1
%	                               YPosition                E 1
%	                               Width                    E 1
%	                               Height                   E 1
%	                               Rotation                 E 1
%	                               Color                    E 3
%
%	ANTEXTObject                   Position                 E 3
%	                               Extent                   E 4
%	                               FontSize                 E 1
%	                               Rotation                 E 1
%	                               Color                    E 3
%	                               HorizontalAlignment      8
%	                               VerticalAlignment        8
%	                               String                   75
%	
%	WorkingFigCloseHandle          InitOnce Flag            1
%
%	PropertiesDialog               WorkingFigure            1
%	                               CurrentPoint             1
%
%	PropertiesDialogCancel         CurrentObjectUserData    (3,5, or 100)
%
%	PropertiesDialogHelp           HelpText                 Variable Size
%
%	MenuFile                       Close Figure Flag        1
%
%	MenuEditNew                    NewFunctionCalls         (NumObjType,8)
%
%	MenuEditModify                 Handle DeselectColor     NumObjx([1,3])
%
%	MenuEditSetIC                  IC Vector                (1,100)
%
%	MenuOptionGrid                 WorkingAxesPosition      4
%
%	MenuOptionAutoAxis             100 Time Steps           100x4
%
%	MenuOptionHideStatus           StatusButtonHandles      5
%
%	MenuOptionReset                Reset Figure Flag        1
%
%	MenuOptionHideButtons          ObjectButtonHandles      NumObjTypes
%
%	MenuSimulationStart            MatchedObjectTypePairs   2*NumObjTypes
%
%	MenuSimulationReset            ButtonDownPosition       2x3
%
%	See also ANCOMLOC, ANCUROBJ, ANDOT   , ANDRAG  , ANDRAW  , ANEDIT  , 
%	         ANFIG   , ANFILE  , ANGETCLR, ANGETPOS, ANLINE  , ANOBJ   ,  
%	         ANOPTION, ANPATCH , ANPRPDLG, ANRECT  , ANRESET , ANSETOBJ,
%	         ANSIM   , ANSIMLTN, ANTEXT  .

%	Loren Dean  March, 1995.
%	Copyright (c) 1995 by The MathWorks, Inc.

% V 1.1  anoption and andraw modified for correct autoscaling so upper
%        and lower limits cannot get to be equal to each other.

SimHandle=get_param(gcb,'Handle');
SimName=bdroot(SimHandle);
SimHandleNest=get_param([gcb,'/ansim'],'Handle');
FigHandles=get(0,'Children');
NumFigHandles=length(FigHandles);
WorkingFig=[];
for lp=1:NumFigHandles,
  if any(get(FigHandles(lp),'UserData')==SimHandle), 
    WorkingFig=FigHandles(lp);
    break;
  end %if any
end %for lp

if WorkingFig~=[],
  WorkingAxes=findobj(WorkingFig,'Tag','WorkingAxes');
end % if WorkingFig

%%%%%%%%%%%%%%%%%%
%%% Initialize %%%
%%%%%%%%%%%%%%%%%%
if strcmp(Action,'#Initialize'),

  %%%%%%%%%%%%%%%%%%%%%%%
  % Open new figure if not open already
  if WorkingFig==[],

    % Set the Figure Position
    FigPosition=get(0,'DefaultFigurePosition');
    FigPosition(3:4)=[500 420];

    % Set the Figure Name
    FigName=['Animation: ' get_param(SimHandle,'Name') ...
             '   ' ...
             'File: (none)'
            ];

    %%%%%%%%%%%%%%%%%%%%%%%%%%%
    %%% Create the Working Figure
    WorkingFig=figure( ...
                     'Name'         , FigName                , ...
                     'NumberTitle'  , 'off'                  , ...
                     'Visible'      , 'off'                  , ...
                     'BackingStore' , 'off'                  , ...
                     'Position'     , FigPosition            , ...
                     'Color'        , [0 0 0]                , ...
                     'UserData'     , []                     , ...
                     'MenuBar'      , 'none'                 , ...
                     'Tag'          , ''                     , ...
                     'NextPlot'     , 'new'                  , ...
                     'Interruptible', 'yes'                  , ...
                     'ButtonDownFcn', 'anfig #FigButtonPress', ...
                     'Pointer'      , 'watch'                , ...
                     'KeyPressFcn'  , 'anfig #KeyPress'        ...
                     );
    
    drawnow;
    
    %%%%%%%%%%%%%%%%%%%%%%%%%%%
    %%% Create the Working Axes
    AxisX=90;
    AxisY=110;
    AxisW=FigPosition(3)-AxisX-20;
    AxisH=FigPosition(4)-AxisY-25;

    WorkingAxes=axes(                                           ...
                    'Parent'       , WorkingFig               , ...
                    'Tag'          , 'WorkingAxes'            , ...
                    'Interruptible', 'yes'                    , ...
                    'ButtonDownFcn', 'anfig #AxisButtonPress' , ...
                    'Units'        , 'pixels'                 , ...
                    'Position'     , [AxisX AxisY AxisW AxisH], ...
                    'DrawMode'     , 'normal'                 , ...
                    'Visible'      , 'on'                     , ...
                    'Layer'        , 'top'                    , ...
                    'Box'          , 'on'                     , ...
                    'GridLineStyle', ':'                      , ...
                    'XLim'         , [0 100]                  , ...
                    'YLim'         , [0 100]                  , ...
                    'XGrid'        , 'off'                    , ...
                    'YGrid'        , 'off'                    , ...
                    'Color'        , [0 0 0]                  , ...
                    'XColor'       , [1 1 1]                  , ...
                    'YColor'       , [1 1 1]                    ...
                    );
    set(WorkingAxes,'Units','normalized');
    
    AxisPos=[get(WorkingAxes,'Position');0.1 0.1 0.85 0.8];
   
    %%%%%%%%%%%%%%%%%%%%%%%%%%%
    %%% Create the menu options
    MenuInfoLabels=str2mat(                              ...
                   str2mat(                              ...
                          '&File'                      , ...
                          '>&Load Configuration Data^l', ...
                          '>&Save Configuration Data^s', ...
                          '>&Close^w')                 , ...
                   str2mat(                               ...
                          '&Edit'                       , ...
                          '>&New Object'                , ...
                          '>&Delete Object^x'           , ...
                          '>Delete &All Objects'           , ...
                          '>&Modify Object...^m')       , ...
                                                          ...
                   str2mat(                           ...
                          '&Options'                , ...
                          '>&A&xis On'              , ...
                          '>Axis &Box On'           , ...
                          '>&Grid On'               , ...
                          '>&Tick Marks/Labels On'  , ...
                          '>&Square Axis'           , ...                  
                          '>&Auto Scale On'         , ...
                          '>&Change Labels...')     , ...                  
                   str2mat(                           ...
                          '>&Hide Status Bar'       , ...
                          '>H&ide Object Buttons')  , ...
                   str2mat(                           ...
                          '>F&ind All Objects'      , ...
                          '>&Find Simulink Diagram' , ...
                          '>&Set Axis Limits...')   , ...
                                                      ...
                   str2mat(                                  ...
                          '&Simulation'                    , ...
                          '>&Start^t'                      , ...
                          '>&Restart')                     , ...
                   str2mat(                                  ...
                          '>&Reset'                        , ...
                          '>&Set Initial Input Vector...')   ...
                          );

    MenuInfoCalls=str2mat(                  ...
                  str2mat(                  ...
                         ''               , ...
                         'anfile #Load'   , ...
                         'anfile #Save'   , ...
                         'anfile #Close') , ...
                                            ...
                  str2mat(                        ...
                         ''                     , ...
                         ''                     , ...
                         'anedit #Delete'       , ...
                         'anedit #DeleteAll'    , ...
                         'anedit #Modify'      ), ...
                                                  ...
                  str2mat(                            ...
                         ''                         , ...
                         'anoption #AxisOn'         , ...
                         'anoption #Box'            , ...
                         'anoption #Grid'           , ...
                         'anoption #TickMark'       , ...
                         'anoption #SquareAxis'     , ...                 
                         'anoption #AutoExpandAxis' , ...
                         'anoption #ChangeLabels')  , ...         
                  str2mat(                            ...
                         'anoption #HideStatus'     , ...
                         'anoption #HideObjectBtn') , ...
                  str2mat(                            ...
                         'anoption #FindObjects'    , ...
                         'anoption #FindDiagram'    , ...    
                         'anoption #SetAxis')       , ...
                  str2mat(                            ...
                         ''                         , ...
                         'ansimltn #Run'            , ...
                         'ansimltn #Restart')       , ...
                  str2mat(                           ...
                         'ansimltn #Reset'         , ...
                         'ansimltn #SetIC'         ) ...
                         );


    MenuInfoTags=str2mat(                  ...
                 str2mat(                  ...
                        'MenuFile'       , ...
                        'MenuFileLoad'   , ...
                        'MenuFileSave'   , ...
                        'MenuFileClose') , ...
                                           ...
                 str2mat(                         ...
                        'MenuEdit'              , ...
                        'MenuEditNew'           , ...
                        'MenuEditDelete'        , ...
                        'MenuEditDeleteAll'     , ...
                        'MenuEditModify'  )     , ...
                                                  ...
                 str2mat(                              ...
                        'MenuOption'                 , ...
                        'MenuOptionAxisOn'           , ...
                        'MenuOptionBox'              , ...
                        'MenuOptionGrid'             , ...
                        'MenuOptionTickMark'         , ...
                        'MenuOptionSquareAxis'       , ...               
                        'MenuOptionAxisAuto'         , ...
                        'MenuOptionAxisChangeLabels'), ...
                 str2mat(                         ...
                        'MenuOptionHideStatus'  , ...
                        'MenuOptionHideButtons'), ...
                 str2mat(                         ...
                        'MenuOptionFindObjects' , ...
                        'MenuOptionFindDiagram' , ...
                        'MenuOptionAxisSet')    , ...
                 str2mat(                              ...
                        'MenuSimulation'             , ...
                        'MenuSimulationStart'        , ...
                        'MenuSimulationRestart'     ), ...
                 str2mat(                              ...
                        'MenuSimulationReset'        , ...
                        'MenuSimulationSetIC'        ) ... 
                        );
                    
    MenuHandles=makemenu(WorkingFig    , ...
                         MenuInfoLabels, ...
                         MenuInfoCalls , ...
                         MenuInfoTags    ...
                         );


    %%% Add Additional Information

    RestartHandle=findobj(MenuHandles,'flat','Tag','MenuSimulationRestart');
    set(RestartHandle,'Enable','off');

    ResetHandle=findobj(MenuHandles,'flat','Tag','MenuSimulationReset');
    set(ResetHandle,'Enable','off','UserData',0);

    FileHandle=findobj(MenuHandles,'flat','Tag','MenuFile');
    set(FileHandle,'UserData',0);

    SaveHandle=findobj(MenuHandles,'flat','Tag','MenuFileSave');
    set(SaveHandle,'UserData','*.mat');
    
    CloseHandle=findobj(MenuHandles,'flat','Tag','MenuFileClose');
    set(CloseHandle,'UserData',0);

    ModifyHandle=findobj(MenuHandles,'flat','Tag','MenuEditModify');
    set(ModifyHandle,'UserData',[]);
    
    DeleteAllHandle=findobj(MenuHandles,'flat','Tag','MenuEditDeleteAll');
    DeleteHandle=findobj(MenuHandles,'flat','Tag','MenuEditDelete');
    set([DeleteHandle,DeleteAllHandle,ModifyHandle],'Enable','off');


    AxisOnHandle=findobj(MenuHandles,'flat','Tag','MenuOptionAxisOn');
    set(AxisOnHandle,'Checked','on');
    
    AutoAxisHandle=findobj(MenuHandles,'flat','Tag','MenuOptionAxisAuto');
    set(AutoAxisHandle,'Checked','on','UserData',ones(100,4)*50);

    BoxHandle=findobj(MenuHandles,'flat','Tag','MenuOptionBox');
    set(BoxHandle,'Checked','on');

    TickHandle=findobj(MenuHandles,'flat','Tag','MenuOptionTickMark');
    set(TickHandle,'Checked','on');
 
    GridHandle=findobj(MenuHandles,'flat','Tag','MenuOptionGrid');
    set(GridHandle,'UserData',AxisPos);
    
    HideBtnHandle=findobj(MenuHandles,'flat','Tag','MenuOptionHideStatus');
    FindObjectsHandle= ...
      findobj(MenuHandles,'flat','Tag','MenuOptionFindObjects');
    AxisSetHandle=findobj(MenuHandles,'flat','Tag','MenuOptionAxisSet');
    set([HideBtnHandle FindObjectsHandle AxisSetHandle],'Separator','on');

    ICHandle=findobj(MenuHandles,'flat','Tag','MenuSimulationSetIC');
    set(ICHandle,'UserData',mat2str([0]));
    
    StartHandle=findobj(MenuHandles,'flat','Tag','MenuSimulationStart');

    set(WorkingFig, ...
       'UserData' ,[SimHandle WorkingAxes AutoAxisHandle StartHandle] ...
       );

    %%%%%%%%%%%%%%%%%%%%
    %%% Create the Buttons
    
    % Object Buttons
    NewHandle=findobj(MenuHandles,'flat','Tag','MenuEditNew');
    anobj(WorkingFig,NewHandle);
    BtnObjHandles=[findobj(WorkingFig,'ButtonDownFcn','btnpress')
                   findobj(WorkingFig,'Tag','ObjectButtons')     
                   findobj(WorkingFig,'Tag','ObjectButtonsText') 
                  ];
    
    HideBtnHandle=findobj(                                     ...
                          MenuHandles,'flat'                 , ...
                         'Tag'       ,'MenuOptionHideButtons'  ...
                         );
    set(HideBtnHandle,'UserData',BtnObjHandles);
    
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    %%% Create the Status Bar
    Frm1X=AxisX;Frm1Y=10;Frm1W=AxisW;Frm1H=55;
    StatusFrm1=uicontrol( ...
                        'Style','frame', ...
                        'Units','pixels', ...
                        'Position',[Frm1X Frm1Y Frm1W Frm1H], ...
                        'Tag','StatusFrame1' ...
                        );
    set(StatusFrm1,'Units','normalized');

    BtnStart=uicontrol(                                        ...
                      'Style'              ,'pushbutton'     , ...
                      'String'             ,'Start'          , ...
                      'HorizontalAlignment','center'         , ...
                      'Units'              ,'pixels'         , ...
                      'Position'           , ...
                          [Frm1X+5 Frm1Y+30 50 20]  , ...
                      'Tag'                ,'StartButton'    , ...
                      'Visible'            ,'on'             , ...
                      'CallBack'           ,'ansimltn #Run'    ...
                      );
    set(BtnStart,'Units','normalized');
    
    BtnClose=uicontrol(                                                ...
                      'Style'              ,'pushbutton'             , ...
                      'String'             ,'Close'                  , ...
                      'HorizontalAlignment','center'                 , ...
                      'Units'              ,'pixels'                 , ...
                      'Position'           , ...
                      [Frm1X+Frm1W-55 Frm1Y+30 50 20], ...
                      'Tag'                ,'CloseButton'            , ...
                      'CallBack'           ,'anfile #Close'            ...
                      );
    set(BtnClose,'Units','normalized');

    BtnShowTrails=uicontrol(                                             ...
                           'Style'              ,'checkbox'            , ...
                           'String'             ,'Show Trails'         , ...
                           'HorizontalAlignment','center'              , ...
                           'Units'              ,'pixels'              , ...
                           'Position'           , ...
                               [Frm1X+Frm1W/2-10-100 Frm1Y+30 100 20]  , ...
                           'Tag'                ,'ShowTrails'          , ...
                           'Visible'            ,'off'                 , ...
                           'CallBack'           ,'ansimltn #ShowTrails'  ...
                           );
    set(BtnShowTrails,'Units','normalized');

    BtnClearTrails=uicontrol(                                              ...
                            'Style'              ,'pushbutton'           , ...
                            'String'             ,'Clear Trails'         , ...
                            'HorizontalAlignment','center'               , ...
                            'Units'              ,'pixels'               , ...
                            'Position'           , ...
                                [Frm1X+Frm1W/2+10 Frm1Y+30 100 20]       , ...
                            'Tag'                ,'ClearTrails'          , ...
                            'Visible'            ,'off'                  , ...
                            'CallBack'           ,'ansimltn #ClearTrails'  ...
                            );
    set(BtnClearTrails,'Units','normalized');

    BtnReset=uicontrol(                                        ...
                      'Style'              ,'pushbutton'     , ...
                      'String'             ,'Reset'          , ...
                      'HorizontalAlignment','center'         , ...
                      'Units'              ,'pixels'         , ...
                      'Position'           , ...
                          [Frm1X+Frm1W/2-10 Frm1Y+30 50 20]  , ...
                      'Tag'                ,'ResetButton'    , ...
                      'Visible'            ,'off'            , ...
                      'CallBack'           ,'ansimltn #Reset'   ...
                      );
    set(BtnReset,'Units','normalized');

    BtnStatus=uicontrol(                                              ...
                       'Style'              ,'text'                 , ...
                       'String'             , ...
                       'Use Object toolbar to add animation objects', ...
                       'HorizontalAlignment','center'               , ...
                       'Units'              ,'pixels'               , ...
                       'Position'           , ...
                           [Frm1X+5 Frm1Y+5 Frm1W-10 20]            , ...
                       'BackgroundColor'    ,[0.7 0.7 0.7]          , ...
                       'Tag'                ,'StatusBar'                 ...
                       );
    set(BtnStatus,'Units','Normalized');

    StatusHandles=[BtnStart BtnReset BtnClose StatusFrm1 BtnStatus ...
                   BtnShowTrails BtnClearTrails];
    HideStatusHandle=findobj(                                    ...
                             MenuHandles,'flat'                , ...
                            'Tag'       ,'MenuOptionHideStatus'  ...
                            );
    set(HideStatusHandle,'UserData',StatusHandles);
    
    %%%% If simulation is running, disable certain features
    if strcmp(get_param(SimName,'Simulation Running'),'on'),
      ansimltn #Disable
      ansimltn #Start/Stop
    end
    
    set(findobj(WorkingFig),'Interruptible','yes');
    
    LoadFileName=get_param(SimHandle,'Mask Help');

%% The following if statement accounts for a MAC specific
%% problem.  When get_param is used with a handle rather
%% than a name, a system call is made and a different 
%% answer is returned.
    if ~isempty(LoadFileName),
      Loc=findstr(LoadFileName,'(Mask)');
      if ~isempty(Loc), LoadFileName(1:Loc+6)=[]; end
      if ~isempty(LoadFileName),
        Loc=findstr(LoadFileName,'No help available.');
        if ~isempty(Loc), LoadFileName(1:Loc+18)=[]; end
      end % if ~isempty
    end % if ~isempty

    if ~isempty(LoadFileName),
      eval(['LoadFlag=1;load ' LoadFileName],'LoadFlag=2;');
     
      if LoadFlag==1,
        LoadFile=menu('Open...'                      , ...
                      'New Animation'                , ...
                     ['Animation file ' LoadFileName]  ...
                     );
        if LoadFile==1,
          set_param(SimHandle,'Mask Help',[]);
        elseif LoadFile==2,
          anfile('#Load',LoadFileName);
        end % if LoadFile
      else,
        Answer=questdlg(str2mat([LoadFileName ,' is an invalid file.'], ...
                                'Attempt to Reload in the future?'), ...
                       'Yes','No' ...
                       );
      
        if strcmp(Answer,'No'),
          set_param(SimHandle,'Mask Help',[]);
        end
      end  % if LoadFlag
    end % if ~isempty

    set_param(SimHandleNest,'parameters',num2str(WorkingFig));
    set(WorkingFig, ...
       'Pointer','arrow' , ...
       'Visible','on'    , ...
       'Tag','WorkingFig'  ...
       );
       
  else,
    figure(WorkingFig);
  end % if WorkingFig

end % if Action
