function [ret,x0,str,ts,xts]=fourbar(t,x,u,flag);
%FOURBAR	is the M-file description of the SIMULINK system named FOURBAR.
%	The block-diagram can be displayed by typing: FOURBAR.
%
%	SYS=FOURBAR(T,X,U,FLAG) returns depending on FLAG certain
%	system values given time point, T, current state vector, X,
%	and input vector, U.
%	FLAG is used to indicate the type of output to be returned in SYS.
%
%	Setting FLAG=1 causes FOURBAR to return state derivatives, FLAG=2
%	discrete states, FLAG=3 system outputs and FLAG=4 next sample
%	time. For more information and other options see SFUNC.
%
%	Calling FOURBAR with a FLAG of zero:
%	[SIZES]=FOURBAR([],[],[],0),  returns a vector, SIZES, which
%	contains the sizes of the state vector and other parameters.
%		SIZES(1) number of states
%		SIZES(2) number of discrete states
%		SIZES(3) number of outputs
%		SIZES(4) number of inputs
%		SIZES(5) number of roots (currently unsupported)
%		SIZES(6) direct feedthrough flag
%		SIZES(7) number of sample times
%
%	For the definition of other parameters in SIZES, see SFUNC.
%	See also, TRIM, LINMOD, LINSIM, EULER, RK23, RK45, ADAMS, GEAR.

% Note: This M-file is only used for saving graphical information;
%       after the model is loaded into memory an internal model
%       representation is used.

% the system will take on the name of this mfile:
sys = mfilename;
new_system(sys)
simver(1.3)
if (0 == (nargin + nargout))
     set_param(sys,'Location',[488,116,988,479])
     open_system(sys)
end;
set_param(sys,'algorithm',     'RK-45')
set_param(sys,'Start time',    '0.0')
set_param(sys,'Stop time',     '999999')
set_param(sys,'Min step size', '0.0001')
set_param(sys,'Max step size', '0.1')
set_param(sys,'Relative error','1e-3')
set_param(sys,'Return vars',   '')
set_param(sys,'AssignSampleTimeColors','on');
set_param(sys,'AssignWideVectorLines','on');

add_block('built-in/Mux',[sys,'/','Mux'])
set_param([sys,'/','Mux'],...
		'hide name',0,...
		'inputs','2',...
		'position',[75,26,110,84])

add_block('built-in/Constant',[sys,'/','y1'])
set_param([sys,'/','y1'],...
		'Value','0',...
		'position',[25,58,50,82])

add_block('built-in/Constant',[sys,'/','x1'])
set_param([sys,'/','x1'],...
		'move name',0,...
		'Value','0',...
		'position',[25,28,50,52])

add_block('built-in/Mux',[sys,'/','Mux1'])
set_param([sys,'/','Mux1'],...
		'hide name',0,...
		'inputs','[2 2 2 2]',...
		'position',[320,153,355,197])


%     Subsystem  'SimAnim'.

new_system([sys,'/','SimAnim'])
set_param([sys,'/','SimAnim'],'Location',[220,207,417,288])

add_block('built-in/Inport',[sys,'/','SimAnim/in_1'])
set_param([sys,'/','SimAnim/in_1'],...
		'Drop Shadow',4,...
		'position',[30,25,50,45])

add_block('built-in/S-Function',[sys,'/','SimAnim/ansim'])
set_param([sys,'/','SimAnim/ansim'],...
		'hide name',0,...
		'function name','ansim',...
		'parameters','1',...
		'position',[105,25,155,45])
add_line([sys,'/','SimAnim'],[55,35;100,35])
set_param([sys,'/','SimAnim'],...
		'Mask Display','Simulation\nAnimation',...
		'Mask Type','Simulation Animation',...
		'Mask Dialogue','eval(''ansimini #Initialize'');',...
		'Mask Help','fourbar.mat')


%     Finished composite block 'SimAnim'.

set_param([sys,'/','SimAnim'],...
		'hide name',0,...
		'position',[380,153,460,197])

add_block('built-in/Constant',[sys,'/','x4'])
set_param([sys,'/','x4'],...
		'move name',0,...
		'Value','10',...
		'position',[20,268,45,292])

add_block('built-in/Constant',[sys,'/','y4'])
set_param([sys,'/','y4'],...
		'Value','0',...
		'position',[20,298,45,322])

add_block('built-in/Mux',[sys,'/','Mux2'])
set_param([sys,'/','Mux2'],...
		'hide name',0,...
		'inputs','2',...
		'position',[75,266,110,324])

add_block('built-in/Constant',[sys,'/','L1'])
set_param([sys,'/','L1'],...
		'move name',0,...
		'Value','5',...
		'position',[135,103,160,127])

add_block('built-in/Fcn',[sys,'/','Theta1'])
set_param([sys,'/','Theta1'],...
		'Expr','abs(u[1]*((u[1]>u[2])&&(u[1]>u[3]))+u[2]*((u[2]>u[1])&&(u[2]>u[3]))+u[3]*((u[3]>u[1])&&(u[3]>u[2])))',...
		'position',[85,120,115,150])

add_block('built-in/Sine Wave',[sys,'/',['Sine',13,'Wave']])
set_param([sys,'/',['Sine',13,'Wave']],...
		'amplitude','pi',...
		'phase','[0  pi/2 2*pi/3]',...
		'position',[40,125,60,145])


%     Subsystem  '[x2 y2]'.

new_system([sys,'/','[x2 y2]'])
set_param([sys,'/','[x2 y2]'],'Location',[75,88,673,218])

add_block('built-in/Fcn',[sys,'/','[x2 y2]/y2'])
set_param([sys,'/','[x2 y2]/y2'],...
		'Expr','u[2]+u[3]*sin(u[4])',...
		'position',[250,68,420,92])

add_block('built-in/Inport',[sys,'/','[x2 y2]/[x1 y1]'])
set_param([sys,'/','[x2 y2]/[x1 y1]'],...
		'Drop Shadow',4,...
		'position',[20,10,40,30])

add_block('built-in/Inport',[sys,'/','[x2 y2]/L1'])
set_param([sys,'/','[x2 y2]/L1'],...
		'Drop Shadow',4,...
		'Port','2',...
		'position',[70,25,90,45])

add_block('built-in/Mux',[sys,'/','[x2 y2]/Mux3'])
set_param([sys,'/','[x2 y2]/Mux3'],...
		'hide name',0,...
		'inputs','[2 1 1]',...
		'position',[165,13,200,57])

add_block('built-in/Mux',[sys,'/','[x2 y2]/Mux2'])
set_param([sys,'/','[x2 y2]/Mux2'],...
		'hide name',0,...
		'inputs','2',...
		'position',[460,38,495,82])

add_block('built-in/Outport',[sys,'/','[x2 y2]/[x2 y2]'])
set_param([sys,'/','[x2 y2]/[x2 y2]'],...
		'Drop Shadow',4,...
		'position',[520,50,540,70])

add_block('built-in/Fcn',[sys,'/','[x2 y2]/x2'])
set_param([sys,'/','[x2 y2]/x2'],...
		'Expr','u[1]+u[3]*cos(u[4])',...
		'position',[250,23,420,47])

add_block('built-in/Inport',[sys,'/','[x2 y2]/Theta1'])
set_param([sys,'/','[x2 y2]/Theta1'],...
		'Drop Shadow',4,...
		'Port','3',...
		'position',[110,40,130,60])
add_line([sys,'/','[x2 y2]'],[45,20;160,20])
add_line([sys,'/','[x2 y2]'],[500,60;515,60])
add_line([sys,'/','[x2 y2]'],[425,35;435,35;435,50;455,50])
add_line([sys,'/','[x2 y2]'],[95,35;160,35])
add_line([sys,'/','[x2 y2]'],[135,50;160,50])
add_line([sys,'/','[x2 y2]'],[205,35;245,35])
add_line([sys,'/','[x2 y2]'],[425,80;435,80;435,70;455,70])
add_line([sys,'/','[x2 y2]'],[220,35;220,80;245,80])


%     Finished composite block '[x2 y2]'.

set_param([sys,'/','[x2 y2]'],...
		'position',[215,88,245,142])


%     Subsystem  '[x3 y3]'.

new_system([sys,'/','[x3 y3]'])
set_param([sys,'/','[x3 y3]'],'Location',[72,89,851,433])

add_block('built-in/Fcn',[sys,'/','[x3 y3]/l'])
set_param([sys,'/','[x3 y3]/l'],...
		'Expr','sqrt( (u[4]-u[2])*(u[4]-u[2]) +(u[3]-u[1])*(u[3]-u[1]) )',...
		'position',[205,13,550,37])

add_block('built-in/Inport',[sys,'/','[x3 y3]/[x2 y2]'])
set_param([sys,'/','[x3 y3]/[x2 y2]'],...
		'Drop Shadow',4,...
		'position',[10,30,30,50])

add_block('built-in/Inport',[sys,'/','[x3 y3]/[x4 y4]'])
set_param([sys,'/','[x3 y3]/[x4 y4]'],...
		'Drop Shadow',4,...
		'Port','5',...
		'position',[60,50,80,70])

add_block('built-in/Mux',[sys,'/','[x3 y3]/Mux6'])
set_param([sys,'/','[x3 y3]/Mux6'],...
		'hide name',0,...
		'inputs','[2 2]',...
		'position',[120,28,155,72])

add_block('built-in/Fcn',[sys,'/','[x3 y3]/Theta3'])
set_param([sys,'/','[x3 y3]/Theta3'],...
		'Expr','atan2(u[2]-u[4],-(u[1]-u[3]))',...
		'position',[205,66,405,94])

add_block('built-in/Fcn',[sys,'/','[x3 y3]/Theta4'])
set_param([sys,'/','[x3 y3]/Theta4'],...
		'orientation',2,...
		'Expr','acos( (u[2]*u[2]-u[1]*u[1]-u[3]*u[3])/(-2*u[1]*u[3]) )',...
		'position',[430,124,725,156])

add_block('built-in/Mux',[sys,'/','[x3 y3]/Mux2'])
set_param([sys,'/','[x3 y3]/Mux2'],...
		'hide name',0,...
		'inputs','2',...
		'position',[665,243,700,287])

add_block('built-in/Outport',[sys,'/','[x3 y3]/[x3 y3]'])
set_param([sys,'/','[x3 y3]/[x3 y3]'],...
		'Drop Shadow',4,...
		'position',[725,255,745,275])

add_block('built-in/Fcn',[sys,'/','[x3 y3]/x3'])
set_param([sys,'/','[x3 y3]/x3'],...
		'Expr','u[3]+u[2]*cos(u[1])',...
		'position',[455,228,625,252])

add_block('built-in/Fcn',[sys,'/','[x3 y3]/y3'])
set_param([sys,'/','[x3 y3]/y3'],...
		'Expr','u[4]+u[2]*sin(u[1])',...
		'position',[455,283,625,307])

add_block('built-in/Sum',[sys,'/','[x3 y3]/Theta2'])
set_param([sys,'/','[x3 y3]/Theta2'],...
		'move name',0,...
		'inputs','--+',...
		'position',[280,167,300,203])

add_block('built-in/Constant',[sys,'/','[x3 y3]/pi'])
set_param([sys,'/','[x3 y3]/pi'],...
		'hide name',0,...
		'move name',0,...
		'Value','pi',...
		'position',[180,183,205,207])

add_block('built-in/Inport',[sys,'/','[x3 y3]/L3 '])
set_param([sys,'/','[x3 y3]/L3 '],...
		'move name',0,...
		'Drop Shadow',4,...
		'Port','4',...
		'position',[280,230,300,250])

add_block('built-in/Mux',[sys,'/','[x3 y3]/Mux5'])
set_param([sys,'/','[x3 y3]/Mux5'],...
		'hide name',0,...
		'inputs','[1 1 2]',...
		'position',[350,218,385,262])

add_block('built-in/Inport',[sys,'/','[x3 y3]/L2'])
set_param([sys,'/','[x3 y3]/L2'],...
		'Drop Shadow',4,...
		'Port','2',...
		'position',[590,30,610,50])

add_block('built-in/Inport',[sys,'/','[x3 y3]/L3'])
set_param([sys,'/','[x3 y3]/L3'],...
		'Drop Shadow',4,...
		'Port','3',...
		'position',[625,45,645,65])

add_block('built-in/Mux',[sys,'/','[x3 y3]/Mux7'])
set_param([sys,'/','[x3 y3]/Mux7'],...
		'hide name',0,...
		'inputs','3',...
		'position',[670,18,705,62])
add_line([sys,'/','[x3 y3]'],[630,295;640,295;640,275;660,275])
add_line([sys,'/','[x3 y3]'],[630,240;640,240;640,255;660,255])
add_line([sys,'/','[x3 y3]'],[705,265;720,265])
add_line([sys,'/','[x3 y3]'],[390,240;450,240])
add_line([sys,'/','[x3 y3]'],[35,40;115,40])
add_line([sys,'/','[x3 y3]'],[85,60;115,60])
add_line([sys,'/','[x3 y3]'],[555,25;665,25])
add_line([sys,'/','[x3 y3]'],[615,40;665,40])
add_line([sys,'/','[x3 y3]'],[650,55;665,55])
add_line([sys,'/','[x3 y3]'],[710,40;750,40;750,140;730,140])
add_line([sys,'/','[x3 y3]'],[410,80;420,80;420,130;225,130;225,185;275,185])
add_line([sys,'/','[x3 y3]'],[160,50;175,50;175,80;200,80])
add_line([sys,'/','[x3 y3]'],[175,50;175,25;200,25])
add_line([sys,'/','[x3 y3]'],[210,195;275,195])
add_line([sys,'/','[x3 y3]'],[425,140;245,140;245,175;275,175])
add_line([sys,'/','[x3 y3]'],[305,185;330,185;330,225;345,225])
add_line([sys,'/','[x3 y3]'],[305,240;345,240])
add_line([sys,'/','[x3 y3]'],[100,60;100,255;345,255])
add_line([sys,'/','[x3 y3]'],[430,240;430,295;450,295])


%     Finished composite block '[x3 y3]'.

set_param([sys,'/','[x3 y3]'],...
		'position',[215,180,245,260])

add_block('built-in/Constant',[sys,'/','L2'])
set_param([sys,'/','L2'],...
		'move name',0,...
		'Value','15',...
		'position',[35,193,60,217])

add_block('built-in/Constant',[sys,'/','L3'])
set_param([sys,'/','L3'],...
		'Value','10',...
		'position',[75,208,100,232])
add_line(sys,[115,55;285,55;285,160;315,160])
add_line(sys,[360,175;375,175])
add_line(sys,[65,135;80,135])
add_line(sys,[55,40;70,40])
add_line(sys,[55,70;70,70])
add_line(sys,[165,115;210,115])
add_line(sys,[120,135;210,135])
add_line(sys,[250,115;265,115;265,170;315,170])
add_line(sys,[50,280;70,280])
add_line(sys,[50,310;70,310])
add_line(sys,[115,295;285,295;285,190;315,190])
add_line(sys,[250,220;265,220;265,180;315,180])
add_line(sys,[65,205;210,205])
add_line(sys,[105,220;210,220])
add_line(sys,[265,170;190,170;190,190;210,190])
add_line(sys,[175,55;175,95;210,95])
add_line(sys,[190,220;190,235;210,235])
add_line(sys,[165,295;165,250;210,250])

drawnow

% Return any arguments.
if (nargin | nargout)
	% Must use feval here to access system in memory
	if (nargin > 3)
		if (flag == 0)
			eval(['[ret,x0,str,ts,xts]=',sys,'(t,x,u,flag);'])
		else
			eval(['ret =', sys,'(t,x,u,flag);'])
		end
	else
		[ret,x0,str,ts,xts] = feval(sys);
	end
else
	drawnow % Flash up the model and execute load callback
end
