function [ret,x0,str,ts,xts]=intrface(t,x,u,flag);
%INTRFACE	is the M-file description of the SIMULINK system named INTRFACE.
%	The block-diagram can be displayed by typing: INTRFACE.
%
%	SYS=INTRFACE(T,X,U,FLAG) returns depending on FLAG certain
%	system values given time point, T, current state vector, X,
%	and input vector, U.
%	FLAG is used to indicate the type of output to be returned in SYS.
%
%	Setting FLAG=1 causes INTRFACE to return state derivatives, FLAG=2
%	discrete states, FLAG=3 system outputs and FLAG=4 next sample
%	time. For more information and other options see SFUNC.
%
%	Calling INTRFACE with a FLAG of zero:
%	[SIZES]=INTRFACE([],[],[],0),  returns a vector, SIZES, which
%	contains the sizes of the state vector and other parameters.
%		SIZES(1) number of states
%		SIZES(2) number of discrete states
%		SIZES(3) number of outputs
%		SIZES(4) number of inputs
%		SIZES(5) number of roots (currently unsupported)
%		SIZES(6) direct feedthrough flag
%		SIZES(7) number of sample times
%
%	For the definition of other parameters in SIZES, see SFUNC.
%	See also, TRIM, LINMOD, LINSIM, EULER, RK23, RK45, ADAMS, GEAR.

% Note: This M-file is only used for saving graphical information;
%       after the model is loaded into memory an internal model
%       representation is used.

% the system will take on the name of this mfile:
sys = mfilename;
new_system(sys)
simver(1.3)
if (0 == (nargin + nargout))
     set_param(sys,'Location',[572,95,873,258])
     open_system(sys)
end;
set_param(sys,'algorithm',     'RK-45')
set_param(sys,'Start time',    '0.0')
set_param(sys,'Stop time',     '200')
set_param(sys,'Min step size', '0.1')
set_param(sys,'Max step size', '.1')
set_param(sys,'Relative error','1e-3')
set_param(sys,'Return vars',   '')

add_block('built-in/Mux',[sys,'/','Mux'])
set_param([sys,'/','Mux'],...
		'hide name',0,...
		'inputs','3',...
		'position',[140,33,170,117])

add_block('built-in/Sine Wave',[sys,'/','Sine Wave'])
set_param([sys,'/','Sine Wave'],...
		'hide name',0,...
		'amplitude','50',...
		'frequency','2',...
		'position',[90,35,110,55])

add_block('built-in/Signal Generator',[sys,'/',['Signal',13,'Generator2']])
set_param([sys,'/',['Signal',13,'Generator2']],...
		'hide name',0,...
		'Peak','90.000000',...
		'Peak Range','90.000000',...
		'Freq','1.000000',...
		'Freq Range','5.000000',...
		'Wave','Sin',...
		'Units','Rads')
set_param([sys,'/',['Signal',13,'Generator2']],...
		'position',[15,88,60,122])

add_block('built-in/Sine Wave',[sys,'/','Sine Wave1'])
set_param([sys,'/','Sine Wave1'],...
		'hide name',0,...
		'amplitude','50',...
		'frequency','2',...
		'phase','pi/2',...
		'position',[90,65,110,85])


%     Subsystem  'SimAnim'.

new_system([sys,'/','SimAnim'])
set_param([sys,'/','SimAnim'],'Location',[220,207,417,288])

add_block('built-in/Inport',[sys,'/','SimAnim/in_1'])
set_param([sys,'/','SimAnim/in_1'],...
		'Drop Shadow',4,...
		'position',[30,25,50,45])

add_block('built-in/S-Function',[sys,'/','SimAnim/ansim'])
set_param([sys,'/','SimAnim/ansim'],...
		'hide name',0,...
		'function name','ansim',...
		'parameters','1',...
		'position',[105,25,155,45])
add_line([sys,'/','SimAnim'],[55,35;100,35])
set_param([sys,'/','SimAnim'],...
		'Mask Display','Simulation\nAnimation',...
		'Mask Type','Simulation Animation',...
		'Mask Dialogue','eval(''ansimini #Initialize'');')


%     Finished composite block 'SimAnim'.

set_param([sys,'/','SimAnim'],...
		'position',[200,53,280,97])
add_line(sys,[115,45;135,45])
add_line(sys,[175,75;195,75])
add_line(sys,[115,75;135,75])
add_line(sys,[65,105;135,105])

drawnow

% Return any arguments.
if (nargin | nargout)
	% Must use feval here to access system in memory
	if (nargin > 3)
		if (flag == 0)
			eval(['[ret,x0,str,ts,xts]=',sys,'(t,x,u,flag);'])
		else
			eval(['ret =', sys,'(t,x,u,flag);'])
		end
	else
		[ret,x0,str,ts,xts] = feval(sys);
	end
else
	drawnow % Flash up the model and execute load callback
end
