function [ret,x0,str,ts,xts]=piston(t,x,u,flag);
%PISTON	is the M-file description of the SIMULINK system named PISTON.
%	The block-diagram can be displayed by typing: PISTON.
%
%	SYS=PISTON(T,X,U,FLAG) returns depending on FLAG certain
%	system values given time point, T, current state vector, X,
%	and input vector, U.
%	FLAG is used to indicate the type of output to be returned in SYS.
%
%	Setting FLAG=1 causes PISTON to return state derivatives, FLAG=2
%	discrete states, FLAG=3 system outputs and FLAG=4 next sample
%	time. For more information and other options see SFUNC.
%
%	Calling PISTON with a FLAG of zero:
%	[SIZES]=PISTON([],[],[],0),  returns a vector, SIZES, which
%	contains the sizes of the state vector and other parameters.
%		SIZES(1) number of states
%		SIZES(2) number of discrete states
%		SIZES(3) number of outputs
%		SIZES(4) number of inputs
%		SIZES(5) number of roots (currently unsupported)
%		SIZES(6) direct feedthrough flag
%		SIZES(7) number of sample times
%
%	For the definition of other parameters in SIZES, see SFUNC.
%	See also, TRIM, LINMOD, LINSIM, EULER, RK23, RK45, ADAMS, GEAR.

% Note: This M-file is only used for saving graphical information;
%       after the model is loaded into memory an internal model
%       representation is used.

% the system will take on the name of this mfile:
sys = mfilename;
new_system(sys)
simver(1.3)
if (0 == (nargin + nargout))
     set_param(sys,'Location',[108,460,892,699])
     open_system(sys)
end;
set_param(sys,'algorithm',     'RK-45')
set_param(sys,'Start time',    '0.0')
set_param(sys,'Stop time',     '999999')
set_param(sys,'Min step size', '0.0001')
set_param(sys,'Max step size', '0.1')
set_param(sys,'Relative error','1e-3')
set_param(sys,'Return vars',   '')

add_block('built-in/Clock',[sys,'/','Clock'])
set_param([sys,'/','Clock'],...
		'position',[20,50,40,70])

add_block('built-in/Fcn',[sys,'/','Fcn1'])
set_param([sys,'/','Fcn1'],...
		'hide name',0,...
		'Expr','sin(u)',...
		'position',[80,110,135,140])

add_block('built-in/Fcn',[sys,'/','Fcn'])
set_param([sys,'/','Fcn'],...
		'hide name',0,...
		'Expr','cos(u)',...
		'position',[85,45,140,75])

add_block('built-in/Gain',[sys,'/','x1'])
set_param([sys,'/','x1'],...
		'Gain','10',...
		'position',[160,40,200,80])

add_block('built-in/Gain',[sys,'/','y1'])
set_param([sys,'/','y1'],...
		'Gain','10',...
		'position',[160,105,200,145])

add_block('built-in/Mux',[sys,'/','Mux'])
set_param([sys,'/','Mux'],...
		'hide name',0,...
		'inputs','2',...
		'position',[255,68,290,112])

add_block('built-in/Mux',[sys,'/','Mux2'])
set_param([sys,'/','Mux2'],...
		'hide name',0,...
		'inputs','2',...
		'position',[555,113,590,157])

add_block('built-in/Mux',[sys,'/','Mux1'])
set_param([sys,'/','Mux1'],...
		'hide name',0,...
		'inputs','[2 2]',...
		'position',[625,78,660,122])


%     Subsystem  'SimAnim'.

new_system([sys,'/','SimAnim'])
set_param([sys,'/','SimAnim'],'Location',[220,207,417,288])

add_block('built-in/Inport',[sys,'/','SimAnim/in_1'])
set_param([sys,'/','SimAnim/in_1'],...
		'Drop Shadow',4,...
		'position',[30,25,50,45])

add_block('built-in/S-Function',[sys,'/','SimAnim/ansim'])
set_param([sys,'/','SimAnim/ansim'],...
		'hide name',0,...
		'function name','ansim',...
		'parameters','1',...
		'position',[105,25,155,45])
add_line([sys,'/','SimAnim'],[55,35;100,35])
set_param([sys,'/','SimAnim'],...
		'Mask Display','Simulation\nAnimation',...
		'Mask Type','Simulation Animation',...
		'Mask Dialogue','eval(''ansimini #Initialize'');',...
		'Mask Help','piston.mat')


%     Finished composite block 'SimAnim'.

set_param([sys,'/','SimAnim'],...
		'position',[680,78,760,122])

add_block('built-in/Fcn',[sys,'/','y2'])
set_param([sys,'/','y2'],...
		'Expr','u(2)+sqrt(20^2-u(1)^2)',...
		'position',[335,164,520,196])

add_block('built-in/Constant',[sys,'/','x2'])
set_param([sys,'/','x2'],...
		'Value','0',...
		'position',[485,110,515,140])
add_line(sys,[45,60;80,60])
add_line(sys,[65,60;75,125])
add_line(sys,[145,60;155,60])
add_line(sys,[140,125;155,125])
add_line(sys,[205,60;220,60;220,80;250,80])
add_line(sys,[205,125;220,125;220,100;250,100])
add_line(sys,[520,125;550,125])
add_line(sys,[525,180;530,180;530,145;550,145])
add_line(sys,[295,90;620,90])
add_line(sys,[595,135;605,135;605,110;620,110])
add_line(sys,[665,100;675,100])
add_line(sys,[320,90;330,180])

drawnow

% Return any arguments.
if (nargin | nargout)
	% Must use feval here to access system in memory
	if (nargin > 3)
		if (flag == 0)
			eval(['[ret,x0,str,ts,xts]=',sys,'(t,x,u,flag);'])
		else
			eval(['ret =', sys,'(t,x,u,flag);'])
		end
	else
		[ret,x0,str,ts,xts] = feval(sys);
	end
else
	drawnow % Flash up the model and execute load callback
end
