function antext(Action,Handle,WorkingFig,u)
%ANTEXT	Text creation and display function.
%	ANTEXT(ACTION,HANDLE,WORKINGFIG,U) is the creation and display 
%	function for the text object in the simulation animation block.
%
%	ACTION may be one of four strings:
%	    '#Draw'  Draw text object.
%	     '#New'  Create new text object.
%	  '#Modify'  Modify text object parameters.
%	  '#Update'  Update object paramaters as entered in currently
%	             displayed dialog.
%
%	HANDLE is a vector of text object handles.
%
%	WORKINGFIG is the handle for the figure that the objects are 
%	drawn on.
%
%	U is the vector of inputs to the animation block.  It is used
%	in the '#Draw' area only.
%
%	See also ANLINE, ANPATCH, ANDOT, ANRECT, ANOBJ.

%	Loren Dean March, 1995.
%	Copyright (c) 1995 by The MathWorks, Inc.

%%%%%%%%%%%
%%% Draw %%%
%%%%%%%%%%%
if strcmp(Action,'#Draw'),

  NumObjs=length(Handle);
  Data=zeros(NumObjs,103);
    
  for lp=1:NumObjs,
    Data(lp,:)=eval(get(Handle(lp),'UserData')    , ...
                  ['['                            , ...
                   'get(Handle(lp),''Position'') ', ...
                   'get(Handle(lp),''Extent'')   ', ...
                   'get(Handle(lp),''FontSize'') ', ...
                   'get(Handle(lp),''Rotation'') ', ...
                   'get(Handle(lp),''Color'')    ', ...
                   'abs(''center  '')            ', ...
                   'abs(''middle  '')            ', ...
                   'abs([''Text'' blanks(71)])   ', ...
                   ']'] ...
                   );
    Data(lp,4:7)=get(Handle(lp),'Extent');
  end % for lp
    
  FigData=get(WorkingFig,'UserData');
  WorkingAxes=FigData(2);
  
  Position = andraw(WorkingFig             , ...
                    Handle                 , ...
                    Data(:,1:7)         , ...
                    get(WorkingAxes,'XLim'), ...
                    get(WorkingAxes,'YLim')  ...
                   );

% Fontsize is limited to >1
  for lp=1:NumObjs,
    set(Handle(lp) , ...
       'Position'  ,Position(lp,1:3)      , ...
       'FontSize'  ,max(abs(Data(lp,8)),1), ...
       'Rotation'  ,Data(lp,9)            , ...
       'Color'     ,abs(Data(lp,10:12))     ...
       );
  end % for lp
  
%%%%%%%%%%%
%%% New %%%
%%%%%%%%%%%
elseif strcmp(Action,'#New'),
  % All Cases except Load from file and double click open
  if nargin==1,
    WorkingFig=findobj(0,'type','figure','Tag','WorkingFig');
    Handle=[];
  end % if nargin
  
  FigData=get(WorkingFig,'UserData');
  WorkingAxes=FigData(2);
  set(WorkingFig,'CurrentAxes',WorkingAxes);
  
  LoadFromFileFlag=length(Handle)>1;


  if LoadFromFileFlag,
    u=angetic(WorkingFig);
    
    Data=eval(Handle,['[sum(get(WorkingAxes,''XLim''))/2,' , ...
                      ' sum(get(WorkingAxes,''YLim''))/2,' , ...
                      ' 0 8 0 0 0 0 0 1 1 1'               , ...
                      ' abs(''center  '')'                 , ...
                      ' abs(''center  '')'                 , ...
                      ' abs(''Text'')]'                      ...
                      ]);
    XPos=Data(1);
    YPos=Data(2);
    FontSize=max(8,abs(Data(4)));
    Rotation=Data(9);
    Color=Data(10:12);
    HorizAlign=deblank(setstr(Data(13:20)));
    VertAlign=deblank(setstr(Data(21:28)));
    String=deblank(setstr(Data(29:103)));
  else,
    if nargin==4,  % Double click open
      [XPos,YPos]=angetpos(WorkingFig,1);
    else,
      [XPos,YPos]=angetpos(WorkingFig);
    end % if nargin
    FontSize=8;
    Rotation=0;
    Color=[1 1 1];
    HorizAlign='center';
    VertAlign='middle';
    String='Text';
  end % if LoadFromFileFlag

  CurrentPt=text(                                            ...
                 XPos                , YPos                , ...
                 String                                    , ...
                'FontSize'           , FontSize            , ...
                'Rotation'           , Rotation            , ...
                'Color'              , Color               , ...
                'HorizontalAlignment', HorizAlign          , ...
                'VerticalAlignment'  , VertAlign           , ...
                'ButtonDownFcn'      , 'anedit #ButtonDown', ...
                'EraseMode'          , 'normal'            , ...
                'Parent',WorkingAxes, ...                
                'Interruptible'      , 'on'                , ...
                'Tag'                , 'AnimText'            ...
                );

  drawnow
  Extent=get(CurrentPt,'Extent');
  
  if LoadFromFileFlag,
    WorkingData=Handle;
  else,
    WorkingData=['[' ...
                num2str(XPos)     ',' num2str(YPos)                   ',' ...
                num2str(0)        ',' mat2str(Extent)                 ',' ...
                num2str(FontSize) ',' num2str(Rotation)               ',' ...
                mat2str(Color)    ','                                     ...
                mat2str(abs([HorizAlign blanks(8-length(HorizAlign))])) ',' ...
                mat2str(abs([VertAlign blanks(8-length(VertAlign))])) ',' ...
                mat2str(abs([String blanks(75-length(String))]))      ',' ...
                ']' ...
                ];
  end % if LoadFromFileFlag

  [SelectColor,DeselectColor]=angetclr('#New',CurrentPt,Color);
  
  set(CurrentPt,'UserData',WorkingData,'Color',SelectColor);
  
  AxesData=get(WorkingAxes,'UserData');
  set(WorkingAxes,'UserData',[]); %Done for speed purposes (not necessary)
  AxesData=[CurrentPt abs('antext  ');AxesData];
  set(WorkingAxes,'UserData',AxesData);

  
  andraw(WorkingFig , CurrentPt  , [XPos YPos 0 Extent]     , ...
         get(WorkingAxes,'XLim'), get(WorkingAxes,'YLim')  ...
        );

  if ~LoadFromFileFlag,
    antext('#Modify',CurrentPt,WorkingFig)
  end
  

%%%%%%%%%%%%%%
%%% Modify %%%
%%%%%%%%%%%%%%
elseif strcmp(Action,'#Modify'),
    
  List='XYZEFRCHVS';
  CurrentData=get(Handle,'UserData');

  CommaLocs=ancomloc(CurrentData);
  
  CurrentX=CurrentData(1,2:CommaLocs(1)-1);
  for lp=2:length(List),
    eval(['Current' List(lp) '=CurrentData(1,CommaLocs(' num2str(lp-1) ...
          ')+1:CommaLocs(' num2str(lp) ')-1);']);
  end % for lp
  
  TextStrings=str2mat('X Coordinate:'                            , ...
                      'Y Coordinate:'                            , ...
                      'Font Size:'                               , ...
                      'Rotation: (Degrees)'                      , ...
                      'Color ([R G B]):'                         , ...
                      'Horizontal Alignment: (left,center,right)', ...
                     ['Vert. Align.: ' , ...
                      '(top,cap,middle,baseline,bottom)']        , ...
                      'String:'                                    ...
                     );
                     
  Values=str2mat(CurrentX              , ...
                 CurrentY              , ...
                 CurrentF              , ...
                 CurrentR              , ...
                 CurrentC              , ...
                 setstr(eval(CurrentH)), ...
                 setstr(eval(CurrentV)), ...
                 setstr(eval(CurrentS))  ...
                 );
                 
  Callbacks=setstr(ones(length(Values(:,1))+1,1)*'antext #Update');

  List(3:4)=[];
  Tags=List';
  
  FigTag='PrpDlgFig';
  FigData=get(WorkingFig,'UserData');
  SimHandle=FigData(1);
  FigTitle=['Text Object Properties: ' get_param(SimHandle,'Name')];
  
  Handles = anprpdlg('#Initialize', Handle, WorkingFig, ...
                     TextStrings  , Values, Callbacks , ...
                     Tags         , FigTag, FigTitle    ...
                     );  
                     
%%%%%%%%%%%%%%
%%% Update %%%
%%%%%%%%%%%%%%
elseif strcmp(Action,'#Update'),

  PrpDlgFig=get(0,'CurrentFigure');
  Data=get(PrpDlgFig,'UserData');
  WorkingFig=Data(1);
  WorkingAxes=findobj(WorkingFig,'Type','axes','Tag','WorkingAxes');


  CurrentPt=Data(2);

  %%% Get Handles for Edit Text blocks
  List='XYFRCHVS';
  for lp=1:length(List),
    %%% Get Handles
    eval([ List(lp) 'Handle=findobj(PrpDlgFig,', ...
          ' ''Type'',''uicontrol'',''Tag'',''' List(lp) ''');']);
          
    %%% Get Strings for Edit Text Blocks
    eval(['Current' List(lp) '=get(' List(lp) 'Handle,''String'');']);
    
    %%% Remove all leading and trailing spaces from CurrentX and CurrentY
    eval(['Current' List(lp) '=deblank(fliplr(Current' List(lp) '));']);
    eval(['Current' List(lp) '=deblank(fliplr(Current' List(lp) '));']);
  end % for lp

  if length(CurrentH)>8,CurrentH=1:8;end
  if length(CurrentV)>8,CurrentV=1:8;end
  if length(CurrentS)>75,CurrentS=1:75;end
  CurrentE=get(CurrentPt,'Extent');
  CurrentPos=get(CurrentPt,'Position');
  
  u=angetic(WorkingFig);
  eval(['XFlag=0;CurrentXPos=' CurrentX ';']           , ...
        'XFlag=1;CurrentXPos=CurrentPos(1);'  ...
      );
  eval(['YFlag=0;CurrentYPos=' CurrentY ';']           , ...
        'YFlag=1;CurrentYPos=CurrentPos(2);'  ...
      );

  eval('FFlag=0;CurrentFVal=max(abs(eval(CurrentF,''8'')),8);', ...
       'FFlag=1;CurrentFVal=get(CurrentPt,''FontSize'');'       ...
      );
  eval(['RFlag=0;CurrentRVal=' CurrentR ';'], ...
       'RFlag=1;CurrentRVal=get(CurrentPt,''Rotation'');' ...
      );
  eval(['CFlag=0;CurrentCVal=' CurrentC ';']            , ...
        'CFlag=1;CurrentCVal=get(CurrentPt,''Color'');'  ...
      );
      
  if ~strcmp(lower(CurrentH),'left')   & ...
     ~strcmp(lower(CurrentH),'center') & ...
     ~strcmp(lower(CurrentH),'right'),
    HFlag=1;CurrentH=get(CurrentPt,'HorizontalAlignment');
  else,
    HFlag=0;
  end
  if ~strcmp(lower(CurrentV),'top')      & ...
     ~strcmp(lower(CurrentV),'cap')      & ...
     ~strcmp(lower(CurrentV),'baseline') & ...
     ~strcmp(lower(CurrentV),'bottom')   & ...
     ~strcmp(lower(CurrentV),'middle'),
    VFlag=1;CurrentV=get(CurrentPt,'VerticalAlignment');
  else,
    VFlag=0;
  end
  
  HCancel=findobj(PrpDlgFig,'Type','uicontrol','Tag','Cancel');
  CurrentData=get(HCancel,'UserData');
  CommaLocs=ancomloc(CurrentData(1,:));
  
  ListLoc=0;
  if XFlag,Low=2;             High=CommaLocs(1)-1;ListLoc=1;end
  if YFlag,Low=CommaLocs(1)+1;High=CommaLocs(2)-1;ListLoc=2;end
  if FFlag,Low=CommaLocs(4)+1;High=CommaLocs(5)-1;ListLoc=3;end
  if RFlag,Low=CommaLocs(5)+1;High=CommaLocs(6)-1;ListLoc=4;end
  if CFlag,Low=CommaLocs(6)+1;High=CommaLocs(7)-1;ListLoc=5;end
  if HFlag,Low=CommaLocs(7)+1;High=CommaLocs(8)-1;ListLoc=6;end
  if VFlag,Low=CommaLocs(8)+1;High=CommaLocs(9)-1;ListLoc=7;end
  
  if ListLoc,
    CurrentString=CurrentData(1,Low:High);
    if ListLoc<5,
      eval(['Current' List(ListLoc) '=CurrentString;']);
      eval(['set(' List(ListLoc) 'Handle,''String'',CurrentString)']);
    else,
      eval(['Current' List(ListLoc) '=setstr(eval(CurrentString));']);
      eval(['set(' List(ListLoc)  ...
            'Handle,''String'',setstr(eval(CurrentString)));']);
    end
    disp([7,7,7 'Last entry was invalid.  Old being used.']);disp(' ');
  end

  
  AllPtData=['['                                                           ...
             CurrentX          ',' CurrentY ',' num2str(CurrentPos(3)) ',' ...
             mat2str(CurrentE) ',' CurrentF ',' CurrentR               ',' ...
             mat2str(CurrentC) ','                                         ...
             mat2str(abs([CurrentH blanks(8-length(CurrentH))]))       ',' ...
             mat2str(abs([CurrentV blanks(8-length(CurrentV))]))       ',' ...
             mat2str(abs([CurrentS blanks(75-length(CurrentS))]))      ',' ...
             ']'                                                           ...
            ];
  

  set(HCancel,'UserData',str2mat(AllPtData,CurrentData(2,:)));
  
  set(CurrentPt           , ...
     'Position'           ,[CurrentXPos CurrentYPos CurrentPos(3)], ...
     'FontSize'           ,CurrentFVal                            , ...
     'Rotation'           ,CurrentRVal                            , ...
     'Color'              ,CurrentCVal                            , ...
     'HorizontalAlignment',CurrentH                               , ...
     'VerticalAlignment'  ,CurrentV                               , ...
     'String'             ,CurrentS                               , ...
     'UserData'           ,AllPtData                                ...
     );

  angetclr('#Modify',CurrentPt,CurrentCVal);

  ansimltn('#Reset',WorkingFig)
  
end % if strcmp    
