function bdgroup(sys,name)
%BDGROUP	Puts all blocks in a model into a subsystem.
%	BDGROUP(SYS,NAME) forms a subsystem out of all the blocks in the
%	specified SIMULINK model.
%	
%	See also NEW_SYSTEM, GET_PARAM.

%	Copyright (c) 1984-94 by The MathWorks, Inc.
%	Rick Spada  5-31-94

% -- check input args

if nargin == 1, name = sys; end

% -- get the list of blocks and lines from the model
blocks = get_param(sys,'blocks');
lines = get_param(sys,'lines');

% -- first delete all the lines
% this is necessary due to limitations in the syntax of delete_line,
% it only looks at a single point in the line, rather than the entire
% line, so the line deleted is not necessarily the one expected
% the loop in itself is sort of hokey, deleting all but option lines,
% reserving them till last, but it is necessary in order to work around
% delete_line and SIMULINK limitations.

tmpLines = lines;
while ~isempty(tmpLines),
  numDeleted = 0;
  for i=1:size(tmpLines,1)
    theLine = tmpLines(i,:);
    if theLine(5) == 0,
      outputBlock = deblank(blocks(theLine(1),:));
      outputPort = theLine(2);
      inputBlock = deblank(blocks(theLine(3),:));
      inputPort = theLine(4);
      delete_line(sys,[outputBlock,'/',num2str(outputPort)],[inputBlock,'/',num2str(inputPort)]);
      numDeleted = numDeleted + 1;
    end
  end
  
  if numDeleted == 0,
    for i=1:size(tmpLines,1)
      theLine = tmpLines(i,:);
      delete_line(sys,tmpLines(6:7));
    end
  end
  
  tmpLines = get_param(sys,'lines');
  
end

% -- create a subsystem
subsys = [sys '/' name];
new_system(subsys);
open_system(subsys);

% -- move the blocks to the subsystem
% Note, there is a hack here that sets the new block's position.  This
% is necessary to work around a SIMULINK bug that would result in unconnected
% ports.

for i=1:size(blocks,1),
  
  block = deblank(blocks(i,:));
  pos = get_param([sys,'/',block],'position');
  add_block([sys,'/',block],[subsys,'/',block]);
  set_param([subsys,'/',block],'position',pos);
  delete_block([sys,'/',block]);
  
end

% -- add the lines
% pretty straightforward stuff here, no magic, no hacks...
    
for i=1:size(lines,1)
  theLine = lines(i,:);
  theLine(1:5) = [];
  theLine(isnan(theLine)) = [];
  x = theLine(1:2:length(theLine)-1)';
  y = theLine(2:2:length(theLine))';
  add_line(subsys,[x,y]);
end
