function bdprint(sys)
%BDPRINT	Prints a SIMULINK model.
%	BDPRINT(SYS) prints a SIMULINK model and all of its subsystem
%	windows.
%
%	See also OPEN_SYSTEM, CLOSE_SYSTEM, GET_PARAM.

%	Copyright (c) 1994 by The MathWorks, Inc.
%	Rick Spada 6-27-94

if nargin == 0, sys = get_param; end

% no arg, go bye
if isempty(sys)
  error('You must pass in a SIMULINK model name.');
  return
end

if exist(sys) == 2,
  % possibly an unopened model
  eval(sys,'');
  if exist(sys) ~= 4,
    error(['Unable to open the SIMULINK model ''',sys,''.']);
  end
end

% sys could be a subsystem name
model = sys;
slash = findstr(sys,'/');
if ~isempty(slash),
  model = sys(1:slash(1)-1);
end  

if exist(model) ~= 4,
  error(['There is no system named ''' model '''']);
end

% it's an open model, print it, then recurse
open_system(sys);
drawnow;
print(['-s',get_param(get_param,'name')])

blocks = get_param(sys,'blocks');
for i=1:size(blocks,1),
  blockName = [sys '/' deblank(blocks(i,:))];
  blockType = get_param(blockName,'BlockType');
  
  % if this block is a subsystem, and it's not masked, open and print
  if strcmp(blockType,'Subsystem'),
    % if the subsystem doesn't have a mask, open it
    maskDisplay   = get_param(blockName,'mask display');
    maskType      = get_param(blockName,'mask type');
    maskDialogue  = get_param(blockName,'mask dialogue');
    maskTranslate = get_param(blockName,'mask translate');
    maskHelp      = get_param(blockName,'mask help');
    maskEntries   = get_param(blockName,'mask entries');
    mask = [maskDisplay maskType maskDialogue maskTranslate maskHelp maskEntries];
    if isempty(mask)
      bdprint(blockName);
      
      % remove the following line if you want the subsystem window to be left open
      close_system(blockName,0);
    end
  end
end
