function [ret,x0,str,ts,xts]=dee(t,x,u,flag);
%DEE	is the M-file description of the SIMULINK system named DEE.
%	The block-diagram can be displayed by typing: DEE.
%
%	SYS=DEE(T,X,U,FLAG) returns depending on FLAG certain
%	system values given time point, T, current state vector, X,
%	and input vector, U.
%	FLAG is used to indicate the type of output to be returned in SYS.
%
%	Setting FLAG=1 causes DEE to return state derivatives, FLAG=2
%	discrete states, FLAG=3 system outputs and FLAG=4 next sample
%	time. For more information and other options see SFUNC.
%
%	Calling DEE with a FLAG of zero:
%	[SIZES]=DEE([],[],[],0),  returns a vector, SIZES, which
%	contains the sizes of the state vector and other parameters.
%		SIZES(1) number of states
%		SIZES(2) number of discrete states
%		SIZES(3) number of outputs
%		SIZES(4) number of inputs
%		SIZES(5) number of roots (currently unsupported)
%		SIZES(6) direct feedthrough flag
%		SIZES(7) number of sample times
%
%	For the definition of other parameters in SIZES, see SFUNC.
%	See also, TRIM, LINMOD, LINSIM, EULER, RK23, RK45, ADAMS, GEAR.

% Note: This M-file is only used for saving graphical information;
%       after the model is loaded into memory an internal model
%       representation is used.

% the system will take on the name of this mfile:
sys = mfilename;
new_system(sys)
simver(1.3)
if (0 == (nargin + nargout))
     set_param(sys,'Location',[240,78,634,208])
     open_system(sys)
end;
set_param(sys,'algorithm',     'RK-45')
set_param(sys,'Start time',    '0.0')
set_param(sys,'Stop time',     '999999')
set_param(sys,'Min step size', '0.0001')
set_param(sys,'Max step size', '10')
set_param(sys,'Relative error','1e-3')
set_param(sys,'Return vars',   '')
set_param(sys,'Real-time build command','!download $model.c $model.h')


%     Subsystem  ['double click ',13,'for a demo'].

new_system([sys,'/',['double click ',13,'for a demo']])
set_param([sys,'/',['double click ',13,'for a demo']],'Location',[82,701,244,823])
set_param([sys,'/',['double click ',13,'for a demo']],...
		'Mask Display','deedemo2',...
		'Mask Type','button',...
		'Mask Dialogue','eval(''deedemo2'');')


%     Finished composite block ['double click ',13,'for a demo'].

set_param([sys,'/',['double click ',13,'for a demo']],...
		'BackGround',5,...
		'hide name',0,...
		'position',[120,85,194,114])


%     Subsystem  ['double click ',13,'for a demo1'].

new_system([sys,'/',['double click ',13,'for a demo1']])
set_param([sys,'/',['double click ',13,'for a demo1']],'Location',[82,701,244,823])
set_param([sys,'/',['double click ',13,'for a demo1']],...
		'Mask Display','deedemo3',...
		'Mask Type','button',...
		'Mask Dialogue','eval(''deedemo3'');')


%     Finished composite block ['double click ',13,'for a demo1'].

set_param([sys,'/',['double click ',13,'for a demo1']],...
		'BackGround',5,...
		'hide name',0,...
		'position',[210,85,282,115])


%     Subsystem  ['double click ',13,'for a demo2'].

new_system([sys,'/',['double click ',13,'for a demo2']])
set_param([sys,'/',['double click ',13,'for a demo2']],'Location',[82,701,244,823])
set_param([sys,'/',['double click ',13,'for a demo2']],...
		'Mask Display','deedemo4',...
		'Mask Type','button',...
		'Mask Dialogue','eval(''deedemo4'');')


%     Finished composite block ['double click ',13,'for a demo2'].

set_param([sys,'/',['double click ',13,'for a demo2']],...
		'BackGround',5,...
		'hide name',0,...
		'position',[295,85,367,115])


%     Subsystem  'DEE'.

new_system([sys,'/','DEE'])
set_param([sys,'/','DEE'],'Location',[100,100,600,400])

add_block('built-in/Mux',[sys,'/','DEE/SysMux'])
set_param([sys,'/','DEE/SysMux'],...
		'inputs','1',...
		'position',[100,100,150,150])
set_param([sys,'/','DEE'],...
		'Mask Display','Differential Equation\n Editor',...
		'Mask Type','Differential Equation Editor (DEE)',...
		'Mask Dialogue','eval(''diffeqed'')')


%     Finished composite block 'DEE'.

set_param([sys,'/','DEE'],...
		'position',[145,30,261,58])


%     Subsystem  ['double click',13,'for a demo'].

new_system([sys,'/',['double click',13,'for a demo']])
set_param([sys,'/',['double click',13,'for a demo']],'Location',[82,701,244,823])
set_param([sys,'/',['double click',13,'for a demo']],...
		'Mask Display','deedemo1',...
		'Mask Type','button',...
		'Mask Dialogue','eval(''deedemo1'');')


%     Finished composite block ['double click',13,'for a demo'].

set_param([sys,'/',['double click',13,'for a demo']],...
		'BackGround',5,...
		'hide name',0,...
		'position',[30,85,106,114])

drawnow

% Return any arguments.
if (nargin | nargout)
	% Must use feval here to access system in memory
	if (nargin > 3)
		if (flag == 0)
			eval(['[ret,x0,str,ts,xts]=',sys,'(t,x,u,flag);'])
		else
			eval(['ret =', sys,'(t,x,u,flag);'])
		end
	else
		[ret,x0,str,ts,xts] = feval(sys);
	end
else
	drawnow % Flash up the model and execute load callback
end
