function [ret,x0,str]=deedemo(t,x,u,flag);
%DEEDEMO	is the M-file description of the SIMULINK system named DEEDEMO.
%	The block-diagram can be displayed by typing: DEEDEMO.
%
%	SYS=DEEDEMO(T,X,U,FLAG) returns depending on FLAG certain
%	system values given time point, T, current state vector, X,
%	and input vector, U.
%	FLAG is used to indicate the type of output to be returned in SYS.
%
%	Setting FLAG=1 causes DEEDEMO to return state derivatives, FLAG=2
%	discrete states, FLAG=3 system outputs and FLAG=4 next sample
%	time. For more information and other options see SFUNC.
%
%	Calling DEEDEMO with a FLAG of zero:
%	[SIZES]=DEEDEMO([],[],[],0),  returns a vector, SIZES, which
%	contains the sizes of the state vector and other parameters.
%		SIZES(1) number of states
%		SIZES(2) number of discrete states
%		SIZES(3) number of outputs
%		SIZES(4) number of inputs.
%	For the definition of other parameters in SIZES, see SFUNC.
%	See also, TRIM, LINMOD, LINSIM, EULER, RK23, RK45, ADAMS, GEAR.

% Note: This M-file is only used for saving graphical information;
%       after the model is loaded into memory an internal model
%       representation is used.

% the system will take on the name of this mfile:
sys = mfilename;
new_system(sys)
simver(1.2)
if(0 == (nargin + nargout))
     set_param(sys,'Location',[154,377,477,485])
     open_system(sys)
end;
set_param(sys,'algorithm',     'RK-45')
set_param(sys,'Start time',    '0.0')
set_param(sys,'Stop time',     '999999')
set_param(sys,'Min step size', '0.0001')
set_param(sys,'Max step size', '10')
set_param(sys,'Relative error','1e-3')
set_param(sys,'Return vars',   '')
set_param(sys,'Real-time build command','!download $model.c $model.h')


%     Subsystem  ['double click',13,'for a demo'].

new_system([sys,'/',['double click',13,'for a demo']])
set_param([sys,'/',['double click',13,'for a demo']],'Location',[82,701,244,823])
set_param([sys,'/',['double click',13,'for a demo']],...
		'Mask Display','deedemo1',...
		'Mask Type','button',...
		'Mask Dialogue','eval(''deedemo1'');')


%     Finished composite block ['double click',13,'for a demo'].

set_param([sys,'/',['double click',13,'for a demo']],...
		'hide name',0,...
		'position',[25,35,103,72])


%     Subsystem  ['double click ',13,'for a demo'].

new_system([sys,'/',['double click ',13,'for a demo']])
set_param([sys,'/',['double click ',13,'for a demo']],'Location',[82,701,244,823])
set_param([sys,'/',['double click ',13,'for a demo']],...
		'Mask Display','deedemo2',...
		'Mask Type','button',...
		'Mask Dialogue','eval(''deedemo2'');')


%     Finished composite block ['double click ',13,'for a demo'].

set_param([sys,'/',['double click ',13,'for a demo']],...
		'hide name',0,...
		'position',[120,35,198,72])


%     Subsystem  ['double click ',13,'for a demo1'].

new_system([sys,'/',['double click ',13,'for a demo1']])
set_param([sys,'/',['double click ',13,'for a demo1']],'Location',[82,701,244,823])
set_param([sys,'/',['double click ',13,'for a demo1']],...
		'Mask Display','deedemo3',...
		'Mask Type','button',...
		'Mask Dialogue','eval(''masspg'');')


%     Finished composite block ['double click ',13,'for a demo1'].

set_param([sys,'/',['double click ',13,'for a demo1']],...
		'hide name',0,...
		'position',[215,35,293,72])

% Return any arguments.
if (nargin | nargout)
	% Must use feval here to access system in memory
	if (nargin > 3)
		if (flag == 0)
			eval(['[ret,x0,str]=',sys,'(t,x,u,flag);'])
		else
			eval(['ret =', sys,'(t,x,u,flag);'])
		end
	else
		[ret,x0,str] = feval(sys);
	end
end
