function [ret,x0,str,ts,xts]=deedemo1(t,x,u,flag);
%DEEDEMO1	is the M-file description of the SIMULINK system named DEEDEMO1.
%	The block-diagram can be displayed by typing: DEEDEMO1.
%
%	SYS=DEEDEMO1(T,X,U,FLAG) returns depending on FLAG certain
%	system values given time point, T, current state vector, X,
%	and input vector, U.
%	FLAG is used to indicate the type of output to be returned in SYS.
%
%	Setting FLAG=1 causes DEEDEMO1 to return state derivatives, FLAG=2
%	discrete states, FLAG=3 system outputs and FLAG=4 next sample
%	time. For more information and other options see SFUNC.
%
%	Calling DEEDEMO1 with a FLAG of zero:
%	[SIZES]=DEEDEMO1([],[],[],0),  returns a vector, SIZES, which
%	contains the sizes of the state vector and other parameters.
%		SIZES(1) number of states
%		SIZES(2) number of discrete states
%		SIZES(3) number of outputs
%		SIZES(4) number of inputs
%		SIZES(5) number of roots (currently unsupported)
%		SIZES(6) direct feedthrough flag
%		SIZES(7) number of sample times
%
%	For the definition of other parameters in SIZES, see SFUNC.
%	See also, TRIM, LINMOD, LINSIM, EULER, RK23, RK45, ADAMS, GEAR.

% Note: This M-file is only used for saving graphical information;
%       after the model is loaded into memory an internal model
%       representation is used.

% the system will take on the name of this mfile:
sys = mfilename;
new_system(sys)
simver(1.3)
if (0 == (nargin + nargout))
     set_param(sys,'Location',[177,348,370,448])
     open_system(sys)
end;
set_param(sys,'algorithm',     'RK-45')
set_param(sys,'Start time',    '0.0')
set_param(sys,'Stop time',     '999999')
set_param(sys,'Min step size', '0.0001')
set_param(sys,'Max step size', '10')
set_param(sys,'Relative error','1e-3')
set_param(sys,'Return vars',   '')
set_param(sys,'Real-time build command','!download $model.c $model.h')


%     Subsystem  ['Van der Pol',13,'Equation'].

new_system([sys,'/',['Van der Pol',13,'Equation']])
set_param([sys,'/',['Van der Pol',13,'Equation']],'Location',[100,100,600,400])

add_block('built-in/Mux',[sys,'/',['Van der Pol',13,'Equation/SysMux']])
set_param([sys,'/',['Van der Pol',13,'Equation/SysMux']],...
		'inputs','2',...
		'position',[100,201,150,254])

add_block('built-in/Fcn',[sys,'/',['Van der Pol',13,'Equation/y1']])
set_param([sys,'/',['Van der Pol',13,'Equation/y1']],...
		'Expr','u(1)',...
		'position',[300,250,330,270])

add_block('built-in/Outport',[sys,'/',['Van der Pol',13,'Equation/Port1']])
set_param([sys,'/',['Van der Pol',13,'Equation/Port1']],...
		'position',[400,250,420,270])

add_block('built-in/Fcn',[sys,'/',['Van der Pol',13,'Equation/x1']])
set_param([sys,'/',['Van der Pol',13,'Equation/x1']],...
		'Expr','u(1)*(1-u(2)*u(2))-u(2)        ',...
		'position',[300,50,330,70])

add_block('built-in/Integrator',[sys,'/',['Van der Pol',13,'Equation/Integ1']])
set_param([sys,'/',['Van der Pol',13,'Equation/Integ1']],...
		'Initial','1',...
		'position',[400,50,430,70])

add_block('built-in/Fcn',[sys,'/',['Van der Pol',13,'Equation/x2']])
set_param([sys,'/',['Van der Pol',13,'Equation/x2']],...
		'Expr','u(1)                           ',...
		'position',[300,100,330,120])

add_block('built-in/Integrator',[sys,'/',['Van der Pol',13,'Equation/Integ2']])
set_param([sys,'/',['Van der Pol',13,'Equation/Integ2']],...
		'Initial','1',...
		'position',[400,100,430,120])
add_line([sys,'/',['Van der Pol',13,'Equation']],[155,230;220,230;220,60;295,60])
add_line([sys,'/',['Van der Pol',13,'Equation']],[335,60;395,60])
add_line([sys,'/',['Van der Pol',13,'Equation']],[435,60;445,60;445,140;80,140;80,215;95,215])
add_line([sys,'/',['Van der Pol',13,'Equation']],[155,230;220,230;220,110;295,110])
add_line([sys,'/',['Van der Pol',13,'Equation']],[335,110;395,110])
add_line([sys,'/',['Van der Pol',13,'Equation']],[435,110;445,110;445,145;75,145;75,240;95,240])
add_line([sys,'/',['Van der Pol',13,'Equation']],[155,230;220,230;220,260;295,260])
add_line([sys,'/',['Van der Pol',13,'Equation']],[335,260;395,260])
set_param([sys,'/',['Van der Pol',13,'Equation']],...
		'Mask Display','vdp',...
		'Mask Type','Differential Equation Editor (DEE)',...
		'Mask Dialogue','eval(''diffeqed'')')


%     Finished composite block ['Van der Pol',13,'Equation'].

set_param([sys,'/',['Van der Pol',13,'Equation']],...
		'position',[45,22,85,58])

add_block('built-in/Scope',[sys,'/','x1'])
set_param([sys,'/','x1'],...
		'Vgain','3.000000',...
		'Hgain','20.000000',...
		'Vmax','6.000000',...
		'Hmax','40.000000',...
		'Window',[415,393,695,613])
open_system([sys,'/','x1'])
set_param([sys,'/','x1'],...
		'position',[130,25,155,55])
add_line(sys,[90,40;125,40])

drawnow

% Return any arguments.
if (nargin | nargout)
	% Must use feval here to access system in memory
	if (nargin > 3)
		if (flag == 0)
			eval(['[ret,x0,str,ts,xts]=',sys,'(t,x,u,flag);'])
		else
			eval(['ret =', sys,'(t,x,u,flag);'])
		end
	else
		[ret,x0,str,ts,xts] = feval(sys);
	end
else
	drawnow % Flash up the model and execute load callback
end
