function [ret,x0,str,ts,xts]=deedemo2(t,x,u,flag);
%DEEDEMO2	is the M-file description of the SIMULINK system named DEEDEMO2.
%	The block-diagram can be displayed by typing: DEEDEMO2.
%
%	SYS=DEEDEMO2(T,X,U,FLAG) returns depending on FLAG certain
%	system values given time point, T, current state vector, X,
%	and input vector, U.
%	FLAG is used to indicate the type of output to be returned in SYS.
%
%	Setting FLAG=1 causes DEEDEMO2 to return state derivatives, FLAG=2
%	discrete states, FLAG=3 system outputs and FLAG=4 next sample
%	time. For more information and other options see SFUNC.
%
%	Calling DEEDEMO2 with a FLAG of zero:
%	[SIZES]=DEEDEMO2([],[],[],0),  returns a vector, SIZES, which
%	contains the sizes of the state vector and other parameters.
%		SIZES(1) number of states
%		SIZES(2) number of discrete states
%		SIZES(3) number of outputs
%		SIZES(4) number of inputs
%		SIZES(5) number of roots (currently unsupported)
%		SIZES(6) direct feedthrough flag
%		SIZES(7) number of sample times
%
%	For the definition of other parameters in SIZES, see SFUNC.
%	See also, TRIM, LINMOD, LINSIM, EULER, RK23, RK45, ADAMS, GEAR.

% Note: This M-file is only used for saving graphical information;
%       after the model is loaded into memory an internal model
%       representation is used.

% the system will take on the name of this mfile:
sys = mfilename;
new_system(sys)
simver(1.3)
if (0 == (nargin + nargout))
     set_param(sys,'Location',[133,385,408,516])
     open_system(sys)
end;
set_param(sys,'algorithm',     'RK-45')
set_param(sys,'Start time',    '0.0')
set_param(sys,'Stop time',     '999999')
set_param(sys,'Min step size', '0.0001')
set_param(sys,'Max step size', '10')
set_param(sys,'Relative error','1e-5')
set_param(sys,'Return vars',   '')
set_param(sys,'Load callback','lorenzi');


%     Subsystem  'DEE'.

new_system([sys,'/','DEE'])
set_param([sys,'/','DEE'],'Location',[100,100,600,400])

add_block('built-in/Mux',[sys,'/','DEE/SysMux'])
set_param([sys,'/','DEE/SysMux'],...
		'inputs','3',...
		'position',[100,250,150,300])

add_block('built-in/Fcn',[sys,'/','DEE/y1'])
set_param([sys,'/','DEE/y1'],...
		'Expr','u(1)             ',...
		'position',[300,300,330,320])

add_block('built-in/Outport',[sys,'/','DEE/Port1'])
set_param([sys,'/','DEE/Port1'],...
		'position',[400,300,420,320])

add_block('built-in/Fcn',[sys,'/','DEE/y2'])
set_param([sys,'/','DEE/y2'],...
		'Expr','u(3)             ',...
		'position',[300,350,330,370])

add_block('built-in/Outport',[sys,'/','DEE/Port2'])
set_param([sys,'/','DEE/Port2'],...
		'Port','2',...
		'position',[400,350,420,370])

add_block('built-in/Fcn',[sys,'/','DEE/x1'])
set_param([sys,'/','DEE/x1'],...
		'Expr','-sigma*u(1)+ sigma*u(2)           ',...
		'position',[300,50,330,70])

add_block('built-in/Integrator',[sys,'/','DEE/Integ1'])
set_param([sys,'/','DEE/Integ1'],...
		'Initial','1',...
		'position',[400,50,430,70])

add_block('built-in/Fcn',[sys,'/','DEE/x2'])
set_param([sys,'/','DEE/x2'],...
		'Expr','-u(1)*u(3)  + rho*u(1) - u(2)     ',...
		'position',[300,100,330,120])

add_block('built-in/Integrator',[sys,'/','DEE/Integ2'])
set_param([sys,'/','DEE/Integ2'],...
		'Initial','1',...
		'position',[400,100,430,120])

add_block('built-in/Fcn',[sys,'/','DEE/x3'])
set_param([sys,'/','DEE/x3'],...
		'Expr','u(1)*u(2) - beta*u(3)   +u(1)     ',...
		'position',[300,150,330,170])

add_block('built-in/Integrator',[sys,'/','DEE/Integ3'])
set_param([sys,'/','DEE/Integ3'],...
		'Initial','1',...
		'position',[400,150,430,170])
add_line([sys,'/','DEE'],[155,275;220,275;220,60;295,60])
add_line([sys,'/','DEE'],[335,60;395,60])
add_line([sys,'/','DEE'],[435,60;445,60;445,130;80,130;80,260;95,260])
add_line([sys,'/','DEE'],[155,275;220,275;220,110;295,110])
add_line([sys,'/','DEE'],[335,110;395,110])
add_line([sys,'/','DEE'],[435,110;445,110;445,190;75,190;75,275;95,275])
add_line([sys,'/','DEE'],[155,275;220,275;220,160;295,160])
add_line([sys,'/','DEE'],[335,160;395,160])
add_line([sys,'/','DEE'],[435,160;445,160;445,195;70,195;70,290;95,290])
add_line([sys,'/','DEE'],[155,275;220,275;220,310;295,310])
add_line([sys,'/','DEE'],[335,310;395,310])
add_line([sys,'/','DEE'],[155,275;220,275;220,360;295,360])
add_line([sys,'/','DEE'],[335,360;395,360])
set_param([sys,'/','DEE'],...
		'Mask Display','Lorenz Attractor',...
		'Mask Type','Differential Equation Editor (DEE)',...
		'Mask Dialogue','eval(''diffeqed'')')


%     Finished composite block 'DEE'.

set_param([sys,'/','DEE'],...
		'position',[35,37,130,68])


%     Subsystem  'XY Graph'.

new_system([sys,'/','XY Graph'])
set_param([sys,'/','XY Graph'],'Location',[8,52,282,245])

add_block('built-in/S-Function',[sys,'/',['XY Graph/S-function',13,'M-file which plots',13,'lines',13,'']])
set_param([sys,'/',['XY Graph/S-function',13,'M-file which plots',13,'lines',13,'']],...
		'function name','sfunxy',...
		'parameters','ax, st',...
		'position',[185,70,235,90])

add_block('built-in/Mux',[sys,'/','XY Graph/Mux'])
set_param([sys,'/','XY Graph/Mux'],...
		'inputs','2',...
		'position',[100,61,130,94])

add_block('built-in/Inport',[sys,'/','XY Graph/x'])
set_param([sys,'/','XY Graph/x'],...
		'position',[10,30,30,50])

add_block('built-in/Inport',[sys,'/','XY Graph/y'])
set_param([sys,'/','XY Graph/y'],...
		'Port','2',...
		'position',[10,100,30,120])
add_line([sys,'/','XY Graph'],[135,80;180,80])
add_line([sys,'/','XY Graph'],[35,40;70,40;70,70;95,70])
add_line([sys,'/','XY Graph'],[35,110;70,110;70,85;95,85])
set_param([sys,'/','XY Graph'],...
		'Mask Display','plot(0,0,100,100,[12,91,91,12,12],[90,90,45,45,90],[51,57,65,75,80,79,75,67,60,54,51,48,42,34,28,27,31,42,51],[71,68,66,66,72,79,83,84,81,77,71,60,54,54,58,65,71,74,71])')
set_param([sys,'/','XY Graph'],...
		'Mask Type','XY scope.',...
		'Mask Dialogue','XY scope using MATLAB graph window.\nFirst input is used as time base.\nEnter plotting ranges.|x-min|x-max|y-min|y-max|Sample Time')
set_param([sys,'/','XY Graph'],...
		'Mask Translate','ax = [@1, @2, @3, @4];st=@5;',...
		'Mask Help','This block can be used to explore limit cycles. Look at the m-file sfunxy.m to see how it works.',...
		'Mask Entries','-30\/30\/0\/50\/.025\/')


%     Finished composite block 'XY Graph'.

set_param([sys,'/','XY Graph'],...
		'position',[190,38,210,67])
add_line(sys,[135,45;185,45])
add_line(sys,[135,60;185,60])

drawnow

% Return any arguments.
if (nargin | nargout)
	% Must use feval here to access system in memory
	if (nargin > 3)
		if (flag == 0)
			eval(['[ret,x0,str,ts,xts]=',sys,'(t,x,u,flag);'])
		else
			eval(['ret =', sys,'(t,x,u,flag);'])
		end
	else
		[ret,x0,str,ts,xts] = feval(sys);
	end
else
	drawnow % Flash up the model and execute load callback
end
