function [ret,x0,str,ts,xts]=deedemo3(t,x,u,flag);
%DEEDEMO3	is the M-file description of the SIMULINK system named DEEDEMO3.
%	The block-diagram can be displayed by typing: DEEDEMO3.
%
%	SYS=DEEDEMO3(T,X,U,FLAG) returns depending on FLAG certain
%	system values given time point, T, current state vector, X,
%	and input vector, U.
%	FLAG is used to indicate the type of output to be returned in SYS.
%
%	Setting FLAG=1 causes DEEDEMO3 to return state derivatives, FLAG=2
%	discrete states, FLAG=3 system outputs and FLAG=4 next sample
%	time. For more information and other options see SFUNC.
%
%	Calling DEEDEMO3 with a FLAG of zero:
%	[SIZES]=DEEDEMO3([],[],[],0),  returns a vector, SIZES, which
%	contains the sizes of the state vector and other parameters.
%		SIZES(1) number of states
%		SIZES(2) number of discrete states
%		SIZES(3) number of outputs
%		SIZES(4) number of inputs
%		SIZES(5) number of roots (currently unsupported)
%		SIZES(6) direct feedthrough flag
%		SIZES(7) number of sample times
%
%	For the definition of other parameters in SIZES, see SFUNC.
%	See also, TRIM, LINMOD, LINSIM, EULER, RK23, RK45, ADAMS, GEAR.

% Note: This M-file is only used for saving graphical information;
%       after the model is loaded into memory an internal model
%       representation is used.

% the system will take on the name of this mfile:
sys = mfilename;
new_system(sys)
simver(1.3)
if (0 == (nargin + nargout))
     set_param(sys,'Location',[125,296,480,507])
     open_system(sys)
end;
set_param(sys,'algorithm',     'RK-45')
set_param(sys,'Start time',    '0.0')
set_param(sys,'Stop time',     '99999999999')
set_param(sys,'Min step size', '0.0001')
set_param(sys,'Max step size', '10')
set_param(sys,'Relative error','1e-3')
set_param(sys,'Return vars',   '')
set_param(sys,'Load callback','masspgi');

add_block('built-in/Scope',[sys,'/','x'])
set_param([sys,'/','x'],...
		'Vgain','18.000000',...
		'Hgain','100.000000',...
		'Vmax','36.000000',...
		'Hmax','200.000000',...
		'Window',[517,365,1026,508])
open_system([sys,'/','x'])
set_param([sys,'/','x'],...
		'position',[295,80,320,110])

add_block('built-in/Signal Generator',[sys,'/','F(t)'])
set_param([sys,'/','F(t)'],...
		'Peak','1.000000',...
		'Peak Range','5.000000',...
		'Freq','0.010000',...
		'Freq Range','0.050000',...
		'Wave','Sqr',...
		'Units','Rads',...
		'position',[25,88,70,122])

add_block('built-in/Note',[sys,'/','Mass on a spring with forcing function'])
set_param([sys,'/','Mass on a spring with forcing function'],...
		'position',[180,5,185,10])

add_block('built-in/Note',[sys,'/',['mx''''+a*x''+kx = F(t)']])
set_param([sys,'/',['mx''''+a*x''+kx = F(t)']],...
		'position',[124,33,129,38])


%     Subsystem  'model'.

new_system([sys,'/','model'])
set_param([sys,'/','model'],'Location',[543,167,1043,467])

add_block('built-in/Outport',[sys,'/','model/Port2'])
set_param([sys,'/','model/Port2'],...
		'Port','2',...
		'position',[400,300,420,320])

add_block('built-in/Fcn',[sys,'/','model/y2'])
set_param([sys,'/','model/y2'],...
		'Expr','u(2)',...
		'position',[300,300,330,320])

add_block('built-in/Mux',[sys,'/','model/SysMux'])
set_param([sys,'/','model/SysMux'],...
		'inputs','3',...
		'position',[100,202,150,258])

add_block('built-in/Fcn',[sys,'/','model/y1'])
set_param([sys,'/','model/y1'],...
		'Expr','u(3)',...
		'position',[300,250,330,270])

add_block('built-in/Outport',[sys,'/','model/Port1'])
set_param([sys,'/','model/Port1'],...
		'position',[400,250,420,270])

add_block('built-in/Inport',[sys,'/','model/SysInport1'])
set_param([sys,'/','model/SysInport1'],...
		'position',[20,50,40,70])

add_block('built-in/Fcn',[sys,'/','model/x1'])
set_param([sys,'/','model/x1'],...
		'Expr','(u(1)-a*u(2)-k*u(3))/m           ',...
		'position',[300,50,330,70])

add_block('built-in/Integrator',[sys,'/','model/Integ1'])
set_param([sys,'/','model/Integ1'],...
		'Initial','-1  ',...
		'position',[400,50,430,70])

add_block('built-in/Fcn',[sys,'/','model/x2'])
set_param([sys,'/','model/x2'],...
		'Expr','u(2)                             ',...
		'position',[300,100,330,120])

add_block('built-in/Integrator',[sys,'/','model/Integ2'])
set_param([sys,'/','model/Integ2'],...
		'Initial','0   ',...
		'position',[400,100,430,120])
add_line([sys,'/','model'],[45,60;65,60;65,210;95,210])
add_line([sys,'/','model'],[155,230;220,230;220,60;295,60])
add_line([sys,'/','model'],[335,60;395,60])
add_line([sys,'/','model'],[435,60;445,60;445,140;75,140;75,230;95,230])
add_line([sys,'/','model'],[155,230;220,230;220,110;295,110])
add_line([sys,'/','model'],[335,110;395,110])
add_line([sys,'/','model'],[435,110;445,110;445,145;70,145;70,250;95,250])
add_line([sys,'/','model'],[155,230;220,230;220,260;295,260])
add_line([sys,'/','model'],[335,260;395,260])
add_line([sys,'/','model'],[155,230;220,230;220,310;295,310])
add_line([sys,'/','model'],[335,310;395,310])
set_param([sys,'/','model'],...
		'Mask Display','mass_on_a_spring',...
		'Mask Type','Differential Equation Editor (DEE)',...
		'Mask Dialogue','eval(''diffeqed'')')


%     Finished composite block 'model'.

set_param([sys,'/','model'],...
		'position',[115,86,225,119])

add_block('built-in/Scope',[sys,'/','x1'])
set_param([sys,'/','x1'],...
		'Vgain','18.000000',...
		'Hgain','100.000000',...
		'Vmax','36.000000',...
		'Hmax','200.000000',...
		'Window',[518,641,1027,784])
open_system([sys,'/','x1'])
set_param([sys,'/','x1'],...
		'position',[295,130,320,160])
add_line(sys,[230,110;265,110;265,145;290,145])
add_line(sys,[230,95;290,95])
add_line(sys,[75,105;110,105])

drawnow

% Return any arguments.
if (nargin | nargout)
	% Must use feval here to access system in memory
	if (nargin > 3)
		if (flag == 0)
			eval(['[ret,x0,str,ts,xts]=',sys,'(t,x,u,flag);'])
		else
			eval(['ret =', sys,'(t,x,u,flag);'])
		end
	else
		[ret,x0,str,ts,xts] = feval(sys);
	end
else
	drawnow % Flash up the model and execute load callback
end
