function [ret,x0,str,ts,xts]=deedemo4(t,x,u,flag);
%DEEDEMO4	is the M-file description of the SIMULINK system named DEEDEMO4.
%	The block-diagram can be displayed by typing: DEEDEMO4.
%
%	SYS=DEEDEMO4(T,X,U,FLAG) returns depending on FLAG certain
%	system values given time point, T, current state vector, X,
%	and input vector, U.
%	FLAG is used to indicate the type of output to be returned in SYS.
%
%	Setting FLAG=1 causes DEEDEMO4 to return state derivatives, FLAG=2
%	discrete states, FLAG=3 system outputs and FLAG=4 next sample
%	time. For more information and other options see SFUNC.
%
%	Calling DEEDEMO4 with a FLAG of zero:
%	[SIZES]=DEEDEMO4([],[],[],0),  returns a vector, SIZES, which
%	contains the sizes of the state vector and other parameters.
%		SIZES(1) number of states
%		SIZES(2) number of discrete states
%		SIZES(3) number of outputs
%		SIZES(4) number of inputs
%		SIZES(5) number of roots (currently unsupported)
%		SIZES(6) direct feedthrough flag
%		SIZES(7) number of sample times
%
%	For the definition of other parameters in SIZES, see SFUNC.
%	See also, TRIM, LINMOD, LINSIM, EULER, RK23, RK45, ADAMS, GEAR.

% Note: This M-file is only used for saving graphical information;
%       after the model is loaded into memory an internal model
%       representation is used.

% the system will take on the name of this mfile:
sys = mfilename;
new_system(sys)
simver(1.3)
if (0 == (nargin + nargout))
     set_param(sys,'Location',[175,288,677,496])
     open_system(sys)
end;
set_param(sys,'algorithm',     'RK-45')
set_param(sys,'Start time',    '0.0')
set_param(sys,'Stop time',     '159.9')
set_param(sys,'Min step size', '0.0001')
set_param(sys,'Max step size', '10')
set_param(sys,'Relative error','1e-2')
set_param(sys,'Return vars',   '')
set_param(sys,'Load callback','deedemi4');
set_param(sys,'Real-time build command','!download $model.c $model.h')

add_block('built-in/Scope',[sys,'/','Scope1'])
set_param([sys,'/','Scope1'],...
		'Vgain','5.000000',...
		'Hgain','60.000000',...
		'Vmax','10.000000',...
		'Hmax','120.000000',...
		'Window',[634,295,914,515],...
		'position',[375,47,395,73])

add_block('built-in/Scope',[sys,'/','Scope'])
set_param([sys,'/','Scope'],...
		'Vgain','5.000000',...
		'Hgain','60.000000',...
		'Vmax','10.000000',...
		'Hmax','120.000000',...
		'Window',[637,590,917,810],...
		'position',[415,32,435,58])


%     Subsystem  'model'.

new_system([sys,'/','model'])
set_param([sys,'/','model'],'Location',[100,100,600,400])

add_block('built-in/Mux',[sys,'/','model/SysMux'])
set_param([sys,'/','model/SysMux'],...
		'inputs','5',...
		'position',[100,300,150,350])

add_block('built-in/Fcn',[sys,'/','model/y1'])
set_param([sys,'/','model/y1'],...
		'Expr','u(2)',...
		'position',[300,350,330,370])

add_block('built-in/Outport',[sys,'/','model/Port1'])
set_param([sys,'/','model/Port1'],...
		'position',[400,350,420,370])

add_block('built-in/Fcn',[sys,'/','model/y2'])
set_param([sys,'/','model/y2'],...
		'Expr','u(3)',...
		'position',[300,400,330,420])

add_block('built-in/Outport',[sys,'/','model/Port2'])
set_param([sys,'/','model/Port2'],...
		'Port','2',...
		'position',[400,400,420,420])

add_block('built-in/Inport',[sys,'/','model/SysInport1'])
set_param([sys,'/','model/SysInport1'],...
		'position',[20,50,40,70])

add_block('built-in/Fcn',[sys,'/','model/x1'])
set_param([sys,'/','model/x1'],...
		'Expr','u(4)                                    ',...
		'position',[300,50,330,70])

add_block('built-in/Integrator',[sys,'/','model/Integ1'])
set_param([sys,'/','model/Integ1'],...
		'Initial','0      ',...
		'position',[400,50,430,70])

add_block('built-in/Fcn',[sys,'/','model/x2'])
set_param([sys,'/','model/x2'],...
		'Expr','u(5)                                    ',...
		'position',[300,100,330,120])

add_block('built-in/Integrator',[sys,'/','model/Integ2'])
set_param([sys,'/','model/Integ2'],...
		'Initial','1.5    ',...
		'position',[400,100,430,120])

add_block('built-in/Fcn',[sys,'/','model/x3'])
set_param([sys,'/','model/x3'],...
		'Expr','-(k1+k2)/m1*u(2)+k2/m1*u(3)-c1*u(4)     ',...
		'position',[300,150,330,170])

add_block('built-in/Integrator',[sys,'/','model/Integ3'])
set_param([sys,'/','model/Integ3'],...
		'Initial','1.5    ',...
		'position',[400,150,430,170])

add_block('built-in/Fcn',[sys,'/','model/x4'])
set_param([sys,'/','model/x4'],...
		'Expr','k2/m2*u(2) -k2/m2*u(3)  -u(1)           ',...
		'position',[300,200,330,220])

add_block('built-in/Integrator',[sys,'/','model/Integ4'])
set_param([sys,'/','model/Integ4'],...
		'Initial','0      ',...
		'position',[400,200,430,220])
add_line([sys,'/','model'],[45,60;65,60;65,305;95,305])
add_line([sys,'/','model'],[155,325;220,325;220,60;295,60])
add_line([sys,'/','model'],[335,60;395,60])
add_line([sys,'/','model'],[435,60;445,60;445,145;75,145;75,315;95,315])
add_line([sys,'/','model'],[155,325;220,325;220,110;295,110])
add_line([sys,'/','model'],[335,110;395,110])
add_line([sys,'/','model'],[435,110;445,110;445,180;70,180;70,325;95,325])
add_line([sys,'/','model'],[155,325;220,325;220,160;295,160])
add_line([sys,'/','model'],[335,160;395,160])
add_line([sys,'/','model'],[435,160;445,160;445,240;65,240;65,335;95,335])
add_line([sys,'/','model'],[155,325;220,325;220,210;295,210])
add_line([sys,'/','model'],[335,210;395,210])
add_line([sys,'/','model'],[435,210;445,210;445,245;60,245;60,345;95,345])
add_line([sys,'/','model'],[155,325;220,325;220,360;295,360])
add_line([sys,'/','model'],[335,360;395,360])
add_line([sys,'/','model'],[155,325;220,325;220,410;295,410])
add_line([sys,'/','model'],[335,410;395,410])
set_param([sys,'/','model'],...
		'Mask Display','damped \nmass/spring\n  system',...
		'Mask Type','Differential Equation Editor (DEE)',...
		'Mask Dialogue','eval(''diffeqed'')')


%     Finished composite block 'model'.

set_param([sys,'/','model'],...
		'position',[160,35,270,70])

add_block('built-in/S-Function',[sys,'/','Animation'])
set_param([sys,'/','Animation'],...
		'BackGround',7,...
		'function name','dee4plt',...
		'parameters','1',...
		'Mask Display','Animation',...
		'Mask Dialogue','eval(''global Handles; Handles = dee4plti;'');',...
		'position',[395,103,470,137])

add_block('built-in/Note',[sys,'/','Coupled Masses and Springs with Damping'])
set_param([sys,'/','Coupled Masses and Springs with Damping'],...
		'position',[225,5,230,10])

add_block('built-in/Note',[sys,'/',['The color of the blocks indicate',13,'position in the x direction. ',13,'']])
set_param([sys,'/',['The color of the blocks indicate',13,'position in the x direction. ',13,'']],...
		'position',[394,163,399,168])

add_block('built-in/Signal Generator',[sys,'/','Signal Gen.'])
set_param([sys,'/','Signal Gen.'],...
		'Peak','2.000000',...
		'Peak Range','10.000000',...
		'Freq','4.860000',...
		'Freq Range','6.000000',...
		'Wave','Sin',...
		'Units','Rads',...
		'position',[10,40,60,70])

add_block('built-in/Mux',[sys,'/','Mux'])
set_param([sys,'/','Mux'],...
		'inputs','3',...
		'position',[335,102,365,138])
add_line(sys,[275,60;370,60])
add_line(sys,[275,45;410,45])
add_line(sys,[370,120;390,120])
add_line(sys,[320,45;330,110])
add_line(sys,[65,55;155,55])
add_line(sys,[295,60;295,120;330,120])
add_line(sys,[135,55;135,90;260,90;260,130;330,130])

drawnow

% Return any arguments.
if (nargin | nargout)
	% Must use feval here to access system in memory
	if (nargin > 3)
		if (flag == 0)
			eval(['[ret,x0,str,ts,xts]=',sys,'(t,x,u,flag);'])
		else
			eval(['ret =', sys,'(t,x,u,flag);'])
		end
	else
		[ret,x0,str,ts,xts] = feval(sys);
	end
else
	drawnow % Flash up the model and execute load callback
end
