function [ret,x0,str,ts,xts]=dff(t,x,u,flag);
%DFF	is the M-file description of the SIMULINK system named DFF.
%	The block-diagram can be displayed by typing: DFF.

%	D-FlipFlop model created in February 1996 by:
%	Paul Popescu
%	Telecommunications and Signal Processing Laboratory
%	McGill University
%	3480 University st. Rm.751
%	Montreal, Quebec, Canada  H3A 2A7
%	Phone: (514)398-5486
%	e-mail: popescu@tsp.ee.mcgill.ca	

%	SYS=DFF(T,X,U,FLAG) returns depending on FLAG certain
%	system values given time point, T, current state vector, X,
%	and input vector, U.
%	FLAG is used to indicate the type of output to be returned in SYS.
%
%	Setting FLAG=1 causes DFF to return state derivatives, FLAG=2
%	discrete states, FLAG=3 system outputs and FLAG=4 next sample
%	time. For more information and other options see SFUNC.
%
%	Calling DFF with a FLAG of zero:
%	[SIZES]=DFF([],[],[],0),  returns a vector, SIZES, which
%	contains the sizes of the state vector and other parameters.
%		SIZES(1) number of states
%		SIZES(2) number of discrete states
%		SIZES(3) number of outputs
%		SIZES(4) number of inputs
%		SIZES(5) number of roots (currently unsupported)
%		SIZES(6) direct feedthrough flag
%		SIZES(7) number of sample times
%
%	For the definition of other parameters in SIZES, see SFUNC.
%	See also, TRIM, LINMOD, LINSIM, EULER, RK23, RK45, ADAMS, GEAR.

% Note: This M-file is only used for saving graphical information;
%       after the model is loaded into memory an internal model
%       representation is used.

% the system will take on the name of this mfile:
sys = mfilename;
new_system(sys)
simver(1.3)
if (0 == (nargin + nargout))
     set_param(sys,'Location',[100,100,600,400])
     open_system(sys)
end;
set_param(sys,'algorithm',     'RK-45')
set_param(sys,'Start time',    '0.0')
set_param(sys,'Stop time',     '999999')
set_param(sys,'Min step size', '0.0001')
set_param(sys,'Max step size', '10')
set_param(sys,'Relative error','1e-3')
set_param(sys,'Return vars',   '')


%     Subsystem  'D-FF'.

new_system([sys,'/','D-FF'])
set_param([sys,'/','D-FF'],'Location',[-30,24576133,527,24576398])

add_block('built-in/Relational Operator',[sys,'/',['D-FF/Relational',13,'Operator']])
set_param([sys,'/',['D-FF/Relational',13,'Operator']],...
		'Operator','<=',...
		'position',[115,123,145,147])

add_block('built-in/Constant',[sys,'/','D-FF/Constant1'])
set_param([sys,'/','D-FF/Constant1'],...
		'Value','0',...
		'position',[70,180,90,200])

add_block('built-in/Memory',[sys,'/','D-FF/Memory2'])
set_param([sys,'/','D-FF/Memory2'],...
		'position',[200,185,240,215])

add_block('built-in/Switch',[sys,'/','D-FF/Switch1'])
set_param([sys,'/','D-FF/Switch1'],...
		'Threshold','0.1',...
		'position',[180,114,210,146])

add_block('built-in/Memory',[sys,'/','D-FF/Memory1'])
set_param([sys,'/','D-FF/Memory1'],...
		'position',[245,115,285,145])

add_block('built-in/Switch',[sys,'/','D-FF/Switch'])
set_param([sys,'/','D-FF/Switch'],...
		'Threshold','0.1',...
		'position',[370,114,400,146])

add_block('built-in/Memory',[sys,'/','D-FF/Memory'])
set_param([sys,'/','D-FF/Memory'],...
		'position',[435,115,475,145])

add_block('built-in/Inport',[sys,'/','D-FF/in_1'])
set_param([sys,'/','D-FF/in_1'],...
		'position',[105,60,125,80])

add_block('built-in/Outport',[sys,'/','D-FF/out_1'])
set_param([sys,'/','D-FF/out_1'],...
		'position',[525,120,545,140])

add_block('built-in/Inport',[sys,'/','D-FF/in_2'])
set_param([sys,'/','D-FF/in_2'],...
		'Port','2',...
		'position',[40,120,60,140])
add_line([sys,'/','D-FF'],[480,130;495,130;495,165;350,165;350,140;365,140])
add_line([sys,'/','D-FF'],[495,130;520,130])
add_line([sys,'/','D-FF'],[150,135;155,135;155,130;175,130])
add_line([sys,'/','D-FF'],[245,200;332,200;332,130;365,130])
add_line([sys,'/','D-FF'],[65,130;110,130])
add_line([sys,'/','D-FF'],[80,130;80,165;110,165;110,200;195,200])
add_line([sys,'/','D-FF'],[95,190;100,190;110,140])
add_line([sys,'/','D-FF'],[130,70;145,70;145,120;175,120])
add_line([sys,'/','D-FF'],[290,130;315,130;315,165;160,165;160,140;175,140])
add_line([sys,'/','D-FF'],[315,130;315,120;365,120])
add_line([sys,'/','D-FF'],[215,130;240,130])
add_line([sys,'/','D-FF'],[405,130;430,130])
set_param([sys,'/','D-FF'],...
		'Mask Display','D    \n\n    Q\n\nCK    ',...
		'Mask Type','D flip-flop',...
		'Mask Dialogue','D flip-flop|Initial State for Output "1":',...
		'Mask Translate','ini=(@1~=0);')
set_param([sys,'/','D-FF'],...
		'Mask Help','When the clock signal is high, if the uncomp- lemented output is currently zero and J becomes one, the output will change to one.  K has no effect on the output in this case.  If the current value of the uncomplemented output is one and K becomes one, the output will change to zero.  J will have no effect on the output in this case.  The system clock period is used to set the state feedback delay of the flip-flop.')
set_param([sys,'/','D-FF'],...
		'Mask Entries','0\/')


%     Finished composite block 'D-FF'.

set_param([sys,'/','D-FF'],...
		'position',[205,81,250,154])

drawnow

% Return any arguments.
if (nargin | nargout)
	% Must use feval here to access system in memory
	if (nargin > 3)
		if (flag == 0)
			eval(['[ret,x0,str,ts,xts]=',sys,'(t,x,u,flag);'])
		else
			eval(['ret =', sys,'(t,x,u,flag);'])
		end
	else
		[ret,x0,str,ts,xts] = feval(sys);
	end
else
	drawnow % Flash up the model and execute load callback
end

