function [ret,x0,str]=divider(t,x,u,flag);
%DIVIDER	is the M-file description of the SIMULINK system named DIVIDER.
%	The block-diagram can be displayed by typing: DIVIDER.
%
%	SYS=DIVIDER(T,X,U,FLAG) returns depending on FLAG certain
%	system values given time point, T, current state vector, X,
%	and input vector, U.
%	FLAG is used to indicate the type of output to be returned in SYS.
%
%	Setting FLAG=1 causes DIVIDER to return state derivatives, FLAG=2
%	discrete states, FLAG=3 system outputs and FLAG=4 next sample
%	time. For more information and other options see SFUNC.
%
%	Calling DIVIDER with a FLAG of zero:
%	[SIZES]=DIVIDER([],[],[],0),  returns a vector, SIZES, which
%	contains the sizes of the state vector and other parameters.
%		SIZES(1) number of states
%		SIZES(2) number of discrete states
%		SIZES(3) number of outputs
%		SIZES(4) number of inputs.
%	For the definition of other parameters in SIZES, see SFUNC.
%	See also, TRIM, LINMOD, LINSIM, EULER, RK23, RK45, ADAMS, GEAR.

% Note: This M-file is only used for saving graphical information;
%       after the model is loaded into memory an internal model
%       representation is used.

% the system will take on the name of this mfile:
sys = mfilename;
new_system(sys)
simver(1.2)
if(0 == (nargin + nargout))
     set_param(sys,'Location',[19,76,386,280])
     open_system(sys)
end;
set_param(sys,'algorithm',     'Euler')
set_param(sys,'Start time',    '0.0')
set_param(sys,'Stop time',     '999999')
set_param(sys,'Min step size', '0.0001')
set_param(sys,'Max step size', '.10')
set_param(sys,'Relative error','1e-3')
set_param(sys,'Return vars',   '')

add_block('built-in/Mux',[sys,'/','Mux'])
set_param([sys,'/','Mux'],...
		'inputs','3',...
		'position',[120,34,150,66])

add_block('built-in/Mux',[sys,'/','Mux1'])
set_param([sys,'/','Mux1'],...
		'hide name',0,...
		'inputs','3',...
		'position',[120,129,150,161])

add_block('built-in/Constant',[sys,'/','Constant'])
set_param([sys,'/','Constant'],...
		'hide name',0,...
		'position',[50,104,75,126])

add_block('built-in/Constant',[sys,'/','Constant1'])
set_param([sys,'/','Constant1'],...
		'hide name',0,...
		'Value','2',...
		'position',[50,134,75,156])

add_block('built-in/Constant',[sys,'/','Constant2'])
set_param([sys,'/','Constant2'],...
		'hide name',0,...
		'Value','3',...
		'position',[50,164,75,186])

add_block('built-in/Sine Wave',[sys,'/','Sine Wave'])
set_param([sys,'/','Sine Wave'],...
		'position',[55,40,75,60])


%     Subsystem  'Divider'.

new_system([sys,'/','Divider'])
set_param([sys,'/','Divider'],'Location',[29,358,360,502])
open_system([sys,'/','Divider'])

add_block('built-in/Mux',[sys,'/','Divider/Mux2'])
set_param([sys,'/','Divider/Mux2'],...
		'inputs','[lu lu]',...
		'position',[75,50,105,85])

add_block('built-in/Inport',[sys,'/','Divider/in_2'])
set_param([sys,'/','Divider/in_2'],...
		'Port','2',...
		'position',[15,80,35,100])

add_block('built-in/Inport',[sys,'/','Divider/in_1'])
set_param([sys,'/','Divider/in_1'],...
		'position',[15,30,35,50])

add_block('built-in/Outport',[sys,'/','Divider/Out'])
set_param([sys,'/','Divider/Out'],...
		'position',[300,50,320,70])

add_block('built-in/MATLAB Fcn',[sys,'/','Divider/MATLAB Fcn'])
set_param([sys,'/','Divider/MATLAB Fcn'],...
		'MATLAB Fcn','div',...
		'position',[125,48,205,92])

add_block('built-in/Demux',[sys,'/','Divider/Demux'])
set_param([sys,'/','Divider/Demux'],...
		'outputs','[lu lu]',...
		'position',[230,50,270,85])
add_line([sys,'/','Divider'],[210,70;220,70])
add_line([sys,'/','Divider'],[110,70;115,70])
add_line([sys,'/','Divider'],[275,60;290,60])
add_line([sys,'/','Divider'],[40,40;50,40;50,60;65,60])
add_line([sys,'/','Divider'],[40,90;50,90;50,75;65,75])
set_param([sys,'/','Divider'],...
		'Mask Display','/',...
		'Mask Type','Divider',...
		'Mask Dialogue','Divider:|Input Width',...
		'Mask Translate','lu=@1;')
set_param([sys,'/','Divider'],...
		'Mask Help','Implements a divider block.  The output is the input 1 divided
by input 2.',...
		'Mask Entries','3\/')


%     Finished composite block 'Divider'.

set_param([sys,'/','Divider'],...
		'position',[210,60,250,140])

add_block('built-in/Scope',[sys,'/','Scope'])
set_param([sys,'/','Scope'],...
		'Vgain','1.000000',...
		'Hgain','11.000000',...
		'Vmax','2.000000',...
		'Hmax','22.000000',...
		'Window',[724,627,1004,847])
open_system([sys,'/','Scope'])
set_param([sys,'/','Scope'],...
		'position',[295,87,315,113])
add_line(sys,[80,50;110,50])
add_line(sys,[80,50;110,60])
add_line(sys,[80,115;110,135])
add_line(sys,[80,145;110,145])
add_line(sys,[80,175;110,155])
add_line(sys,[155,50;165,50;165,80;200,80])
add_line(sys,[155,145;165,145;165,120;200,120])
add_line(sys,[255,100;285,100])
add_line(sys,[80,50;110,40])

% Return any arguments.
if (nargin | nargout)
	% Must use feval here to access system in memory
	if (nargin > 3)
		if (flag == 0)
			eval(['[ret,x0,str]=',sys,'(t,x,u,flag);'])
		else
			eval(['ret =', sys,'(t,x,u,flag);'])
		end
	else
		[ret,x0,str] = feval(sys);
	end
end
