function [ret,x0,str,ts,xts]=dpmblock(t,x,u,flag);
%DPMBLOCK	is the M-file description of the SIMULINK system named DPMBLOCK.
%	The block-diagram can be displayed by typing: DPMBLOCK.
%
%	SYS=DPMBLOCK(T,X,U,FLAG) returns depending on FLAG certain
%	system values given time point, T, current state vector, X,
%	and input vector, U.
%	FLAG is used to indicate the type of output to be returned in SYS.
%
%	Setting FLAG=1 causes DPMBLOCK to return state derivatives, FLAG=2
%	discrete states, FLAG=3 system outputs and FLAG=4 next sample
%	time. For more information and other options see SFUNC.
%
%	Calling DPMBLOCK with a FLAG of zero:
%	[SIZES]=DPMBLOCK([],[],[],0),  returns a vector, SIZES, which
%	contains the sizes of the state vector and other parameters.
%		SIZES(1) number of states
%		SIZES(2) number of discrete states
%		SIZES(3) number of outputs
%		SIZES(4) number of inputs
%		SIZES(5) number of roots (currently unsupported)
%		SIZES(6) direct feedthrough flag
%		SIZES(7) number of sample times
%
%	For the definition of other parameters in SIZES, see SFUNC.
%	See also, TRIM, LINMOD, LINSIM, EULER, RK23, RK45, ADAMS, GEAR.

% Note: This M-file is only used for saving graphical information;
%       after the model is loaded into memory an internal model
%       representation is used.

% the system will take on the name of this mfile:
sys = mfilename;
new_system(sys)
simver(1.3)
if (0 == (nargin + nargout))
     set_param(sys,'Location',[160,401,336,532])
     open_system(sys)
end;
set_param(sys,'algorithm',     'RK-45')
set_param(sys,'Start time',    '0.0')
set_param(sys,'Stop time',     '999999')
set_param(sys,'Min step size', '0.0001')
set_param(sys,'Max step size', '10')
set_param(sys,'Relative error','1e-3')
set_param(sys,'Return vars',   '')


%     Subsystem  'dpmeter'.

new_system([sys,'/','dpmeter'])
set_param([sys,'/','dpmeter'],'Location',[264,271,424,391])

add_block('built-in/Inport',[sys,'/','dpmeter/in_1'])
set_param([sys,'/','dpmeter/in_1'],...
		'position',[15,55,35,75])

add_block('built-in/S-Function',[sys,'/','dpmeter/DPM'])
set_param([sys,'/','dpmeter/DPM'],...
		'function name','dpmeter',...
		'parameters','num,on',...
		'position',[65,57,110,73])
add_line([sys,'/','dpmeter'],[40,65;60,65])
set_param([sys,'/','dpmeter'],...
		'Mask Display','Meter',...
		'Mask Type','Digital Panel Meter',...
		'Mask Dialogue','Running numerical display of a variable.|Meter ON=1, OFF=0:|Time steps between updates (N):')
set_param([sys,'/','dpmeter'],...
		'Mask Translate','on=@1;num=max(fix(abs(@2)),1);')
set_param([sys,'/','dpmeter'],...
		'Mask Help','A signal, its Max, and its Min are displayed by this block in a Handle Graphics window. The display is updated whenever, Max or Min changes or every N integration steps.This block is a masked S-function that calls the M-file DPMETER.M.')
set_param([sys,'/','dpmeter'],...
		'Mask Entries','1\/5\/')


%     Finished composite block 'dpmeter'.

set_param([sys,'/','dpmeter'],...
		'position',[70,50,110,70])

drawnow

% Return any arguments.
if (nargin | nargout)
	% Must use feval here to access system in memory
	if (nargin > 3)
		if (flag == 0)
			eval(['[ret,x0,str,ts,xts]=',sys,'(t,x,u,flag);'])
		else
			eval(['ret =', sys,'(t,x,u,flag);'])
		end
	else
		[ret,x0,str,ts,xts] = feval(sys);
	end
else
	drawnow % Flash up the model and execute load callback
end
