function [sys,x0]=dpmeter(t,x,u,flag,num,on)
%DPMETER S-Function Digital Panel Meter using a figure window.
%
% This M-file is designed to be used in a SIMULINK S-Function block.
% It displays the input signal and time as text in a figure window.
% It also displays the max and min values of the input and their
% associated time of occurances.

% D.C. Hanselman, University of Maine, Orono, ME 04469
% duaneh@eece.maine.edu
% modified 1/12/96

if ~on&flag==0				% initialization with meter OFF
	sys=[0 2 0 1 0 0];
	x0=[0 0];
	
elseif ~on&flag==2			% simulation is running with meter OFF
	sys=x;
	
elseif flag==0				% initialization with meter ON

	csys=get_param;			% get current system name
	i=find('/'==csys);
	figname=csys(i(1)+1:length(csys)); % name for meter title bar

	
	ch=findobj(0,'type','figure');	% see if figure window already exists, if so, use it
%	ch=get(0,'Children');	% this works for versions earlier than 4.2

	hcf=[];					% handle for current figure
	for fh=1:length(ch)		% check all figures for a match in title bar name
		if strcmp(get(ch(fh),'Name'),figname)	% got it
			hcf=ch(fh);hui=get(hcf,'Children');
			maxmin=[-inf 0;inf 0];	% data structure for [max tmax; min tmin]
			set(hui,'Userdata',maxmin); % reset data
			break
		end
	end
	
	if isempty(hcf)			% no current matching figure, so make one
		syspos=get_param(csys(1:i(1)-1),'Location');	% simulink system position
		blkpos=get_param(csys,'Position');				% meter postion within system
		dpmpos=syspos([3 2 2 2])+[10 blkpos(2:4)];		% simulink position for meter
		
		sunits=get(0,'Units');		% convert simulink position vector to matlab orientation
		set(0,'Units','pixels')		% set screen units
		ssize=get(0,'Screensize');	% get screensize in pixels
		set(0,'Units',sunits);		% set screen units back to original
		
		% SIZE of Meter Figure Window (adjust as necessary)
		DPM_width=240; % pixels
		DPM_height=50;
		
		msyspos=[min(dpmpos(1),ssize(3)-200) max(ssize(4)-dpmpos(4),1) ...
			DPM_width DPM_height];	% matlab position for meter
		
		if strcmp(computer,'MAC2'), mbar='figure';
		else, mbar='none';	% no menubar on meter if not Macintosh
		end
		
		hcf=figure(	'Name',figname,...
					'NumberTitle','off',...
					'Menubar',mbar,...
					'Resize','off',...
					'units','pixel',...
					'Position',msyspos,...
					'Nextplot','new',...
					'Backingstore','off');

		maxmin=[-inf 0;inf 0];	% data structure for [max tmax; min tmin]
		hui=uicontrol(hcf,	'style','edit',...
							'units','normal',...
							'Position',[0 0 1 1],...
							'Min',0,'Max',3,...
							'Userdata',maxmin);
	end
	sys=[0 2 0 1 0 0];
	x0=[hui;0];	% store data [handle;count] in states for future calls
	
elseif abs(flag)==2			% simulation is running with meter ON
		
	x(2)=x(2)+1;
	uflag=0;
	maxmin=get(x(1),'Userdata'); % check for max and min values
	if u>maxmin(1,1)
		maxmin(1,:)=[u t];
		uflag=1;
	end
	if u<maxmin(2,1)
		maxmin(2,:)=[u t];
		uflag=1;
	end
	if uflag|rem(x(2),num)==0
		dpmstr=sprintf('max = %.4g   t = %.4g|input = %.4g   t = %.4g|min = %.4g   t = %.4g',...
						maxmin(1,:),u,t,maxmin(2,:) );
		set(x(1),	'string',dpmstr,...
					'Userdata',maxmin);
	end
	sys=x;
else
	sys=[];
end
