      SUBROUTINE DDRIVE (N,T0,H0,Y0,TOUT,EPS,IERROR,MF,INDEX,IMESS)
C THIS IS THE JUNE 24, 1975  VERSION OF
C EPISODE..  EXPERIMENTAL PACKAGE FOR INTEGRATION OF
C SYSTEMS OF ORDINARY DIFFERENTIAL EQUATIONS,
C    DY/DT = F(Y,T),  Y = (Y(1),Y(2),...,Y(N)) TRANSPOSE,
C GIVEN THE INITIAL VALUE OF Y.
C THIS CODE IS FOR THE IBM 370/195 AT ARGONNE NATIONAL LABORATORY
C AND IS A MODIFICATION OF EARLIER VERSIONS BY G.D.BYRNE
C AND A.C.HINDMARSH.
C
C Modified slightly by M. T. Eaton for use as a Matlab (R) MEX file 1993-94
C
C                 REFERENCES
C 1.  G. D. BYRNE AND A. C. HINDMARSH, A POLYALGORITHM FOR THE
C       NUMERICAL SOLUTION OF ORDINARY DIFFERENTIAL EQUATIONS,
C       UCRL-75652, LAWRENCE LIVERMORE LABORATORY, P. O. BOX 808,
C       LIVERMORE, CA 94550, APRIL 1974. ALSO IN ACM TRANSACTIONS
C       ON MATHEMATICAL SOFTWARE, 1 (1975), PP. 71-96.
C
C 2.  A. C. HINDMARSH AND G. D. BYRNE, EPISODE.. AN EXPERIMENTAL
C       PACKAGE FOR THE INTEGRATION OF SYSTEMS OF ORDINARY
C       DIFFERENTIAL EQUATIONS, UCID-30112, L.L.L., MAY, 1975.
C
C 3.  A. C. HINDMARSH, GEAR.. ORDINARY DIFFERENTIAL EQUATION
C       SYSTEM SOLVER, UCID-30001, REV. 3, L.L.L., DECEMBER, 1974.
C
C-----------------------------------------------------------------------

C DRIVE IS A DRIVER SUBROUTINE FOR THE EPISODE PACKAGE.
C DRIVE IS TO BE CALLED ONCE FOR EACH OUTPUT VALUE OF T.
C IT THEN MAKES REPEATED CALLS TO THE CORE INTEGRATOR
C SUBROUTINE, TSTEP.
C
C THE INPUT PARAMETERS ARE AS FOLLOWS.
C   N     =  THE NUMBER OF DIFFERENTIAL EQUATIONS (USED ONLY ON
C              FIRST CALL, UNLESS INDEX = -1).  N MUST NEVER BE
C              INCREASED DURING A GIVEN PROBLEM.
C   T0    =  THE INITIAL VALUE OF T, THE INDEPENDENT VARIABLE
C              (USED FOR INPUT ONLY ON FIRST CALL).
C   H0    =  THE STEP SIZE IN T (USED FOR INPUT ONLY ON THE
C              FIRST CALL, UNLESS INDEX = 3 ON INPUT).  WHEN
C              INDEX = 3, H0 IS THE MAXIMUM ABSOLUTE VALUE OF
C              THE STEP SIZE TO BE USED.
C   Y0    =  A VECTOR OF LENGTH N CONTAINING THE INITIAL VALUES OF
C              Y (USED FOR INPUT ONLY ON FIRST CALL).
C   TOUT  =  THE VALUE OF T AT WHICH OUTPUT IS DESIRED NEXT.
C              INTEGRATION WILL NORMALLY GO BEYOND TOUT AND
C              INTERPOLATE TO T = TOUT.  (USED ONLY FOR INPUT.)
C   EPS   =  THE RELATIVE ERROR BOUND (USED ONLY ON FIRST CALL,
C              UNLESS INDEX = -1).  THIS BOUND IS USED AS FOLLOWS.
C              LET R(I) DENOTE THE ESTIMATED RELATIVE LOCAL ERROR
C              IN Y(I), I.E. THE ERROR RELATIVE TO YMAX(I), AS
C              MEASURED PER STEP (OF SIZE H) OR PER SS UNITS OF T.
C              THEN EPS IS A BOUND ON THE ROOT-MEAN-SQUARE NORM
C              OF THE VECTOR R, I.E.
C                      N
C              SQRT ( SUM ( R(I)**2 )/N ) .LT. EPS.
C                     I=1
C              THE VECTOR YMAX IS COMPUTED IN DRIVE AS DESCRIBED
C              UNDER IERROR BELOW.
C              IF ERROR CONTROL PER SS UNITS OF T IS DESIRED, SET SS
C              TO A POSITIVE NUMBER AFTER STATEMENT 10 (WHERE IT IS
C              NOW SET TO ZERO) AND UPDATE IT AFTER STATEMENT 60.
C              SEE ALSO THE COMMENTS ON SS AND YMAX BELOW.
C  IERROR =  THE ERROR FLAG WITH VALUES AND MEANINGS AS FOLLOW.
C         1    ABSOLUTE ERROR IS CONTROLLED.  YMAX(I) = 1.0.
C         2    ERROR RELATIVE TO ABS(Y) IS CONTROLLED.  IF Y(I) = 0.0
C              A DIVIDE ERROR WILL OCCUR.  YMAX(I) = ABS(Y(I)).
C         3    ERROR RELATIVE TO THE LARGEST VALUE OF ABS(Y(I)) SEEN
C              SO FAR IS CONTROLLED.  IF THE INITIAL VALUE OF Y(I) IS
C              0.0, THEN YMAX(I) IS SET TO 1.0 INITIALLY AND REMAINS
C              AT LEAST 1.0.
C   MF    =  THE METHOD FLAG (USED ONLY ON FIRST CALL, UNLESS
C              INDEX = -1).  ALLOWED VALUES ARE 10, 11, 12, 13,
C              20, 21, 22, 23.  MF IS AN INTEGER WITH TWO DECIMAL
C              DIGITS, METH AND MITER (MF = 10*METH + MITER).  (MF
C              CAN BE THOUGHT OF AS THE ORDERED PAIR (METH,MITER).)
C              METH IS THE BASIC METHOD INDICATOR.
C                METH = 1 INDICATES VARIABLE-STEP SIZE, VARIABLE-
C                         ORDER ADAMS METHOD, SUITABLE FOR NON-
C                         STIFF PROBLEMS.
C                METH = 2 INDICATES VARIABLE-STEP SIZE, VARIABLE-
C                         ORDER BACKWARD DIFFERENTIATION METHOD,
C                         SUITABLE FOR STIFF PROBLEMS.
C              MITER INDICATES THE METHOD OF ITERATIVE CORRECTION
C                (NONLINEAR SYSTEM SOLUTION).
C                MITER = 0 INDICATES FUNCTIONAL ITERATION (NO
C                          PARTIAL DERIVATIVES NEEDED).
C                MITER = 1 INDICATES A CHORD OR SEMI-STATIONARY
C                          NEWTON METHOD WITH CLOSED FORM (EXACT)
C                          JACOBIAN, WHICH IS COMPUTED IN THE
C                          USER SUPPLIED SUBROUTINE
C                          PEDERV(N,T,Y,PD,N0) DESCRIBED BELOW.
C                MITER = 2 INDICATES A CHORD  OR SEMI-STATIONARY
C                          NEWTON METHOD WITH AN INTERNALLY
C                          COMPUTED FINITE DIFFERENCE APPROXIMATION
C                          TO THE JACOBIAN.
C                MITER = 3 INDICATES A CHORD OR SEMI-STATIONARY
C                          NEWTON METHOD WITH AN INTERNALLY
C                          COMPUTED DIAGONAL MATRIX APPROXIMATION
C                          TO THE JACOBIAN, BASED ON A DIRECTIONAL
C                          DERIVATIVE.
C   INDEX =  INTEGER USED ON INPUT TO INDICATE TYPE OF CALL,
C              WITH THE FOLLOWING VALUES AND MEANINGS..
C         1    THIS IS THE FIRST CALL FOR THIS PROBLEM.
C         0    THIS IS NOT THE FIRST CALL FOR THIS PROBLEM,
C              AND INTEGRATION IS TO CONTINUE.
C        -1    THIS IS NOT THE FIRST CALL FOR THE PROBLEM,
C              AND THE USER HAS RESET N, EPS, AND/OR MF.
C         2    SAME AS 0 EXCEPT THAT TOUT IS TO BE HIT
C              EXACTLY (NO INTERPOLATION IS DONE).
C              ASSUMES TOUT .GE. THE CURRENT T.
C         3    SAME AS 0 EXCEPT CONTROL RETURNS TO CALLING
C              PROGRAM AFTER ONE STEP.  TOUT IS IGNORED.
C            SINCE THE NORMAL OUTPUT VALUE OF INDEX IS 0,
C            IT NEED NOT BE RESET FOR NORMAL CONTINUATION.
C
C AFTER THE INITIAL CALL, IF A NORMAL RETURN OCCURRED AND A NORMAL
C CONTINUATION IS DESIRED, SIMPLY RESET TOUT AND CALL AGAIN.
C ALL OTHER PARAMETERS WILL BE READY FOR THE NEXT CALL.
C A CHANGE OF PARAMETERS WITH INDEX = -1 CAN BE MADE AFTER
C EITHER A SUCCESSFUL OR AN UNSUCCESSFUL RETURN.
C
C THE OUTPUT PARAMETERS ARE AS FOLLOWS.
C   T0    =  THE OUTPUT VALUE OF T.  IF INTEGRATION WAS SUCCESSFUL,
C            T0 = TOUT.  OTHERWISE, T0 IS THE LAST VALUE OF T
C            REACHED SUCCESSFULLY.
C   H0    =  THE STEP SIZE H USED LAST, WHETHER SUCCESSFULLY OR NOT.
C   Y0    =  THE COMPUTED VALUES OF Y AT T = T0.
C   INDEX =  INTEGER USED ON OUTPUT TO INDICATE RESULTS,
C              WITH THE FOLLOWING VALUES AND MEANINGS..
C         0    INTEGRATION WAS COMPLETED TO TOUT OR BEYOND.
C        -1    THE INTEGRATION WAS HALTED AFTER FAILING TO PASS THE
C              ERROR TEST EVEN AFTER REDUCING H BY A FACTOR OF
C              1.E10 FROM ITS INITIAL VALUE.
C        -2    AFTER SOME INITIAL SUCCESS, THE INTEGRATION WAS
C              HALTED EITHER BY REPEATED ERROR TEST FAILURES OR
C              BY A TEST ON EPS.  POSSIBLY TOO MUCH ACCURACY HAS
C              BEEN REQUESTED, OR A BAD CHOICE OF MF WAS MADE.
C        -3    THE INTEGRATION WAS HALTED AFTER FAILING TO ACHIEVE
C              CORRECTOR CONVERGENCE EVEN AFTER REDUCING H BY A
C              FACTOR OF 1.E10 FROM ITS INITIAL VALUE.
C        -4    IMMEDIATE HALT BECAUSE OF ILLEGAL VALUES OF INPUT
C              PARAMETERS.  SEE PRINTED MESSAGE.
C        -5    INDEX WAS -1 ON INPUT, BUT THE DESIRED CHANGES OF
C              PARAMETERS WERE NOT IMPLEMENTED BECAUSE TOUT
C              WAS NOT BEYOND T.  INTERPOLATION TO T = TOUT WAS
C              PERFORMED AS ON A NORMAL RETURN.  TO CONTINUE,
C              SIMPLY CALL AGAIN WITH INDEX = -1 AND A NEW TOUT.
C        -6    INDEX WAS 2 ON INPUT, BUT TOUT WAS NOT BEYOND T.
C              NO ACTION WAS TAKEN.
C
C IN ADDITION TO DRIVE, THE FOLLOWING SUBROUTINES ARE USED BY AND
C PROVIDED IN THIS PACKAGE:
C   INTERP(TOUT,Y,N0,Y0)  INTERPOLATES TO GIVE OUTPUT VALUES AT
C                         T = TOUT  BY USING DATA IN THE Y ARRAY.
C   TSTEP(Y,N0)  IS THE CORE INTEGRATION SUBROUTINE, WHICH INTEGRATES
C                OVER A SINGLE STEP AND DOES ASSOCIATED ERROR
C                CONTROL.
C   COSET  SETS COEFFICIENTS FOR USE IN TSTEP.
C   ADJUST(Y,N0)  ADJUSTS THE HISTORY ARRAY Y ON REDUCTION OF ORDER.
C   PSET(Y,N0,CON,MITER,IER)  COMPUTES AND PROCESSES THE JACOBIAN
C                             MATRIX, J = DF/DY.
C   DEC(N,N0,A,IP,IER)  PERFORMS THE LU DECOMPOSITION OF A MATRIX.
C   SOL(N,N0,A,B,IP)  SOLVES A LINEAR SYSTEM A*X = B, AFTER DEC
C                       HAS BEEN CALLED FOR THE MATRIX A.
C NOTE:  PSET, DEC, AND SOL ARE CALLED IF AND ONLY IF MITER = 1
C        OR MITER = 2.
C
C THE USER MUST FURNISH THE FOLLOWING SUBROUTINES: 
C  *** For EPISODE.MEX, they are now pre-defined in episodeg.f ***
C   DIFFUN(N,T,Y,YDOT)  COMPUTES THE FUNCTION  YDOT = F(Y,T),
C                       THE RIGHT HAND SIDE OF THE ORDINARY
C                       DIFFERENTIAL EQUATION SYSTEM, WHERE Y
C                       AND YDOT ARE VECTORS OF LENGTH N.
C
C   PEDERV(N,T,Y,PD,N0)  COMPUTES THE N BY N JACOBIAN MATRIX OF
C                        PARTIAL DERIVATIVES AND STORES IT IN PD AS
C                        AN N0 BY N0 ARRAY.   PD(I,J) IS TO BE SET
C                        TO THE PARTIAL DERIVATIVE OF YDOT(I) WITH
C                        RESPECT TO Y(J).  PEDERV IS CALLED IF AND
C                        ONLY IF MITER = 1. FOR OTHER VALUES OF
C                        MITER, PEDERV CAN BE A DUMMY SUBROUTINE.
C
C NOTE!!!!  The caution below no longer applies.  The user may change
C           the maximum allowed number of equations (system states)
C           by simply changing the parameter MAX_X in the include file
C           named epi_siz_lim_defs.inc to the desired value.
C
C CAUTION:  AT THE PRESENT TIME THE MAXIMUM NUMBER OF DIFFERENTIAL
C           EQUATIONS, WHICH CAN BE SOLVED BY EPISODE, IS 20.  TO
C           CHANGE THIS NUMBER TO A NEW VALUE, SAY NMAX, CHANGE
C           Y(20,13) TO Y(NMAX,13), YMAX(20) TO YMAX(NMAX),
C           ERROR(20) TO ERROR(NMAX), SAVE1(20) TO SAVE1(NMAX),
C           SAVE2(20) TO SAVE2(NMAX), PW(400) TO PW(NMAX*NMAX),
C           AND IPIV(20) TO IPIV(NMAX) IN THE COMMON AND DIMENSION
C           STATEMENTS BELOW.  ALSO CHANGE THE ARGUMENT IN THE
C           IF...GO TO 440 STATEMENT (AFTER THE COMMON STATEMENTS)
C           FROM 20 TO NMAX.  NO OTHER CHANGES NEED TO BE MADE TO
C           ANY OTHER SUBROUTINE IN THIS PACKAGE WHEN THE MAXIMUM
C           NUMBER OF EQUATIONS IS CHANGED.  ELSEWHERE, THE COLUMN
C           LENGTH OF THE Y ARRAY IS N0 INSTEAD OF 20.  THE ROW
C           LENGTH OF Y CAN BE REDUCED FROM 13 TO 6 IF METH = 2.
C           THE ARRAY IPIV IS USED IF AND ONLY IF MITER = 1 OR
C           MITER = 2.  THE SIZE OF THE PW ARRAY CAN BE REDUCED
C           TO 1 IF MITER = 0 OR TO N IF MITER = 3.
C
C THE COMMON BLOCK EPCOM9 CAN BE ACCESSED EXTERNALLY BY THE USER,
C IF HE DESIRES.  IT CONTAINS THE STEP SIZE LAST USED SUCCESSFULLY
C (HUSED), THE ORDER LAST USED SUCCESSFULLY (NQUSED), THE
C NUMBER OF STEPS TAKEN SO FAR (NSTEP), THE NUMBER OF FUNCTION
C EVALUATIONS (DIFFUN CALLS) SO FAR (NFE), AND THE NUMBER OF
C JACOBIAN EVALUATIONS SO FAR (NJE).
C
C IN A DATA STATEMENT BELOW, LOUT IS SET TO THE LOGICAL UNIT NUMBER
C FOR THE OUTPUT OF MESSAGES DURING INTEGRATION.  CURRENTLY, LOUT
C = 5.  *** Messages are now routed to MATLAB display via dispmess() ***
C-----------------------------------------------------------------------
C
C *** For MEX file usage, DO NOT change the subroutines below 
C     back to single precision!!! ***
C
C$ THIS IS THE DOUBLE PRECISION VERSION OF SUBROUTINE DRIVE.  A
C FORTRAN PREPROCESSOR IS INCLUDED IN THIS PACKAGE TO CHANGE
C PRECISION.  THE CODE CONVRT CONVERTS FROM DOUBLE TO SINGLE
C PRECISION.   CONVERSION FROM SINGLE PRECISION TO DOUBLE
C PRECISION CAN BE DONE BY FIRST APPLYING SUBROUTINE CONVRT TO
C ITSELF AND THEN USING THAT SUBROUTINE.  THE ORDERING AND
C AND FLAGGING DESCRIBED BELOW ARE ASSUMED, THE USER MUST SET
C UROUND, AND THE PREPROCESSOR CONVERTS ONE SUBROUTINE AT A TIME.
C
C THE ORDERING AND FLAGGING ARE AS FOLLOWS.  IN EACH SUBROUTINE,
C  C$  IS USED IN COLUMNS 1 AND 2 TO FLAG A COMMENT STATING THE
C PRECISION OF THE SUBROUTINE.  IT OCCURS ONCE PER SUBROUTINE.
C LET P (AND 2*P+2) DENOTE AN INTEGER.  IMMEDIATELY AFTER A
C STATEMENT WITH  C(P  IN COLUMNS 1 THROUGH 4, THERE FOLLOWS A BLOCK
C OF P CONSECUTIVE DOUBLE PRECISION STATEMENTS.  THIS BLOCK IS
C IMMEDIATELY FOLLOWED BY A STATEMENT WITH  C)P  IN COLUMNS 1
C THROUGH 4. THE  C)P  STATEMENT IS IMMEDIATELY FOLLOWED BY A
C BLOCK OF P CONSECUTIVE SINGLE PRECISION STATEMENTS.  THIS BLOCK
C IS IMMEDIATELY FOLLOWED BY A STATEMENT WITH  C/(2*P+2)  IN
C COLUMNS 1 THROUGH 4.  IF THE CODE IS IN SINGLE PRECISION, EACH
C DOUBLE PRECISION STATEMENT HAS  CD  IN COLUMNS 1 AND 2.  IF
C IT IS IN DOUBLE PRECISION, EACH SINGLE PRECISION STATEMENT HAS
C  CS  IN COLUMNS 1 AND 2.
C
C TO CONVERT FROM DOUBLE PRECISION TO SINGLE PRECISION BY HAND,
C BY THE USERS PREPROCESSOR, OR BY AN EDITOR, SIMPLY INSERT  CD  IN
C COLUMNS 1 AND 2 OF EACH STATEMENT OF EACH BLOCK IMMEDIATELY AFTER
C A  C(P  STATEMENT AND IMMEDIATELY BEFORE A  C)P  STATEMENT.  AT
C THE SAME TIME, REPLACE  CS  BY BLANKS IN  COLUMNS 1 AND 2 OF EACH
C STATEMENT OF EACH BLOCK IMMEDIATELY AFTER A  C)P  STATEMENT AND
C IMMEDIATELY BEFORE A  C/(2*P+2)  STATEMENT.
C
C TO CONVERT FROM SINGLE PRECISION TO DOUBLE PRECISION, REPLACE
C  CD  BY BLANKS IN COLUMNS 1 AND 2 OF EACH STATEMENT IN EACH
C BLOCK IMMEDIATELY FOLLOWING A  C(P  STATEMENT AND IMMEDIATELY
C BEFORE A  C)P  STATEMENT.  AT THE SAME TIME,  INSERT  CS  IN
C COLUMNS 1 AND 2 OF EACH STATEMENT OF EACH BLOCK IMMEDIATELY
C FOLLOWING A  C)P  STATEMENT AND IMMEDIATELY BEFORE A  C/(2*P+2)
C STATEMENT.
C-----------------------------------------------------------------------
C

	INCLUDE 'epi_siz_lim_defs.inc'	! Sets size limit on state vector
	
C Of all the parameters defined in the above include file,
C only MAX_X is used.  You may safely ignore compiler warning messages that
C indicate that the other names (eg MAX_U) were defined but unused.

      INTEGER IERROR, INDEX, MF, N
      INTEGER IPIV, JSTART, KFLAG, MFC, NC, NFE, NJE,
     1        NQUSED, NSQ, NSTEP
      INTEGER I, KGO, NHCUT, N0
      INTEGER LOUT
C(6
      DOUBLE PRECISION EPS, H0, TOUT, T0, Y0
      DOUBLE PRECISION EPSC, EPSJ, ERROR, HMAX, H, HMIN, HUSED,
     1                 PW, SAVE1, SAVE2, SS, T, UROUND, YMAX
      DOUBLE PRECISION AYI, D, T0P, Y
      DOUBLE PRECISION HCUT
      DOUBLE PRECISION FOUR, HUNDRD, ONE, TEN, ZERO
C)6
CS    REAL EPS, TOUT, T0, Y0
CS    REAL EPSC, ERROR, HMAX, H, HMIN, HUSED,
CS   1     PW, SAVE1, SAVE2, SS, T, UROUND, YMAX
CS    REAL AYI, D, EPSJ, H0, T0P, Y
CS    REAL HCUT
CS    REAL FOUR, HUNDRD, ONE, TEN, ZERO
C/14
      DIMENSION Y(MAX_X,13)
      DIMENSION Y0(N)
C
      COMMON /EPCOM1/T,H,HMIN,HMAX,EPSC,SS,UROUND,NC,MFC,KFLAG,JSTART
      COMMON /EPCOM2/ YMAX(MAX_X)
      COMMON /EPCOM3/ ERROR(MAX_X)
      COMMON /EPCOM4/ SAVE1(MAX_X)
      COMMON /EPCOM5/ SAVE2(MAX_X)
      COMMON /EPCOM6/ PW(MAX_X*MAX_X)
      COMMON /EPCOM7/ IPIV(MAX_X)
      COMMON /EPCOM8/ EPSJ,NSQ
      COMMON /EPCOM9/ HUSED,NQUSED,NSTEP,NFE,NJE
	COMMON/ SAVEME1/ N0, NHCUT, T0P, Y

C *** NOTE: the DDRIVE subroutine assumed that ALL variables were static.
C           For platforms that allocate local variables dynamically, the
C           common block SAVEME1 holds those variables that must actually
C           be static for proper opperation.  THIS LIST MAY BE INCOMPLETE
C           AND/OR CONTAIN EXTRANEOUS MEMBERS!

C
      DATA LOUT /5/
C(3
      DATA HCUT /0.1D0/
      DATA FOUR /4.0D0/, HUNDRD /1.0D2/, ONE  /1.0D0/,
     1     TEN  /1.0D1/, ZERO   /0.0D0/
C)3
CS    DATA HCUT /0.1E0/
CS    DATA FOUR /4.0E0/, HUNDRD /1.0E2/, ONE  /1.0E0/,
CS   1     TEN  /1.0E1/, ZERO   /0.0E0/
C/8
      INTEGER MAXLINES, NO_OF_LINES, IMESS       ! define variables for dispmess routine
	  CHARACTER*80   EPISODEMESSAGE(10)
      MAXLINES = 10
   	  
      IF (INDEX .EQ. 0) GO TO 20
      IF (INDEX .EQ. 2) GO TO 25
      IF (INDEX .EQ. -1) GO TO 30
      IF (INDEX .EQ. 3) GO TO 40
      IF (INDEX .NE. 1) GO TO 430
      IF (EPS .LE. ZERO) GO TO 400
      IF (N .LE. 0) GO TO 410
      IF (N .GT. MAX_X) GO TO 440
      IF ((T0-TOUT)*H0 .GE. ZERO) GO TO 420
C-----------------------------------------------------------------------
C IF INITIAL VALUES FOR YMAX OTHER THAN THOSE BELOW ARE DESIRED,
C THEY SHOULD BE SET HERE.  ALL YMAX(I) MUST BE POSITIVE.  IF
C VALUES FOR HMIN OR HMAX, THE BOUNDS ON THE ABSOLUTE VALUE OF H,
C OTHER THAN THOSE BELOW, ARE DESIRED, THEY ALSO SHOULD BE SET HERE.
C IF ERROR PER SS UNITS OF T IS TO BE CONTROLLED, SS SHOULD BE SET
C TO A POSITIVE VALUE BELOW.  ERROR PER UNIT STEP IS CONTROLLED
C WHEN SS = 1.  THE DEFAULT VALUE FOR SS IS 0 AND YIELDS CONTROL
C OF ERROR PER STEP.
C-----------------------------------------------------------------------
C SET UROUND, THE MACHINE ROUNDOFF CONSTANT, HERE.
C USE STATEMENT BELOW FOR SHORT PRECISION ON IBM 360 OR 370.
C     UROUND = 9.53674E-7
C USE STATEMENT BELOW FOR SINGLE PRECISION ON CDC 7600 OR 6600.
C     UROUND = 7.105427406E-15
C USE STATEMENT BELOW FOR LONG PRECISION ON IBM 360 OR 370.
C     UROUND = 2.220446047D-16
C USE STATEMENT BELOW FOR SINGLE PRECISION ON PDP 11/55
C     UROUND = 0.59605E-07
C USE STATEMENT BELOW FOR DOUBLE PRECISION ON PDP 11/55
C     UROUND = 0.13877778781D-16
C USE STATEMENT BELOW FOR MAC II MATLAB
C-----------------------------------------------------------------------
	   UROUND = 2.2204D-16
      DO 10 I = 1,N
        GO TO (5, 6, 7), IERROR
C IERROR   =   1, 2, 3  ------------------------------------------------
  5     YMAX(I) = ONE
        GO TO 10
C(3
  6     YMAX(I) = DABS(Y0(I))
        GO TO 10
  7     YMAX(I) = DABS(Y0(I))
C)3
CS6     YMAX(I) = ABS(Y0(I))
CS      GO TO 10
CS7     YMAX(I) = ABS(Y0(I))
C/8
        IF (YMAX(I) .EQ. ZERO) YMAX(I) = ONE
 10     Y(I,1) = Y0(I)
      NC = N
      T = T0
      H = H0
	  IF ((T+H) .EQ. T) THEN 
	  		WRITE(EPISODEMESSAGE,15) T
	  		NO_OF_LINES = 4
	  		CALL DISPMESS(EPISODEMESSAGE, NO_OF_LINES, MAXLINES)
	   END IF		
 15   FORMAT(/46H---  MESSAGE FROM SUBROUTINE DRIVE IN EPISODE,,
     1       24H THE O.D.E. SOLVER.  ---/22H WARNING.. T + H = T =,
     2       E18.8,18H IN THE NEXT STEP./)
C(2
      HMIN = DABS(H0)
      HMAX = DABS(T0 - TOUT)*TEN
C)2
CS    HMIN = ABS(H0)
CS    HMAX = ABS(T0 - TOUT)*TEN
C/6
      EPSC = EPS
      MFC = MF
      JSTART = 0
      SS = ZERO
      N0 = N
      NSQ = N0*N0
C(1
      EPSJ = DSQRT(UROUND)
C)1
CS    EPSJ = SQRT(UROUND)
C/4
      NHCUT = 0
      GO TO 50
C T0P IS THE PREVIOUS OUTPUT VALUE OF T0 FOR USE IN HMAX. --------------
C(3
  20  HMAX = DABS(TOUT - T0P)*TEN
      GO TO 80
  25  HMAX = DABS(TOUT - T0P)*TEN
C)3
CS20  HMAX = ABS(TOUT - T0P)*TEN
CS    GO TO 80
CS25  HMAX = ABS(TOUT - T0P)*TEN
C/8
C
       IF ((T-TOUT)*H .GE. ZERO) GO TO 460
       GO TO 85
C
 30   IF ((T-TOUT)*H .GE. ZERO) GO TO 450
      IF (MF .NE. MFC) JSTART = -1
      NC = N
      EPSC = EPS
      MFC = MF
      GO TO 45
C
 40   HMAX = H0
C
 45   IF ((T+H) .EQ. T)  THEN
 				WRITE(EPISODEMESSAGE,15) T
 	    		NO_OF_LINES = 4
	    		CALL DISPMESS(EPISODEMESSAGE, NO_OF_LINES, MAXLINES)
		END IF		
C
 50   CALL DTSTEP (Y, N0)
C
      KGO = 1 - KFLAG
      GO TO (60, 100, 200, 300), KGO
C KFLAG  =   0,  -1,  -2,  -3  -----------------------------------------
C
 60   CONTINUE
C-----------------------------------------------------------------------
C NORMAL RETURN FROM TSTEP.
C
C THE WEIGHTS YMAX(I) ARE UPDATED.  IF DIFFERENT VALUES ARE DESIRED,
C THEY SHOULD BE SET HERE.  IF SS IS TO BE UPDATED FOR CONTROL OF
C ERROR PER SS UNITS OF T, IT SHOULD ALSO BE DONE HERE.  A TEST IS
C MADE TO DETERMINE IF EPS IS TOO SMALL FOR MACHINE PRECISION.
C
C ANY OTHER TESTS OR CALCULATIONS THAT ARE REQUIRED AFTER EACH STEP
C SHOULD BE INSERTED HERE.
C
C IF INDEX = 3, Y0 IS SET TO THE CURRENT Y VALUES ON RETURN.
C IF INDEX = 2, H IS CONTROLLED TO HIT TOUT (WITHIN ROUNDOFF
C ERROR), AND THEN THE CURRENT Y VALUES ARE PUT IN Y0 ON
C RETURN.  FOR ANY OTHER VALUE OF INDEX, CONTROL RETURNS TO
C THE INTEGRATOR UNLESS TOUT HAS BEEN REACHED.  THEN
C INTERPOLATED VALUES OF Y ARE COMPUTED AND STORED IN Y0 ON
C RETURN.
C IF INTERPOLATION IS NOT DESIRED, THE CALL TO INTERP SHOULD
C BE DELETED AND CONTROL TRANSFERRED TO STATEMENT 500 INSTEAD
C OF 520.
C-----------------------------------------------------------------------
      D = ZERO
      DO 70 I = 1,N
C(1
        AYI = DABS(Y(I,1))
C)1
CS      AYI = ABS(Y(I,1))
C/4
        GO TO (70, 66, 67), IERROR
C IERROR  =     1,  2,  3  ---------------------------------------------
 66     YMAX(I) = AYI
        GO TO 70
C(4
  67    YMAX(I) = DMAX1(YMAX(I), AYI)
  70    D = D + (AYI/YMAX(I))**2
      D = D*(UROUND/EPS)**2
      IF (D .GT. DFLOAT(N)) GO TO 250
C)4
CS67    YMAX(I) = AMAX1(YMAX(I), AYI)
CS70    D = D + (AYI/YMAX(I))**2
CS    D = D*(UROUND/EPS)**2
CS    IF (D .GT. FLOAT(N)) GO TO 250
C/10
      IF (INDEX .EQ. 3) GO TO 500
      IF (INDEX .EQ. 2) GO TO 85
 80   IF ((T-TOUT)*H .LT. ZERO) GO TO 45
      CALL DINTRP (TOUT, Y, N0, Y0)
      T0 = TOUT
      GO TO 520
 85   IF (((T+H)-TOUT)*H .LE. ZERO) GO TO 45
C(1
      IF (DABS(T-TOUT) .LE. HUNDRD*UROUND*HMAX) GO TO 500
C)1
CS    IF (ABS(T-TOUT) .LE. HUNDRD*UROUND*HMAX) GO TO 500
C/4
      IF ((T-TOUT)*H .GE. ZERO) GO TO 500
      H = (TOUT - T)*(ONE - FOUR*UROUND)
      JSTART = -1
      GO TO 45
C-----------------------------------------------------------------------
C ON AN ERROR RETURN FROM TSTEP, AN IMMEDIATE RETURN OCCURS IF
C KFLAG = -2, AND RECOVERY ATTEMPTS ARE MADE OTHERWISE.
C TO RECOVER, H AND HMIN ARE REDUCED BY A FACTOR OF .1 UP TO 10
C TIMES BEFORE GIVING UP.
C-----------------------------------------------------------------------
 100  IF(IMESS . GT. 0) THEN
 		WRITE (EPISODEMESSAGE,101)
	     	NO_OF_LINES = 3
	     	CALL DISPMESS(EPISODEMESSAGE, NO_OF_LINES, MAXLINES)
 101  	FORMAT (/46H---  MESSAGE FROM SUBROUTINE DRIVE IN EPISODE,,
     +      24H THE O.D.E. SOLVER.  ---/)
	 
         	WRITE(EPISODEMESSAGE,105) T,HMIN
 	     	NO_OF_LINES = 5
	     	CALL DISPMESS(EPISODEMESSAGE, NO_OF_LINES, MAXLINES)
 105  	FORMAT(//35H KFLAG = -1 FROM INTEGRATOR AT T = ,E18.8/
     1          40H  ERROR TEST FAILED WITH ABS(H) = HMIN =,E18.8/)
	 END IF
	 
 110  IF (NHCUT .EQ. 10) GO TO 150
      NHCUT = NHCUT + 1
      HMIN = HCUT*HMIN
      H = HCUT*H
	  	IF (IMESS .GT. 0) THEN
      			WRITE (EPISODEMESSAGE,115) H
 	    		NO_OF_LINES = 3
	    		CALL DISPMESS(EPISODEMESSAGE, NO_OF_LINES, MAXLINES)
 115  		FORMAT(24H  H HAS BEEN REDUCED TO ,E18.8,
     +       		26H  AND STEP WILL BE RETRIED//)
	    	END IF
	 
      JSTART = -1
      GO TO 45
C
 150  WRITE (EPISODEMESSAGE,155)
 	     NO_OF_LINES = 4
	     CALL DISPMESS(EPISODEMESSAGE, NO_OF_LINES, MAXLINES)
 155  FORMAT(//44H PROBLEM APPEARS UNSOLVABLE WITH GIVEN INPUT//)
      GO TO 500
C
 200  WRITE (EPISODEMESSAGE,101)
 	     NO_OF_LINES = 3
	     CALL DISPMESS(EPISODEMESSAGE, NO_OF_LINES, MAXLINES)
		
         WRITE (EPISODEMESSAGE,205) T,H,EPS
 	     NO_OF_LINES = 5
	     CALL DISPMESS(EPISODEMESSAGE, NO_OF_LINES, MAXLINES)
 205  FORMAT(//16H KFLAG = -2  T =,E18.8,4H H =,E18.8,6H EPS =,E18.8/
     1       50H  THE REQUESTED ERROR IS TOO SMALL FOR INTEGRATOR.//)
      GO TO 500
C
 250  WRITE (EPISODEMESSAGE,101)
 	     NO_OF_LINES = 3
	     CALL DISPMESS(EPISODEMESSAGE, NO_OF_LINES, MAXLINES)
         WRITE (EPISODEMESSAGE,255) T,EPS
 	     NO_OF_LINES = 6
	     CALL DISPMESS(EPISODEMESSAGE, NO_OF_LINES, MAXLINES)
 255  FORMAT(//46H INTEGRATION HALTED BY SUBROUTINE DRIVE AT T =,
     1       E18.8/43H EPS IS TOO SMALL FOR MACHINE PRECISION AND/
     2       29H PROBLEM BEING SOLVED.  EPS =,E18.8//)
      KFLAG = -2
      GO TO 500
C
 300  IF (IMESS .GT. 0) THEN
 		 		WRITE (EPISODEMESSAGE,101)
 	     		NO_OF_LINES = 3
	     		CALL DISPMESS(EPISODEMESSAGE, NO_OF_LINES, MAXLINES)
         		WRITE (EPISODEMESSAGE,305) T
 	     		NO_OF_LINES = 4
	     		CALL DISPMESS(EPISODEMESSAGE, NO_OF_LINES, MAXLINES)
 305  		FORMAT(//34H KFLAG = -3 FROM INTEGRATOR AT T =,E18.8/
     +       	45H  CORRECTOR CONVERGENCE COULD NOT BE ACHIEVED/)
		END IF	
      GO TO 110
C
 400  WRITE (EPISODEMESSAGE,101)
 	     NO_OF_LINES = 3
	     CALL DISPMESS(EPISODEMESSAGE, NO_OF_LINES, MAXLINES)
         WRITE (EPISODEMESSAGE,405) EPS
 	     NO_OF_LINES = 4
	     CALL DISPMESS(EPISODEMESSAGE, NO_OF_LINES, MAXLINES)
 405  FORMAT(//35H ILLEGAL INPUT.. EPS .LE. 0. EPS = ,E18.8//)
      INDEX = -4
      RETURN
C
 410  WRITE (EPISODEMESSAGE,101)
 	     NO_OF_LINES = 3
	     CALL DISPMESS(EPISODEMESSAGE, NO_OF_LINES, MAXLINES)
         WRITE (EPISODEMESSAGE,415) N
 	     NO_OF_LINES = 4
	     CALL DISPMESS(EPISODEMESSAGE, NO_OF_LINES, MAXLINES)
 415  FORMAT(//31H ILLEGAL INPUT.. N .LE. 0. N = ,I8//)
      INDEX = -4
      RETURN
C
 420  WRITE (EPISODEMESSAGE,101)
 	     NO_OF_LINES = 3
	     CALL DISPMESS(EPISODEMESSAGE, NO_OF_LINES, MAXLINES)
          WRITE (EPISODEMESSAGE,425) T0,TOUT,H0
 	    NO_OF_LINES = 5
	     CALL DISPMESS(EPISODEMESSAGE, NO_OF_LINES, MAXLINES)
 425  FORMAT(//39H ILLEGAL INPUT.. (T0 - TOUT)*H0 .GE. 0./
     1       5H T0 =,E18.8,7H TOUT =,E18.8,5H H0 =,E18.8//)
      INDEX = -4
      RETURN
C
 430  WRITE (EPISODEMESSAGE,101)
  	     NO_OF_LINES = 3
	     CALL DISPMESS(EPISODEMESSAGE, NO_OF_LINES, MAXLINES)
         WRITE (EPISODEMESSAGE,435) INDEX
 	     NO_OF_LINES = 4
	     CALL DISPMESS(EPISODEMESSAGE, NO_OF_LINES, MAXLINES)
 435  FORMAT(//24H ILLEGAL INPUT.. INDEX =,I8//)
      INDEX = -4
      RETURN
C
 440  WRITE (EPISODEMESSAGE,101)
 	     NO_OF_LINES = 3
	     CALL DISPMESS(EPISODEMESSAGE, NO_OF_LINES, MAXLINES)
         WRITE (EPISODEMESSAGE,445) N
 	     NO_OF_LINES = 6
	     CALL DISPMESS(EPISODEMESSAGE, NO_OF_LINES, MAXLINES)
 445  FORMAT (//39H ILLEGAL INPUT.  THE NUMBER OF ORDINARY/
     1        43H DIFFERENTIAL EQUATIONS BEING SOLVED IS N =, I6/
     2        42H STORAGE ALLOCATION IN SUBROUTINE DRIVE IS/
     3        46H TOO SMALL.  SEE COMMENTS IN SUBROUTINE DRIVE./)
      INDEX = -4
      RETURN
C
 450  WRITE (EPISODEMESSAGE,101)
 	     NO_OF_LINES = 3
	     CALL DISPMESS(EPISODEMESSAGE, NO_OF_LINES, MAXLINES)
         WRITE (EPISODEMESSAGE,455) T,TOUT,H
 	     NO_OF_LINES = 7
	     CALL DISPMESS(EPISODEMESSAGE, NO_OF_LINES, MAXLINES)
 455  FORMAT(//46H INDEX = -1 ON INPUT WITH (T - TOUT)*H .GE. 0./
     1       44H INTERPOLATION WAS DONE AS ON NORMAL RETURN./
     2       41H DESIRED PARAMETER CHANGES WERE NOT MADE./
     3       4H T =,E18.8,7H TOUT =,E18.8,4H H =,E18.8//)
      CALL DINTRP (TOUT, Y, N0, Y0)
      T0 = TOUT
      INDEX = -5
      RETURN
C
 460  WRITE (EPISODEMESSAGE,101)
 	     NO_OF_LINES = 3
	     CALL DISPMESS(EPISODEMESSAGE, NO_OF_LINES, MAXLINES)
         WRITE (EPISODEMESSAGE,465) T,TOUT,H
 	     NO_OF_LINES = 5
	     CALL DISPMESS(EPISODEMESSAGE, NO_OF_LINES, MAXLINES)
 465  FORMAT(//45H INDEX = 2 ON INPUT WITH (T - TOUT)*H .GE. 0./
     1       4H T =,E18.8,7H TOUT =,E18.8,4H H =,E18.8//)
      INDEX = -6
      RETURN
C
 500  T0 = T
      DO 510 I = 1,N
 510    Y0(I) = Y(I,1)
 520  INDEX = KFLAG
      T0P = T0
      H0 = HUSED
      IF (KFLAG .NE. 0) H0 = H
      RETURN
C-----------------------  END OF SUBROUTINE DDRIVE  --------------------
      END
      SUBROUTINE DINTRP (TOUT, Y, N0, Y0)
C-----------------------------------------------------------------------
C SUBROUTINE INTERP COMPUTES INTERPOLATED VALUES OF THE DEPENDENT
C VARIABLE Y AND STORES THEM IN Y0.  THE INTERPOLATION IS TO THE
C POINT T = TOUT AND USES THE NORDSIECK HISTORY ARRAY Y AS FOLLOWS..
C                             NQ
C                  Y0(I)  =  SUM  Y(I,J+1)*S**J ,
C                            J=0
C WHERE S = -(T-TOUT)/H.
C-----------------------------------------------------------------------
C$ THIS IS THE DOUBLE PRECISION VERSION OF SUBROUTINE INTERP.
C
C CHANGE PRECISION VIA THE INSTRUCTIONS IN SUBROUTINE DRIVE.
C-----------------------------------------------------------------------
C CAUTION:  NOT ALL MEMBERS OF EPCOM1 ARE USED IN THIS SUBROUTINE.
C-----------------------------------------------------------------------
      INTEGER N0
      INTEGER JSTART, KFLAG, MF, N
      INTEGER I, J, L
C(4
      DOUBLE PRECISION TOUT, Y, Y0
      DOUBLE PRECISION EPS, H, HMAX, HMIN, SS, T, UROUND
      DOUBLE PRECISION S, S1
      DOUBLE PRECISION ONE
C)4
CS    REAL TOUT, Y, Y0
CS    REAL EPS, H, HMAX, HMIN, SS, T, UROUND
CS    REAL S, S1
CS    REAL ONE
C/10
      DIMENSION Y0(N0),Y(N0,13)
C
      COMMON /EPCOM1/ T,H,HMIN,HMAX,EPS,SS,UROUND,N,MF,KFLAG,JSTART
C(1
      DATA ONE /1.0D0/
C)1
CS    DATA ONE /1.0E0/
C/4
      DO 10 I = 1,N
 10     Y0(I) = Y(I,1)
      L = JSTART + 1
      S = (TOUT - T)/H
      S1 = ONE
      DO 30 J = 2,L
        S1 = S1*S
        DO 20 I = 1,N
 20       Y0(I) = Y0(I) + S1*Y(I,J)
 30     CONTINUE
      RETURN
C-----------------------  END OF SUBROUTINE DINTRP  --------------------
      END
      SUBROUTINE DTSTEP (Y, N0)
C-----------------------------------------------------------------------
C TSTEP PERFORMS ONE STEP OF THE INTEGRATION OF AN INITIAL VALUE
C PROBLEM FOR A SYSTEM OF ORDINARY DIFFERENTIAL EQUATIONS.
C COMMUNICATION WITH TSTEP IS VIA THE FOLLOWING VARIABLES..
C
C   Y       AN N0 BY LMAX ARRAY CONTAINING THE DEPENDENT VARIABLES
C             AND THEIR SCALED DERIVATIVES.  LMAX IS CURRENTLY 6 FOR
C             THE VARIABLE STEP BACKWARD DIFFERENTIATION FORMULAS,
C             AND 13 FOR THE VARIABLE STEP ADAMS FORMULAS.
C             (LMAX -1) = MAXDER, THE MAXIMUM ORDER USED.
C             SEE SUBROUTINE COSET.  Y(I,J+1) CONTAINS THE
C             J-TH DERIVATIVE OF Y(I), SCALED BY H**J/FACTORIAL(J)
C             FOR J = 0,1,...,NQ, WHERE NQ IS THE CURRENT ORDER.
C   N0      A CONSTANT INTEGER .GE. N, USED FOR DIMENSIONING
C             PURPOSES.
C   T       THE INDEPENDENT VARIABLE, UPDATED ON EACH STEP TAKEN.
C   H       THE STEP SIZE TO BE ATTEMPTED ON THE NEXT STEP.
C             H IS ALTERED BY THE ERROR CONTROL ALGORITHM DURING
C             THE SOLUTION OF THE PROBLEM. H CAN BE EITHER POSITIVE
C             OR NEGATIVE, BUT ITS SIGN MUST REMAIN CONSTANT
C             THROUGHOUT THE PROBLEM RUN.
C   HMIN,   THE MINIMUM AND MAXIMUM ABSOLUTE VALUES OF THE STEP
C    HMAX     SIZE TO BE USED FOR THE STEP. THESE MAY BE CHANGED AT
C             ANY TIME, BUT THE CHANGE WILL NOT TAKE EFFECT UNTIL THE
C             NEXT CHANGE IN H IS MADE.
C   EPS     THE RELATIVE ERROR BOUND.  SEE DESCRIPTION IN
C             SUBROUTINE DRIVE.
C   SS      THE SIZE OF THE TIME INTERVAL TO BE USED FOR ERROR
C             CONTROL.  A DEFAULT VALUE OF 0 IS USED TO PRODUCE
C             CONTROL OF ERROR PER STEP.  SEE SUBROUTINE DRIVE.
C   UROUND  THE UNIT OF ROUNDOFF FOR THE COMPUTER BEING USED.
C   N       THE NUMBER OF FIRST ORDER ORDINARY DIFFERENTIAL
C             EQUATIONS BEING SOLVED.
C   MF      THE METHOD FLAG.  SEE DESCRIPTION IN SUBROUTINE DRIVE.
C   KFLAG   A COMPLETION CODE WITH THE FOLLOWING MEANINGS..
C                     0  THE STEP WAS SUCCESFUL.
C                    -1  THE REQUESTED ERROR COULD NOT BE ACHIEVED
C                          WITH ABS(H) = HMIN.
C                    -2  THE REQUESTED ERROR IS SMALLER THAN CAN
C                          BE HANDLED FOR THIS PROBLEM.
C                    -3  CORRECTOR CONVERGENCE COULD NOT BE
C                          ACHIEVED FOR ABS(H) = HMIN.
C             ON A RETURN WITH KFLAG NEGATIVE, THE VALUES OF T AND
C             THE Y ARRAY ARE AS OF THE BEGINNING OF THE LAST
C             STEP AND H IS THE LAST STEP SIZE ATTEMPTED.
C   JSTART  AN INTEGER USED ON INPUT AND OUTPUT.
C             ON INPUT, IT HAS THE FOLLOWING VALUES AND MEANINGS..
C                     0  PERFORM THE FIRST STEP.
C                 .GT.0  TAKE A NEW STEP CONTINUING FROM THE LAST.
C                 .LT.0  TAKE THE NEXT STEP WITH A NEW VALUE OF
C                          H AND/OR MF.
C             ON EXIT, JSTART IS SET TO NQ, THE CURRENT ORDER OF THE
C             METHOD.
C   YMAX      AN ARRAY OF N ELEMENTS WITH WHICH THE ESTIMATED LOCAL
C               ERRORS IN Y ARE COMPARED.
C   ERROR     AN ARRAY OF N ELEMENTS.  ERROR(I)/TQ(2) IS THE
C               ESTIMATED LOCAL ERROR IN Y(I) PER SS UNITS OF
C               T OR PER STEP (OF SIZE H).
C   SAVE1,    TWO ARRAYS FOR WORKING STORAGE,
C     SAVE2     EACH OF LENGTH N.
C   PW        A BLOCK OF LOCATIONS USED FOR THE PARTIAL DERIVATIVES
C               OF F WITH RESPECT TO Y, IF MITER IS NOT O.  SEE
C               DESCRIPTION IN SUBROUTINE DRIVE.
C   IPIV      AN INTEGER ARRAY OF LENGTH N, WHICH IS USED FOR PIVOT
C               INFORMATION FOR THE LINEAR ALGEBRAIC SYSTEM IN THE
C               CORRECTION PROCESS, WHEN MITER = 1 OR 2.
C
C THE COMMON BLOCK EPCM10, DECLARED BELOW, IS PRIMARILY INTENDED
C FOR INTERNAL USE, BUT IT CAN BE ACCESSED EXTERNALLY.
C-----------------------------------------------------------------------
C$ THIS IS THE DOUBLE PRECISION VERSION OF SUBROUTINE TSTEP.
C
C CHANGE PRECISION VIA THE INSTRUCTIONS IN SUBROUTINE DRIVE.
C-----------------------------------------------------------------------
      INTEGER N0
      INTEGER IPIV, JSTART, KFLAG, L, LMAX, METH, MF, N, NFE, NJE,
     1        NQ, NQINDX, NQUSED, NSTEP
      INTEGER I, IBACK, IER, IREDO, J, J1, J2, M, MFOLD, MIO,
     1        MITER, MITER1, NEWJ, NSTEPJ
      INTEGER ISTEPJ, KFC, KFH, MAXCOR
C(11
      DOUBLE PRECISION Y
      DOUBLE PRECISION EL, EPS, ERROR, H, HMAX, HMIN, HUSED, PW,
     1                 SAVE1, SAVE2, SS, T, TAU, TQ, UROUND, YMAX
      DOUBLE PRECISION BND, CNQUOT, CON, CONP, CRATE, D, DRC,
     1                 D1, E, EDN, ETA, ETAMAX, ETAMIN, ETAQ, ETAQM1,
     2                 ETAQP1, EUP, FLOTL, FLOTN, HOLD, HRL1, PHRL1,
     3                 PRL1, R, RC, RL1, R0, R1, TOLD
      DOUBLE PRECISION ADDON, BIAS1, BIAS2, BIAS3, CRDOWN, DELRC,
     1                 ETACF, ETAMXF, ETAMX1, ETAMX2,
     2                 ETAMX3, ONEPSM, SHORT, THRESH
      DOUBLE PRECISION ONE, PT5, ZERO
C)11
CS    REAL Y
CS    REAL EL, EPS, ERROR, H, HMAX, HMIN, HUSED, PW,
CS   1     SAVE1, SAVE2, SS, T, TAU, TQ, UROUND, YMAX
CS    REAL BND, CNQUOT, CON, CONP, CRATE, D, DRC,
CS   1     D1, E, EDN, ETA, ETAMAX, ETAQ, ETAQM1,
CS   2     ETAQP1, EUP, FLOTL, FLOTN, HOLD, HRL1, PHRL1,
CS   3     PRL1, R, RC, RL1, R0, R1, TOLD
CS    REAL ADDON, BIAS1, BIAS2, BIAS3, CRDOWN, DELRC,
CS   1     ETACF, ETAMIN, ETAMXF, ETAMX1, ETAMX2,
CS   2     ETAMX3, ONEPSM, SHORT, THRESH
CS    REAL ONE, PT5, ZERO
C/24
      DIMENSION Y(N0,13)
C
      COMMON /EPCOM1/ T,H,HMIN,HMAX,EPS,SS,UROUND,N,MF,KFLAG,JSTART
      COMMON /EPCOM2/ YMAX(1)
      COMMON /EPCOM3/ ERROR(1)
      COMMON /EPCOM4/ SAVE1(1)
      COMMON /EPCOM5/ SAVE2(1)
      COMMON /EPCOM6/ PW(1)
      COMMON /EPCOM7/ IPIV(1)
      COMMON /EPCOM9/ HUSED,NQUSED,NSTEP,NFE,NJE
      COMMON /EPCM10/ TAU(13),EL(13),TQ(5),LMAX,METH,NQ,L,NQINDX
	COMMON /SAVEME2/ HOLD, ETAMAX, PRL1, HRL1, RC, CRATE, 
     +		     D1, R, MFOLD, MITER, NEWJ, NSTEPJ, MITER1
     
C *** NOTE: the DTSTEP subroutine assumed that ALL variables were static.
C           For platforms that allocate local variables dynamically, the
C           common block SAVEME2 holds those variables that must actually
C           be static for proper opperation.  THIS LIST MAY BE INCOMPLETE
C           AND/OR CONTAIN EXTRANEOUS MEMBERS!


C
      DATA ISTEPJ /20/, KFC /-3/, KFH /-7/, MAXCOR /3/
C(6
      DATA ADDON  /1.0D-6/,    BIAS1  /2.5D1/, BIAS2  /2.5D1/,
     1     BIAS3  /1.0D2/,     CRDOWN /0.1D0/, DELRC  /0.3D0/,
     2     ETACF  /0.25D0/,    ETAMIN /0.1D0/, ETAMXF /0.2D0/,
     3     ETAMX1 /1.0D4/,     ETAMX2 /1.0D1/, ETAMX3 /1.5D0/,
     4     ONEPSM /1.00001D0/, SHORT  /0.1D0/, THRESH /1.3D0/
      DATA ONE /1.0D0/, PT5 /0.5D0/, ZERO /0.0D0/
C)6
CS    DATA ADDON  /1.0E-6/,    BIAS1  /2.5E1/, BIAS2  /2.5E1/,
CS   1     BIAS3  /1.0E2/,     CRDOWN /0.1E0/, DELRC  /0.3E0/,
CS   2     ETACF  /0.25E0/,    ETAMIN /0.1E0/, ETAMXF /0.2E0/,
CS   3     ETAMX1 /1.0E4/,     ETAMX2 /1.0E1/, ETAMX3 /1.5E0/,
CS   4     ONEPSM /1.00001E0/, SHORT  /0.1E0/, THRESH /1.3E0/
CS    DATA ONE /1.0E0/, PT5 /0.5E0/, ZERO /0.0E0/
C/14
      KFLAG = 0
      TOLD = T
C(1
      FLOTN = DFLOAT(N)
C)1
CS    FLOTN = FLOAT(N)
C/4
      IF (JSTART .GT. 0) GO TO 200
      IF (JSTART .NE. 0) GO TO 150
C-----------------------------------------------------------------------
C ON THE FIRST CALL, THE ORDER IS SET TO 1 AND THE INITIAL
C DERIVATIVES ARE CALCULATED.  ETAMAX IS THE MAXIMUM RATIO BY
C WHICH H CAN BE INCREASED IN A SINGLE STEP.  IT IS 1.E04 FOR THE
C FIRST STEP TO COMPENSATE FOR THE SMALL INITIAL H, THEN 10 FOR
C THE NEXT 10 STEPS, AND THEN 1.5 THEREAFTER.  IF A FAILURE
C OCCURS (IN CORRECTOR CONVERGENCE OR ERROR TEST), ETAMAX IS SET AT 1
C FOR THE NEXT INCREASE.  ETAMIN = .1 IS THE MINIMUM RATIO BY WHICH
C H CAN BE REDUCED ON ANY RETRY OF A STEP.
C-----------------------------------------------------------------------
      CALL DDIFUN (N, T, Y, SAVE1)
      DO 110 I = 1,N
 110    Y(I,2) = H*SAVE1(I)
      METH = MF/10
      MITER = MF - 10*METH
      MITER1 = MITER + 1
      MFOLD = MF
      NQ = 1
      L = 2
      TAU(1) = H
      PRL1 = ONE
      RC = ZERO
      ETAMAX = ETAMX1
      NQINDX = 2
      NSTEP = 0
      NSTEPJ = 0
      NFE = 1
      NJE = 0
      GO TO 200
C-----------------------------------------------------------------------
C IF THE USER HAS CHANGED H, THEN Y MUST BE RESCALED.  IF THE
C USER HAS CHANGED MITER, THEN NEWJ IS SET TO MITER TO FORCE
C THE PARTIAL DERIVATIVEES TO BE UPDATED, IF THEY ARE BEING USED.
C-----------------------------------------------------------------------
 150  IF (MF .EQ. MFOLD) GO TO 170
      MIO = MITER
      METH = MF/10
      MITER = MF - 10*METH
      MFOLD = MF
      IF (MITER .EQ. MIO) GO TO 170
      NEWJ = MITER
      MITER1 = MITER + 1
 170  IF (H .EQ. HOLD) GO TO 200
      ETA = H/HOLD
      H = HOLD
      IREDO = 3
      GO TO 185
C(2
  180 ETA = DMAX1(ETA,HMIN/DABS(H),ETAMIN)
  185 ETA = DMIN1(ETA,HMAX/DABS(H),ETAMAX)
C)2
CS180 ETA = AMAX1(ETA,HMIN/ABS(H),ETAMIN)
CS185 ETA = AMIN1(ETA,HMAX/ABS(H),ETAMAX)
C/6
      R1 = ONE
      DO 190 J = 2,L
        R1 = R1*ETA
        DO 190 I = 1,N
 190      Y(I,J) = Y(I,J)*R1
      H = H*ETA
      RC = RC*ETA
      IF (IREDO .EQ. 0) GO TO 690
C-----------------------------------------------------------------------
C THIS SECTION COMPUTES THE PREDICTED VALUES BY EFFECTIVELY
C MULTIPLYING THE Y ARRAY BY THE PASCAL TRIANGLE MATRIX.  THEN
C COSET IS CALLED TO OBTAIN EL, THE VECTOR OF COEFFICIENTS OF
C LENGTH NQ + 1.  RC IS THE RATIO OF NEW TO OLD VALUES OF THE
C COEFFICIENT H/EL(2).  WHEN RC DIFFERS FROM 1 BY MORE THAN
C DELRC, NEWJ IS SET TO MITER TO FORCE THE PARTIAL DERIVATIVES
C TO BE UPDATED, IF USED.  DELRC IS 0.3.  IN ANY CASE, THE PARTIAL
C DERIVATIVES ARE UPDATED AT LEAST EVERY 20-TH STEP.
C-----------------------------------------------------------------------
 200  T = T + H
      DO 210 J1 = 1,NQ
        DO 210 J2 = J1,NQ
          J = (NQ + J1) - J2
          DO 210 I = 1,N
 210        Y(I,J) = Y(I,J) + Y(I,J+1)
      CALL DCOSET
      BND = FLOTN*(TQ(4)*EPS)**2
      RL1 = ONE/EL(2)
      RC = RC*(RL1/PRL1)
      PRL1 = RL1
      IF (NSTEP .GE. NSTEPJ+ISTEPJ) NEWJ = MITER
C(1
      DRC = DABS(RC-ONE)
C)1
CS    DRC = ABS(RC-ONE)
C/4
      IF (DRC .LE. DELRC) GO TO 215
      NEWJ = MITER
      CRATE = ONE
      RC = ONE
      GO TO 220
  215 IF ((MITER .NE. 0) .AND. (DRC .NE. ZERO)) CRATE = ONE
C-----------------------------------------------------------------------
C UP TO 3 CORRECTOR ITERATIONS ARE TAKEN.  A CONVERGENCE TEST IS MADE
C ON THE ROOT MEAN SQUARE NORM OF EACH CORRECTION, USING BND, WHICH
C IS DEPENDENT ON EPS.  THE SUM OF THE CORRECTIONS IS ACCUMULATED IN
C THE VECTOR ERROR.  THE Y ARRAY IS NOT ALTERED IN THE CORRECTOR
C LOOP.  THE UPDATED Y VECTOR IS STORED TEMPORARILY IN SAVE1.
C-----------------------------------------------------------------------
 220  DO 230 I = 1,N
 230    ERROR(I) = ZERO
      M = 0
      CALL DDIFUN (N, T, Y, SAVE2)
      NFE = NFE + 1
      IF (NEWJ .LE. 0) GO TO 290
C-----------------------------------------------------------------------
C IF INDICATED, THE MATRIX P = I - H*RL1*J IS REEVALUATED BEFORE
C STARTING THE CORRECTOR ITERATION.  NEWJ IS SET TO 0 AS AN
C INDICATOR THAT THIS HAS BEEN DONE.  IF MITER = 1 OR 2, P IS
C COMPUTED AND PROCESSED IN PSET.  IF MITER = 3, THE MATRIX  IS
C P = I - H*RL1*D, WHERE D IS A DIAGONAL MATRIX.  RL1 IS 1/EL(2).
C-----------------------------------------------------------------------
      NEWJ = 0
      RC = ONE
      NJE = NJE + 1
      NSTEPJ = NSTEP
      GO TO (250, 240, 260), MITER
 240  NFE = NFE + N
 250  CON = -H*RL1
      CALL DPSET(Y, N0, CON, MITER, IER)
      IF (IER .NE. 0) GO TO 420
      GO TO 350
 260  R = RL1*SHORT
      DO 270 I = 1,N
 270    PW(I) = Y(I,1) + R*(H*SAVE2(I) - Y(I,2))
      CALL DDIFUN(N, T, PW, SAVE1)
      NFE = NFE + 1
      HRL1 = H*RL1
      DO 280 I = 1,N
        R0 = H*SAVE2(I) - Y(I,2)
        PW(I) = ONE
        D = SHORT*R0 - H*(SAVE1(I) - SAVE2(I))
        SAVE1(I) = ZERO
C(2
        IF (DABS(R0) .LT. UROUND*YMAX(I)) GO TO 280
        IF (DABS(D) .EQ. ZERO) GO TO 420
C)2
CS      IF (ABS(R0) .LT. UROUND*YMAX(I)) GO TO 280
CS      IF (ABS(D) .EQ. ZERO) GO TO 420
C/6
        PW(I) = SHORT*R0/D
        SAVE1(I) = PW(I)*RL1*R0
 280    CONTINUE
      GO TO 370
 290  GO TO (295, 350, 350, 310), MITER1
C-----------------------------------------------------------------------
C IN THE CASE OF FUNCTIONAL ITERATION, Y IS UPDATED DIRECTLY FROM
C THE RESULT OF THE LAST DIFFUN CALL.
C-----------------------------------------------------------------------
 295  D = ZERO
      DO 300 I = 1,N
        R = RL1*(H*SAVE2(I) - Y(I,2))
        D = D + ((R - ERROR(I))/YMAX(I))**2
        SAVE1(I) = Y(I,1) + R
 300    ERROR(I) = R
      GO TO 400
C-----------------------------------------------------------------------
C IN THE CASE OF A CHORD METHOD, THE RESIDUAL -G(Y SUB N(M))
C IS COMPUTED AND THE LINEAR SYSTEM WITH THAT AS RIGHT-HAND SIDE
C AND P AS COEFFICIENT MATRIX IS SOLVED, USING THE LU DECOMPOSITION
C OF P IF MITER = 1 OR 2.  IF MITER = 3 THE SCALAR H*RL1 IS UPDATED.
C-----------------------------------------------------------------------
 310  PHRL1 = HRL1
      HRL1 = H*RL1
      IF (HRL1 .EQ. PHRL1) GO TO 330
      R = HRL1/PHRL1
      DO 320 I = 1,N
        D = ONE - R*(ONE - ONE/PW(I))
C(1
        IF (DABS(D) .EQ. ZERO) GO TO 440
C)1
CS      IF (ABS(D) .EQ. ZERO) GO TO 440
C/4
 320    PW(I) = ONE/D
 330  DO 340 I = 1,N
 340    SAVE1(I) = PW(I)*(RL1*H*SAVE2(I) - (RL1*Y(I,2) + ERROR(I)))
      GO TO 370
 350  DO 360 I = 1,N
 360    SAVE1(I) = RL1*H*SAVE2(I) - (RL1*Y(I,2) + ERROR(I))
      CALL DSOL (N, N0, PW, SAVE1, IPIV)
 370  D = ZERO
      DO 380 I = 1,N
        ERROR(I) = ERROR(I) + SAVE1(I)
        D = D + (SAVE1(I)/YMAX(I))**2
 380    SAVE1(I) = Y(I,1) + ERROR(I)
C-----------------------------------------------------------------------
C TEST FOR CONVERGENCE.  IF M .GT. 0, AN ESTIMATE OF THE SQUARE OF
C THE CONVERGENCE RATE CONSTANT IS STORED IN CRATE, AND THIS IS USED
C IN THE TEST.
C-----------------------------------------------------------------------
C(2
  400 IF (M .NE. 0) CRATE = DMAX1(CRDOWN*CRATE,D/D1)
      IF (D*DMIN1(ONE,CRATE) .LE. BND) GO TO 450
C)2
CS400 IF (M .NE. 0) CRATE = AMAX1(CRDOWN*CRATE,D/D1)
CS    IF (D*AMIN1(ONE,CRATE) .LE. BND) GO TO 450
C/6
      D1 = D
      M = M + 1
      IF (M .EQ. MAXCOR) GO TO 410
      CALL DDIFUN (N, T, SAVE1, SAVE2)
      GO TO (295, 350, 350, 310), MITER1
C-----------------------------------------------------------------------
C THE CORRECTOR ITERATION FAILED TO CONVERGE IN 3 TRIES. IF PARTIAL
C DERIVATIVES ARE INVOLVED BUT ARE NOT UP TO DATE, THEY ARE
C REEVALUATED FOR THE NEXT TRY.  OTHERWISE THE Y ARRAY IS RESTORED
C TO ITS VALUES BEFORE PREDICTION, AND H IS REDUCED,
C IF POSSIBLE.  IF NOT, A NO-CONVERGENCE EXIT IS TAKEN.
C-----------------------------------------------------------------------
 410  NFE = NFE + MAXCOR - 1
      IF (NEWJ .EQ. -1) GO TO 440
 420  T = TOLD
      ETAMAX = ONE
      DO 430 J1 = 1,NQ
        DO 430 J2 = J1,NQ
          J = (NQ + J1) - J2
          DO 430 I = 1,N
 430        Y(I,J) = Y(I,J) - Y(I,J+1)
C(1
      IF (DABS(H) .LE. HMIN*ONEPSM) GO TO 680
C)1
CS    IF (ABS(H) .LE. HMIN*ONEPSM) GO TO 680
C/4
      ETA = ETACF
      IREDO = 1
      GO TO 180
 440  NEWJ = MITER
      GO TO 220
C-----------------------------------------------------------------------
C THE CORRECTOR HAS CONVERGED.  NEWJ IS SET TO -1 IF PARTIAL
C DERIVATIVES WERE USED, TO SIGNAL THAT THEY MAY NEED UPDATING ON
C SUBSEQUENT STEPS.  THE ERROR TEST IS MADE AND CONTROL PASSES TO
C STATEMENT 500 IF IT FAILS.
C-----------------------------------------------------------------------
 450  IF (MITER .NE. 0) NEWJ = -1
      NFE = NFE + M
      D = ZERO
      DO 460 I = 1,N
 460    D = D + (ERROR(I)/YMAX(I))**2
      E = FLOTN*(TQ(2)*EPS)**2
      IF (D .GT. E) GO TO 500
C-----------------------------------------------------------------------
C AFTER A SUCCESSFUL STEP, THE Y ARRAY, TAU, NSTEP, AND NQINDX ARE
C UPDATED, AND A NEW VALUE OF H AT ORDER NQ IS COMPUTED.
C THE VECTOR TAU CONTAINS THE NQ + 1 MOST RECENT VALUES OF H.
C A CHANGE IN NQ UP OR DOWN BY 1 IS CONSIDERED IF NQINDX = 0.
C IF NQINDX = 1 AND NQ .LT. MAXDER, THEN ERROR IS SAVED
C FOR USE IN A POSSIBLE ORDER INCREASE ON THE NEXT STEP.
C A CHANGE IN H OR NQ IS MADE ONLY OF THE INCREASE IN H
C IS BY A FACTOR OF AT LEAST 1.3.
C IF NOT, NQINDX IS SET TO 2 TO PREVENT TESTING FOR THAT MANY
C STEPS.  IF NQ IS CHANGED, NQINDX IS SET TO NQ + 1 (NEW VALUE).
C-----------------------------------------------------------------------
      KFLAG = 0
      IREDO = 0
      NSTEP = NSTEP + 1
      HUSED = H
      NQUSED = NQ
      DO 470 IBACK = 1,NQ
        I = L - IBACK
 470    TAU(I+1) = TAU(I)
      TAU(1) = H
      DO 480 J = 1,L
        DO 480 I = 1,N
 480      Y(I,J) = Y(I,J) + ERROR(I)*EL(J)
      NQINDX = NQINDX - 1
      IF ((L .EQ. LMAX) .OR. (NQINDX .NE. 1)) GO TO 495
      DO 490 I = 1,N
 490    Y(I,LMAX) = ERROR(I)
      CONP = TQ(5)
 495  IF (ETAMAX .NE. ONE) GO TO 520
      IF (NQINDX .LT. 2) NQINDX = 2
      GO TO 690
C-----------------------------------------------------------------------
C THE ERROR TEST FAILED.  KFLAG KEEPS TRACK OF MULTIPLE FAILURES.
C T AND THE Y ARRAY ARE RESTORED TO THEIR PREVIOUS VALUES.  A NEW
C H FOR A RETRY OF THE STEP IS COMPUTED.  THE ORDER IS KEPT FIXED.
C-----------------------------------------------------------------------
 500  KFLAG = KFLAG - 1
      T = TOLD
      DO 510 J1 = 1,NQ
        DO 510 J2 = J1,NQ
          J = (NQ + J1) - J2
          DO 510 I = 1,N
 510        Y(I,J) = Y(I,J) - Y(I,J+1)
      NEWJ = MITER
      ETAMAX = ONE
C(1
      IF (DABS(H) .LE. HMIN*ONEPSM) GO TO 660
C)1
CS    IF (ABS(H) .LE. HMIN*ONEPSM) GO TO 660
C/4
      IF (KFLAG .LE. KFC) GO TO 630
      IREDO = 2
C COMPUTE RATIO OF NEW H TO CURRENT H AT THE CURRENT ORDER. ------------
C(1
  520 FLOTL = DFLOAT(L)
C)1
CS520 FLOTL = FLOAT(L)
C/4
      ETAQ = ONE/((BIAS2*D/E)**(PT5/FLOTL) + ADDON)
      IF ((NQINDX .NE. 0) .OR. (KFLAG .NE. 0)) GO TO 580
      ETAQM1 = ZERO
      IF (NQ .EQ. 1) GO TO 540
C COMPUTE RATIO OF NEW H TO CURRENT H AT THE CURRENT ORDER LESS ONE. ---
      D = ZERO
      DO 530 I = 1,N
 530    D = D + (Y(I,L)/YMAX(I))**2
      EDN = FLOTN*(TQ(1)*EPS)**2
      ETAQM1 = ONE/((BIAS1*D/EDN)**(PT5/(FLOTL - ONE)) + ADDON)
 540  ETAQP1 = ZERO
      IF (L .EQ. LMAX) GO TO 560
C COMPUTE RATIO OF NEW H TO CURRENT H AT CURRENT ORDER PLUS ONE. -------
      CNQUOT = (TQ(5)/CONP)*(H/TAU(2))**L
      D = ZERO
      DO 550 I = 1,N
 550    D = D + ((ERROR(I) - CNQUOT*Y(I,LMAX))/YMAX(I))**2
      EUP = FLOTN*(TQ(3)*EPS)**2
      ETAQP1 = ONE/((BIAS3*D/EUP)**(PT5/(FLOTL + ONE)) + ADDON)
 560  NQINDX = 2
      IF (ETAQ .GE. ETAQP1) GO TO 570
      IF (ETAQP1 .GT. ETAQM1) GO TO 600
      GO TO 590
 570  IF (ETAQ .LT. ETAQM1) GO TO 590
 580  IF ((ETAQ .LT. THRESH) .AND. (KFLAG .EQ. 0)) GO TO 690
      ETA = ETAQ
      IF ((KFLAG .LE. -2) .AND. (ETA .GT. ETAMXF)) ETA = ETAMXF
      GO TO 180
 590  IF (ETAQM1 .LT. THRESH) GO TO 690
      CALL DADJST (Y, N0)
      L = NQ
      NQ = NQ - 1
      ETA = ETAQM1
      NQINDX = L
      GO TO 180
 600  IF (ETAQP1 .LT. THRESH) GO TO 690
      NQ = L
      ETA = ETAQP1
      L = L + 1
      DO 610 I = 1,N
 610    Y(I,L) = ZERO
      NQINDX = L
      GO TO 180
C-----------------------------------------------------------------------
C CONTROL REACHES THIS SECTION IF 3 OR MORE CONSECUTIVE FAILURES
C HAVE OCCURRED.  IT IS ASSUMED THAT THE ELEMENTS OF THE Y ARRAY
C HAVE ACCUMULATED ERRORS OF THE WRONG ORDER.  THE ORDER IS REDUCED
C BY ONE, IF POSSIBLE.  THEN H IS REDUCED BY A FACTOR OF 0.1 AND
C THE STEP IS RETRIED.  AFTER A TOTAL OF 7 CONSECUTIVE FAILURES,
C AN EXIT IS TAKEN WITH KFLAG = -2.
C-----------------------------------------------------------------------
 630  IF (KFLAG .EQ. KFH) GO TO 670
      IF (NQ .EQ. 1) GO TO 640
      ETA = ETAMIN
      CALL DADJST (Y, N0)
      L = NQ
      NQ = NQ - 1
      NQINDX = L
      GO TO 180
C(1
  640 ETA = DMAX1(ETAMIN,HMIN/DABS(H))
C)1
CS640 ETA = AMAX1(ETAMIN,HMIN/ABS(H))
C/4
      H = H*ETA
      CALL DDIFUN (N, T, Y, SAVE1)
      NFE = NFE + 1
      DO 650 I = 1,N
 650    Y(I,2) = H*SAVE1(I)
      NQINDX = 10
      GO TO 200
C-----------------------------------------------------------------------
C ALL RETURNS ARE MADE THROUGH THIS SECTION.  H IS SAVED IN HOLD
C TO ALLOW THE CALLER TO CHANGE H ON THE NEXT STEP.
C-----------------------------------------------------------------------
 660  KFLAG = -1
      GO TO 700
 670  KFLAG = -2
      GO TO 700
 680  KFLAG = -3
      GO TO 700
 690  ETAMAX = ETAMX3
      IF (NSTEP .LE. 10) ETAMAX = ETAMX2
 700  HOLD = H
      JSTART = NQ
      RETURN
C-----------------------  END OF SUBROUTINE DTSTEP  --------------------
      END
      SUBROUTINE DCOSET
C-----------------------------------------------------------------------
C COSET IS CALLED BY TSTEP AND SETS COEFFICIENTS FOR USE THERE.
C
C FOR EACH ORDER NQ, THE COEFFICIENTS IN EL ARE CALCULATED BY USE OF
C  THE GENERATING POLYNOMIAL LAMBDA(X), WITH COEFFICIENTS EL(I):
C      LAMBDA(X) = EL(1) + EL(2)*X + ... + EL(NQ+1)*(X**NQ).
C FOR THE BACKWARD DIFFERENTIATION FORMULAS,
C                    NQ
C      LAMBDA(X) = PRODUCT (1 + X/XI(I) ) .
C                   I = 1
C FOR THE ADAMS FORMULAS,
C                              NQ-1
C      (D/DX) LAMBDA(X) = C * PRODUCT (1 + X/XI(I) ) ,
C                              I = 1
C      LAMBDA(-1) = 0,    LAMBDA(0) = 1,
C WHERE C IS A NORMALIZATION CONSTANT.
C IN BOTH CASES, XI(I) IS DEFINED BY
C      H*XI(I) = T SUB N  -  T SUB (N-I)
C              = H + TAU(1) + TAU(2) + ... TAU(I-1).
C
C COSET ALSO SETS MAXDER, THE MAXIMUM ORDER OF THE FORMULAS
C AVAILABLE. CURRENTLY THIS IS 5 FOR THE BACKWARD DIFFERENTIATION
C FORMULAS, AND 12 FOR THE ADAMS FORMULAS.  TO USE DIFFERENT
C VALUES (.LE. 13),  CHANGE THE NUMBERS IN STATEMENTS 1 AND 2 BELOW.
C
C IN ADDITION TO VARIABLES DESCRIBED PREVIOUSLY, COMMUNICATION
C WITH COSET USES THE FOLLOWING..
C   TAU    = A VECTOR OF LENGTH 13 CONTAINING THE PAST NQ VALUES
C            OF H.
C   EL     = A VECTOR OF LENGTH 13 IN WHICH COSET STORES THE
C            COEFFICIENTS FOR THE CORRECTOR FORMULA.
C   TQ     = A VECTOR OF LENGTH 5 IN WHICH COSET STORES CONSTANTS
C            USED FOR THE CONVERGENCE TEST, THE ERROR TEST, AND
C            SELECTION OF H AT A NEW ORDER.
C   LMAX   = MAXDER + 1, WHERE MAXDER IS THE MAXIMUM ORDER
C            AVAILABLE.  LMAX IS THE MAXIMUM NUMBER OF COLUMNS
C            OF THE Y ARRAY TO BE USED.
C   METH   = THE BASIC METHOD INDICATOR.
C   NQ     = THE CURRENT ORDER.
C   L      = NQ + 1, THE LENGTH OF THE VECTOR STORED IN EL, AND
C            THE NUMBER OF COLUMNS OF THE Y ARRAY BEING USED.
C   NQINDX = A COUNTER CONTROLLING THE FREQUENCY OF ORDER CHANGES.
C            AN ORDER CHANGE IS ABOUT TO BE CONSIDERED IF
C            NQINDX = 1.
C-----------------------------------------------------------------------
C$ THIS IS THE DOUBLE PRECISION VERSION OF SUBROUTINE COSET.
C
C CHANGE PRECISION VIA INSTRUCTIONS IN SUBROUTINE DRIVE.
C-----------------------------------------------------------------------
C CAUTION:  NOT ALL MEMBERS OF EPCOM1 ARE USED IN THIS SUBROUTINE.
C-----------------------------------------------------------------------
      INTEGER I, IBACK, J, JP1, JSTART, KFLAG, L, LMAX, MAXDER,
     1        METH, MF,N, NQ, NQINDX, NQM1
C(6
      DOUBLE PRECISION EL, EPS, H, HMAX, HMIN, SS, T, TAU, TQ,
     1                 UROUND
      DOUBLE PRECISION AHDSS, CNQM1, CSUM, ELP, EM, EM0, FLOTI,
     1                 FLOTL, FLOTNQ, HSUM, HSUM1, PROD, RXI, S, XI
      DOUBLE PRECISION CORTES
      DOUBLE PRECISION ONE, SIX, TWO, ZERO
C)6
CS    REAL EL, EPS, H, HAX, HMIN, SS, T, TAU, TQ,
CS   1     UROUND
CS    REAL AHDSS, CNQM1, CSUM, ELP, EM, EM0, FLOTI,
CS   1     FLOTL, FLOTNQ, HSUM, HSUM1, PROD, RXI, S, XI
CS    REAL CORTES
CS    REAL ONE, SIX, TWO, ZERO
C/14
      DIMENSION EM(13)
C
      COMMON /EPCOM1/ T,H,HMIN,HMAX,EPS,SS,UROUND,N,MF,KFLAG,JSTART
      COMMON /EPCM10/ TAU(13),EL(13),TQ(5),LMAX,METH,NQ,L,NQINDX
C(2
      DATA CORTES /0.1D0/
      DATA ONE  /1.0D0/, SIX /6.0D0/, TWO /2.0D0/, ZERO /0.0D0/
C)2
CS    DATA CORTES /0.1E0/
CS    DATA ONE  /1.0E0/, SIX /6.0E0/, TWO /2.0E0/, ZERO /0.0E0/
C/6
      AHDSS = ONE
C(2
      IF (SS .NE. ZERO) AHDSS = DABS(H)/SS
      FLOTL = DFLOAT(L)
C)2
CS    IF (SS .NE. ZERO) AHDSS = ABS(H)/SS
CS    FLOTL = FLOAT(L)
C/6
      NQM1 = NQ - 1
      GO TO (1, 2), METH
 1    MAXDER = 12
      GO TO 100
C
 2    MAXDER = 5
      GO TO 200
C
 100  IF (NQ .NE. 1) GO TO 110
      EL(1) = ONE
      EL(2) = ONE
      TQ(1) = ONE
      TQ(2) = TWO*AHDSS
      TQ(3) = SIX*TQ(2)
      TQ(5) = ONE
      GO TO 300
 110  HSUM = H
      EM(1) = ONE
      FLOTNQ = FLOTL - ONE
      DO 115 I = 2,L
 115    EM(I) = ZERO
      DO 150 J = 1,NQM1
        IF ((J .NE. NQM1) .OR. (NQINDX .NE. 1)) GO TO 130
        S = ONE
        CSUM = ZERO
        DO 120 I = 1,NQM1
C(1
          CSUM = CSUM + S*EM(I)/DFLOAT(I+1)
C)1
CS        CSUM = CSUM + S*EM(I)/FLOAT(I+1)
C/4
 120      S = -S
        TQ(1) = AHDSS*EM(NQM1)/(FLOTNQ*CSUM)
 130    RXI = H/HSUM
        DO 140 IBACK = 1,J
          I = (J + 2) - IBACK
 140      EM(I) = EM(I) + EM(I-1)*RXI
 150    HSUM = HSUM + TAU(J)
C COMPUTE INTEGRAL FROM -1 TO 0 OF POLYNOMIAL AND OF X TIMES IT. -------
      S = ONE
      EM0 = ZERO
      CSUM = ZERO
      DO 160 I = 1,NQ
C(1
        FLOTI = DFLOAT(I)
C)1
CS      FLOTI = FLOAT(I)
C/4
        EM0 = EM0 + S*EM(I)/FLOTI
        CSUM = CSUM + S*EM(I)/(FLOTI+1)
 160    S = -S
C IN EL, FORM COEFFICIENTS OF NORMALIZED INTEGRATED POLYNOMIAL. --------
      S = ONE/EM0
      EL(1) = ONE
      DO 170 I = 1,NQ
C(1
  170   EL(I+1) = S*EM(I)/DFLOAT(I)
C)1
CS170   EL(I+1) = S*EM(I)/FLOAT(I)
C/4
      XI = HSUM/H
      TQ(2) = AHDSS*XI*EM0/CSUM
      TQ(5) = XI/EL(L)
      IF (NQINDX .NE. 1) GO TO 300
C FOR HIGHER ORDER CONTROL CONSTANT, MULTIPLY POLYNOMIAL BY 1+X/XI(Q). -
      RXI = ONE/XI
      DO 180 IBACK = 1,NQ
        I = (L + 1) - IBACK
 180    EM(I) = EM(I) + EM(I-1)*RXI
C COMPUTE INTEGRAL OF POLYNOMIAL. --------------------------------------
      S = ONE
      CSUM = ZERO
      DO 190 I = 1,L
C(1
      CSUM = CSUM + S*EM(I)/DFLOAT(I+1)
C)1
CS    CSUM = CSUM + S*EM(I)/FLOAT(I+1)
C/4
 190    S = -S
      TQ(3) = AHDSS*FLOTL*EM0/CSUM
      GO TO 300
C
 200  DO 210 I = 3,L
 210    EL(I) = ZERO
      EL(1) = ONE
      EL(2) = ONE
      HSUM = H
      HSUM1 = ZERO
      PROD = ONE
      RXI = ONE
      IF (NQ .EQ. 1) GO TO 240
      DO 230 J = 1,NQM1
C IN EL, CONSTRUCT COEFFICIENTS OF (1+X/XI(1))*...*(1+X/XI(J+1)). ------
        HSUM = HSUM + TAU(J)
        HSUM1 = HSUM1 + TAU(J)
        PROD = PROD*(HSUM/HSUM1)
        RXI = H/HSUM
        JP1 = J + 1
        DO 220 IBACK = 1,JP1
          I = (J + 3) - IBACK
 220      EL(I) = EL(I) + EL(I-1)*RXI
 230    CONTINUE
 240  TQ(2) = AHDSS*EL(2)*(ONE + PROD)
      TQ(5) = (ONE + PROD)/EL(L)
      IF (NQINDX .NE. 1) GO TO 300
      CNQM1 = RXI/EL(L)
      ELP = EL(2) - RXI
      TQ(1) = AHDSS*ELP/CNQM1
      HSUM = HSUM + TAU(NQ)
      RXI = H/HSUM
      ELP = EL(2) + RXI
      TQ(3) = AHDSS*ELP*RXI*(ONE + PROD)*(FLOTL + ONE)
 300  TQ(4) = CORTES*TQ(2)
      LMAX = MAXDER + 1
      RETURN
C-----------------------  END OF SUBROUTINE DCOSET  --------------------
      END
      SUBROUTINE DADJST (Y, N0)
C-----------------------------------------------------------------------
C THIS SUBROUTINE ADJUSTS THE Y ARRAY ON REDUCTION OF ORDER.
C SEE REFERENCE 1 FOR DETAILS.
C-----------------------------------------------------------------------
C$ THIS IS THE DOUBLE PRECISION VERSION OF SUBROUTINE ADJUST.
C
C CHANGE PRECISION VIA THE INSTRUCTIONS IN SUBROUTINE DRIVE.
C-----------------------------------------------------------------------
C CAUTION:  NOT ALL MEMBERS OF EPCOM1 ARE USED IN THIS SUBROUTINE.
C-----------------------------------------------------------------------
      INTEGER N0
      INTEGER JSTART, KFLAG, L, LMAX, METH, MF, N, NQ, NQINDX
      INTEGER I, IBACK, J, JP1, NQM1, NQM2
C(4
      DOUBLE PRECISION Y
      DOUBLE PRECISION EL, EPS, H, HMAX, HMIN, SS, T, TAU, TQ, UROUND
      DOUBLE PRECISION HSUM, XI
      DOUBLE PRECISION ONE, ZERO
C)4
CS    REAL Y
CS    REAL EL, EPS, H, HMAX, HMIN, SS, T, TAU, TQ, UROUND
CS    REAL HSUM, XI
CS    REAL ONE, ZERO
C/10
      DIMENSION Y(N0,13)
C
      COMMON /EPCOM1/ T,H,HMIN,HMAX,EPS,SS,UROUND,N,MF,KFLAG,JSTART
      COMMON /EPCM10/ TAU(13),EL(13),TQ(5),LMAX,METH,NQ,L,NQINDX
C(1
      DATA ONE /1.0D0/, ZERO /0.0D0/
C)1
CS    DATA ONE /1.0E0/, ZERO /0.0E0/
C/4
      IF (NQ .EQ. 2) RETURN
      NQM1 = NQ - 1
      NQM2 = NQ - 2
      GO TO (100, 200), METH
C
 100  DO 110 J = 1,LMAX
 110    EL(J) = ZERO
      EL(2) = ONE
      HSUM = ZERO
      DO 130 J = 1,NQM2
C CONSTRUCT COEFFICIENTS OF X*(X+XI(1))*...*(X+XI(J)). -----------------
        HSUM = HSUM + TAU(J)
        XI = HSUM/H
        JP1 = J + 1
        DO 120 IBACK = 1,JP1
          I = (J + 3) - IBACK
 120      EL(I) = EL(I)*XI + EL(I-1)
 130    CONTINUE
C CONSTRUCT COEFFICIENTS OF INTEGRATED POLYNOMIAL. ---------------------
      DO 140 J = 2,NQM1
C(1
  140   EL(J+1) = DFLOAT(NQ)*EL(J)/DFLOAT(J)
C)1
CS140   EL(J+1) = FLOAT(NQ)*EL(J)/FLOAT(J)
C/4
      GO TO 300
C
 200  DO 210 J = 1,LMAX
 210    EL(J) = ZERO
      EL(3) = ONE
      HSUM = ZERO
      DO 230 J = 1,NQM2
C CONSTRUCT COEFFICIENTS OF X*X*(X+XI(1))*...*(X+XI(J)). ---------------
        HSUM = HSUM + TAU(J)
        XI = HSUM/H
        JP1 = J + 1
        DO 220 IBACK = 1,JP1
          I = (J + 4) - IBACK
 220      EL(I) = EL(I)*XI + EL(I-1)
 230    CONTINUE
C
C SUBTRACT CORRECTION TERMS FROM Y ARRAY. ------------------------------
 300  DO 320 J = 3,NQ
        DO 310 I = 1,N
 310      Y(I,J) = Y(I,J) - Y(I,L)*EL(J)
 320    CONTINUE
      RETURN
C-----------------------  END OF SUBROUTINE DADJST  --------------------
      END
      SUBROUTINE DPSET (Y,N0,CON,MITER,IER)
C-----------------------------------------------------------------------
C PSET IS CALLED BY TSTEP TO COMPUTE AND TO PROCESS THE MATRIX
C P = I - (H/EL(2))*J, WHERE J IS AN APPROXIMATION TO THE
C JACOBIAN.  J IS COMPUTED BY EITHER THE USER SUPPLIED
C SUBROUTINE PEDERV, WHEN MITER = 1, OR BY FINITE DIFFERENCES,
C WHEN MITER = 2.  J IS STORED IN PW AND REPLACED BY P, USING
C CON = -H/EL(2).  THEN P IS SUBJECTED TO AN LU DECOMPOSITION
C FOR LATER SOLUTION OF LINEAR ALGEBRAIC SYSTEMS WITH P AS THE
C COEFFICIENT MATRIX.
C
C IN ADDITION TO VARIABLES DESCRIBED PREVIOUSLY, COMMUNICATION
C WITH PSET USES THE FOLLOWING..
C   EPSJ = SQRT(UROUND), USED IN THE NUMERICAL JACOBIAN INCREMENTS.
C   NSQ  = N0**2.
C-----------------------------------------------------------------------
C CAUTION:  NOT ALL EPCOM1 VARIABLES ARE USED INTHIS SUBROUTINE.
C-----------------------------------------------------------------------
C$ THIS IS THE DOUBLE PRECISION VERSION OF SUBROUTINE PSET.
C
C CHANGE PRECISION VIA THE INSTRUCTIONS IN SUBROUTINE DRIVE.
C-----------------------------------------------------------------------
      INTEGER IER, MITER, N0
      INTEGER IPIV, JSTART, KFLAG, MF, N, NSQ
      INTEGER I, J, J1
C(5
      DOUBLE PRECISION CON, Y
      DOUBLE PRECISION EPS, EPSJ, H, HMAX, HMIN, PW, SAVE1, SAVE2,
     1                 SS, T, UROUND, YMAX
      DOUBLE PRECISION D, R, R0, YJ
      DOUBLE PRECISION ONE, REP, ZERO
C)5
CS    REAL CON, Y
CS    REAL EPS, EPSJ, H, HMAX, HMIN, PW, SAVE1, SAVE2,
CS   1     SS, UROUND, YMAX
CS    REAL D, R, R0, T, YJ
CS    REAL ONE, REP, ZERO
C/12
      DIMENSION Y(N0,1)
C
      COMMON /EPCOM1/ T,H,HMIN,HMAX,EPS,SS,UROUND,N,MF,KFLAG,JSTART
      COMMON /EPCOM2/ YMAX(1)
      COMMON /EPCOM4/ SAVE1(1)
      COMMON /EPCOM5/ SAVE2(1)
      COMMON /EPCOM6/ PW(1)
      COMMON /EPCOM7/ IPIV(1)
      COMMON /EPCOM8/ EPSJ,NSQ
C(1
      DATA ONE /1.0D0/, REP /1.0D-3/, ZERO /0.0D0/
C)1
CS    DATA ONE /1.0E0/, REP /1.0E-3/, ZERO /0.0E0/
C/4
      IF (MITER .EQ. 2) GO TO 20
C IF MITER = 1, CALL PEDERV AND MULTIPLY BY A SCALAR.  -----------------
      CALL DPDERV (N, T, Y, PW, N0)
      DO 10 I = 1,NSQ
  10    PW(I) = PW(I)*CON
      GO TO 60
C IF MITER = 2, MAKE N CALLS TO DIFFUN TO APPROXIMATE J. ---------------
  20  D = ZERO
      DO 30 I = 1,N
  30    D = D + SAVE2(I)**2
C(1
      R0 = DABS(H)*DSQRT(D)*UROUND/REP
C)1
CS    R0 = ABS(H)*SQRT(D)*UROUND/REP
C/4
      J1 = 0
      DO 50 J = 1,N
        YJ = Y(J,1)
        R = EPSJ*YMAX(J)
C(1
        R = DMAX1(R,R0)
C)1
CS      R = AMAX1(R,R0)
C/4
        Y(J,1) = Y(J,1) + R
        D = CON/R
        CALL DDIFUN (N, T, Y, SAVE1)
        DO 40 I = 1,N
  40      PW(I+J1) = (SAVE1(I) - SAVE2(I))*D
        Y(J,1) = YJ
        J1 = J1 + N0
  50    CONTINUE
C ADD ON THE IDENTITY MATRIX.  -----------------------------------------
  60  J = 1
      DO 70 I = 1,N
        PW(J) = PW(J) + ONE
  70    J = J + (N0 + 1)
C GET LU DECOMPOSITION OF P. -------------------------------------------
      CALL DDEC (N, N0, PW, IPIV, IER)
      RETURN
C-----------------------  END OF SUBROUTINE DPSET ----------------------
      END
      SUBROUTINE DDEC (N, NDIM, A, IP, IER)
C-----------------------------------------------------------------------
C MATRIX TRIANGULARIZATION BY GAUSSIAN ELIMINATION.
C INPUT..
C    N = ORDER OF MATRIX.
C    NDIM = DECLARED DIMENSION OF ARRAY  A .
C    A = MATRIX TO BE TRIANGULARIZED.
C OUTPUT..
C    A(I,J), I.LE.J = UPPER TRIANGULAR FACTOR, U .
C    A(I,J), I.GT.J = MULTIPLIERS = LOWER TRIANGULAR FACTOR, I - L.
C    IP(K), K.LT.N = INDEX OF K-TH PIVOT ROW.
C    IP(N) = (-1)**(NUMBER OF INTERCHANGES) OR O .
C    IER = 0 IF A NONSINGULAR, OR K IF A FOUND TO BE
C          SINGULAR AT STAGE K.
C USE  SOL  TO OBTAIN SOLUTION OF LINEAR SYSTEM.
C DETERM(A) = IP(N)*A(1,1)*A(2,2)*...*A(N,N).
C IF IP(N)=0, A IS SINGULAR, SOL WILL DIVIDE BY ZERO.
C INTERCHANGES FINISHED IN U , ONLY PARTLY IN L .
C
C REFERENCE..
C C. B. MOLER, ALGORITHM 423, LINEAR EQUATION SOLVER,
C COMM. ASSOC. COMPUT. MACH., 15 (1972), P. 274.
C-----------------------------------------------------------------------
C$ THIS IS THE DOUBLE PRECISION VERSION OF SUBROUTINE DEC.
C
C CHANGE PRECISION VIA THE INSTRUCTIONS IN SUBROUTINE DRIVE.
C-----------------------------------------------------------------------
      INTEGER IER, IP, N, NDIM
      INTEGER I, J, K, KP1, M, NM1
C(3
      DOUBLE PRECISION A
      DOUBLE PRECISION T
      DOUBLE PRECISION ONE, ZERO
C)3
CS    REAL A
CS    REAL T
CS    REAL ONE, ZERO
C/8
      DIMENSION A(NDIM,N),IP(N)
C(1
      DATA ONE /1.0D0/, ZERO /0.0D0/
C)1
CS    DATA ONE /1.0E0/, ZERO /0.0E0/
C/4
      IER = 0
      IP(N) = 1
      IF (N .EQ. 1) GO TO 70
      NM1 = N - 1
      DO 60 K = 1,NM1
        KP1 = K + 1
        M = K
        DO 10 I = KP1,N
C(1
  10      IF (DABS(A(I,K)) .GT. DABS(A(M,K))) M = I
C)1
CS10      IF (ABS(A(I,K)) .GT. ABS(A(M,K))) M = I
C/4
        IP(K) = M
        T = A(M,K)
        IF (M .EQ. K) GO TO 20
        IP(N) = -IP(N)
        A(M,K) = A(K,K)
        A(K,K) = T
 20     IF (T .EQ. ZERO) GO TO 80
        T = ONE/T
        DO 30 I = KP1,N
 30       A(I,K) = -A(I,K)*T
        DO 50 J = KP1,N
          T = A(M,J)
          A(M,J) = A(K,J)
          A(K,J) = T
          IF (T .EQ. ZERO) GO TO 50
          DO 40 I = KP1,N
 40         A(I,J) = A(I,J) + A(I,K)*T
 50       CONTINUE
 60     CONTINUE
 70   K = N
      IF (A(N,N) .EQ. ZERO) GO TO 80
      RETURN
 80   IER = K
      IP(N) = 0
      RETURN
C-----------------------  END OF SUBROUTINE DDEC  ----------------------
      END
      SUBROUTINE DSOL (N, NDIM, A, B, IP)
C-----------------------------------------------------------------------
C SOLUTION OF LINEAR SYSTEM, A*X = B .
C INPUT..
C   N = ORDER OF MATRIX.
C   NDIM = DECLARED DIMENSION OF ARRAY  A .
C   A = TRIANGULARIZED MATRIX OBTAINED FROM DEC.
C   B = RIGHT HAND SIDE VECTOR.
C   IP = PIVOT VECTOR OBTAINED FROM DEC.
C DO NOT USE IF DEC HAS SET IER .NE. 0.
C OUTPUT..
C   B = SOLUTION VECTOR, X .
C-----------------------------------------------------------------------
C$ THIS IS THE DOUBLE PRECISION VERSION OF SUBROUTINE SOL.
C
C CHANGE PRECISION VIA THE INSTRUCTIONS IN SUBROUTINE DRIVE.
C-----------------------------------------------------------------------
      INTEGER IP, N, NDIM
      INTEGER I, K, KB, KM1, KP1, M, NM1
C(2
      DOUBLE PRECISION A, B
      DOUBLE PRECISION T
C)2
CS    REAL A, B
CS    REAL T
C/6
      DIMENSION A(NDIM, N), B(N), IP(N)
C
      IF (N .EQ. 1) GO TO 50
      NM1 = N - 1
      DO 20 K = 1,NM1
        KP1 = K + 1
        M = IP(K)
        T = B(M)
        B(M) = B(K)
        B(K) = T
        DO 10 I = KP1,N
 10       B(I) = B(I) + A(I,K)*T
 20     CONTINUE
      DO 40 KB = 1,NM1
        KM1 = N - KB
        K = KM1 + 1
        B(K) = B(K)/A(K,K)
        T = -B(K)
        DO 30 I = 1,KM1
 30       B(I) = B(I) + A(I,K)*T
 40     CONTINUE
 50   B(1) = B(1)/A(1,1)
      RETURN
C-----------------------  END OF SUBROUTINE DSOL  ----------------------
      END
