function [ret,x0,str,ts,xts]=global(t,x,u,flag);
%GLOBAL	is the M-file description of the SIMULINK system named GLOBAL.
%	The block-diagram can be displayed by typing: GLOBAL.
%
%	SYS=GLOBAL(T,X,U,FLAG) returns depending on FLAG certain
%	system values given time point, T, current state vector, X,
%	and input vector, U.
%	FLAG is used to indicate the type of output to be returned in SYS.
%
%	Setting FLAG=1 causes GLOBAL to return state derivatives, FLAG=2
%	discrete states, FLAG=3 system outputs and FLAG=4 next sample
%	time. For more information and other options see SFUNC.
%
%	Calling GLOBAL with a FLAG of zero:
%	[SIZES]=GLOBAL([],[],[],0),  returns a vector, SIZES, which
%	contains the sizes of the state vector and other parameters.
%		SIZES(1) number of states
%		SIZES(2) number of discrete states
%		SIZES(3) number of outputs
%		SIZES(4) number of inputs
%		SIZES(5) number of roots (currently unsupported)
%		SIZES(6) direct feedthrough flag
%		SIZES(7) number of sample times
%
%	For the definition of other parameters in SIZES, see SFUNC.
%	See also, TRIM, LINMOD, LINSIM, EULER, RK23, RK45, ADAMS, GEAR.

% Note: This M-file is only used for saving graphical information;
%       after the model is loaded into memory an internal model
%       representation is used.

% the system will take on the name of this mfile:
sys = mfilename;
new_system(sys)
simver(1.3)
if (0 == (nargin + nargout))
     set_param(sys,'Location',[19,66,347,270])
     open_system(sys)
end;
set_param(sys,'algorithm',     'RK-45')
set_param(sys,'Start time',    '0.0')
set_param(sys,'Stop time',     '999999')
set_param(sys,'Min step size', '0.0001')
set_param(sys,'Max step size', '.10')
set_param(sys,'Relative error','1e-3')
set_param(sys,'Return vars',   '')

add_block('built-in/Note',[sys,'/',['These blocks can be used to transfer signals',13,'through your block diagram without using lines.',13,'Open the demo for an example of how to use them.']])
set_param([sys,'/',['These blocks can be used to transfer signals',13,'through your block diagram without using lines.',13,'Open the demo for an example of how to use them.']],...
		'position',[170,21,175,26])


%     Subsystem  'Put Signal'.

new_system([sys,'/','Put Signal'])
set_param([sys,'/','Put Signal'],'Location',[95,507,307,644])

add_block('built-in/Inport',[sys,'/','Put Signal/in_1'])
set_param([sys,'/','Put Signal/in_1'],...
		'position',[15,65,35,85])

add_block('built-in/S-Function',[sys,'/','Put Signal/S-Function'])
set_param([sys,'/','Put Signal/S-Function'],...
		'function name','putsig',...
		'parameters','width,name',...
		'position',[70,62,125,88])
add_line([sys,'/','Put Signal'],[40,75;65,75])
set_param([sys,'/','Put Signal'],...
		'Mask Display','PUTSIG',...
		'Mask Type','Put Signal',...
		'Mask Dialogue','Put a signal into the MATLAB workspace.  Specify the signal width and name. | Signal Width: | Name (in quotes):')
set_param([sys,'/','Put Signal'],...
		'Mask Translate','width=@1;name=@2;',...
		'Mask Help','Send a signal to the MATLAB workspace. To be used in conjunction with GETSIG. Name must be enetered as a string. Code for this block is putsig.c')
set_param([sys,'/','Put Signal'],...
		'Mask Entries','3\/''signal''\/')


%     Finished composite block 'Put Signal'.

set_param([sys,'/','Put Signal'],...
		'position',[35,91,105,129])


%     Subsystem  'Get Signal'.

new_system([sys,'/','Get Signal'])
set_param([sys,'/','Get Signal'],'Location',[200,522,342,636])

add_block('built-in/S-Function',[sys,'/','Get Signal/S-Function1'])
set_param([sys,'/','Get Signal/S-Function1'],...
		'function name','getsig',...
		'parameters','width,name',...
		'position',[65,48,115,72])

add_block('built-in/Outport',[sys,'/','Get Signal/out_1'])
set_param([sys,'/','Get Signal/out_1'],...
		'position',[125,50,145,70])
add_line([sys,'/','Get Signal'],[120,60;120,60])
set_param([sys,'/','Get Signal'],...
		'Mask Display','GETSIG',...
		'Mask Type','GEt Signal',...
		'Mask Dialogue','Put a signal into the MATLAB workspace.  Specify the signal width and name. | Signal Width: | Name (in quotes):')
set_param([sys,'/','Get Signal'],...
		'Mask Translate','width=@1;name=@2;',...
		'Mask Help','Get signal from the MATLAB workspace. To be used in conjunction with PUTSIG. Names must be entered as strings.  The code for this block is getsig.c')
set_param([sys,'/','Get Signal'],...
		'Mask Entries','3\/''signal''\/')


%     Finished composite block 'Get Signal'.

set_param([sys,'/','Get Signal'],...
		'position',[245,90,305,130])


%     Subsystem  'Global Demo'.

new_system([sys,'/','Global Demo'])
set_param([sys,'/','Global Demo'],'Location',[21,60,479,228])

add_block('built-in/Signal Generator',[sys,'/',['Global Demo/Signal',13,'Generator']])
set_param([sys,'/',['Global Demo/Signal',13,'Generator']],...
		'Peak','2.000000',...
		'Peak Range','5.000000',...
		'Freq','2.000000',...
		'Freq Range','5.000000',...
		'Wave','Saw',...
		'Units','Rads')
open_system([sys,'/',['Global Demo/Signal',13,'Generator']])
set_param([sys,'/',['Global Demo/Signal',13,'Generator']],...
		'position',[35,33,80,67])


%     Subsystem  'Global Demo/Put Signal'.

new_system([sys,'/','Global Demo/Put Signal'])
set_param([sys,'/','Global Demo/Put Signal'],'Location',[95,507,307,644])

add_block('built-in/S-Function',[sys,'/','Global Demo/Put Signal/S-Function'])
set_param([sys,'/','Global Demo/Put Signal/S-Function'],...
		'function name','putsig',...
		'parameters','width,name',...
		'position',[70,62,125,88])

add_block('built-in/Inport',[sys,'/','Global Demo/Put Signal/in_1'])
set_param([sys,'/','Global Demo/Put Signal/in_1'],...
		'position',[15,65,35,85])
add_line([sys,'/','Global Demo/Put Signal'],[40,75;65,75])
set_param([sys,'/','Global Demo/Put Signal'],...
		'Mask Display','PUTSIG',...
		'Mask Type','Put Signal',...
		'Mask Dialogue','Put a signal into the MATLAB workspace.  Specify the signal width and name. | Signal Width: | Name (in quotes):')
set_param([sys,'/','Global Demo/Put Signal'],...
		'Mask Translate','width=@1;name=@2;')
set_param([sys,'/','Global Demo/Put Signal'],...
		'Mask Help','Send a signal to the MATLAB workspace. To be used in conjunction with GETSIG. Name must be enetered as a string. Code for this block is putsig.c',...
		'Mask Entries','1\/''siggen''\/')


%     Finished composite block 'Global Demo/Put Signal'.

set_param([sys,'/','Global Demo/Put Signal'],...
		'position',[120,31,190,69])


%     Subsystem  'Global Demo/Get Signal'.

new_system([sys,'/','Global Demo/Get Signal'])
set_param([sys,'/','Global Demo/Get Signal'],'Location',[200,522,342,636])

add_block('built-in/Outport',[sys,'/','Global Demo/Get Signal/out_1'])
set_param([sys,'/','Global Demo/Get Signal/out_1'],...
		'position',[125,50,145,70])

add_block('built-in/S-Function',[sys,'/','Global Demo/Get Signal/S-Function1'])
set_param([sys,'/','Global Demo/Get Signal/S-Function1'],...
		'function name','getsig',...
		'parameters','width,name',...
		'position',[65,48,115,72])
add_line([sys,'/','Global Demo/Get Signal'],[120,60;120,60])
set_param([sys,'/','Global Demo/Get Signal'],...
		'Mask Display','GETSIG',...
		'Mask Type','GEt Signal',...
		'Mask Dialogue','Put a signal into the MATLAB workspace.  Specify the signal width and name. | Signal Width: | Name (in quotes):')
set_param([sys,'/','Global Demo/Get Signal'],...
		'Mask Translate','width=@1;name=@2;')
set_param([sys,'/','Global Demo/Get Signal'],...
		'Mask Help','Get signal from the MATLAB workspace. To be used in conjunction with PUTSIG. Names must be entered as strings.  The code for this block is getsig.c')
set_param([sys,'/','Global Demo/Get Signal'],...
		'Mask Entries','1\/''siggen''\/')


%     Finished composite block 'Global Demo/Get Signal'.

set_param([sys,'/','Global Demo/Get Signal'],...
		'position',[270,30,330,70])

add_block('built-in/Scope',[sys,'/','Global Demo/Scope'])
set_param([sys,'/','Global Demo/Scope'],...
		'Vgain','3.000000',...
		'Hgain','12.000000',...
		'Vmax','6.000000',...
		'Hmax','24.489796',...
		'Window',[512,131,843,445],...
		'position',[370,35,400,65])

add_block('built-in/Note',[sys,'/',['Global Demo/Use a PUTSIG to transfer the',13,'Signal Generator output to a',13,'MATLAB workspace variable.']])
set_param([sys,'/',['Global Demo/Use a PUTSIG to transfer the',13,'Signal Generator output to a',13,'MATLAB workspace variable.']],...
		'position',[110,107,115,112])

add_block('built-in/Note',[sys,'/',['Global Demo/Use a GETSIG to pick up the',13,'Signal Generator output from a',13,'MATLAB workspace variable.']])
set_param([sys,'/',['Global Demo/Use a GETSIG to pick up the',13,'Signal Generator output from a',13,'MATLAB workspace variable.']],...
		'position',[335,107,340,112])
add_line([sys,'/','Global Demo'],[335,50;365,50])
add_line([sys,'/','Global Demo'],[85,50;115,50])
set_param([sys,'/','Global Demo'],...
		'Mask Display','Demo')


%     Finished composite block 'Global Demo'.

set_param([sys,'/','Global Demo'],...
		'position',[130,139,205,181])

drawnow

% Return any arguments.
if (nargin | nargout)
	% Must use feval here to access system in memory
	if (nargin > 3)
		if (flag == 0)
			eval(['[ret,x0,str,ts,xts]=',sys,'(t,x,u,flag);'])
		else
			eval(['ret =', sys,'(t,x,u,flag);'])
		end
	else
		[ret,x0,str,ts,xts] = feval(sys);
	end
else
	drawnow % Flash up the model and execute load callback
end
