function [ret,x0,str,ts,xts]=imotor(t,x,u,flag);
%IMOTOR	is the M-file description of the SIMULINK system named IMOTOR.
%	The block-diagram can be displayed by typing: IMOTOR.
%
%	SYS=IMOTOR(T,X,U,FLAG) returns depending on FLAG certain
%	system values given time point, T, current state vector, X,
%	and input vector, U.
%	FLAG is used to indicate the type of output to be returned in SYS.
%
%	Setting FLAG=1 causes IMOTOR to return state derivatives, FLAG=2
%	discrete states, FLAG=3 system outputs and FLAG=4 next sample
%	time. For more information and other options see SFUNC.
%
%	Calling IMOTOR with a FLAG of zero:
%	[SIZES]=IMOTOR([],[],[],0),  returns a vector, SIZES, which
%	contains the sizes of the state vector and other parameters.
%		SIZES(1) number of states
%		SIZES(2) number of discrete states
%		SIZES(3) number of outputs
%		SIZES(4) number of inputs
%		SIZES(5) number of roots (currently unsupported)
%		SIZES(6) direct feedthrough flag
%		SIZES(7) number of sample times
%
%	For the definition of other parameters in SIZES, see SFUNC.
%	See also, TRIM, LINMOD, LINSIM, EULER, RK23, RK45, ADAMS, GEAR.

% Note: This M-file is only used for saving graphical information;
%       after the model is loaded into memory an internal model
%       representation is used.

% the system will take on the name of this mfile:
sys = mfilename;
new_system(sys)
simver(1.3)
if (0 == (nargin + nargout))
     set_param(sys,'Location',[120,73,816,400])
     open_system(sys)
end;
set_param(sys,'algorithm',     'Gear')
set_param(sys,'Start time',    '0.0')
set_param(sys,'Stop time',     '5')
set_param(sys,'Min step size', '0.000001')
set_param(sys,'Max step size', '1')
set_param(sys,'Relative error','1e-4')
set_param(sys,'Return vars',   '')

add_block('built-in/Clock',[sys,'/','Clock'])
set_param([sys,'/','Clock'],...
		'position',[75,95,95,115])

add_block('built-in/To Workspace',[sys,'/','To Workspace2'])
set_param([sys,'/','To Workspace2'],...
		'hide name',0,...
		'mat-name','t',...
		'buffer','',...
		'position',[140,97,190,113])


%     Subsystem  ['Rotate into',13,'stationary',13,'coordinates'].

new_system([sys,'/',['Rotate into',13,'stationary',13,'coordinates']])
set_param([sys,'/',['Rotate into',13,'stationary',13,'coordinates']],'Location',[120,434,575,701])


%     Subsystem  ['Rotate into',13,'stationary',13,'coordinates/Cartesian to polar'].

new_system([sys,'/',['Rotate into',13,'stationary',13,'coordinates/Cartesian to polar']])
set_param([sys,'/',['Rotate into',13,'stationary',13,'coordinates/Cartesian to polar']],'Location',[0,0,359,206])

add_block('built-in/Fcn',[sys,'/',['Rotate into',13,'stationary',13,'coordinates/Cartesian to polar/x->r']])
set_param([sys,'/',['Rotate into',13,'stationary',13,'coordinates/Cartesian to polar/x->r']],...
		'Expr','hypot(u[1],u[2])',...
		'position',[155,72,260,98])

add_block('built-in/Fcn',[sys,'/',['Rotate into',13,'stationary',13,'coordinates/Cartesian to polar/x->theta']])
set_param([sys,'/',['Rotate into',13,'stationary',13,'coordinates/Cartesian to polar/x->theta']],...
		'Expr','atan2(u[2],u[1])',...
		'position',[160,129,265,151])

add_block('built-in/Mux',[sys,'/',['Rotate into',13,'stationary',13,'coordinates/Cartesian to polar/Mux']])
set_param([sys,'/',['Rotate into',13,'stationary',13,'coordinates/Cartesian to polar/Mux']],...
		'inputs','2',...
		'position',[75,96,105,129])

add_block('built-in/Outport',[sys,'/',['Rotate into',13,'stationary',13,'coordinates/Cartesian to polar/r']])
set_param([sys,'/',['Rotate into',13,'stationary',13,'coordinates/Cartesian to polar/r']],...
		'position',[295,75,315,95])

add_block('built-in/Inport',[sys,'/',['Rotate into',13,'stationary',13,'coordinates/Cartesian to polar/x']])
set_param([sys,'/',['Rotate into',13,'stationary',13,'coordinates/Cartesian to polar/x']],...
		'position',[20,70,40,90])

add_block('built-in/Inport',[sys,'/',['Rotate into',13,'stationary',13,'coordinates/Cartesian to polar/y']])
set_param([sys,'/',['Rotate into',13,'stationary',13,'coordinates/Cartesian to polar/y']],...
		'Port','2',...
		'position',[20,129,40,151])

add_block('built-in/Outport',[sys,'/',['Rotate into',13,'stationary',13,'coordinates/Cartesian to polar/theta']])
set_param([sys,'/',['Rotate into',13,'stationary',13,'coordinates/Cartesian to polar/theta']],...
		'Port','2',...
		'position',[295,130,315,150])

add_block('built-in/Note',[sys,'/',['Rotate into',13,'stationary',13,'coordinates/Cartesian to polar/Cartesian to Polar']])
set_param([sys,'/',['Rotate into',13,'stationary',13,'coordinates/Cartesian to polar/Cartesian to Polar']],...
		'position',[165,30,170,35])
add_line([sys,'/',['Rotate into',13,'stationary',13,'coordinates/Cartesian to polar']],[110,115;125,115;125,85;150,85])
add_line([sys,'/',['Rotate into',13,'stationary',13,'coordinates/Cartesian to polar']],[125,115;125,140;155,140])
add_line([sys,'/',['Rotate into',13,'stationary',13,'coordinates/Cartesian to polar']],[265,85;290,85])
add_line([sys,'/',['Rotate into',13,'stationary',13,'coordinates/Cartesian to polar']],[45,80;70,105])
add_line([sys,'/',['Rotate into',13,'stationary',13,'coordinates/Cartesian to polar']],[45,140;70,120])
add_line([sys,'/',['Rotate into',13,'stationary',13,'coordinates/Cartesian to polar']],[270,140;290,140])
set_param([sys,'/',['Rotate into',13,'stationary',13,'coordinates/Cartesian to polar']],...
		'Mask Display','plot(0,0,100,100,[24,20,15,20,20],[85,95,85,95,20],[80,20,95,85,95,85],[70,20,20,15,20,24],[56,56,55,52,50,46],[20,26,31,35,38,42])')
set_param([sys,'/',['Rotate into',13,'stationary',13,'coordinates/Cartesian to polar']],...
		'Mask Type','[x,y]->[r,theta]',...
		'Mask Dialogue','Tranformation from cartesian to polar\ncoordinates.\nr=sqrt(x^2+y^2), theta=atan(y/x)')
set_param([sys,'/',['Rotate into',13,'stationary',13,'coordinates/Cartesian to polar']],...
		'Mask Help','Unmask this block for more help.')


%     Finished composite block ['Rotate into',13,'stationary',13,'coordinates/Cartesian to polar'].

set_param([sys,'/',['Rotate into',13,'stationary',13,'coordinates/Cartesian to polar']],...
		'hide name',0,...
		'position',[135,57,170,108])


%     Subsystem  ['Rotate into',13,'stationary',13,'coordinates/Polar to cartesian'].

new_system([sys,'/',['Rotate into',13,'stationary',13,'coordinates/Polar to cartesian']])
set_param([sys,'/',['Rotate into',13,'stationary',13,'coordinates/Polar to cartesian']],'Location',[0,0,359,206])

add_block('built-in/Note',[sys,'/',['Rotate into',13,'stationary',13,'coordinates/Polar to cartesian/Polar to Cartesian']])
set_param([sys,'/',['Rotate into',13,'stationary',13,'coordinates/Polar to cartesian/Polar to Cartesian']],...
		'position',[170,25,175,30])

add_block('built-in/Outport',[sys,'/',['Rotate into',13,'stationary',13,'coordinates/Polar to cartesian/y']])
set_param([sys,'/',['Rotate into',13,'stationary',13,'coordinates/Polar to cartesian/y']],...
		'Port','2',...
		'position',[295,130,315,150])

add_block('built-in/Inport',[sys,'/',['Rotate into',13,'stationary',13,'coordinates/Polar to cartesian/theta ']])
set_param([sys,'/',['Rotate into',13,'stationary',13,'coordinates/Polar to cartesian/theta ']],...
		'Port','2',...
		'position',[20,129,40,151])

add_block('built-in/Inport',[sys,'/',['Rotate into',13,'stationary',13,'coordinates/Polar to cartesian/r ']])
set_param([sys,'/',['Rotate into',13,'stationary',13,'coordinates/Polar to cartesian/r ']],...
		'position',[20,70,40,90])

add_block('built-in/Outport',[sys,'/',['Rotate into',13,'stationary',13,'coordinates/Polar to cartesian/x']])
set_param([sys,'/',['Rotate into',13,'stationary',13,'coordinates/Polar to cartesian/x']],...
		'position',[295,75,315,95])

add_block('built-in/Mux',[sys,'/',['Rotate into',13,'stationary',13,'coordinates/Polar to cartesian/Mux']])
set_param([sys,'/',['Rotate into',13,'stationary',13,'coordinates/Polar to cartesian/Mux']],...
		'hide name',0,...
		'inputs','2',...
		'position',[75,96,105,129])

add_block('built-in/Fcn',[sys,'/',['Rotate into',13,'stationary',13,'coordinates/Polar to cartesian/theta->y']])
set_param([sys,'/',['Rotate into',13,'stationary',13,'coordinates/Polar to cartesian/theta->y']],...
		'Expr','u[1]*sin(u[2])',...
		'position',[160,129,265,151])

add_block('built-in/Fcn',[sys,'/',['Rotate into',13,'stationary',13,'coordinates/Polar to cartesian/r->x']])
set_param([sys,'/',['Rotate into',13,'stationary',13,'coordinates/Polar to cartesian/r->x']],...
		'Expr','u[1]*cos(u[2])',...
		'position',[155,72,260,98])
add_line([sys,'/',['Rotate into',13,'stationary',13,'coordinates/Polar to cartesian']],[270,140;290,140])
add_line([sys,'/',['Rotate into',13,'stationary',13,'coordinates/Polar to cartesian']],[45,140;70,120])
add_line([sys,'/',['Rotate into',13,'stationary',13,'coordinates/Polar to cartesian']],[45,80;70,105])
add_line([sys,'/',['Rotate into',13,'stationary',13,'coordinates/Polar to cartesian']],[265,85;290,85])
add_line([sys,'/',['Rotate into',13,'stationary',13,'coordinates/Polar to cartesian']],[110,115;125,115;125,85;150,85])
add_line([sys,'/',['Rotate into',13,'stationary',13,'coordinates/Polar to cartesian']],[125,115;125,140;155,140])
set_param([sys,'/',['Rotate into',13,'stationary',13,'coordinates/Polar to cartesian']],...
		'Mask Display','plot(0,0,100,100,[25,20,15,20,20],[85,95,85,95,20],[70,20,95,86,95,85],[60,20,20,15,20,25],[70,70],[45,54],[70,70],[30,40],[70,70],[20,25],[55,65],[60,60],[40,50],[60,60],[25,34],[60,60],[20,21],[60,60],[70,70,68],[57,60,60])')
set_param([sys,'/',['Rotate into',13,'stationary',13,'coordinates/Polar to cartesian']],...
		'Mask Type','[r,theta]->[x,y]',...
		'Mask Dialogue','Tranformation from polar to cartesian\ncoordinates.\nx=r.cos(theta), y=r.sin(theta)')
set_param([sys,'/',['Rotate into',13,'stationary',13,'coordinates/Polar to cartesian']],...
		'Mask Help','Unmask this block for more help.')


%     Finished composite block ['Rotate into',13,'stationary',13,'coordinates/Polar to cartesian'].

set_param([sys,'/',['Rotate into',13,'stationary',13,'coordinates/Polar to cartesian']],...
		'hide name',0,...
		'position',[275,55,310,115])

add_block('built-in/Sum',[sys,'/',['Rotate into',13,'stationary',13,'coordinates/Sum1']])
set_param([sys,'/',['Rotate into',13,'stationary',13,'coordinates/Sum1']],...
		'hide name',0,...
		'Drop Shadow',4,...
		'position',[215,90,235,110])

add_block('built-in/Inport',[sys,'/',['Rotate into',13,'stationary',13,'coordinates/x']])
set_param([sys,'/',['Rotate into',13,'stationary',13,'coordinates/x']],...
		'Port','2',...
		'position',[30,60,50,80])

add_block('built-in/Inport',[sys,'/',['Rotate into',13,'stationary',13,'coordinates/y']])
set_param([sys,'/',['Rotate into',13,'stationary',13,'coordinates/y']],...
		'Port','3',...
		'position',[30,95,50,115])

add_block('built-in/Outport',[sys,'/',['Rotate into',13,'stationary',13,'coordinates/x''']])
set_param([sys,'/',['Rotate into',13,'stationary',13,'coordinates/x''']],...
		'position',[360,60,380,80])

add_block('built-in/Outport',[sys,'/',['Rotate into',13,'stationary',13,'coordinates/y''']])
set_param([sys,'/',['Rotate into',13,'stationary',13,'coordinates/y''']],...
		'Port','2',...
		'position',[360,100,380,120])

add_block('built-in/Inport',[sys,'/',['Rotate into',13,'stationary',13,'coordinates/phi']])
set_param([sys,'/',['Rotate into',13,'stationary',13,'coordinates/phi']],...
		'position',[30,140,50,160])

add_block('built-in/Gain',[sys,'/',['Rotate into',13,'stationary',13,'coordinates/Gain3']])
set_param([sys,'/',['Rotate into',13,'stationary',13,'coordinates/Gain3']],...
		'hide name',0,...
		'Gain','direction',...
		'position',[140,140,160,160])
add_line([sys,'/',['Rotate into',13,'stationary',13,'coordinates']],[175,95;210,95])
add_line([sys,'/',['Rotate into',13,'stationary',13,'coordinates']],[175,70;270,70])
add_line([sys,'/',['Rotate into',13,'stationary',13,'coordinates']],[240,100;270,100])
add_line([sys,'/',['Rotate into',13,'stationary',13,'coordinates']],[55,70;130,70])
add_line([sys,'/',['Rotate into',13,'stationary',13,'coordinates']],[55,105;85,105;85,95;130,95])
add_line([sys,'/',['Rotate into',13,'stationary',13,'coordinates']],[315,70;355,70])
add_line([sys,'/',['Rotate into',13,'stationary',13,'coordinates']],[315,100;325,100;325,110;355,110])
add_line([sys,'/',['Rotate into',13,'stationary',13,'coordinates']],[55,150;135,150])
add_line([sys,'/',['Rotate into',13,'stationary',13,'coordinates']],[165,150;180,150;180,105;210,105])
set_param([sys,'/',['Rotate into',13,'stationary',13,'coordinates']],...
		'Mask Display','plot(0,0,100,100,[35,30,25],[80,90,80],[70,70,30,30],[60,70,10,90],[63,70],[68,70],[54,55,48,40,30],[55,47,55,59,60],[50,55],[48,47])')
set_param([sys,'/',['Rotate into',13,'stationary',13,'coordinates']],...
		'Mask Dialogue','Angle rotation. See Help.\nUmask to see block.\nEnter direction of rotation\n|1 = positive, -1 =  negative',...
		'Mask Translate','direction=@1;')
set_param([sys,'/',['Rotate into',13,'stationary',13,'coordinates']],...
		'Mask Help','Rotates the vector whose real and imaginary parts enter in port 2 and 3 by the angle which enters port 1.  The direction of \nrotation may be specified in the dialogue.')
set_param([sys,'/',['Rotate into',13,'stationary',13,'coordinates']],...
		'Mask Entries','1\/')


%     Finished composite block ['Rotate into',13,'stationary',13,'coordinates'].

set_param([sys,'/',['Rotate into',13,'stationary',13,'coordinates']],...
		'position',[245,148,305,202])

add_block('built-in/To Workspace',[sys,'/','To Workspace8'])
set_param([sys,'/','To Workspace8'],...
		'hide name',0,...
		'mat-name','vsa',...
		'buffer','',...
		'position',[625,227,675,243])

add_block('built-in/To Workspace',[sys,'/','To Workspace4'])
set_param([sys,'/','To Workspace4'],...
		'hide name',0,...
		'mat-name','vsb',...
		'buffer','',...
		'position',[625,247,675,263])

add_block('built-in/To Workspace',[sys,'/','To Workspace1'])
set_param([sys,'/','To Workspace1'],...
		'hide name',0,...
		'mat-name','wr',...
		'buffer','',...
		'position',[625,207,675,223])

add_block('built-in/To Workspace',[sys,'/','To Workspace6'])
set_param([sys,'/','To Workspace6'],...
		'hide name',0,...
		'mat-name','frb',...
		'buffer','',...
		'position',[625,187,675,203])

add_block('built-in/To Workspace',[sys,'/','To Workspace7'])
set_param([sys,'/','To Workspace7'],...
		'hide name',0,...
		'mat-name','fra',...
		'buffer','',...
		'position',[625,167,675,183])

add_block('built-in/To Workspace',[sys,'/','To Workspace3'])
set_param([sys,'/','To Workspace3'],...
		'hide name',0,...
		'mat-name','isb',...
		'buffer','',...
		'position',[625,147,675,163])

add_block('built-in/To Workspace',[sys,'/','To Workspace5'])
set_param([sys,'/','To Workspace5'],...
		'hide name',0,...
		'mat-name','isa',...
		'buffer','',...
		'position',[625,127,675,143])


%     Subsystem  ['Current source approximation',13,'of induction motor'].

new_system([sys,'/',['Current source approximation',13,'of induction motor']])
set_param([sys,'/',['Current source approximation',13,'of induction motor']],'Location',[333,358,1020,732])
open_system([sys,'/',['Current source approximation',13,'of induction motor']])

add_block('built-in/Inport',[sys,'/',['Current source approximation',13,'of induction motor/isbref']])
set_param([sys,'/',['Current source approximation',13,'of induction motor/isbref']],...
		'Port','2',...
		'position',[100,155,120,175])

add_block('built-in/Inport',[sys,'/',['Current source approximation',13,'of induction motor/isaref']])
set_param([sys,'/',['Current source approximation',13,'of induction motor/isaref']],...
		'position',[100,110,120,130])

add_block('built-in/Sum',[sys,'/',['Current source approximation',13,'of induction motor/Sum3']])
set_param([sys,'/',['Current source approximation',13,'of induction motor/Sum3']],...
		'hide name',0,...
		'inputs','-+',...
		'position',[205,105,225,125])

add_block('built-in/Sum',[sys,'/',['Current source approximation',13,'of induction motor/Sum2']])
set_param([sys,'/',['Current source approximation',13,'of induction motor/Sum2']],...
		'hide name',0,...
		'inputs','-+',...
		'position',[205,150,225,170])

add_block('built-in/Outport',[sys,'/',['Current source approximation',13,'of induction motor/fra']])
set_param([sys,'/',['Current source approximation',13,'of induction motor/fra']],...
		'Port','3',...
		'position',[625,125,645,145])

add_block('built-in/Outport',[sys,'/',['Current source approximation',13,'of induction motor/wr']])
set_param([sys,'/',['Current source approximation',13,'of induction motor/wr']],...
		'Port','5',...
		'position',[625,250,645,270])

add_block('built-in/Outport',[sys,'/',['Current source approximation',13,'of induction motor/isa']])
set_param([sys,'/',['Current source approximation',13,'of induction motor/isa']],...
		'position',[625,20,645,40])

add_block('built-in/Outport',[sys,'/',['Current source approximation',13,'of induction motor/isb']])
set_param([sys,'/',['Current source approximation',13,'of induction motor/isb']],...
		'Port','2',...
		'position',[625,75,645,95])

add_block('built-in/Outport',[sys,'/',['Current source approximation',13,'of induction motor/frb']])
set_param([sys,'/',['Current source approximation',13,'of induction motor/frb']],...
		'Port','4',...
		'position',[625,190,645,210])


%     Subsystem  ['Current source approximation',13,'of induction motor/Flux monitor'].

new_system([sys,'/',['Current source approximation',13,'of induction motor/Flux monitor']])
set_param([sys,'/',['Current source approximation',13,'of induction motor/Flux monitor']],'Location',[0,59,274,252])

add_block('built-in/Inport',[sys,'/',['Current source approximation',13,'of induction motor/Flux monitor/x']])
set_param([sys,'/',['Current source approximation',13,'of induction motor/Flux monitor/x']],...
		'position',[65,55,85,75])

add_block('built-in/S-Function',[sys,'/',['Current source approximation',13,'of induction motor/Flux monitor/S-function',13,'M-file which plots',13,'lines',13,'']])
set_param([sys,'/',['Current source approximation',13,'of induction motor/Flux monitor/S-function',13,'M-file which plots',13,'lines',13,'']],...
		'function name','sfuny',...
		'parameters','ax, color,dt',...
		'position',[130,55,180,75])
add_line([sys,'/',['Current source approximation',13,'of induction motor/Flux monitor']],[90,65;125,65])
set_param([sys,'/',['Current source approximation',13,'of induction motor/Flux monitor']],...
		'Mask Display','plot(0,0,100,100,[90,10,10,10,90,90,10],[65,65,90,40,40,90,90],[90,78,69,54,40,31,25,10],[77,60,48,46,56,75,81,84])')
set_param([sys,'/',['Current source approximation',13,'of induction motor/Flux monitor']],...
		'Mask Type','Graph scope.')
set_param([sys,'/',['Current source approximation',13,'of induction motor/Flux monitor']],...
		'Mask Dialogue','Graph scope using MATLAB graph window.\nEnter plotting ranges and line type.|Time range:|y-min:|y-max:|Line type (rgbw-:*). Seperate each plot by ''/'':')
set_param([sys,'/',['Current source approximation',13,'of induction motor/Flux monitor']],...
		'Mask Translate','color = @4; ax = [0, @1, @2, @3]; dt = -1;')
set_param([sys,'/',['Current source approximation',13,'of induction motor/Flux monitor']],...
		'Mask Help','This block plots to the MATLAB graph window and can be used as an improved version of the Scope block. Look at the m-file sfuny.m to see how it works. This block can take scalar or vector input signal.')
set_param([sys,'/',['Current source approximation',13,'of induction motor/Flux monitor']],...
		'Mask Entries','2\/-1.2\/1.2\/''y-/g--/c-./w:/m*/ro/b+''\/')


%     Finished composite block ['Current source approximation',13,'of induction motor/Flux monitor'].

set_param([sys,'/',['Current source approximation',13,'of induction motor/Flux monitor']],...
		'orientation',2,...
		'position',[400,235,430,275])


%     Subsystem  ['Current source approximation',13,'of induction motor/Rotor speed'].

new_system([sys,'/',['Current source approximation',13,'of induction motor/Rotor speed']])
set_param([sys,'/',['Current source approximation',13,'of induction motor/Rotor speed']],'Location',[0,59,274,252])

add_block('built-in/S-Function',[sys,'/',['Current source approximation',13,'of induction motor/Rotor speed/S-function',13,'M-file which plots',13,'lines',13,'']])
set_param([sys,'/',['Current source approximation',13,'of induction motor/Rotor speed/S-function',13,'M-file which plots',13,'lines',13,'']],...
		'function name','sfuny',...
		'parameters','ax, color,dt',...
		'position',[130,55,180,75])

add_block('built-in/Inport',[sys,'/',['Current source approximation',13,'of induction motor/Rotor speed/x']])
set_param([sys,'/',['Current source approximation',13,'of induction motor/Rotor speed/x']],...
		'position',[65,55,85,75])
add_line([sys,'/',['Current source approximation',13,'of induction motor/Rotor speed']],[90,65;125,65])
set_param([sys,'/',['Current source approximation',13,'of induction motor/Rotor speed']],...
		'Mask Display','plot(0,0,100,100,[90,10,10,10,90,90,10],[65,65,90,40,40,90,90],[90,78,69,54,40,31,25,10],[77,60,48,46,56,75,81,84])')
set_param([sys,'/',['Current source approximation',13,'of induction motor/Rotor speed']],...
		'Mask Type','Graph scope.')
set_param([sys,'/',['Current source approximation',13,'of induction motor/Rotor speed']],...
		'Mask Dialogue','Graph scope using MATLAB graph window.\nEnter plotting ranges and line type.|Time range:|y-min:|y-max:|Line type (rgbw-:*). Seperate each plot by ''/'':')
set_param([sys,'/',['Current source approximation',13,'of induction motor/Rotor speed']],...
		'Mask Translate','color = @4; ax = [0, @1, @2, @3]; dt = -1;')
set_param([sys,'/',['Current source approximation',13,'of induction motor/Rotor speed']],...
		'Mask Help','This block plots to the MATLAB graph window and can be used as an improved version of the Scope block. Look at the m-file sfuny.m to see how it works. This block can take scalar or vector input signal.')
set_param([sys,'/',['Current source approximation',13,'of induction motor/Rotor speed']],...
		'Mask Entries','5\/0\/20\/''y-/g--/c-./w:/m*/ro/b+''\/')


%     Finished composite block ['Current source approximation',13,'of induction motor/Rotor speed'].

set_param([sys,'/',['Current source approximation',13,'of induction motor/Rotor speed']],...
		'orientation',2,...
		'position',[400,300,430,340])

add_block('built-in/Outport',[sys,'/',['Current source approximation',13,'of induction motor/vsb']])
set_param([sys,'/',['Current source approximation',13,'of induction motor/vsb']],...
		'Port','7',...
		'position',[350,225,370,245])


%     Subsystem  ['Current source approximation',13,'of induction motor/Induction motor',13,'a-b model'].

new_system([sys,'/',['Current source approximation',13,'of induction motor/Induction motor',13,'a-b model']])
set_param([sys,'/',['Current source approximation',13,'of induction motor/Induction motor',13,'a-b model']],'Location',[121,92,937,711])

add_block('built-in/Gain',[sys,'/',['Current source approximation',13,'of induction motor/Induction motor',13,'a-b model/Gain4']])
set_param([sys,'/',['Current source approximation',13,'of induction motor/Induction motor',13,'a-b model/Gain4']],...
		'orientation',2,...
		'hide name',0,...
		'Gain','Lm/Lr',...
		'position',[255,380,275,400])

add_block('built-in/Gain',[sys,'/',['Current source approximation',13,'of induction motor/Induction motor',13,'a-b model/Gain3']])
set_param([sys,'/',['Current source approximation',13,'of induction motor/Induction motor',13,'a-b model/Gain3']],...
		'orientation',2,...
		'hide name',0,...
		'Gain','Lm/Lr',...
		'position',[250,120,270,140])

add_block('built-in/Outport',[sys,'/',['Current source approximation',13,'of induction motor/Induction motor',13,'a-b model/fra']])
set_param([sys,'/',['Current source approximation',13,'of induction motor/Induction motor',13,'a-b model/fra']],...
		'orientation',2,...
		'Port','3',...
		'position',[140,210,160,230])

add_block('built-in/Outport',[sys,'/',['Current source approximation',13,'of induction motor/Induction motor',13,'a-b model/frb']])
set_param([sys,'/',['Current source approximation',13,'of induction motor/Induction motor',13,'a-b model/frb']],...
		'orientation',2,...
		'Port','4',...
		'position',[140,300,160,320])

add_block('built-in/Outport',[sys,'/',['Current source approximation',13,'of induction motor/Induction motor',13,'a-b model/isa']])
set_param([sys,'/',['Current source approximation',13,'of induction motor/Induction motor',13,'a-b model/isa']],...
		'position',[500,15,520,35])

add_block('built-in/Gain',[sys,'/',['Current source approximation',13,'of induction motor/Induction motor',13,'a-b model/Gain13']])
set_param([sys,'/',['Current source approximation',13,'of induction motor/Induction motor',13,'a-b model/Gain13']],...
		'hide name',0,...
		'Gain','P',...
		'position',[315,275,335,295])

add_block('built-in/Gain',[sys,'/',['Current source approximation',13,'of induction motor/Induction motor',13,'a-b model/Gain12']])
set_param([sys,'/',['Current source approximation',13,'of induction motor/Induction motor',13,'a-b model/Gain12']],...
		'hide name',0,...
		'Gain','P',...
		'position',[315,235,335,255])

add_block('built-in/Inport',[sys,'/',['Current source approximation',13,'of induction motor/Induction motor',13,'a-b model/vsa']])
set_param([sys,'/',['Current source approximation',13,'of induction motor/Induction motor',13,'a-b model/vsa']],...
		'position',[35,75,55,95])

add_block('built-in/Gain',[sys,'/',['Current source approximation',13,'of induction motor/Induction motor',13,'a-b model/Gain']])
set_param([sys,'/',['Current source approximation',13,'of induction motor/Induction motor',13,'a-b model/Gain']],...
		'hide name',0,...
		'Gain','Lr/(Lm^2-Lr*Ls)',...
		'position',[340,75,360,95])

add_block('built-in/Gain',[sys,'/',['Current source approximation',13,'of induction motor/Induction motor',13,'a-b model/Gain7']])
set_param([sys,'/',['Current source approximation',13,'of induction motor/Induction motor',13,'a-b model/Gain7']],...
		'orientation',2,...
		'hide name',0,...
		'Gain','Lm*Rr/Lr',...
		'position',[400,120,420,140])

add_block('built-in/Sum',[sys,'/',['Current source approximation',13,'of induction motor/Induction motor',13,'a-b model/Sum3']])
set_param([sys,'/',['Current source approximation',13,'of induction motor/Induction motor',13,'a-b model/Sum3']],...
		'orientation',2,...
		'hide name',0,...
		'inputs','+--',...
		'position',[315,142,335,178])

add_block('built-in/Gain',[sys,'/',['Current source approximation',13,'of induction motor/Induction motor',13,'a-b model/Gain9']])
set_param([sys,'/',['Current source approximation',13,'of induction motor/Induction motor',13,'a-b model/Gain9']],...
		'hide name',0,...
		'Gain','Rr/Lr',...
		'position',[250,195,270,215])

add_block('built-in/Sum',[sys,'/',['Current source approximation',13,'of induction motor/Induction motor',13,'a-b model/Sum2']])
set_param([sys,'/',['Current source approximation',13,'of induction motor/Induction motor',13,'a-b model/Sum2']],...
		'orientation',2,...
		'hide name',0,...
		'inputs','-++',...
		'position',[315,347,335,383])

add_block('built-in/Gain',[sys,'/',['Current source approximation',13,'of induction motor/Induction motor',13,'a-b model/Gain8']])
set_param([sys,'/',['Current source approximation',13,'of induction motor/Induction motor',13,'a-b model/Gain8']],...
		'hide name',0,...
		'Gain','Rr/Lr',...
		'position',[250,315,270,335])

add_block('built-in/Product',[sys,'/',['Current source approximation',13,'of induction motor/Induction motor',13,'a-b model/Product1']])
set_param([sys,'/',['Current source approximation',13,'of induction motor/Induction motor',13,'a-b model/Product1']],...
		'hide name',0,...
		'position',[245,235,270,255])

add_block('built-in/Product',[sys,'/',['Current source approximation',13,'of induction motor/Induction motor',13,'a-b model/Product']])
set_param([sys,'/',['Current source approximation',13,'of induction motor/Induction motor',13,'a-b model/Product']],...
		'hide name',0,...
		'position',[245,275,270,295])

add_block('built-in/Product',[sys,'/',['Current source approximation',13,'of induction motor/Induction motor',13,'a-b model/Product2']])
set_param([sys,'/',['Current source approximation',13,'of induction motor/Induction motor',13,'a-b model/Product2']],...
		'hide name',0,...
		'position',[515,215,540,235])

add_block('built-in/Product',[sys,'/',['Current source approximation',13,'of induction motor/Induction motor',13,'a-b model/Product3']])
set_param([sys,'/',['Current source approximation',13,'of induction motor/Induction motor',13,'a-b model/Product3']],...
		'hide name',0,...
		'position',[515,295,540,315])

add_block('built-in/Sum',[sys,'/',['Current source approximation',13,'of induction motor/Induction motor',13,'a-b model/Sum4']])
set_param([sys,'/',['Current source approximation',13,'of induction motor/Induction motor',13,'a-b model/Sum4']],...
		'hide name',0,...
		'inputs','+-',...
		'position',[575,255,595,275])

add_block('built-in/Note',[sys,'/',['Current source approximation',13,'of induction motor/Induction motor',13,'a-b model/Induction motor model.',13,'Andy Robertson 1996']])
set_param([sys,'/',['Current source approximation',13,'of induction motor/Induction motor',13,'a-b model/Induction motor model.',13,'Andy Robertson 1996']],...
		'position',[680,15,685,20])

add_block('built-in/Outport',[sys,'/',['Current source approximation',13,'of induction motor/Induction motor',13,'a-b model/wr']])
set_param([sys,'/',['Current source approximation',13,'of induction motor/Induction motor',13,'a-b model/wr']],...
		'Port','5',...
		'position',[775,255,795,275])

add_block('built-in/Transfer Fcn',[sys,'/',['Current source approximation',13,'of induction motor/Induction motor',13,'a-b model/First order',13,'resistive',13,'mechanical',13,'load']])
set_param([sys,'/',['Current source approximation',13,'of induction motor/Induction motor',13,'a-b model/First order',13,'resistive',13,'mechanical',13,'load']],...
		'Denominator','[J C]',...
		'position',[670,238,725,292])

add_block('built-in/Integrator',[sys,'/',['Current source approximation',13,'of induction motor/Induction motor',13,'a-b model/Integrator3']])
set_param([sys,'/',['Current source approximation',13,'of induction motor/Induction motor',13,'a-b model/Integrator3']],...
		'orientation',2,...
		'hide name',0,...
		'position',[215,145,245,175])

add_block('built-in/Integrator',[sys,'/',['Current source approximation',13,'of induction motor/Induction motor',13,'a-b model/Integrator4']])
set_param([sys,'/',['Current source approximation',13,'of induction motor/Induction motor',13,'a-b model/Integrator4']],...
		'hide name',0,...
		'position',[400,70,430,100])

add_block('built-in/Integrator',[sys,'/',['Current source approximation',13,'of induction motor/Induction motor',13,'a-b model/Integrator6']])
set_param([sys,'/',['Current source approximation',13,'of induction motor/Induction motor',13,'a-b model/Integrator6']],...
		'orientation',2,...
		'hide name',0,...
		'position',[215,350,245,380])

add_block('built-in/Gain',[sys,'/',['Current source approximation',13,'of induction motor/Induction motor',13,'a-b model/Gain11']])
set_param([sys,'/',['Current source approximation',13,'of induction motor/Induction motor',13,'a-b model/Gain11']],...
		'orientation',2,...
		'hide name',0,...
		'Gain','Rs',...
		'position',[335,15,355,35])

add_block('built-in/Gain',[sys,'/',['Current source approximation',13,'of induction motor/Induction motor',13,'a-b model/Gain6']])
set_param([sys,'/',['Current source approximation',13,'of induction motor/Induction motor',13,'a-b model/Gain6']],...
		'orientation',2,...
		'hide name',0,...
		'Gain','Lm*Rr/Lr',...
		'position',[395,375,415,395])

add_block('built-in/Gain',[sys,'/',['Current source approximation',13,'of induction motor/Induction motor',13,'a-b model/Gain10']])
set_param([sys,'/',['Current source approximation',13,'of induction motor/Induction motor',13,'a-b model/Gain10']],...
		'hide name',0,...
		'Gain','P*Lm/Lr',...
		'position',[620,255,640,275])

add_block('built-in/Sum',[sys,'/',['Current source approximation',13,'of induction motor/Induction motor',13,'a-b model/Sum']])
set_param([sys,'/',['Current source approximation',13,'of induction motor/Induction motor',13,'a-b model/Sum']],...
		'hide name',0,...
		'inputs','+-+',...
		'position',[260,67,280,103])

add_block('built-in/Gain',[sys,'/',['Current source approximation',13,'of induction motor/Induction motor',13,'a-b model/Gain5']])
set_param([sys,'/',['Current source approximation',13,'of induction motor/Induction motor',13,'a-b model/Gain5']],...
		'orientation',2,...
		'hide name',0,...
		'Gain','Rs',...
		'position',[340,485,360,505])

add_block('built-in/Gain',[sys,'/',['Current source approximation',13,'of induction motor/Induction motor',13,'a-b model/Gain1']])
set_param([sys,'/',['Current source approximation',13,'of induction motor/Induction motor',13,'a-b model/Gain1']],...
		'hide name',0,...
		'Gain','Lr/(Lm^2-Lr*Ls)',...
		'position',[340,425,360,445])

add_block('built-in/Integrator',[sys,'/',['Current source approximation',13,'of induction motor/Induction motor',13,'a-b model/Integrator5']])
set_param([sys,'/',['Current source approximation',13,'of induction motor/Induction motor',13,'a-b model/Integrator5']],...
		'hide name',0,...
		'position',[395,420,425,450])

add_block('built-in/Sum',[sys,'/',['Current source approximation',13,'of induction motor/Induction motor',13,'a-b model/Sum1']])
set_param([sys,'/',['Current source approximation',13,'of induction motor/Induction motor',13,'a-b model/Sum1']],...
		'hide name',0,...
		'inputs','+-+',...
		'position',[270,417,290,453])

add_block('built-in/Inport',[sys,'/',['Current source approximation',13,'of induction motor/Induction motor',13,'a-b model/vsb']])
set_param([sys,'/',['Current source approximation',13,'of induction motor/Induction motor',13,'a-b model/vsb']],...
		'Port','2',...
		'position',[25,425,45,445])

add_block('built-in/Outport',[sys,'/',['Current source approximation',13,'of induction motor/Induction motor',13,'a-b model/isb']])
set_param([sys,'/',['Current source approximation',13,'of induction motor/Induction motor',13,'a-b model/isb']],...
		'Port','2',...
		'position',[500,485,520,505])
add_line([sys,'/',['Current source approximation',13,'of induction motor/Induction motor',13,'a-b model']],[310,365;250,365])
add_line([sys,'/',['Current source approximation',13,'of induction motor/Induction motor',13,'a-b model']],[295,365;295,390;280,390])
add_line([sys,'/',['Current source approximation',13,'of induction motor/Induction motor',13,'a-b model']],[210,365;194,365;194,325;245,325])
add_line([sys,'/',['Current source approximation',13,'of induction motor/Induction motor',13,'a-b model']],[194,365;120,365;120,290;170,240;240,240])
add_line([sys,'/',['Current source approximation',13,'of induction motor/Induction motor',13,'a-b model']],[310,160;250,160])
add_line([sys,'/',['Current source approximation',13,'of induction motor/Induction motor',13,'a-b model']],[290,160;290,130;275,130])
add_line([sys,'/',['Current source approximation',13,'of induction motor/Induction motor',13,'a-b model']],[210,160;124,160;124,240;174,290;240,290])
add_line([sys,'/',['Current source approximation',13,'of induction motor/Induction motor',13,'a-b model']],[194,325;194,310;510,310])
add_line([sys,'/',['Current source approximation',13,'of induction motor/Induction motor',13,'a-b model']],[194,310;165,310])
add_line([sys,'/',['Current source approximation',13,'of induction motor/Induction motor',13,'a-b model']],[430,435;460,435;460,300;490,230;510,230])
add_line([sys,'/',['Current source approximation',13,'of induction motor/Induction motor',13,'a-b model']],[435,85;459,85;459,25;360,25])
add_line([sys,'/',['Current source approximation',13,'of induction motor/Induction motor',13,'a-b model']],[545,225;555,225;555,260;570,260])
add_line([sys,'/',['Current source approximation',13,'of induction motor/Induction motor',13,'a-b model']],[545,305;555,305;555,270;570,270])
add_line([sys,'/',['Current source approximation',13,'of induction motor/Induction motor',13,'a-b model']],[340,285;385,285;385,365;340,365])
add_line([sys,'/',['Current source approximation',13,'of induction motor/Induction motor',13,'a-b model']],[275,285;310,285])
add_line([sys,'/',['Current source approximation',13,'of induction motor/Induction motor',13,'a-b model']],[340,245;385,245;385,160;340,160])
add_line([sys,'/',['Current source approximation',13,'of induction motor/Induction motor',13,'a-b model']],[275,245;310,245])
add_line([sys,'/',['Current source approximation',13,'of induction motor/Induction motor',13,'a-b model']],[730,265;770,265])
add_line([sys,'/',['Current source approximation',13,'of induction motor/Induction motor',13,'a-b model']],[459,85;459,130;425,130])
add_line([sys,'/',['Current source approximation',13,'of induction motor/Induction motor',13,'a-b model']],[335,495;225,495;225,445;265,445])
add_line([sys,'/',['Current source approximation',13,'of induction motor/Induction motor',13,'a-b model']],[645,265;665,265])
add_line([sys,'/',['Current source approximation',13,'of induction motor/Induction motor',13,'a-b model']],[600,265;615,265])
add_line([sys,'/',['Current source approximation',13,'of induction motor/Induction motor',13,'a-b model']],[250,390;224,390;224,425;265,425])
add_line([sys,'/',['Current source approximation',13,'of induction motor/Induction motor',13,'a-b model']],[245,130;229,130;229,95;255,95])
add_line([sys,'/',['Current source approximation',13,'of induction motor/Induction motor',13,'a-b model']],[275,205;359,205;359,170;340,170])
add_line([sys,'/',['Current source approximation',13,'of induction motor/Induction motor',13,'a-b model']],[275,325;364,325;364,355;340,355])
add_line([sys,'/',['Current source approximation',13,'of induction motor/Induction motor',13,'a-b model']],[395,130;359,130;359,150;340,150])
add_line([sys,'/',['Current source approximation',13,'of induction motor/Induction motor',13,'a-b model']],[390,385;364,385;364,375;340,375])
add_line([sys,'/',['Current source approximation',13,'of induction motor/Induction motor',13,'a-b model']],[50,435;265,435])
add_line([sys,'/',['Current source approximation',13,'of induction motor/Induction motor',13,'a-b model']],[330,25;229,25;229,75;255,75])
add_line([sys,'/',['Current source approximation',13,'of induction motor/Induction motor',13,'a-b model']],[365,435;390,435])
add_line([sys,'/',['Current source approximation',13,'of induction motor/Induction motor',13,'a-b model']],[295,435;335,435])
add_line([sys,'/',['Current source approximation',13,'of induction motor/Induction motor',13,'a-b model']],[60,85;255,85])
add_line([sys,'/',['Current source approximation',13,'of induction motor/Induction motor',13,'a-b model']],[285,85;335,85])
add_line([sys,'/',['Current source approximation',13,'of induction motor/Induction motor',13,'a-b model']],[365,85;395,85])
add_line([sys,'/',['Current source approximation',13,'of induction motor/Induction motor',13,'a-b model']],[750,265;750,555;90,555;90,265;200,265;200,280;240,280])
add_line([sys,'/',['Current source approximation',13,'of induction motor/Induction motor',13,'a-b model']],[200,265;200,250;240,250])
add_line([sys,'/',['Current source approximation',13,'of induction motor/Induction motor',13,'a-b model']],[460,385;420,385])
add_line([sys,'/',['Current source approximation',13,'of induction motor/Induction motor',13,'a-b model']],[200,160;200,205;245,205])
add_line([sys,'/',['Current source approximation',13,'of induction motor/Induction motor',13,'a-b model']],[200,205;200,220;510,220])
add_line([sys,'/',['Current source approximation',13,'of induction motor/Induction motor',13,'a-b model']],[200,220;165,220])
add_line([sys,'/',['Current source approximation',13,'of induction motor/Induction motor',13,'a-b model']],[459,25;495,25])
add_line([sys,'/',['Current source approximation',13,'of induction motor/Induction motor',13,'a-b model']],[459,130;459,235;510,300])
add_line([sys,'/',['Current source approximation',13,'of induction motor/Induction motor',13,'a-b model']],[460,435;460,495;365,495])
add_line([sys,'/',['Current source approximation',13,'of induction motor/Induction motor',13,'a-b model']],[460,495;495,495])
set_param([sys,'/',['Current source approximation',13,'of induction motor/Induction motor',13,'a-b model']],...
		'Mask Display','plot(0,0,100,100,[70,80,20,30],[30,10,10,30],[50+8*cos(-0.1:0.1:2*pi)],[50+8*sin(-0.1:0.1:2*pi)],[50+28*cos(-0.1:0.1:2*pi)],[50+28*sin(-0.1:0.1:2*pi)],[50,30],[50,35])')
set_param([sys,'/',['Current source approximation',13,'of induction motor/Induction motor',13,'a-b model']],...
		'Mask Dialogue','Induction Motor model. See Help. \nUnmask to see model. \nEnter machine paramters:|Electrical parameters: [Rs, Rr, Ls, Lr, Lm, P] |Mechanical load parameters:  [J, B]')
set_param([sys,'/',['Current source approximation',13,'of induction motor/Induction motor',13,'a-b model']],...
		'Mask Translate','Rs=@1(1);Rr=@1(2);Ls=@1(3);Lr=@1(4);Lm=@1(5);P=@1(6);J=@2(1);C=@2(2);')
set_param([sys,'/',['Current source approximation',13,'of induction motor/Induction motor',13,'a-b model']],...
		'Mask Help','Induction motor a-b model.  The model operates in stationary a-b coordinates.  The\nmechanical load is contained ''inside'' this model and may be changed as necessary.  Unmask block to see the model.  Comments and suggestions to andrew@iit.upco.es.')
set_param([sys,'/',['Current source approximation',13,'of induction motor/Induction motor',13,'a-b model']],...
		'Mask Entries','[0.73,  0.45, 0.16, 0.17, 0.15, 2]\/[1, 0.4]\/')


%     Finished composite block ['Current source approximation',13,'of induction motor/Induction motor',13,'a-b model'].

set_param([sys,'/',['Current source approximation',13,'of induction motor/Induction motor',13,'a-b model']],...
		'Drop Shadow',4,...
		'position',[345,91,460,179])

add_block('built-in/Outport',[sys,'/',['Current source approximation',13,'of induction motor/vsa']])
set_param([sys,'/',['Current source approximation',13,'of induction motor/vsa']],...
		'Port','6',...
		'position',[350,40,370,60])

add_block('built-in/Note',[sys,'/',['Current source approximation',13,'of induction motor/This layer is a current controlled',13,' feedback loop allowing the ',13,'direct control of machine current variables.']])
set_param([sys,'/',['Current source approximation',13,'of induction motor/This layer is a current controlled',13,' feedback loop allowing the ',13,'direct control of machine current variables.']],...
		'position',[180,275,185,280])

add_block('built-in/Mux',[sys,'/',['Current source approximation',13,'of induction motor/Mux']])
set_param([sys,'/',['Current source approximation',13,'of induction motor/Mux']],...
		'orientation',2,...
		'hide name',0,...
		'inputs','2',...
		'position',[460,237,490,268])

add_block('built-in/Gain',[sys,'/',['Current source approximation',13,'of induction motor/Gain3']])
set_param([sys,'/',['Current source approximation',13,'of induction motor/Gain3']],...
		'hide name',0,...
		'Gain','50',...
		'position',[260,150,280,170])

add_block('built-in/Gain',[sys,'/',['Current source approximation',13,'of induction motor/Gain2']])
set_param([sys,'/',['Current source approximation',13,'of induction motor/Gain2']],...
		'hide name',0,...
		'Gain','50',...
		'position',[260,105,280,125])
add_line([sys,'/',['Current source approximation',13,'of induction motor']],[465,165;560,165;560,260;620,260])
add_line([sys,'/',['Current source approximation',13,'of induction motor']],[465,150;585,150;585,200;620,200])
add_line([sys,'/',['Current source approximation',13,'of induction motor']],[465,135;620,135])
add_line([sys,'/',['Current source approximation',13,'of induction motor']],[465,120;535,120;535,10;150,10;150,155;200,155])
add_line([sys,'/',['Current source approximation',13,'of induction motor']],[285,160;340,160])
add_line([sys,'/',['Current source approximation',13,'of induction motor']],[320,160;320,235;345,235])
add_line([sys,'/',['Current source approximation',13,'of induction motor']],[285,115;340,115])
add_line([sys,'/',['Current source approximation',13,'of induction motor']],[320,115;320,50;345,50])
add_line([sys,'/',['Current source approximation',13,'of induction motor']],[465,105;500,105;500,30;170,30;170,110;200,110])
add_line([sys,'/',['Current source approximation',13,'of induction motor']],[535,85;620,85])
add_line([sys,'/',['Current source approximation',13,'of induction motor']],[230,160;255,160])
add_line([sys,'/',['Current source approximation',13,'of induction motor']],[230,115;255,115])
add_line([sys,'/',['Current source approximation',13,'of induction motor']],[125,165;200,165])
add_line([sys,'/',['Current source approximation',13,'of induction motor']],[125,120;200,120])
add_line([sys,'/',['Current source approximation',13,'of induction motor']],[500,30;620,30])
add_line([sys,'/',['Current source approximation',13,'of induction motor']],[455,255;435,255])
add_line([sys,'/',['Current source approximation',13,'of induction motor']],[505,135;495,245])
add_line([sys,'/',['Current source approximation',13,'of induction motor']],[560,260;560,320;435,320])
add_line([sys,'/',['Current source approximation',13,'of induction motor']],[535,150;535,260;495,260])
set_param([sys,'/',['Current source approximation',13,'of induction motor']],...
		'Mask Display','plot(0,0,100,100,[50+20*sin(-0.1:0.1:2*pi)],[40+20*cos(-0.1:0.1:2*pi)],[50+20*sin(-0.1:0.1:2*pi)],[60+20*cos(-0.1:0.1:2*pi)],[50,50],[80,90],[50,50],[20,10],[20:80],[60+10*sin(0:2*pi/60:2*pi)],[20:79],[30*ones(1,60)])')
set_param([sys,'/',['Current source approximation',13,'of induction motor']],...
		'Mask Type','Induction motor')


%     Finished composite block ['Current source approximation',13,'of induction motor'].

set_param([sys,'/',['Current source approximation',13,'of induction motor']],...
		'Drop Shadow',4,...
		'position',[375,132,515,258])

add_block('built-in/Step Fcn',[sys,'/',['Flux current',13,'ref.']])
set_param([sys,'/',['Flux current',13,'ref.']],...
		'Time','0',...
		'After','8',...
		'position',[75,165,95,185])

add_block('built-in/Step Fcn',[sys,'/',['Torque current',13,'ref.']])
set_param([sys,'/',['Torque current',13,'ref.']],...
		'Time','0',...
		'After','1.5',...
		'position',[75,230,95,250])


%     Subsystem  'Cartesian to polar'.

new_system([sys,'/','Cartesian to polar'])
set_param([sys,'/','Cartesian to polar'],'Location',[0,0,359,206])

add_block('built-in/Note',[sys,'/','Cartesian to polar/Cartesian to Polar'])
set_param([sys,'/','Cartesian to polar/Cartesian to Polar'],...
		'position',[165,30,170,35])

add_block('built-in/Outport',[sys,'/','Cartesian to polar/theta'])
set_param([sys,'/','Cartesian to polar/theta'],...
		'Port','2',...
		'position',[295,130,315,150])

add_block('built-in/Inport',[sys,'/','Cartesian to polar/y'])
set_param([sys,'/','Cartesian to polar/y'],...
		'Port','2',...
		'position',[20,129,40,151])

add_block('built-in/Inport',[sys,'/','Cartesian to polar/x'])
set_param([sys,'/','Cartesian to polar/x'],...
		'position',[20,70,40,90])

add_block('built-in/Outport',[sys,'/','Cartesian to polar/r'])
set_param([sys,'/','Cartesian to polar/r'],...
		'position',[295,75,315,95])

add_block('built-in/Mux',[sys,'/','Cartesian to polar/Mux'])
set_param([sys,'/','Cartesian to polar/Mux'],...
		'inputs','2',...
		'position',[75,96,105,129])

add_block('built-in/Fcn',[sys,'/','Cartesian to polar/x->theta'])
set_param([sys,'/','Cartesian to polar/x->theta'],...
		'Expr','atan2(u[2],u[1])',...
		'position',[160,129,265,151])

add_block('built-in/Fcn',[sys,'/','Cartesian to polar/x->r'])
set_param([sys,'/','Cartesian to polar/x->r'],...
		'Expr','hypot(u[1],u[2])',...
		'position',[155,72,260,98])
add_line([sys,'/','Cartesian to polar'],[270,140;290,140])
add_line([sys,'/','Cartesian to polar'],[45,140;70,120])
add_line([sys,'/','Cartesian to polar'],[45,80;70,105])
add_line([sys,'/','Cartesian to polar'],[265,85;290,85])
add_line([sys,'/','Cartesian to polar'],[110,115;125,115;125,85;150,85])
add_line([sys,'/','Cartesian to polar'],[125,115;125,140;155,140])
set_param([sys,'/','Cartesian to polar'],...
		'Mask Display','plot(0,0,100,100,[24,20,15,20,20],[85,95,85,95,20],[80,20,95,85,95,85],[70,20,20,15,20,24],[56,56,55,52,50,46],[20,26,31,35,38,42])',...
		'Mask Type','[x,y]->[r,theta]')
set_param([sys,'/','Cartesian to polar'],...
		'Mask Dialogue','Tranformation from cartesian to polar\ncoordinates.\nr=sqrt(x^2+y^2), theta=atan(y/x)',...
		'Mask Help','Unmask this block for more help.')


%     Finished composite block 'Cartesian to polar'.

set_param([sys,'/','Cartesian to polar'],...
		'orientation',2,...
		'hide name',0,...
		'position',[440,55,475,110])

add_block('built-in/Note',[sys,'/',['Three-phase a-b induction motor model. v1.1',13,'Andy Robertson 1996',13,'',13,'Type ''Help imotor'' at command prompt !']])
set_param([sys,'/',['Three-phase a-b induction motor model. v1.1',13,'Andy Robertson 1996',13,'',13,'Type ''Help imotor'' at command prompt !']],...
		'position',[170,5,175,10])
add_line(sys,[100,105;135,105])
add_line(sys,[520,215;620,215])
add_line(sys,[520,195;620,195])
add_line(sys,[520,175;620,175])
add_line(sys,[520,155;620,155])
add_line(sys,[520,135;620,135])
add_line(sys,[100,175;240,175])
add_line(sys,[100,240;165,240;165,195;240,195])
add_line(sys,[590,175;590,70;480,70])
add_line(sys,[520,235;620,235])
add_line(sys,[520,255;620,255])
add_line(sys,[435,95;220,95;220,155;240,155])
add_line(sys,[570,195;570,95;480,95])
add_line(sys,[310,165;370,165])
add_line(sys,[310,190;325,190;325,230;370,230])

drawnow

% Return any arguments.
if (nargin | nargout)
	% Must use feval here to access system in memory
	if (nargin > 3)
		if (flag == 0)
			eval(['[ret,x0,str,ts,xts]=',sys,'(t,x,u,flag);'])
		else
			eval(['ret =', sys,'(t,x,u,flag);'])
		end
	else
		[ret,x0,str,ts,xts] = feval(sys);
	end
else
	drawnow % Flash up the model and execute load callback
end
