function [ret,x0,str,ts,xts]=bdlib(t,x,u,flag);
%BDLIB	is the M-file description of the SIMULINK system named BDLIB.
%	The block-diagram can be displayed by typing: BDLIB.
%
%	SYS=BDLIB(T,X,U,FLAG) returns depending on FLAG certain
%	system values given time point, T, current state vector, X,
%	and input vector, U.
%	FLAG is used to indicate the type of output to be returned in SYS.
%
%	Setting FLAG=1 causes BDLIB to return state derivatives, FLAG=2
%	discrete states, FLAG=3 system outputs and FLAG=4 next sample
%	time. For more information and other options see SFUNC.
%
%	Calling BDLIB with a FLAG of zero:
%	[SIZES]=BDLIB([],[],[],0),  returns a vector, SIZES, which
%	contains the sizes of the state vector and other parameters.
%		SIZES(1) number of states
%		SIZES(2) number of discrete states
%		SIZES(3) number of outputs
%		SIZES(4) number of inputs
%		SIZES(5) number of roots (currently unsupported)
%		SIZES(6) direct feedthrough flag
%		SIZES(7) number of sample times
%
%	For the definition of other parameters in SIZES, see SFUNC.
%	See also, TRIM, LINMOD, LINSIM, EULER, RK23, RK45, ADAMS, GEAR.

% Note: This M-file is only used for saving graphical information;
%       after the model is loaded into memory an internal model
%       representation is used.

% the system will take on the name of this mfile:
sys = mfilename;
new_system(sys)
simver(1.3)
if (0 == (nargin + nargout))
     set_param(sys,'Location',[370,94,994,394])
     open_system(sys)
end;
set_param(sys,'algorithm',     'RK-45')
set_param(sys,'Start time',    '0.0')
set_param(sys,'Stop time',     '999999')
set_param(sys,'Min step size', '0.0001')
set_param(sys,'Max step size', '10')
set_param(sys,'Relative error','1e-3')
set_param(sys,'Return vars',   '')


%     Subsystem  'Update Model'.

new_system([sys,'/','Update Model'])
set_param([sys,'/','Update Model'],'Location',[108,240,294,384])
set_param([sys,'/','Update Model'],...
		'Mask Display','Update',...
		'Mask Type','Update Library',...
		'Mask Dialogue','eval(''rbupdate'')')


%     Finished composite block 'Update Model'.

set_param([sys,'/','Update Model'],...
		'Drop Shadow',4,...
		'position',[270,101,330,126])


%     Subsystem  'Random Masked Block1'.

new_system([sys,'/','Random Masked Block1'])
set_param([sys,'/','Random Masked Block1'],'Location',[6,68,506,341])
open_system([sys,'/','Random Masked Block1'])

add_block('built-in/Filter',[sys,'/','Random Masked Block1/Filter2'])
set_param([sys,'/','Random Masked Block1/Filter2'],...
		'Denominator','[1 2]',...
		'position',[115,91,170,129])

add_block('built-in/Filter',[sys,'/','Random Masked Block1/Filter3'])
set_param([sys,'/','Random Masked Block1/Filter3'],...
		'Denominator','[1 2]',...
		'position',[120,181,175,219])

add_block('built-in/Inport',[sys,'/','Random Masked Block1/Inport2'])
set_param([sys,'/','Random Masked Block1/Inport2'],...
		'position',[30,55,50,75])

add_block('built-in/Inport',[sys,'/','Random Masked Block1/Inport3'])
set_param([sys,'/','Random Masked Block1/Inport3'],...
		'Port','2',...
		'position',[30,135,50,155])

add_block('built-in/Outport',[sys,'/','Random Masked Block1/Outport4'])
set_param([sys,'/','Random Masked Block1/Outport4'],...
		'position',[195,105,215,125])

add_block('built-in/Outport',[sys,'/','Random Masked Block1/Outport5'])
set_param([sys,'/','Random Masked Block1/Outport5'],...
		'Port','2',...
		'position',[195,190,215,210])
add_line([sys,'/','Random Masked Block1'],[175,110;190,115])
add_line([sys,'/','Random Masked Block1'],[55,145;95,145;95,200;115,200])
add_line([sys,'/','Random Masked Block1'],[180,200;190,200])
add_line([sys,'/','Random Masked Block1'],[55,65;100,110;110,110])
set_param([sys,'/','Random Masked Block1'],...
		'Mask Display','')


%     Finished composite block 'Random Masked Block1'.

set_param([sys,'/','Random Masked Block1'],...
		'position',[380,186,410,259])


%     Subsystem  'Bind Library'.

new_system([sys,'/','Bind Library'])
set_param([sys,'/','Bind Library'],'Location',[108,240,294,384])
set_param([sys,'/','Bind Library'],...
		'Mask Display','Bind',...
		'Mask Type','Bind Library',...
		'Mask Dialogue','eval(''rbbind'')')


%     Finished composite block 'Bind Library'.

set_param([sys,'/','Bind Library'],...
		'Drop Shadow',4,...
		'position',[180,36,240,66])


%     Subsystem  'bdlib'.

new_system([sys,'/','bdlib'])
set_param([sys,'/','bdlib'],'Location',[108,216,776,521])
set_param([sys,'/','bdlib'],...
		'Mask Display','Version',...
		'Mask Type','Version',...
		'Mask Dialogue','Version|Library:|Description:|Version:|Author:|Last Changed:',...
		'Mask Help','Block Version Identifier')
set_param([sys,'/','bdlib'],...
		'Mask Entries','bdlib\/Block Diagram Base Library\/1.0\/Mike Wolf\/Today\/')


%     Finished composite block 'bdlib'.

set_param([sys,'/','bdlib'],...
		'Drop Shadow',4,...
		'position',[80,101,150,141])


%     Subsystem  'Random Masked Block'.

new_system([sys,'/','Random Masked Block'])
set_param([sys,'/','Random Masked Block'],'Location',[214,62,759,422])

add_block('built-in/Outport',[sys,'/','Random Masked Block/Outport5'])
set_param([sys,'/','Random Masked Block/Outport5'],...
		'Port','2',...
		'position',[160,135,180,155])

add_block('built-in/Filter',[sys,'/','Random Masked Block/Filter1'])
set_param([sys,'/','Random Masked Block/Filter1'],...
		'Denominator','[1 2]',...
		'position',[90,171,145,209])

add_block('built-in/Inport',[sys,'/','Random Masked Block/Inport'])
set_param([sys,'/','Random Masked Block/Inport'],...
		'position',[15,10,35,30])

add_block('built-in/Filter',[sys,'/','Random Masked Block/Filter'])
set_param([sys,'/','Random Masked Block/Filter'],...
		'Denominator','[1 2]',...
		'position',[75,36,130,74])

add_block('built-in/Inport',[sys,'/','Random Masked Block/Inport1'])
set_param([sys,'/','Random Masked Block/Inport1'],...
		'Port','2',...
		'position',[20,100,40,120])

add_block('built-in/Outport',[sys,'/','Random Masked Block/Outport4'])
set_param([sys,'/','Random Masked Block/Outport4'],...
		'position',[155,45,175,65])

add_block('built-in/Outport',[sys,'/','Random Masked Block/Outport6'])
set_param([sys,'/','Random Masked Block/Outport6'],...
		'Port','3',...
		'position',[365,55,385,75])

add_block('built-in/Filter',[sys,'/','Random Masked Block/Filter2'])
set_param([sys,'/','Random Masked Block/Filter2'],...
		'Denominator','[1 2]',...
		'position',[285,46,340,84])

add_block('built-in/Inport',[sys,'/','Random Masked Block/Inport2'])
set_param([sys,'/','Random Masked Block/Inport2'],...
		'Port','3',...
		'position',[225,20,245,40])


%     Subsystem  'Random Masked Block/bdlib'.

new_system([sys,'/','Random Masked Block/bdlib'])
set_param([sys,'/','Random Masked Block/bdlib'],'Location',[100,100,600,400])
set_param([sys,'/','Random Masked Block/bdlib'],...
		'Mask Display','Version',...
		'Mask Type','Version',...
		'Mask Dialogue','Version|Library:|Description:|Version:|Author:|Last Changed:',...
		'Mask Help','Block Version Identifier')
set_param([sys,'/','Random Masked Block/bdlib'],...
		'Mask Entries','bdlib\/Block Diagram Base Library\/1.0\/Mike Wolf\/Today\/')


%     Finished composite block 'Random Masked Block/bdlib'.

set_param([sys,'/','Random Masked Block/bdlib'],...
		'Drop Shadow',4,...
		'position',[475,320,545,340])
add_line([sys,'/','Random Masked Block'],[40,20;50,20;50,55;70,55])
add_line([sys,'/','Random Masked Block'],[135,55;150,55])
add_line([sys,'/','Random Masked Block'],[150,190;155,145])
add_line([sys,'/','Random Masked Block'],[45,110;65,110;65,130;100,130;100,150;35,150;35,175;55,175;55,190;85,190])
add_line([sys,'/','Random Masked Block'],[250,30;260,30;260,65;280,65])
add_line([sys,'/','Random Masked Block'],[345,65;360,65])
set_param([sys,'/','Random Masked Block'],...
		'Mask Display','Draw',...
		'Mask Type','Foobar',...
		'Mask Dialogue','this|That',...
		'Mask Translate','foo = @1',...
		'Mask Help','Help',...
		'Mask Entries','1,3\/')


%     Finished composite block 'Random Masked Block'.

set_param([sys,'/','Random Masked Block'],...
		'position',[155,169,190,231])


%     Subsystem  ['Open Block',13,''].

new_system([sys,'/',['Open Block',13,'']])
set_param([sys,'/',['Open Block',13,'']],'Location',[108,240,294,384])
set_param([sys,'/',['Open Block',13,'']],...
		'Mask Display','Open!',...
		'Mask Type','Open',...
		'Mask Dialogue','eval(''openblok'')')


%     Finished composite block ['Open Block',13,''].

set_param([sys,'/',['Open Block',13,'']],...
		'Drop Shadow',4,...
		'position',[445,81,505,111])
add_line(sys,[195,180;375,205])
add_line(sys,[195,200;365,240;375,240])

drawnow

% Return any arguments.
if (nargin | nargout)
	% Must use feval here to access system in memory
	if (nargin > 3)
		if (flag == 0)
			eval(['[ret,x0,str,ts,xts]=',sys,'(t,x,u,flag);'])
		else
			eval(['ret =', sys,'(t,x,u,flag);'])
		end
	else
		[ret,x0,str,ts,xts] = feval(sys);
	end
else
	drawnow % Flash up the model and execute load callback
end
