function vhChildren = getchild(hParent)
%    GETCHILD Children of a simulink block.
%
% INPUTS:
%	hParent : a handle to a Simulink block. This is the parent block
% OUTPUTS:
%	vhChildren : a vector of handles to the children of the parent block
%
% GLOBALS:
%	none
% EXAMPLE:
%        vChildren = GETCHILD( hParent )
%
%    When called with a single handle, SIM_GETCHILDREN returns
%    a vector of children of that block. If the block has no
%    children, it returns an empty vector.
%
%    TestData:   hParent = vhAllBlocks(i);
%
%	Author: Mike Wolf 7/11/95
%	Copyright (c) 1995 by The MathWorks Inc.
%	Revision: Bob Silverman 8/21/95
%	    stylistic changes
%	    function name changes

%	Construct fully qualified parent name

svChildren = get_param( hParent, 'Blocks');
sParent = get_param (hParent, 'Name' );
sParentParent = get_param(hParent, 'Parent');
if length(sParentParent) ~= 0
   sParent = [sParentParent '/' sParent];
end
 

%	Go through the list of blocks; extract each child and construct
%	its fully qualified name. Then get a handle to that child and insert
%	it into the vhChildren vector.

[nChildren, wChildren] = size( svChildren);
vhChildren = ones( 1, nChildren);
for i = 1:nChildren
   sChild = svChildren( i, :);
   wLenChild = min(find( sChild == 0 ));
   if wLenChild == [] 
      wLenChild = wChildren;
   end
   sChild = sChild( 1: wLenChild );
   sChild = [ sParent, '/' , sChild ];		% fully qualified child's name
   vhChildren(i) = get_param( sChild, 'handle');        
end
 
%disp( vhChildren);
