function openblok( h )
%OPENBLOK Open a SIMULINK subsystem block.
%
% INPUTS:
%	h : a handle for the block to be opened
% OUTPUTS:
%	none
% GLOBALS:
%	none
%
%	This routine opens a Simulink (sub)system block. It takes as input
%	a handle to the block. If none is input, then the routine attempts
%	to open the nearest block (geometrically speaking) to the current block.
%	In order to open it, it must be first unmasked; This means that the 
%	current mask values must be retrieved, then set to null before opening
%	the block. Finally, the block is opened and the mask values restored.
%
%	Author: Mike Wolf 7/11/95
%	Copyright (c) 1995 by The MathWorks Inc.
%	Revision: Bob Silverman 8/21/95
%	    stylistic changes
%	    function name changes
%	    fixed value setting for Drop Shadow from '' to 0
%	    now works under GUI control instead of opening nearest block
%
%
%	Testdata h = get_param([bdroot,'/Random Masked Block'],'Handle');

% if the number of args is zero, open the nearest block to the current one
 
if nargin == 0
   h = get_param(gcb, 'Handle');
   if h == []					% could not find one
       error('There is no selected block to open.');
       return
   end      
end
 
%	Get the mask values for the block

mtype = get_param( h, 'Mask Type' );
mdialogue = get_param( h, 'Mask Dialogue' );
mtranslate = get_param( h, 'Mask Translate');
mhelp = get_param( h, 'Mask Help' );
mentries = get_param( h, 'Mask Entries' );
mdisplay = get_param( h, 'Mask Display' );
dshadow =  get_param( h, 'Drop Shadow' );
     
%	Set the mask values to null in order to unmask the block

set_param( h, 'Mask Type', '');
set_param( h, 'Mask Dialogue', '');
set_param( h, 'Mask Translate', '');
set_param( h, 'Mask Help', '');
set_param( h, 'Mask Entries', '');
set_param( h, 'Mask Display', '');
set_param( h, 'Drop Shadow', 0);

open_system (h);				% now we can open the block


%	Finally, we restore the previously retrieved mask values

set_param( h, 'Mask Type', mtype);
set_param( h, 'Mask Dialogue', mdialogue);
set_param( h, 'Mask Translate', mtranslate);
set_param( h, 'Mask Help', mhelp);
set_param( h, 'Mask Entries', mentries);
set_param( h, 'Mask Display', mdisplay);
set_param( h, 'Drop Shadow', dshadow);
