function [] = rbbind
%     SIM_BINDMODEL bind current SIMULINK model.
%
% INPUTS:
%	none
% OUTPUTS:
%	none
% GLOBALS:
%	none
%
%     Supports reusable block libraries by binding the model name to
%     the model's version block (there must be one) and copying the
%     block into every sub-model.

% First see if there is a version block, by iterating over the top blocks of
% the model.
% TestCase:	 open_system('bdlib')
%
%	Author: Mike Wolf 7/11/95
%	Copyright (c) 1995 by The MathWorks Inc.
%	Revision: Bob Silverman 8/21/95
%	    stylistic changes
%	    function name changes
%	    force bound version block to have same name as model
%

% get handles to all blocks...
 
vhAllBlocks = getchild(get_param(bdroot, 'Handle'));
vhVersionBlock = getblock( vhAllBlocks,'Mask Dialogue' ,'Version');

%	make sure there is one, and only one version block....
if length( vhVersionBlock) < 1
    error ('There is no version block in this library');
elseif length( vhVersionBlock) > 1
    error ('Too many version blocks; Remove one');
end
 
%	Make sure the name of the version block matches the model name.
%	Because set_param will not change the name of a block, we must
%	create a new block by copying the old one but using the new name,
%	deleting the old one, then reopening the handle to the version
%	block.
%
sroot_name = get_param(bdroot,'Name');		% bdroot is the model name
sversion_name = get_param(vhVersionBlock,'Name');	% version block name

if (strcmp(sroot_name,sversion_name) == 0)	% if names not the same then...

   sold_name = [sroot_name '/' sversion_name];
   snew_name = [sroot_name '/' sroot_name];
   add_block(sold_name, snew_name);
   delete_block(vhVersionBlock);			% delete the old one
   vhAllBlocks = getchild(get_param(bdroot, 'Handle'));   % open the new
   vhVersionBlock = getblock( vhAllBlocks,'Mask Dialogue' ,'Version');
end


%	iterate through the blocks
 
for i = 1:length(vhAllBlocks)

%	get children of nth block
 
   vhAllChildren = getchild( vhAllBlocks(i));
   if length( vhAllChildren) > 0
 
%	this is a subsystem block... get any version blocks...
 
      vhChildsVersions = getblock( vhAllChildren,'Mask Dialogue', 'Version');
 
%	delete them all....
 
      for j = 1: length(vhChildsVersions)
         delete_block( vhChildsVersions(j));
      end
%	now add a copy of this one...
 
      copyblok (vhAllBlocks(i), vhVersionBlock);
   end
end 
