function [] = rbupdate(hBlock)
%RBUPDATE     Update block from library.
%
% INPUTS:
%	hBlock : a handle to the block being updated.
% OUTPUTS:
%	none
% GLOBALS:
%	none
%
%	This routine updates a block from the existing library;
%	It is assumed that the block is a copy of another block that
%	has been changed. The idea is to propogate the change through
%	all copies.
%
%	Author: Mike Wolf 7/11/95
%	Copyright (c) 1995 by The MathWorks Inc.
%	Revision: Bob Silverman 8/21/95
%	    stylistic changes
%	    function name changes
%	    test whether trying to update parent block
%

if nargin == 0		% if no input, open the root block
   hBlock = get_param( bdroot, 'Handle');
end

%	get all the children of the current block
 
vhChildren = getchild( hBlock );

for i = 1:length(vhChildren)
 
%	See if any of these children has a version block inside it...
 
    vhGrandChildren = getchild( vhChildren(i) );
    if length(vhGrandChildren) ~= 0	 % something to update
    
        vhVersions = getblock(vhGrandChildren,'Mask Dialogue', 'Version');
    
        if length(vhVersions) == 0	% no version blocks; update child
           rbupdate( vhChildren(i));
        elseif length(vhVersions) > 1
           disp('too many version blocks');
        else						% open this child
           sThisBlockName = get_param( vhChildren(i), 'Mask Type' );
           sLibNameAndRev = get_param( vhVersions, 'Name');
           sLibName = lower(strtok(sLibNameAndRev));
           open_system( sLibName);
           hLib = get_param( sLibName, 'handle');
	   if (hLib == get_param(bdroot,'Handle'))
		error('You can not update the parent block.');
	   end
           if isempty (hLib)				% could not open
               sprintf('Could not load block library %s', sLibName);
           else				% copy the child to the version blocks
              vhLibChildren = getchild(hLib);
              vhLibBlock = getblock(vhLibChildren, 'Mask Type', sThisBlockName );
              copyblok (vhChildren(i), vhLibBlock, 0 );
           end
        end
    end 
end         
