function [ret,x0,str,ts,xts]=rlsest2(t,x,u,flag);
%RLSEST2	is the M-file description of the SIMULINK system named RLSEST2.
%	The block-diagram can be displayed by typing: RLSEST2.
%
%	SYS=RLSEST2(T,X,U,FLAG) returns depending on FLAG certain
%	system values given time point, T, current state vector, X,
%	and input vector, U.
%	FLAG is used to indicate the type of output to be returned in SYS.
%
%	Setting FLAG=1 causes RLSEST2 to return state derivatives, FLAG=2
%	discrete states, FLAG=3 system outputs and FLAG=4 next sample
%	time. For more information and other options see SFUNC.
%
%	Calling RLSEST2 with a FLAG of zero:
%	[SIZES]=RLSEST2([],[],[],0),  returns a vector, SIZES, which
%	contains the sizes of the state vector and other parameters.
%		SIZES(1) number of states
%		SIZES(2) number of discrete states
%		SIZES(3) number of outputs
%		SIZES(4) number of inputs
%		SIZES(5) number of roots (currently unsupported)
%		SIZES(6) direct feedthrough flag
%		SIZES(7) number of sample times
%
%	For the definition of other parameters in SIZES, see SFUNC.
%	See also, TRIM, LINMOD, LINSIM, EULER, RK23, RK45, ADAMS, GEAR.

% Note: This M-file is only used for saving graphical information;
%       after the model is loaded into memory an internal model
%       representation is used.

% the system will take on the name of this mfile:
sys = mfilename;
new_system(sys)
simver(1.3)
if (0 == (nargin + nargout))
     set_param(sys,'Location',[161,175,969,590])
     open_system(sys)
end;
set_param(sys,'algorithm',     'RK-45')
set_param(sys,'Start time',    '0.0')
set_param(sys,'Stop time',     '9999999')
set_param(sys,'Min step size', '1')
set_param(sys,'Max step size', '10')
set_param(sys,'Relative error','1e-3')
set_param(sys,'Return vars',   '')
set_param(sys,'AssignSampleTimeColors','on');
set_param(sys,'AssignWideVectorLines','on');

add_block('built-in/Note',[sys,'/',['To run the simulation, select "Start"',13,'from the "Simulation" pull-down menu']])
set_param([sys,'/',['To run the simulation, select "Start"',13,'from the "Simulation" pull-down menu']],...
		'position',[155,360,160,365])

add_block('built-in/Note',[sys,'/','y[n]'])
set_param([sys,'/','y[n]'],...
		'position',[660,60,665,65])

add_block('built-in/Note',[sys,'/','u[n]'])
set_param([sys,'/','u[n]'],...
		'position',[480,55,485,60])


%     Subsystem  'phi'.

new_system([sys,'/','phi'])
set_param([sys,'/','phi'],'Location',[203,129,617,252])

add_block('built-in/Mux',[sys,'/','phi/Mux1'])
set_param([sys,'/','phi/Mux1'],...
		'inputs','[1 1]',...
		'position',[65,21,95,139])

add_block('built-in/Inport',[sys,'/','phi/in_2'])
set_param([sys,'/','phi/in_2'],...
		'Port','2',...
		'position',[15,100,35,120])

add_block('built-in/Outport',[sys,'/','phi/out_1'])
set_param([sys,'/','phi/out_1'],...
		'position',[280,70,300,90])

add_block('built-in/Inport',[sys,'/','phi/in_1'])
set_param([sys,'/','phi/in_1'],...
		'position',[15,40,35,60])

add_block('built-in/Discrete State-Space',[sys,'/','phi/Disc. State-space'])
set_param([sys,'/','phi/Disc. State-space'],...
		'A','[zeros(1,2*order);eye(order-1,2*order);zeros(1,2*order);zeros(order-1,order),eye(order-1,order)]',...
		'B','[1, zeros(1,2*order-1);zeros(1,order),-1,zeros(1,order-1)]''')
set_param([sys,'/','phi/Disc. State-space'],...
		'C','eye(2*order)',...
		'D','[zeros(2*order,order)]',...
		'Sample time','ts',...
		'position',[145,60,255,100])
add_line([sys,'/','phi'],[100,80;140,80])
add_line([sys,'/','phi'],[40,50;60,50])
add_line([sys,'/','phi'],[260,80;275,80])
add_line([sys,'/','phi'],[40,110;60,110])
set_param([sys,'/','phi'],...
		'Mask Display','State\nGenerator',...
		'Mask Type','State Generator',...
		'Mask Dialogue','State Generator:|Model Order:|Sample Time:',...
		'Mask Translate','order = @1;ts = @2;')
set_param([sys,'/','phi'],...
		'Mask Help','This block generates the state vector for use with the RLS parameter estimator.',...
		'Mask Entries','2\/1\/')


%     Finished composite block 'phi'.

set_param([sys,'/','phi'],...
		'orientation',1,...
		'move name',0,...
		'position',[529,150,636,190])


%     Subsystem  ['Recursive least squares',13,' Parameter Estimator'].

new_system([sys,'/',['Recursive least squares',13,' Parameter Estimator']])
set_param([sys,'/',['Recursive least squares',13,' Parameter Estimator']],'Location',[243,483,679,634])

add_block('built-in/S-Function',[sys,'/',['Recursive least squares',13,' Parameter Estimator/rlsests']])
set_param([sys,'/',['Recursive least squares',13,' Parameter Estimator/rlsests']],...
		'function name','rlsests',...
		'parameters','nstates,lambda,ts',...
		'position',[175,80,225,100])

add_block('built-in/Outport',[sys,'/',['Recursive least squares',13,' Parameter Estimator/theta']])
set_param([sys,'/',['Recursive least squares',13,' Parameter Estimator/theta']],...
		'position',[265,80,285,100])

add_block('built-in/Inport',[sys,'/',['Recursive least squares',13,' Parameter Estimator/phi']])
set_param([sys,'/',['Recursive least squares',13,' Parameter Estimator/phi']],...
		'position',[15,40,35,60])

add_block('built-in/Inport',[sys,'/',['Recursive least squares',13,' Parameter Estimator/yk']])
set_param([sys,'/',['Recursive least squares',13,' Parameter Estimator/yk']],...
		'Port','2',...
		'position',[15,110,35,130])

add_block('built-in/Mux',[sys,'/',['Recursive least squares',13,' Parameter Estimator/Mux']])
set_param([sys,'/',['Recursive least squares',13,' Parameter Estimator/Mux']],...
		'inputs','[nstates 1]',...
		'position',[95,70,125,105])
add_line([sys,'/',['Recursive least squares',13,' Parameter Estimator']],[40,120;60,120;60,95;90,95])
add_line([sys,'/',['Recursive least squares',13,' Parameter Estimator']],[230,90;260,90])
add_line([sys,'/',['Recursive least squares',13,' Parameter Estimator']],[40,50;60,50;60,80;90,80])
add_line([sys,'/',['Recursive least squares',13,' Parameter Estimator']],[130,90;170,90])
set_param([sys,'/',['Recursive least squares',13,' Parameter Estimator']],...
		'Mask Display','RLS\nEstimator',...
		'Mask Type','RLS Estimator')
set_param([sys,'/',['Recursive least squares',13,' Parameter Estimator']],...
		'Mask Dialogue','Hook input 1 to a state vector, and input 2 to the system output.\n|Model Order:|Forgetting Factor:|Sample Time:')
set_param([sys,'/',['Recursive least squares',13,' Parameter Estimator']],...
		'Mask Translate','nstates = 2*@1;lambda=@2;ts=@3;')
set_param([sys,'/',['Recursive least squares',13,' Parameter Estimator']],...
		'Mask Help','Implements a Recursive Least Squares parameter estimator. Mask and unmask this block to see how it works.',...
		'Mask Entries','2\/.95\/1\/')


%     Finished composite block ['Recursive least squares',13,' Parameter Estimator'].

set_param([sys,'/',['Recursive least squares',13,' Parameter Estimator']],...
		'orientation',2,...
		'position',[455,223,540,272])

add_block('built-in/S-Function',[sys,'/',['Pole Placement',13,'Controller Design']])
set_param([sys,'/',['Pole Placement',13,'Controller Design']],...
		'orientation',2,...
		'function name','rlspps',...
		'parameters','order,char_poly,ts',...
		'Mask Display','rlsppd',...
		'Mask Type','Pole Placement')
set_param([sys,'/',['Pole Placement',13,'Controller Design']],...
		'Mask Dialogue','Pole Placement|ModelOrder|Characterstic Polynomial|Sample Time',...
		'Mask Translate','order=@1;char_poly=@2;ts=@3;')
set_param([sys,'/',['Pole Placement',13,'Controller Design']],...
		'Mask Help','Implements a pole placement design scheme for a discrete time controller.  Change the characteristic polynomial to see how the closed loop behavior changes.')
set_param([sys,'/',['Pole Placement',13,'Controller Design']],...
		'Mask Entries','2\/poly([.6 .6 .6])\/ 1\/',...
		'position',[240,235,340,265])


%     Subsystem  'More Info'.

new_system([sys,'/','More Info'])
set_param([sys,'/','More Info'],'Location',[221,570,657,837])

add_block('built-in/Note',[sys,'/',['More Info/This demonstration shows how an adaptive controller can',13,'be designed and simulated.']])
set_param([sys,'/',['More Info/This demonstration shows how an adaptive controller can',13,'be designed and simulated.']],...
		'position',[205,20,210,25])

add_block('built-in/Note',[sys,'/',['More Info/This adaptive controller was implemented using a Time Varying',13,'Discrete Transfer Function block.  Unmask the other blocks ',13,'to see how they were implemented.']])
set_param([sys,'/',['More Info/This adaptive controller was implemented using a Time Varying',13,'Discrete Transfer Function block.  Unmask the other blocks ',13,'to see how they were implemented.']],...
		'position',[205,125,210,130])

add_block('built-in/Note',[sys,'/',['More Info/Modify the parameters of the Plant during a simulation and observe',13,'that the adaptive controller always maintains stability.']])
set_param([sys,'/',['More Info/Modify the parameters of the Plant during a simulation and observe',13,'that the adaptive controller always maintains stability.']],...
		'position',[219,65,224,70])

add_block('built-in/Note',[sys,'/',['More Info/This system uses an updated version of rlspps.m which',13,'should be availble in the same directory as this file.']])
set_param([sys,'/',['More Info/This system uses an updated version of rlspps.m which',13,'should be availble in the same directory as this file.']],...
		'position',[205,180,210,185])
set_param([sys,'/','More Info'],...
		'Mask Display','?')


%     Finished composite block 'More Info'.

set_param([sys,'/','More Info'],...
		'Drop Shadow',4,...
		'position',[365,320,392,345])

add_block('built-in/Scope',[sys,'/',['Parameter',13,'Estimates']])
set_param([sys,'/',['Parameter',13,'Estimates']],...
		'orientation',2,...
		'Vgain','10.000000',...
		'Hgain','100.000000',...
		'Vmax','13.698630',...
		'Hmax','200.000000',...
		'Window',[200,598,471,772])
open_system([sys,'/',['Parameter',13,'Estimates']])
set_param([sys,'/',['Parameter',13,'Estimates']],...
		'position',[370,160,390,190])

add_block('built-in/Demux',[sys,'/','demux'])
set_param([sys,'/','demux'],...
		'orientation',2,...
		'hide name',0,...
		'outputs','[2 2]',...
		'position',[155,220,210,275])

add_block('built-in/Discrete Transfer Fcn',[sys,'/','Plant'])
set_param([sys,'/','Plant'],...
		'Numerator','[-3.4 1.5]',...
		'Denominator','[1 -1.6 0.8]',...
		'position',[530,67,630,103])

add_block('built-in/Scope',[sys,'/',['Plant',13,'Output']])
set_param([sys,'/',['Plant',13,'Output']],...
		'Vgain','50.000000',...
		'Hgain','100.000000',...
		'Vmax','104.166667',...
		'Hmax','200.000000',...
		'Window',[802,543,1082,763])
open_system([sys,'/',['Plant',13,'Output']])
set_param([sys,'/',['Plant',13,'Output']],...
		'Mask Display','',...
		'Mask Dialogue','ws|variable:|rows:',...
		'Mask Translate','var=@1;rows=@2;',...
		'Mask Entries','''yout''\/1000\/',...
		'position',[705,72,725,98])

add_block('built-in/Note',[sys,'/',['Adaptive Control of Second Order ',13,'Discrete Time Transfer Function',13,'(Double click on the "?" for more info)']])
set_param([sys,'/',['Adaptive Control of Second Order ',13,'Discrete Time Transfer Function',13,'(Double click on the "?" for more info)']],...
		'position',[161,315,166,320])


%     Subsystem  ['Time Varying',13,'Discrete Transfer Function'].

new_system([sys,'/',['Time Varying',13,'Discrete Transfer Function']])
set_param([sys,'/',['Time Varying',13,'Discrete Transfer Function']],'Location',[471,402,911,610])

add_block('built-in/Inport',[sys,'/',['Time Varying',13,'Discrete Transfer Function/Input']])
set_param([sys,'/',['Time Varying',13,'Discrete Transfer Function/Input']],...
		'position',[55,20,75,40])

add_block('built-in/Inport',[sys,'/',['Time Varying',13,'Discrete Transfer Function/Numerator']])
set_param([sys,'/',['Time Varying',13,'Discrete Transfer Function/Numerator']],...
		'Port','2',...
		'position',[55,80,75,100])

add_block('built-in/Inport',[sys,'/',['Time Varying',13,'Discrete Transfer Function/Denominator']])
set_param([sys,'/',['Time Varying',13,'Discrete Transfer Function/Denominator']],...
		'Port','3',...
		'position',[55,145,75,165])

add_block('built-in/Mux',[sys,'/',['Time Varying',13,'Discrete Transfer Function/Mux']])
set_param([sys,'/',['Time Varying',13,'Discrete Transfer Function/Mux']],...
		'inputs','[1 dim dim]',...
		'position',[150,74,180,106])

add_block('built-in/S-Function',[sys,'/',['Time Varying',13,'Discrete Transfer Function/S-Function']])
set_param([sys,'/',['Time Varying',13,'Discrete Transfer Function/S-Function']],...
		'function name','stvdtf',...
		'parameters','num,den,paramTs,Ts',...
		'Mask Display','',...
		'position',[220,78,310,102])

add_block('built-in/Outport',[sys,'/',['Time Varying',13,'Discrete Transfer Function/Output']])
set_param([sys,'/',['Time Varying',13,'Discrete Transfer Function/Output']],...
		'position',[340,80,360,100])
add_line([sys,'/',['Time Varying',13,'Discrete Transfer Function']],[185,90;215,90])
add_line([sys,'/',['Time Varying',13,'Discrete Transfer Function']],[80,155;95,155;95,100;145,100])
add_line([sys,'/',['Time Varying',13,'Discrete Transfer Function']],[80,90;145,90])
add_line([sys,'/',['Time Varying',13,'Discrete Transfer Function']],[80,30;95,30;95,80;145,80])
add_line([sys,'/',['Time Varying',13,'Discrete Transfer Function']],[315,90;335,90])
set_param([sys,'/',['Time Varying',13,'Discrete Transfer Function']],...
		'Mask Display','dpoly(num,[den],''z'')',...
		'Mask Type','Time Varying Discrete Transfer Function')
set_param([sys,'/',['Time Varying',13,'Discrete Transfer Function']],...
		'Mask Dialogue','Time Varying Discrete Transfer Function:|Initial Numerator:|Initial Denominator:|Sample Time:|Parameter Sample Time')
set_param([sys,'/',['Time Varying',13,'Discrete Transfer Function']],...
		'Mask Translate','num=@1;den=@2;Ts=@3;paramTs=@4;dim=length(den);')
set_param([sys,'/',['Time Varying',13,'Discrete Transfer Function']],...
		'Mask Help','This block is a TimeVarying Discrete Transfer Function.  The first input to the block is the transfer function input.  Inputs two and three are the numerator and denominator polynomials respectively.  If either input two or three is unconnected, the respective polynomial is time invariant.')
set_param([sys,'/',['Time Varying',13,'Discrete Transfer Function']],...
		'Mask Entries','[0.296, 2.88]\/[1, -3.096]\/1\/2\/')


%     Finished composite block ['Time Varying',13,'Discrete Transfer Function'].

set_param([sys,'/',['Time Varying',13,'Discrete Transfer Function']],...
		'position',[310,56,420,114])

add_block('built-in/Mux',[sys,'/','Mux'])
set_param([sys,'/','Mux'],...
		'hide name',0,...
		'inputs','2',...
		'position',[215,143,245,187])

add_block('built-in/Scope',[sys,'/','Setpoint//Plant'])
set_param([sys,'/','Setpoint//Plant'],...
		'Vgain','1000.000000',...
		'Hgain','100.000000',...
		'Vmax','1666.666667',...
		'Hmax','200.000000',...
		'Window',[488,601,751,774])
open_system([sys,'/','Setpoint//Plant'])
set_param([sys,'/','Setpoint//Plant'],...
		'position',[280,150,300,180])

add_block('built-in/Sum',[sys,'/','Sum'])
set_param([sys,'/','Sum'],...
		'hide name',0,...
		'inputs','-+',...
		'position',[210,45,230,80])

add_block('built-in/Signal Generator',[sys,'/','Setpoint'])
set_param([sys,'/','Setpoint'],...
		'Peak','5.000000',...
		'Peak Range','25.000000',...
		'Freq','0.100000',...
		'Freq Range','1.000000',...
		'Wave','Sqr',...
		'Units','Rads',...
		'position',[50,53,95,87])
add_line(sys,[585,195;585,235;545,235])
add_line(sys,[425,85;525,85])
add_line(sys,[480,85;480,125;555,125;555,145])
add_line(sys,[235,65;305,65])
add_line(sys,[450,250;345,250])
add_line(sys,[430,250;430,175;395,175])
add_line(sys,[635,85;700,85])
add_line(sys,[680,85;680,260;545,260])
add_line(sys,[680,120;610,120;610,145])
add_line(sys,[680,85;680,30;185,30;185,55;205,55])
add_line(sys,[185,55;185,155;210,155])
add_line(sys,[250,165;275,165])
add_line(sys,[100,70;205,70])
add_line(sys,[235,250;215,250])
add_line(sys,[150,260;120,260;120,85;305,85])
add_line(sys,[150,235;135,235;135,105;305,105])
add_line(sys,[170,70;170,175;210,175])

drawnow

% Return any arguments.
if (nargin | nargout)
	% Must use feval here to access system in memory
	if (nargin > 3)
		if (flag == 0)
			eval(['[ret,x0,str,ts,xts]=',sys,'(t,x,u,flag);'])
		else
			eval(['ret =', sys,'(t,x,u,flag);'])
		end
	else
		[ret,x0,str,ts,xts] = feval(sys);
	end
else
	drawnow % Flash up the model and execute load callback
end
