function [ret,x0,str,ts,xts]=rtc(t,x,u,flag);
%RTC	is the M-file description of the SIMULINK system named RTC.
%	The block-diagram can be displayed by typing: RTC.
%
%	SYS=RTC(T,X,U,FLAG) returns depending on FLAG certain
%	system values given time point, T, current state vector, X,
%	and input vector, U.
%	FLAG is used to indicate the type of output to be returned in SYS.
%
%	Setting FLAG=1 causes RTC to return state derivatives, FLAG=2
%	discrete states, FLAG=3 system outputs and FLAG=4 next sample
%	time. For more information and other options see SFUNC.
%
%	Calling RTC with a FLAG of zero:
%	[SIZES]=RTC([],[],[],0),  returns a vector, SIZES, which
%	contains the sizes of the state vector and other parameters.
%		SIZES(1) number of states
%		SIZES(2) number of discrete states
%		SIZES(3) number of outputs
%		SIZES(4) number of inputs
%		SIZES(5) number of roots (currently unsupported)
%		SIZES(6) direct feedthrough flag
%		SIZES(7) number of sample times
%
%	For the definition of other parameters in SIZES, see SFUNC.
%	See also, TRIM, LINMOD, LINSIM, EULER, RK23, RK45, ADAMS, GEAR.

% Note: This M-file is only used for saving graphical information;
%       after the model is loaded into memory an internal model
%       representation is used.

% the system will take on the name of this mfile:
sys = mfilename;
new_system(sys)
simver(1.3)
if (0 == (nargin + nargout))
     set_param(sys,'Location',[97,383,364,524])
     open_system(sys)
end;
set_param(sys,'algorithm',     'RK-45')
set_param(sys,'Start time',    '0.0')
set_param(sys,'Stop time',     '999999')
set_param(sys,'Min step size', '0.0001')
set_param(sys,'Max step size', '10')
set_param(sys,'Relative error','1e-3')
set_param(sys,'Return vars',   '')


%     Subsystem  ['Real-time',13,'Clock'].

new_system([sys,'/',['Real-time',13,'Clock']])
set_param([sys,'/',['Real-time',13,'Clock']],'Location',[25,81,220,206])

add_block('built-in/S-Function',[sys,'/',['Real-time',13,'Clock/Real-time',13,'Clock']])
set_param([sys,'/',['Real-time',13,'Clock/Real-time',13,'Clock']],...
		'hide name',0,...
		'function name','rtclock',...
		'parameters','sample_time, tolerance',...
		'position',[70,52,140,78])
set_param([sys,'/',['Real-time',13,'Clock']],...
		'Mask Display','plot(0,0,100,100,[40,60,60,54,54,64,69,76,82,77,81,83,83,81,78,74,70,64,57,49,41,35,32,30,30,31,34,40,47,47,40,40],[90,90,85,85,80,79,76,87,80,70,64,57,49,41,33,28,24,22,21,23,25,31,37,46,56,65,73,78,80,85,85,90],[69,53,53],[64,50,73])')
set_param([sys,'/',['Real-time',13,'Clock']],...
		'Mask Type','Real-time Clock',...
		'Mask Dialogue','Real-time Synchronization Block|Synchronize with real-time every n seconds:|Real-time warning tolerance (seconds):')
set_param([sys,'/',['Real-time',13,'Clock']],...
		'Mask Translate','sample_time=@1;tolerance=@2;')
set_param([sys,'/',['Real-time',13,'Clock']],...
		'Mask Help','This block synchronizes simulation time with the PC real-time clock or UNIX system clock. The first dialog entry is the period at which the clock is checked to insure real-time synchronization. The second dialog entry is the number of seconds that the simulation time must be within real-time before a warning is printed.')
set_param([sys,'/',['Real-time',13,'Clock']],...
		'Mask Entries','.1\/.5\/')


%     Finished composite block ['Real-time',13,'Clock'].

set_param([sys,'/',['Real-time',13,'Clock']],...
		'position',[106,36,143,67])

drawnow

% Return any arguments.
if (nargin | nargout)
	% Must use feval here to access system in memory
	if (nargin > 3)
		if (flag == 0)
			eval(['[ret,x0,str,ts,xts]=',sys,'(t,x,u,flag);'])
		else
			eval(['ret =', sys,'(t,x,u,flag);'])
		end
	else
		[ret,x0,str,ts,xts] = feval(sys);
	end
else
	drawnow % Flash up the model and execute load callback
end
