function [path,filename] = findpath(filename),
%FINDPATH  Returns the path to a file that is on the MATLABPATH or
%      in the current directory.

%		Returns '', if the file was not found or read permission
%		was denied. 

%		Copyright (c) 1994 by The MathWorks, Inc.

if (nargin ~= 1 | ~isstr(filename)),
	error('findpath requires a single string argument');
end

% inputs:  filename = string that contains the name of the file
% outputs: path


% take care of null case
if isempty(filename),
    path = '';
    filename = '';
    return
end

comp = computer;
pc = strcmp(comp(1:2),'PC');

if pc,
	SLASH = '\';
else
	SLASH = '/';
end

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% make sure that file exists and is readable
%    it still may be a directory though
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

fid = fopen(filename,'r');
if fid < 0,
   path = '';
   return   
end
[filepath junk] = fopen(fid);
fclose(fid);


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% check to see if an explicit path was indicated
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
ind = findstr(filename,SLASH);

if ~isempty(ind),        % if path specified then do the following
    ln = length(ind);
    path = filename(1:ind(ln));
    filename = filename((ind(ln)+1):length(filename));
    return
end


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% take care of the special case where fopen only returns
%      the filename (i.e., when the file is in the current 
%      directory
% otherwise, rip off the filename leaving only path protion
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
if size(filepath) == size(filename),
	path = [cd,SLASH];
else
	ind = findstr(filepath,SLASH);
	len = length(ind);
    if len > 0,
		path = filepath(1:ind(len));
	else
		path = filepath(1:ind);
	end
end


