function [sys, x0] = sd3plot(t,x,u,flag,plotit),
%SD3PLOT plot routine used for SDDEMO3 animation

%		Copyright (c) 1993 by The MathWorks, Inc.
%		Jay Torgerson

ts = .01;
global sd3hands;
if abs(flag) == 0,
    sys = [ 0 1 0 4 0 0 ];
    x0 = 0;
    if isempty(sd3hands)
      return;   
    end
    if plotit,
      set(sd3hands(1),'Visible','On','Color','y');
      set(sd3hands(2),'Visible','On','Color','b');
      set(sd3hands(3),'Visible','On','Color','r');
      set(sd3hands(4),'Visible','On','Color','w');
    end
elseif (flag == 2),
    if isempty(sd3hands)
      return;   
    end
if  (abs(round(t/ts) - t/ts) < 1e-8),
if plotit,
		% get position data		
		pos1 = u(1);
		theta = u(2);   % wedge angular displacement
		pos2 = u(3);
		alpha = u(4);   % pendulum angular displacement

		% get axis limits and scale factor for cart lines
		v = axis;
		pl = .61; wedgewidth = .5;
		
		% setup handles
        wedgeh = sd3hands(1);
        cart1h = sd3hands(2);
        cart2h = sd3hands(3);
		pendh = sd3hands(4);

		wedge_fudge = .025;
		cartscale = abs(wedgewidth)/20;
		rotmat = [ cos(theta) sin(theta); -sin(theta) cos(theta) ];

        % compute coords for the wedge
        x1 = [ -.5 .5 ];
        y1 = [ tan(pi-theta)*(-wedgewidth) tan(-theta)*(wedgewidth) ];

		% compute coords for cart1 in the wedge frame
        x2p = [ pos1-cartscale pos1+cartscale ];
        y2p = [ wedge_fudge wedge_fudge ];

		% rotate to intertial reference frame
		m = rotmat*[ x2p;y2p ];
		x2 = m(1,:);
		y2 = m(2,:);

		% compute coords for cart2 in the wedge frame
        x3p = [ pos2-cartscale pos2+cartscale ];
        y3p = [ wedge_fudge wedge_fudge ];

		% rotate to intertial frame
		m = rotmat*[x3p;y3p ];
		x3 = m(1,:);
		y3 = m(2,:);

		% compute coords for pendulum 
		m = rotmat*[pos2;wedge_fudge];    % this is actually cart2's C.M. coords in
  			  				    % the intertial reference frame
    	x4 = [ m(1) m(1)+sin(alpha+theta)*pl ];
		y4 = [ m(2) m(2)+cos(alpha+theta)*pl ];

		
		% call chgblob to redraw these blobs if their position has changed
    	set(wedgeh,'Xdata',x1,'Ydata',y1);
    	set(cart1h,'Xdata',x2,'Ydata',y2);
    	set(cart2h,'Xdata',x3,'Ydata',y3);
    	set(pendh,'Xdata',x4,'Ydata',y4);
        drawnow
    end
 end
    sys = 0;
elseif flag == 4,
	t = t + .1;
else
    sys = [];
end





