function sdbuild(flag),
%SDBUILB Builds a SIMULINK MEX-file out of an SD/FAST system
%		SDBUILD is called from the SD/FAST Interface Control Panel.

%		Copyright (c) 1994 by The MathWorks, Inc.

%This function:
%      (1) calls sdfast to generate .c-file from .sd-file
%      (2) calls cmex to creat .mex4-file corresponding to system

% get handle to control panel and handles to everything else
fig = gcf;
nl = setstr(10);
handles = get(fig,'UserData');
comp = computer;
pc  = strcmp(comp(1:2),'PC');

SPACE = ' ';
if pc,
    SLASH  = '\';
    CPYCMD = 'copy ';
    CATCMD = 'type ';	
    DELCMD = 'del ';	
    SHELLSUFFIX = ' |';
else
    SLASH  = '/';
    CPYCMD = 'cp ';    				
    CATCMD = 'cat ';	
    DELCMD = 'rm -f ';	
    SHELLSUFFIX = '';
end
CURRENTDIR = [cd,SLASH];

% useful handles and strings
sdstatush = handles(1);
sdname = get(handles(5),'String');
sddir = get(handles(4),'String');
sdinputfile = get(handles(8),'String');
sdinputdir = get(handles(7),'String');
sdoutputfile = get(handles(11),'String');
sdoutputdir = get(handles(10),'String');

INPUTLOCAL  = strcmp(CURRENTDIR,sdinputdir);
OUTPUTLOCAL = strcmp(CURRENTDIR,sdoutputdir);

previous_string = get(sdstatush,'String');

set(fig,'Pointer','Watch');
drawnow

% Make sure the sdlib.c file is on the path
sdlibpath = findpath('sdlib.c');
if isempty(sdlibpath)
  ErrorMsg = ['Error: could not find required source file, "sdlib.c."',setstr(10),...
	      'Add the directory where this file lives to your MATLABPATH. '];
  errordlg(ErrorMsg);
  set(sdstatush,'String',previous_string);  
  set(fig,'Pointer','Arrow');
   return
end  

sdlibfile = [sdlibpath,'sdlib.c'];


% check to see if verbose was asked for
if strcmp(flag,'v'),
   verbose = 1;
   verbosetext = '-v ';
else
   verbose = 0;
   verbosetext = '';
end

if pc,
    verbosetext = '';
end

% call sdgen to generate .c-file 
if  verbose,
    generated = sdgen('v');
    SHELLSUFFIX = '';
else
    generated = sdgen('');
end
  
if  ~generated,
    return
end
% set pionter to watch again
set(fig,'Pointer','Watch');
drawnow

% take off the ".sd" portion of the variable 'name'
i = findstr(lower(sdname),'.sd');
if ~isempty(i),
	name = sdname(1:i(1)-1);
else 
	name = sdname;
end
namec = [name,'.c'];

% make sure that sdfmex.c template file is found and 
%  copy it to a new file whos base name is the system 
%  base name
if exist('sdfmex.c') ~= 2,
   errordlg(['SD/FAST template MEX-file, "sdfmex.c", not found -',...
             'make sure that the "SD/Fast Interface" directory is on your MATLAB path.']);
   set(sdstatush,'String',previous_string);
   set(fig,'Pointer','Arrow');
   return
else
   set(sdstatush,'String',['Building "',name,'.mex" in current directory...']);drawnow
          
   fullsdfmex = [findpath('sdfmex.c'),'sdfmex.c'];
   fullname = [CURRENTDIR,name];

   % first, delete it
   command = [DELCMD,namec];      
   unix(command);   
   
   command = [CPYCMD,fullsdfmex,SPACE,fullname,'.c'];
   unix(command);
end
   
% define file names
sdcfile = [fullname,'.c'];
if ~pc,
   dynfile = [name,'_dyn.c'];
   sarfile = [name,'_sar.c'];
else
   dynfile = [name,'_d.c'];
   sarfile = [name,'_s.c'];
end

infile  = [sdinputdir,sdinputfile];
outfile = [sdoutputdir,sdoutputfile];

% call cmex to create correspondvnb sdfast mex-file

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% copy files to current directory since DOS can't deal with > 128 chars
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
if (~INPUTLOCAL)
  command = [DELCMD,sdinputfile,SHELLSUFFIX];  
  unix(command);  
  command = [CPYCMD,infile,SPACE,CURRENTDIR,sdinputfile,SHELLSUFFIX];
  unix(command);
end

if (~OUTPUTLOCAL)
  command = [DELCMD,sdoutputfile,SHELLSUFFIX];    
  unix(command);  
  command = [CPYCMD,outfile,SPACE,CURRENTDIR,sdoutputfile,SHELLSUFFIX];
  unix(command);
end

compilecmd = ['cmex ',verbosetext,namec,SPACE,sdinputfile,SPACE,sdoutputfile,SPACE,dynfile,SPACE,sarfile,SPACE,sdlibfile,SHELLSUFFIX];

if verbose,
    eval(['! ',compilecmd])
else
    unix(compilecmd);
end

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% If you had to copy them, now delete them.
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
if (~INPUTLOCAL)
    command = [DELCMD,CURRENTDIR,sdinputfile,SHELLSUFFIX];
    unix(command);
end

if (~OUTPUTLOCAL)
    command = [DELCMD,CURRENTDIR,sdoutputfile,SHELLSUFFIX];
    unix(command);
end

set(sdstatush,'String',previous_string);
set(fig,'Pointer','Arrow');
drawnow   









