function [ret,x0,str,ts,xts]=sddemo1(t,x,u,flag);
%SDDEMO1	is the M-file description of the SIMULINK system named SDDEMO1.
%	The block-diagram can be displayed by typing: SDDEMO1.
%
%	SYS=SDDEMO1(T,X,U,FLAG) returns depending on FLAG certain
%	system values given time point, T, current state vector, X,
%	and input vector, U.
%	FLAG is used to indicate the type of output to be returned in SYS.
%
%	Setting FLAG=1 causes SDDEMO1 to return state derivatives, FLAG=2
%	discrete states, FLAG=3 system outputs and FLAG=4 next sample
%	time. For more information and other options see SFUNC.
%
%	Calling SDDEMO1 with a FLAG of zero:
%	[SIZES]=SDDEMO1([],[],[],0),  returns a vector, SIZES, which
%	contains the sizes of the state vector and other parameters.
%		SIZES(1) number of states
%		SIZES(2) number of discrete states
%		SIZES(3) number of outputs
%		SIZES(4) number of inputs
%		SIZES(5) number of roots (currently unsupported)
%		SIZES(6) direct feedthrough flag
%		SIZES(7) number of sample times
%
%	For the definition of other parameters in SIZES, see SFUNC.
%	See also, TRIM, LINMOD, LINSIM, EULER, RK23, RK45, ADAMS, GEAR.

% Note: This M-file is only used for saving graphical information;
%       after the model is loaded into memory an internal model
%       representation is used.

% the system will take on the name of this mfile:
sys = mfilename;
new_system(sys)
simver(1.3)
if (0 == (nargin + nargout))
     set_param(sys,'Location',[211,130,775,437])
     open_system(sys)
end;
set_param(sys,'algorithm',     'Adams/Gear')
set_param(sys,'Start time',    '0')
set_param(sys,'Stop time',     '49')
set_param(sys,'Min step size', '0.0002')
set_param(sys,'Max step size', '.10')
set_param(sys,'Relative error','1e-4')
set_param(sys,'Return vars',   '')
set_param(sys,'Compile command','!cmex4 $model.c')
set_param(sys,'Real-time build command','!download $model.c $model.h')

add_block('built-in/Gain',[sys,'/','Gain'])
set_param([sys,'/','Gain'],...
		'Gain','200',...
		'position',[120,124,160,156])

add_block('built-in/Scope',[sys,'/','ang velocity'])
set_param([sys,'/','ang velocity'],...
		'Vgain','2.000000',...
		'Hgain','50.000000',...
		'Vmax','3.333333',...
		'Hmax','87.719298',...
		'Window',[450,780,868,895],...
		'position',[460,165,485,195])

add_block('built-in/Demux',[sys,'/','Demux'])
set_param([sys,'/','Demux'],...
		'hide name',0,...
		'outputs','2',...
		'position',[355,130,395,165])

add_block('built-in/Mux',[sys,'/','Mux'])
set_param([sys,'/','Mux'],...
		'hide name',0,...
		'inputs','2',...
		'position',[200,130,230,165])

add_block('built-in/Scope',[sys,'/','ang position'])
set_param([sys,'/','ang position'],...
		'Vgain','2.000000',...
		'Hgain','50.000000',...
		'Vmax','4.000000',...
		'Hmax','100.000000',...
		'Window',[453,540,870,657],...
		'position',[460,95,485,125])

add_block('built-in/S-Function',[sys,'/','SD//FAST'])
set_param([sys,'/','SD//FAST'],...
		'function name','pend',...
		'parameters','2,2,[ 0 ],[ 0 ],[ 0 ],[ 0 ],.001,.001',...
		'Mask Display','pend',...
		'Mask Type','SD/FAST Interface block',...
		'Mask Dialogue','eval(''sdpanel('''''''');'');')
set_param([sys,'/','SD//FAST'],...
		'Mask Help','pend.sd,pendi.c,pendo.c',...
		'position',[265,137,320,163])

add_block('built-in/Scope',[sys,'/','input'])
set_param([sys,'/','input'],...
		'Vgain','200.000000',...
		'Hgain','50.000000',...
		'Vmax','400.000000',...
		'Hmax','100.000000',...
		'Window',[23,544,439,666],...
		'position',[230,85,255,115])

add_block('built-in/Note',[sys,'/',['This system simulates a one degree of freedom',13,'pendulum that is hit at approximately t = 10 seconds. ',13,'A linear friction model is used. ']])
set_param([sys,'/',['This system simulates a one degree of freedom',13,'pendulum that is hit at approximately t = 10 seconds. ',13,'A linear friction model is used. ']],...
		'position',[270,10,275,15])


%     Subsystem  'sddemo5'.

new_system([sys,'/','sddemo5'])
set_param([sys,'/','sddemo5'],'Location',[-10,380,117,533])
set_param([sys,'/','sddemo5'],...
		'Mask Display','Double Click Here to\nsee this model with\ntorsion spring friction.',...
		'Mask Dialogue','eval(''sddemo5'')')


%     Finished composite block 'sddemo5'.

set_param([sys,'/','sddemo5'],...
		'BackGround',5,...
		'hide name',0,...
		'position',[398,235,554,296])

add_block('built-in/Fcn',[sys,'/','Fcn2'])
set_param([sys,'/','Fcn2'],...
		'orientation',2,...
		'hide name',0,...
		'Expr','-Frictcoef*u',...
		'Mask Display','Friction\nModel',...
		'Mask Type','Friction Model',...
		'Mask Dialogue','Torque  = Frictcoeff*u. | Frictcoeff:')
set_param([sys,'/','Fcn2'],...
		'Mask Translate','Frictcoef = @1;',...
		'Mask Entries','10\/',...
		'position',[260,202,325,228])

add_block('built-in/From Workspace',[sys,'/','Pulse'])
set_param([sys,'/','Pulse'],...
		'matl_expr','[T'', U'']',...
		'Mask Display','plot(T,U)',...
		'Mask Type','Look-up Table',...
		'Mask Dialogue','Input Flow|Time Values (t):|Pulse Values(U):',...
		'Mask Translate','T=@1;U=@2;')
set_param([sys,'/','Pulse'],...
		'Mask Entries','[0       9.9       10     10.1   50]\/[0        0           1       0       0]\/',...
		'position',[35,127,75,153])
add_line(sys,[325,150;350,150])
add_line(sys,[400,140;415,140;415,110;455,110])
add_line(sys,[400,155;415,155;415,180;455,180])
add_line(sys,[80,140;115,140])
add_line(sys,[235,150;260,150])
add_line(sys,[165,140;195,140])
add_line(sys,[175,140;175,100;225,100])
add_line(sys,[255,215;175,215;175,155;195,155])
add_line(sys,[415,180;415,215;330,215])

drawnow

% Return any arguments.
if (nargin | nargout)
	% Must use feval here to access system in memory
	if (nargin > 3)
		if (flag == 0)
			eval(['[ret,x0,str,ts,xts]=',sys,'(t,x,u,flag);'])
		else
			eval(['ret =', sys,'(t,x,u,flag);'])
		end
	else
		[ret,x0,str,ts,xts] = feval(sys);
	end
else
	drawnow % Flash up the model and execute load callback
end
