function [ret,x0,str,ts,xts]=sddemo2(t,x,u,flag);
%SDDEMO2	is the M-file description of the SIMULINK system named SDDEMO2.
%	The block-diagram can be displayed by typing: SDDEMO2.
%
%	SYS=SDDEMO2(T,X,U,FLAG) returns depending on FLAG certain
%	system values given time point, T, current state vector, X,
%	and input vector, U.
%	FLAG is used to indicate the type of output to be returned in SYS.
%
%	Setting FLAG=1 causes SDDEMO2 to return state derivatives, FLAG=2
%	discrete states, FLAG=3 system outputs and FLAG=4 next sample
%	time. For more information and other options see SFUNC.
%
%	Calling SDDEMO2 with a FLAG of zero:
%	[SIZES]=SDDEMO2([],[],[],0),  returns a vector, SIZES, which
%	contains the sizes of the state vector and other parameters.
%		SIZES(1) number of states
%		SIZES(2) number of discrete states
%		SIZES(3) number of outputs
%		SIZES(4) number of inputs
%		SIZES(5) number of roots (currently unsupported)
%		SIZES(6) direct feedthrough flag
%		SIZES(7) number of sample times
%
%	For the definition of other parameters in SIZES, see SFUNC.
%	See also, TRIM, LINMOD, LINSIM, EULER, RK23, RK45, ADAMS, GEAR.

% Note: This M-file is only used for saving graphical information;
%       after the model is loaded into memory an internal model
%       representation is used.

% the system will take on the name of this mfile:
sys = mfilename;
new_system(sys)
simver(1.3)
if (0 == (nargin + nargout))
     set_param(sys,'Location',[283,95,853,408])
     open_system(sys)
end;
set_param(sys,'algorithm',     'RK-45')
set_param(sys,'Start time',    '0')
set_param(sys,'Stop time',     '59')
set_param(sys,'Min step size', '0.0002')
set_param(sys,'Max step size', '.1')
set_param(sys,'Relative error','1e-3')
set_param(sys,'Return vars',   '')
set_param(sys,'Real-time build command','!download $model.c $model.h')

add_block('built-in/Scope',[sys,'/','input'])
set_param([sys,'/','input'],...
		'Vgain','20.000000',...
		'Hgain','100.000000',...
		'Vmax','40.000000',...
		'Hmax','Inf',...
		'Window',[103,220,519,342],...
		'position',[200,120,225,150])

add_block('built-in/Gain',[sys,'/','Gain'])
set_param([sys,'/','Gain'],...
		'position',[110,179,150,211])

add_block('built-in/Scope',[sys,'/','slider position'])
set_param([sys,'/','slider position'],...
		'Vgain','10.000000',...
		'Hgain','60.000000',...
		'Vmax','17.543860',...
		'Hmax','Inf',...
		'Window',[67,224,483,342],...
		'position',[475,85,500,115])

add_block('built-in/Scope',[sys,'/','pendulum ang velocity'])
set_param([sys,'/','pendulum ang velocity'],...
		'Vgain','1.000000',...
		'Hgain','60.000000',...
		'Vmax','1.724138',...
		'Hmax','Inf',...
		'Window',[613,453,1026,583],...
		'position',[475,260,500,290])

add_block('built-in/Demux',[sys,'/','Demux'])
set_param([sys,'/','Demux'],...
		'hide name',0,...
		'Mask Display','',...
		'position',[280,173,325,217])

add_block('built-in/Note',[sys,'/',['This is an SD//FAST model of a pendulum connected to a cart which',13,'can move only the x direction.  The system has two freedoms of motion: ',13,'']])
set_param([sys,'/',['This is an SD//FAST model of a pendulum connected to a cart which',13,'can move only the x direction.  The system has two freedoms of motion: ',13,'']],...
		'position',[240,8,245,13])

add_block('built-in/Note',[sys,'/',' ii) the horizontal displacement of the cart and pendulum system.'])
set_param([sys,'/',' ii) the horizontal displacement of the cart and pendulum system.'],...
		'position',[245,58,250,63])

add_block('built-in/Note',[sys,'/','i) the angular displacement of the pendulum , and'])
set_param([sys,'/','i) the angular displacement of the pendulum , and'],...
		'position',[210,40,215,45])

add_block('built-in/S-Function',[sys,'/','SD//FAST'])
set_param([sys,'/','SD//FAST'],...
		'function name','pndcrt',...
		'parameters','1,4,[ 0 0 ],[ 0 0 ],[ 0 0 ],[ 0 0 ],.001,.001',...
		'Mask Display','pndcrt',...
		'Mask Type','SD/FAST Interface block')
set_param([sys,'/','SD//FAST'],...
		'Mask Dialogue','eval(''sdpanel('''''''');'');',...
		'Mask Help','pndcrt.sd,pndcrti.c,pndcrto.c',...
		'position',[185,182,240,208])

add_block('built-in/Scope',[sys,'/','pendulum ang position'])
set_param([sys,'/','pendulum ang position'],...
		'Vgain','0.500000',...
		'Hgain','60.000000',...
		'Vmax','Inf',...
		'Hmax','Inf',...
		'Window',[627,205,1042,318],...
		'position',[475,150,500,180])

add_block('built-in/Scope',[sys,'/','slider velocity'])
set_param([sys,'/','slider velocity'],...
		'Vgain','0.500000',...
		'Hgain','60.000000',...
		'Vmax','0.847458',...
		'Hmax','Inf',...
		'Window',[64,475,482,605],...
		'position',[475,205,500,235])

add_block('built-in/Note',[sys,'/',['Torsional friction between the cart and the pendulum',13,'is applied in sdinputs() (pndinvi.c) to dampen the oscillations']])
set_param([sys,'/',['Torsional friction between the cart and the pendulum',13,'is applied in sdinputs() (pndinvi.c) to dampen the oscillations']],...
		'position',[175,260,180,265])

add_block('built-in/From Workspace',[sys,'/','Pulse'])
set_param([sys,'/','Pulse'],...
		'matl_expr','[T'', U'']',...
		'Mask Display','plot(T,U)',...
		'Mask Type','Look-up Table',...
		'Mask Dialogue','Input Flow|Time Values (t):|Pulse Values(U):',...
		'Mask Translate','T=@1;U=@2;')
set_param([sys,'/','Pulse'],...
		'Mask Entries','[0       9.9       10     10.1   50]\/[0        0           1       0       0]\/',...
		'position',[30,182,70,208])
add_line(sys,[155,195;180,195])
add_line(sys,[245,195;275,195])
add_line(sys,[330,180;355,180;355,100;470,100])
add_line(sys,[330,190;410,190;410,165;470,165])
add_line(sys,[330,200;410,200;410,220;470,220])
add_line(sys,[330,210;355,210;355,275;470,275])
add_line(sys,[75,195;105,195])
add_line(sys,[155,195;155,135;195,135])

drawnow

% Return any arguments.
if (nargin | nargout)
	% Must use feval here to access system in memory
	if (nargin > 3)
		if (flag == 0)
			eval(['[ret,x0,str,ts,xts]=',sys,'(t,x,u,flag);'])
		else
			eval(['ret =', sys,'(t,x,u,flag);'])
		end
	else
		[ret,x0,str,ts,xts] = feval(sys);
	end
else
	drawnow % Flash up the model and execute load callback
end
