function [ret,x0,str,ts,xts]=sddemo3(t,x,u,flag);
%SDDEMO3	is the M-file description of the SIMULINK system named SDDEMO3.
%	The block-diagram can be displayed by typing: SDDEMO3.
%
%	SYS=SDDEMO3(T,X,U,FLAG) returns depending on FLAG certain
%	system values given time point, T, current state vector, X,
%	and input vector, U.
%	FLAG is used to indicate the type of output to be returned in SYS.
%
%	Setting FLAG=1 causes SDDEMO3 to return state derivatives, FLAG=2
%	discrete states, FLAG=3 system outputs and FLAG=4 next sample
%	time. For more information and other options see SFUNC.
%
%	Calling SDDEMO3 with a FLAG of zero:
%	[SIZES]=SDDEMO3([],[],[],0),  returns a vector, SIZES, which
%	contains the sizes of the state vector and other parameters.
%		SIZES(1) number of states
%		SIZES(2) number of discrete states
%		SIZES(3) number of outputs
%		SIZES(4) number of inputs
%		SIZES(5) number of roots (currently unsupported)
%		SIZES(6) direct feedthrough flag
%		SIZES(7) number of sample times
%
%	For the definition of other parameters in SIZES, see SFUNC.
%	See also, TRIM, LINMOD, LINSIM, EULER, RK23, RK45, ADAMS, GEAR.

% Note: This M-file is only used for saving graphical information;
%       after the model is loaded into memory an internal model
%       representation is used.

% the system will take on the name of this mfile:
sys = mfilename;
new_system(sys)
simver(1.3)
if (0 == (nargin + nargout))
     set_param(sys,'Location',[150,106,864,589])
     open_system(sys)
end;
set_param(sys,'algorithm',     'RK-45')
set_param(sys,'Start time',    '0.0')
set_param(sys,'Stop time',     '999999')
set_param(sys,'Min step size', '0.0001')
set_param(sys,'Max step size', '10')
set_param(sys,'Relative error','1e-3')
set_param(sys,'Return vars',   '')
set_param(sys,'Load callback','Klqr = [-204.04411 -378.80606 -169.44962 -28.571865 -23.526945 -112.93424 -27.368847 -6.131576 -0.52220171 -3.6556576 ;-41.117369 28.086293 12.428597 195.12509 -4.6631353 9.659292 32.80728 54.485445 3.8534014 -3.3026936 ];');

add_block('built-in/Scope',[sys,'/','x1'])
set_param([sys,'/','x1'],...
		'Vgain','0.500000',...
		'Hgain','10.000000',...
		'Vmax','1.000000',...
		'Hmax','20.000000',...
		'Window',[83,182,501,306],...
		'position',[265,147,285,173])

add_block('built-in/Note',[sys,'/','back EMF'])
set_param([sys,'/','back EMF'],...
		'position',[541,131,546,136])

add_block('built-in/S-Function',[sys,'/','SD//FAST'])
set_param([sys,'/','SD//FAST'],...
		'function name','invpnd',...
		'parameters','2,6,[ 0 -.2 -.2 0],[  0 0 0 0 ],[ 0 0 0 0 ],[ 0 0 0 0 ],.001,.001',...
		'Mask Display','invpnd',...
		'Mask Type','SD/Fast interface block')
set_param([sys,'/','SD//FAST'],...
		'Mask Dialogue','eval(''sdpanel('''''''');'');',...
		'Mask Help','invpnd.sd,invpndi.c,invpndo.c',...
		'position',[520,177,575,203])

add_block('built-in/Scope',[sys,'/','x2'])
set_param([sys,'/','x2'],...
		'Vgain','0.500000',...
		'Hgain','10.000000',...
		'Vmax','1.000000',...
		'Hmax','20.000000',...
		'Window',[576,164,1004,285],...
		'position',[220,127,240,153])


%     Subsystem  'demux'.

new_system([sys,'/','demux'])
set_param([sys,'/','demux'],'Location',[170,150,461,302])

add_block('built-in/Demux',[sys,'/','demux/Demux1'])
set_param([sys,'/','demux/Demux1'],...
		'hide name',0,...
		'outputs','6',...
		'position',[70,32,110,98])

add_block('built-in/Inport',[sys,'/','demux/in_1'])
set_param([sys,'/','demux/in_1'],...
		'position',[20,35,40,55])

add_block('built-in/Outport',[sys,'/','demux/out_1'])
set_param([sys,'/','demux/out_1'],...
		'Port','2',...
		'position',[250,45,270,65])

add_block('built-in/Mux',[sys,'/','demux/Mux'])
set_param([sys,'/','demux/Mux'],...
		'hide name',0,...
		'position',[155,32,185,78])

add_block('built-in/Mux',[sys,'/','demux/Mux1'])
set_param([sys,'/','demux/Mux1'],...
		'hide name',0,...
		'inputs','2',...
		'position',[155,96,185,129])

add_block('built-in/Outport',[sys,'/','demux/out_2'])
set_param([sys,'/','demux/out_2'],...
		'position',[250,105,270,125])
add_line([sys,'/','demux'],[190,115;245,115])
add_line([sys,'/','demux'],[115,90;150,120])
add_line([sys,'/','demux'],[115,80;150,105])
add_line([sys,'/','demux'],[190,55;245,55])
add_line([sys,'/','demux'],[115,70;150,70])
add_line([sys,'/','demux'],[115,60;150,60])
add_line([sys,'/','demux'],[115,50;150,50])
add_line([sys,'/','demux'],[45,45;65,65])
add_line([sys,'/','demux'],[115,40;150,40])
set_param([sys,'/','demux'],...
		'Mask Display','Demux',...
		'Mask Type','Demux (special case)')


%     Finished composite block 'demux'.

set_param([sys,'/','demux'],...
		'hide name',0,...
		'position',[605,170,645,210])


%     Subsystem  'Volts to Newtons'.

new_system([sys,'/','Volts to Newtons'])
set_param([sys,'/','Volts to Newtons'],'Location',[194,174,656,384])

add_block('built-in/Inport',[sys,'/','Volts to Newtons/in_2'])
set_param([sys,'/','Volts to Newtons/in_2'],...
		'Port','2',...
		'position',[185,70,205,90])

add_block('built-in/Outport',[sys,'/','Volts to Newtons/out_1'])
set_param([sys,'/','Volts to Newtons/out_1'],...
		'position',[415,80,435,100])

add_block('built-in/Mux',[sys,'/','Volts to Newtons/Mux'])
set_param([sys,'/','Volts to Newtons/Mux'],...
		'hide name',0,...
		'inputs','2',...
		'position',[355,51,380,124])

add_block('built-in/Fcn',[sys,'/','Volts to Newtons/Fcn'])
set_param([sys,'/','Volts to Newtons/Fcn'],...
		'hide name',0,...
		'Expr','u[2] -7.28*u[1]',...
		'position',[285,60,325,80])

add_block('built-in/Fcn',[sys,'/','Volts to Newtons/Fcn1'])
set_param([sys,'/','Volts to Newtons/Fcn1'],...
		'hide name',0,...
		'Expr','u[2] -7.28*u[1]',...
		'position',[285,95,325,115])

add_block('built-in/Mux',[sys,'/','Volts to Newtons/Mux1'])
set_param([sys,'/','Volts to Newtons/Mux1'],...
		'hide name',0,...
		'inputs','2',...
		'position',[230,50,265,90])

add_block('built-in/Demux',[sys,'/','Volts to Newtons/Demux'])
set_param([sys,'/','Volts to Newtons/Demux'],...
		'hide name',0,...
		'outputs','2',...
		'position',[80,50,120,85])

add_block('built-in/Inport',[sys,'/','Volts to Newtons/in_3'])
set_param([sys,'/','Volts to Newtons/in_3'],...
		'Port','3',...
		'position',[180,150,200,170])

add_block('built-in/Inport',[sys,'/','Volts to Newtons/in_1'])
set_param([sys,'/','Volts to Newtons/in_1'],...
		'position',[35,60,55,80])

add_block('built-in/Mux',[sys,'/','Volts to Newtons/Mux2'])
set_param([sys,'/','Volts to Newtons/Mux2'],...
		'hide name',0,...
		'inputs','2',...
		'position',[230,131,265,169])
add_line([sys,'/','Volts to Newtons'],[270,150;280,105])
add_line([sys,'/','Volts to Newtons'],[270,70;280,70])
add_line([sys,'/','Volts to Newtons'],[330,105;350,105])
add_line([sys,'/','Volts to Newtons'],[330,70;350,70])
add_line([sys,'/','Volts to Newtons'],[385,90;410,90])
add_line([sys,'/','Volts to Newtons'],[60,70;75,70])
add_line([sys,'/','Volts to Newtons'],[125,60;225,60])
add_line([sys,'/','Volts to Newtons'],[210,80;225,80])
add_line([sys,'/','Volts to Newtons'],[125,75;150,75;150,140;225,140])
add_line([sys,'/','Volts to Newtons'],[205,160;225,160])


%     Finished composite block 'Volts to Newtons'.

set_param([sys,'/','Volts to Newtons'],...
		'position',[455,163,485,217])

add_block('built-in/Scope',[sys,'/','theta (fulcrum)'])
set_param([sys,'/','theta (fulcrum)'],...
		'Vgain','1.700000',...
		'Hgain','100.000000',...
		'Vmax','3.400000',...
		'Hmax','200.000000',...
		'Window',[90,755,532,875],...
		'position',[535,277,555,303])

add_block('built-in/Scope',[sys,'/','alpha (pendulum)'])
set_param([sys,'/','alpha (pendulum)'],...
		'Vgain','1.700000',...
		'Hgain','100.000000',...
		'Vmax','3.400000',...
		'Hmax','200.000000',...
		'Window',[557,733,1010,854],...
		'position',[535,347,555,373])

add_block('built-in/Note',[sys,'/',['The system modeled by SD//FAST is that',13,'of two carts on a seesaw.  Cart 2 has an ',13,'inverted pendulum balanced on it.  Double',13,'click on the Animation block and start the',13,'simulation to see the system.']])
set_param([sys,'/',['The system modeled by SD//FAST is that',13,'of two carts on a seesaw.  Cart 2 has an ',13,'inverted pendulum balanced on it.  Double',13,'click on the Animation block and start the',13,'simulation to see the system.']],...
		'position',[236,11,241,16])


%     Subsystem  ['LQR Controller',13,'with  position feedback,',13,'velocity estimators, and ',13,'no motor dynamics'].

new_system([sys,'/',['LQR Controller',13,'with  position feedback,',13,'velocity estimators, and ',13,'no motor dynamics']])
set_param([sys,'/',['LQR Controller',13,'with  position feedback,',13,'velocity estimators, and ',13,'no motor dynamics']],'Location',[125,181,1053,758])

add_block('built-in/Note',[sys,'/',['LQR Controller',13,'with  position feedback,',13,'velocity estimators, and ',13,'no motor dynamics/Fcart2']])
set_param([sys,'/',['LQR Controller',13,'with  position feedback,',13,'velocity estimators, and ',13,'no motor dynamics/Fcart2']],...
		'position',[846,358,851,363])

add_block('built-in/Note',[sys,'/',['LQR Controller',13,'with  position feedback,',13,'velocity estimators, and ',13,'no motor dynamics/Fcart1']])
set_param([sys,'/',['LQR Controller',13,'with  position feedback,',13,'velocity estimators, and ',13,'no motor dynamics/Fcart1']],...
		'position',[846,308,851,313])

add_block('built-in/Outport',[sys,'/',['LQR Controller',13,'with  position feedback,',13,'velocity estimators, and ',13,'no motor dynamics/out_2']])
set_param([sys,'/',['LQR Controller',13,'with  position feedback,',13,'velocity estimators, and ',13,'no motor dynamics/out_2']],...
		'Port','2',...
		'position',[800,360,820,380])

add_block('built-in/Constant',[sys,'/',['LQR Controller',13,'with  position feedback,',13,'velocity estimators, and ',13,'no motor dynamics/Constant']])
set_param([sys,'/',['LQR Controller',13,'with  position feedback,',13,'velocity estimators, and ',13,'no motor dynamics/Constant']],...
		'Value','0',...
		'position',[40,420,60,440])

add_block('built-in/Gain',[sys,'/',['LQR Controller',13,'with  position feedback,',13,'velocity estimators, and ',13,'no motor dynamics/Gain3']])
set_param([sys,'/',['LQR Controller',13,'with  position feedback,',13,'velocity estimators, and ',13,'no motor dynamics/Gain3']],...
		'Gain','1/2',...
		'position',[210,330,230,350])

add_block('built-in/Gain',[sys,'/',['LQR Controller',13,'with  position feedback,',13,'velocity estimators, and ',13,'no motor dynamics/Gain2']])
set_param([sys,'/',['LQR Controller',13,'with  position feedback,',13,'velocity estimators, and ',13,'no motor dynamics/Gain2']],...
		'position',[210,234,230,256])

add_block('built-in/Gain',[sys,'/',['LQR Controller',13,'with  position feedback,',13,'velocity estimators, and ',13,'no motor dynamics/Gain1']])
set_param([sys,'/',['LQR Controller',13,'with  position feedback,',13,'velocity estimators, and ',13,'no motor dynamics/Gain1']],...
		'Gain','1/2',...
		'position',[205,150,225,170])

add_block('built-in/State-Space',[sys,'/',['LQR Controller',13,'with  position feedback,',13,'velocity estimators, and ',13,'no motor dynamics/Matrix gain.']])
set_param([sys,'/',['LQR Controller',13,'with  position feedback,',13,'velocity estimators, and ',13,'no motor dynamics/Matrix gain.']],...
		'A','[]',...
		'B','[]',...
		'C','[]',...
		'D','K',...
		'Mask Display','Klqr')
set_param([sys,'/',['LQR Controller',13,'with  position feedback,',13,'velocity estimators, and ',13,'no motor dynamics/Matrix gain.']],...
		'Mask Type','Matrix gain',...
		'Mask Dialogue','Matrix Gain.|Gain matrix:')
set_param([sys,'/',['LQR Controller',13,'with  position feedback,',13,'velocity estimators, and ',13,'no motor dynamics/Matrix gain.']],...
		'Mask Translate','K = @1;')
set_param([sys,'/',['LQR Controller',13,'with  position feedback,',13,'velocity estimators, and ',13,'no motor dynamics/Matrix gain.']],...
		'Mask Help','Multiplies input vector by entered matrix to produce output vector (y=Au).')
set_param([sys,'/',['LQR Controller',13,'with  position feedback,',13,'velocity estimators, and ',13,'no motor dynamics/Matrix gain.']],...
		'Mask Entries','Klqr\/',...
		'position',[570,341,675,389])


%     Subsystem  ['LQR Controller',13,'with  position feedback,',13,'velocity estimators, and ',13,'no motor dynamics/Finite difference',13,'velocity estimators',13,'with filters'].

new_system([sys,'/',['LQR Controller',13,'with  position feedback,',13,'velocity estimators, and ',13,'no motor dynamics/Finite difference',13,'velocity estimators',13,'with filters']])
set_param([sys,'/',['LQR Controller',13,'with  position feedback,',13,'velocity estimators, and ',13,'no motor dynamics/Finite difference',13,'velocity estimators',13,'with filters']],'Location',[16,307,267,646])

add_block('built-in/Discrete Transfer Fcn',[sys,'/',['LQR Controller',13,'with  position feedback,',13,'velocity estimators, and ',13,'no motor dynamics/Finite difference',13,'velocity estimators',13,'with filters/X1 velocity estimator']])
set_param([sys,'/',['LQR Controller',13,'with  position feedback,',13,'velocity estimators, and ',13,'no motor dynamics/Finite difference',13,'velocity estimators',13,'with filters/X1 velocity estimator']],...
		'Numerator','a*[1 -1]')
set_param([sys,'/',['LQR Controller',13,'with  position feedback,',13,'velocity estimators, and ',13,'no motor dynamics/Finite difference',13,'velocity estimators',13,'with filters/X1 velocity estimator']],...
		'Denominator','[(1+ts*a)  -1]')
set_param([sys,'/',['LQR Controller',13,'with  position feedback,',13,'velocity estimators, and ',13,'no motor dynamics/Finite difference',13,'velocity estimators',13,'with filters/X1 velocity estimator']],...
		'Sample time','ts')
set_param([sys,'/',['LQR Controller',13,'with  position feedback,',13,'velocity estimators, and ',13,'no motor dynamics/Finite difference',13,'velocity estimators',13,'with filters/X1 velocity estimator']],...
		'position',[60,40,155,80])

add_block('built-in/Discrete Transfer Fcn',[sys,'/',['LQR Controller',13,'with  position feedback,',13,'velocity estimators, and ',13,'no motor dynamics/Finite difference',13,'velocity estimators',13,'with filters/Alpha velocity estimator3']])
set_param([sys,'/',['LQR Controller',13,'with  position feedback,',13,'velocity estimators, and ',13,'no motor dynamics/Finite difference',13,'velocity estimators',13,'with filters/Alpha velocity estimator3']],...
		'Numerator','a*[1 -1]')
set_param([sys,'/',['LQR Controller',13,'with  position feedback,',13,'velocity estimators, and ',13,'no motor dynamics/Finite difference',13,'velocity estimators',13,'with filters/Alpha velocity estimator3']],...
		'Denominator','[(1+ts*a)  -1]')
set_param([sys,'/',['LQR Controller',13,'with  position feedback,',13,'velocity estimators, and ',13,'no motor dynamics/Finite difference',13,'velocity estimators',13,'with filters/Alpha velocity estimator3']],...
		'Sample time','ts')
set_param([sys,'/',['LQR Controller',13,'with  position feedback,',13,'velocity estimators, and ',13,'no motor dynamics/Finite difference',13,'velocity estimators',13,'with filters/Alpha velocity estimator3']],...
		'position',[60,215,155,255])

add_block('built-in/Discrete Transfer Fcn',[sys,'/',['LQR Controller',13,'with  position feedback,',13,'velocity estimators, and ',13,'no motor dynamics/Finite difference',13,'velocity estimators',13,'with filters/X2 velocity estimator2']])
set_param([sys,'/',['LQR Controller',13,'with  position feedback,',13,'velocity estimators, and ',13,'no motor dynamics/Finite difference',13,'velocity estimators',13,'with filters/X2 velocity estimator2']],...
		'Numerator','a*[1 -1]')
set_param([sys,'/',['LQR Controller',13,'with  position feedback,',13,'velocity estimators, and ',13,'no motor dynamics/Finite difference',13,'velocity estimators',13,'with filters/X2 velocity estimator2']],...
		'Denominator','[(1+ts*a)  -1]')
set_param([sys,'/',['LQR Controller',13,'with  position feedback,',13,'velocity estimators, and ',13,'no motor dynamics/Finite difference',13,'velocity estimators',13,'with filters/X2 velocity estimator2']],...
		'Sample time','ts')
set_param([sys,'/',['LQR Controller',13,'with  position feedback,',13,'velocity estimators, and ',13,'no motor dynamics/Finite difference',13,'velocity estimators',13,'with filters/X2 velocity estimator2']],...
		'position',[60,155,155,195])

add_block('built-in/Discrete Transfer Fcn',[sys,'/',['LQR Controller',13,'with  position feedback,',13,'velocity estimators, and ',13,'no motor dynamics/Finite difference',13,'velocity estimators',13,'with filters/Theta velocity estimator1']])
set_param([sys,'/',['LQR Controller',13,'with  position feedback,',13,'velocity estimators, and ',13,'no motor dynamics/Finite difference',13,'velocity estimators',13,'with filters/Theta velocity estimator1']],...
		'Numerator','a*[1 -1]')
set_param([sys,'/',['LQR Controller',13,'with  position feedback,',13,'velocity estimators, and ',13,'no motor dynamics/Finite difference',13,'velocity estimators',13,'with filters/Theta velocity estimator1']],...
		'Denominator','[(1+ts*a)  -1]')
set_param([sys,'/',['LQR Controller',13,'with  position feedback,',13,'velocity estimators, and ',13,'no motor dynamics/Finite difference',13,'velocity estimators',13,'with filters/Theta velocity estimator1']],...
		'Sample time','ts')
set_param([sys,'/',['LQR Controller',13,'with  position feedback,',13,'velocity estimators, and ',13,'no motor dynamics/Finite difference',13,'velocity estimators',13,'with filters/Theta velocity estimator1']],...
		'position',[60,95,155,135])

add_block('built-in/Inport',[sys,'/',['LQR Controller',13,'with  position feedback,',13,'velocity estimators, and ',13,'no motor dynamics/Finite difference',13,'velocity estimators',13,'with filters/in_1']])
set_param([sys,'/',['LQR Controller',13,'with  position feedback,',13,'velocity estimators, and ',13,'no motor dynamics/Finite difference',13,'velocity estimators',13,'with filters/in_1']],...
		'position',[10,50,30,70])

add_block('built-in/Outport',[sys,'/',['LQR Controller',13,'with  position feedback,',13,'velocity estimators, and ',13,'no motor dynamics/Finite difference',13,'velocity estimators',13,'with filters/out_1']])
set_param([sys,'/',['LQR Controller',13,'with  position feedback,',13,'velocity estimators, and ',13,'no motor dynamics/Finite difference',13,'velocity estimators',13,'with filters/out_1']],...
		'position',[185,50,205,70])

add_block('built-in/Inport',[sys,'/',['LQR Controller',13,'with  position feedback,',13,'velocity estimators, and ',13,'no motor dynamics/Finite difference',13,'velocity estimators',13,'with filters/in_2']])
set_param([sys,'/',['LQR Controller',13,'with  position feedback,',13,'velocity estimators, and ',13,'no motor dynamics/Finite difference',13,'velocity estimators',13,'with filters/in_2']],...
		'Port','2',...
		'position',[10,105,30,125])

add_block('built-in/Outport',[sys,'/',['LQR Controller',13,'with  position feedback,',13,'velocity estimators, and ',13,'no motor dynamics/Finite difference',13,'velocity estimators',13,'with filters/out_2']])
set_param([sys,'/',['LQR Controller',13,'with  position feedback,',13,'velocity estimators, and ',13,'no motor dynamics/Finite difference',13,'velocity estimators',13,'with filters/out_2']],...
		'Port','2',...
		'position',[185,105,205,125])

add_block('built-in/Inport',[sys,'/',['LQR Controller',13,'with  position feedback,',13,'velocity estimators, and ',13,'no motor dynamics/Finite difference',13,'velocity estimators',13,'with filters/in_3']])
set_param([sys,'/',['LQR Controller',13,'with  position feedback,',13,'velocity estimators, and ',13,'no motor dynamics/Finite difference',13,'velocity estimators',13,'with filters/in_3']],...
		'Port','3',...
		'position',[10,165,30,185])

add_block('built-in/Outport',[sys,'/',['LQR Controller',13,'with  position feedback,',13,'velocity estimators, and ',13,'no motor dynamics/Finite difference',13,'velocity estimators',13,'with filters/out_3']])
set_param([sys,'/',['LQR Controller',13,'with  position feedback,',13,'velocity estimators, and ',13,'no motor dynamics/Finite difference',13,'velocity estimators',13,'with filters/out_3']],...
		'Port','3',...
		'position',[185,165,205,185])

add_block('built-in/Inport',[sys,'/',['LQR Controller',13,'with  position feedback,',13,'velocity estimators, and ',13,'no motor dynamics/Finite difference',13,'velocity estimators',13,'with filters/in_4']])
set_param([sys,'/',['LQR Controller',13,'with  position feedback,',13,'velocity estimators, and ',13,'no motor dynamics/Finite difference',13,'velocity estimators',13,'with filters/in_4']],...
		'Port','4',...
		'position',[10,225,30,245])

add_block('built-in/Outport',[sys,'/',['LQR Controller',13,'with  position feedback,',13,'velocity estimators, and ',13,'no motor dynamics/Finite difference',13,'velocity estimators',13,'with filters/out_4']])
set_param([sys,'/',['LQR Controller',13,'with  position feedback,',13,'velocity estimators, and ',13,'no motor dynamics/Finite difference',13,'velocity estimators',13,'with filters/out_4']],...
		'Port','4',...
		'position',[185,225,205,245])
add_line([sys,'/',['LQR Controller',13,'with  position feedback,',13,'velocity estimators, and ',13,'no motor dynamics/Finite difference',13,'velocity estimators',13,'with filters']],[35,60;55,60])
add_line([sys,'/',['LQR Controller',13,'with  position feedback,',13,'velocity estimators, and ',13,'no motor dynamics/Finite difference',13,'velocity estimators',13,'with filters']],[160,60;180,60])
add_line([sys,'/',['LQR Controller',13,'with  position feedback,',13,'velocity estimators, and ',13,'no motor dynamics/Finite difference',13,'velocity estimators',13,'with filters']],[35,115;55,115])
add_line([sys,'/',['LQR Controller',13,'with  position feedback,',13,'velocity estimators, and ',13,'no motor dynamics/Finite difference',13,'velocity estimators',13,'with filters']],[160,115;180,115])
add_line([sys,'/',['LQR Controller',13,'with  position feedback,',13,'velocity estimators, and ',13,'no motor dynamics/Finite difference',13,'velocity estimators',13,'with filters']],[35,175;55,175])
add_line([sys,'/',['LQR Controller',13,'with  position feedback,',13,'velocity estimators, and ',13,'no motor dynamics/Finite difference',13,'velocity estimators',13,'with filters']],[160,175;180,175])
add_line([sys,'/',['LQR Controller',13,'with  position feedback,',13,'velocity estimators, and ',13,'no motor dynamics/Finite difference',13,'velocity estimators',13,'with filters']],[35,235;55,235])
add_line([sys,'/',['LQR Controller',13,'with  position feedback,',13,'velocity estimators, and ',13,'no motor dynamics/Finite difference',13,'velocity estimators',13,'with filters']],[160,235;180,235])
set_param([sys,'/',['LQR Controller',13,'with  position feedback,',13,'velocity estimators, and ',13,'no motor dynamics/Finite difference',13,'velocity estimators',13,'with filters']],...
		'Mask Display','FD w/ filter')
set_param([sys,'/',['LQR Controller',13,'with  position feedback,',13,'velocity estimators, and ',13,'no motor dynamics/Finite difference',13,'velocity estimators',13,'with filters']],...
		'Mask Type','Finite difference velocity estimator with filter.')
set_param([sys,'/',['LQR Controller',13,'with  position feedback,',13,'velocity estimators, and ',13,'no motor dynamics/Finite difference',13,'velocity estimators',13,'with filters']],...
		'Mask Dialogue','Finite difference velocity estimator with filter.|Cutoff frequency( hz ):|Sample time:')
set_param([sys,'/',['LQR Controller',13,'with  position feedback,',13,'velocity estimators, and ',13,'no motor dynamics/Finite difference',13,'velocity estimators',13,'with filters']],...
		'Mask Translate','hz =@1; a=hz*2*pi; ts=@2;')
set_param([sys,'/',['LQR Controller',13,'with  position feedback,',13,'velocity estimators, and ',13,'no motor dynamics/Finite difference',13,'velocity estimators',13,'with filters']],...
		'Mask Entries','1.5\/0.01\/')


%     Finished composite block ['LQR Controller',13,'with  position feedback,',13,'velocity estimators, and ',13,'no motor dynamics/Finite difference',13,'velocity estimators',13,'with filters'].

set_param([sys,'/',['LQR Controller',13,'with  position feedback,',13,'velocity estimators, and ',13,'no motor dynamics/Finite difference',13,'velocity estimators',13,'with filters']],...
		'position',[365,453,405,527])

add_block('built-in/Integrator',[sys,'/',['LQR Controller',13,'with  position feedback,',13,'velocity estimators, and ',13,'no motor dynamics/Integrator']])
set_param([sys,'/',['LQR Controller',13,'with  position feedback,',13,'velocity estimators, and ',13,'no motor dynamics/Integrator']],...
		'position',[335,190,355,210])

add_block('built-in/Integrator',[sys,'/',['LQR Controller',13,'with  position feedback,',13,'velocity estimators, and ',13,'no motor dynamics/Integrator1']])
set_param([sys,'/',['LQR Controller',13,'with  position feedback,',13,'velocity estimators, and ',13,'no motor dynamics/Integrator1']],...
		'position',[300,100,320,120])

add_block('built-in/Note',[sys,'/',['LQR Controller',13,'with  position feedback,',13,'velocity estimators, and ',13,'no motor dynamics/This controller assumes only position feedback.']])
set_param([sys,'/',['LQR Controller',13,'with  position feedback,',13,'velocity estimators, and ',13,'no motor dynamics/This controller assumes only position feedback.']],...
		'position',[706,83,711,88])

add_block('built-in/Demux',[sys,'/',['LQR Controller',13,'with  position feedback,',13,'velocity estimators, and ',13,'no motor dynamics/Demux']])
set_param([sys,'/',['LQR Controller',13,'with  position feedback,',13,'velocity estimators, and ',13,'no motor dynamics/Demux']],...
		'outputs','2',...
		'position',[715,345,755,380])

add_block('built-in/Mux',[sys,'/',['LQR Controller',13,'with  position feedback,',13,'velocity estimators, and ',13,'no motor dynamics/Mux']])
set_param([sys,'/',['LQR Controller',13,'with  position feedback,',13,'velocity estimators, and ',13,'no motor dynamics/Mux']],...
		'inputs','10',...
		'position',[495,284,525,441])

add_block('built-in/Inport',[sys,'/',['LQR Controller',13,'with  position feedback,',13,'velocity estimators, and ',13,'no motor dynamics/in_2']])
set_param([sys,'/',['LQR Controller',13,'with  position feedback,',13,'velocity estimators, and ',13,'no motor dynamics/in_2']],...
		'Port','2',...
		'position',[40,150,60,170])

add_block('built-in/Inport',[sys,'/',['LQR Controller',13,'with  position feedback,',13,'velocity estimators, and ',13,'no motor dynamics/in_3']])
set_param([sys,'/',['LQR Controller',13,'with  position feedback,',13,'velocity estimators, and ',13,'no motor dynamics/in_3']],...
		'Port','3',...
		'position',[35,235,55,255])

add_block('built-in/Inport',[sys,'/',['LQR Controller',13,'with  position feedback,',13,'velocity estimators, and ',13,'no motor dynamics/in_4']])
set_param([sys,'/',['LQR Controller',13,'with  position feedback,',13,'velocity estimators, and ',13,'no motor dynamics/in_4']],...
		'Port','4',...
		'position',[35,330,55,350])

add_block('built-in/Note',[sys,'/',['LQR Controller',13,'with  position feedback,',13,'velocity estimators, and ',13,'no motor dynamics/Theta']])
set_param([sys,'/',['LQR Controller',13,'with  position feedback,',13,'velocity estimators, and ',13,'no motor dynamics/Theta']],...
		'position',[51,128,56,133])

add_block('built-in/Note',[sys,'/',['LQR Controller',13,'with  position feedback,',13,'velocity estimators, and ',13,'no motor dynamics/X2']])
set_param([sys,'/',['LQR Controller',13,'with  position feedback,',13,'velocity estimators, and ',13,'no motor dynamics/X2']],...
		'position',[41,208,46,213])

add_block('built-in/Note',[sys,'/',['LQR Controller',13,'with  position feedback,',13,'velocity estimators, and ',13,'no motor dynamics/Alpha']])
set_param([sys,'/',['LQR Controller',13,'with  position feedback,',13,'velocity estimators, and ',13,'no motor dynamics/Alpha']],...
		'position',[46,308,51,313])

add_block('built-in/Note',[sys,'/',['LQR Controller',13,'with  position feedback,',13,'velocity estimators, and ',13,'no motor dynamics/X1']])
set_param([sys,'/',['LQR Controller',13,'with  position feedback,',13,'velocity estimators, and ',13,'no motor dynamics/X1']],...
		'position',[51,31,56,36])

add_block('built-in/Inport',[sys,'/',['LQR Controller',13,'with  position feedback,',13,'velocity estimators, and ',13,'no motor dynamics/in_1']])
set_param([sys,'/',['LQR Controller',13,'with  position feedback,',13,'velocity estimators, and ',13,'no motor dynamics/in_1']],...
		'position',[35,55,55,75])

add_block('built-in/Gain',[sys,'/',['LQR Controller',13,'with  position feedback,',13,'velocity estimators, and ',13,'no motor dynamics/Gain']])
set_param([sys,'/',['LQR Controller',13,'with  position feedback,',13,'velocity estimators, and ',13,'no motor dynamics/Gain']],...
		'position',[205,54,225,76])

add_block('built-in/Outport',[sys,'/',['LQR Controller',13,'with  position feedback,',13,'velocity estimators, and ',13,'no motor dynamics/out_1']])
set_param([sys,'/',['LQR Controller',13,'with  position feedback,',13,'velocity estimators, and ',13,'no motor dynamics/out_1']],...
		'position',[800,315,820,335])

add_block('built-in/Sum',[sys,'/',['LQR Controller',13,'with  position feedback,',13,'velocity estimators, and ',13,'no motor dynamics/Sum1']])
set_param([sys,'/',['LQR Controller',13,'with  position feedback,',13,'velocity estimators, and ',13,'no motor dynamics/Sum1']],...
		'inputs','+-',...
		'position',[290,190,310,210])
add_line([sys,'/',['LQR Controller',13,'with  position feedback,',13,'velocity estimators, and ',13,'no motor dynamics']],[60,340;205,340])
add_line([sys,'/',['LQR Controller',13,'with  position feedback,',13,'velocity estimators, and ',13,'no motor dynamics']],[60,245;205,245])
add_line([sys,'/',['LQR Controller',13,'with  position feedback,',13,'velocity estimators, and ',13,'no motor dynamics']],[325,110;391,110;391,430;490,430])
add_line([sys,'/',['LQR Controller',13,'with  position feedback,',13,'velocity estimators, and ',13,'no motor dynamics']],[360,200;376,200;376,415;490,415])
add_line([sys,'/',['LQR Controller',13,'with  position feedback,',13,'velocity estimators, and ',13,'no motor dynamics']],[760,370;795,370])
add_line([sys,'/',['LQR Controller',13,'with  position feedback,',13,'velocity estimators, and ',13,'no motor dynamics']],[230,160;441,160;441,310;490,310])
add_line([sys,'/',['LQR Controller',13,'with  position feedback,',13,'velocity estimators, and ',13,'no motor dynamics']],[266,160;266,188;136,188;136,480;360,480])
add_line([sys,'/',['LQR Controller',13,'with  position feedback,',13,'velocity estimators, and ',13,'no motor dynamics']],[235,340;490,340])
add_line([sys,'/',['LQR Controller',13,'with  position feedback,',13,'velocity estimators, and ',13,'no motor dynamics']],[276,340;276,520;360,520])
add_line([sys,'/',['LQR Controller',13,'with  position feedback,',13,'velocity estimators, and ',13,'no motor dynamics']],[235,245;416,245;416,325;490,325])
add_line([sys,'/',['LQR Controller',13,'with  position feedback,',13,'velocity estimators, and ',13,'no motor dynamics']],[266,245;266,278;146,278;146,500;360,500])
add_line([sys,'/',['LQR Controller',13,'with  position feedback,',13,'velocity estimators, and ',13,'no motor dynamics']],[410,520;471,520;471,400;490,400])
add_line([sys,'/',['LQR Controller',13,'with  position feedback,',13,'velocity estimators, and ',13,'no motor dynamics']],[410,500;456,500;456,385;490,385])
add_line([sys,'/',['LQR Controller',13,'with  position feedback,',13,'velocity estimators, and ',13,'no motor dynamics']],[410,480;441,480;441,370;490,370])
add_line([sys,'/',['LQR Controller',13,'with  position feedback,',13,'velocity estimators, and ',13,'no motor dynamics']],[410,460;426,460;426,355;490,355])
add_line([sys,'/',['LQR Controller',13,'with  position feedback,',13,'velocity estimators, and ',13,'no motor dynamics']],[530,365;565,365])
add_line([sys,'/',['LQR Controller',13,'with  position feedback,',13,'velocity estimators, and ',13,'no motor dynamics']],[680,365;710,365])
add_line([sys,'/',['LQR Controller',13,'with  position feedback,',13,'velocity estimators, and ',13,'no motor dynamics']],[266,160;266,110;295,110])
add_line([sys,'/',['LQR Controller',13,'with  position feedback,',13,'velocity estimators, and ',13,'no motor dynamics']],[315,200;330,200])
add_line([sys,'/',['LQR Controller',13,'with  position feedback,',13,'velocity estimators, and ',13,'no motor dynamics']],[60,65;200,65])
add_line([sys,'/',['LQR Controller',13,'with  position feedback,',13,'velocity estimators, and ',13,'no motor dynamics']],[230,65;271,65;271,93;126,93;126,460;360,460])
add_line([sys,'/',['LQR Controller',13,'with  position feedback,',13,'velocity estimators, and ',13,'no motor dynamics']],[65,160;200,160])
add_line([sys,'/',['LQR Controller',13,'with  position feedback,',13,'velocity estimators, and ',13,'no motor dynamics']],[65,430;101,430;101,195;285,195])
add_line([sys,'/',['LQR Controller',13,'with  position feedback,',13,'velocity estimators, and ',13,'no motor dynamics']],[270,65;480,65;490,295])
add_line([sys,'/',['LQR Controller',13,'with  position feedback,',13,'velocity estimators, and ',13,'no motor dynamics']],[760,355;765,355;765,325;795,325])
add_line([sys,'/',['LQR Controller',13,'with  position feedback,',13,'velocity estimators, and ',13,'no motor dynamics']],[265,245;265,205;285,205])


%     Finished composite block ['LQR Controller',13,'with  position feedback,',13,'velocity estimators, and ',13,'no motor dynamics'].

set_param([sys,'/',['LQR Controller',13,'with  position feedback,',13,'velocity estimators, and ',13,'no motor dynamics']],...
		'position',[305,177,390,303])

add_block('built-in/Note',[sys,'/','Do not double click during simulation.'])
set_param([sys,'/','Do not double click during simulation.'],...
		'position',[550,25,555,30])

add_block('built-in/S-Function',[sys,'/','Double Click Me'])
set_param([sys,'/','Double Click Me'],...
		'BackGround',7,...
		'hide name',0,...
		'function name','sd3plot',...
		'parameters','0',...
		'Mask Display','Animation',...
		'Mask Dialogue','eval(''global sd3hands; sd3hands = sd3ploti;'');')
set_param([sys,'/','Double Click Me'],...
		'position',[525,47,585,73])

add_block('built-in/Demux',[sys,'/','Demux'])
set_param([sys,'/','Demux'],...
		'hide name',0,...
		'position',[105,181,155,299])
add_line(sys,[160,285;300,285])
add_line(sys,[196,285;196,396;471,396;471,360;530,360])
add_line(sys,[650,180;651,180;651,151;431,151;431,170;450,170])
add_line(sys,[395,275;416,275;416,210;450,210])
add_line(sys,[395,210;406,210;406,190;450,190])
add_line(sys,[650,200;670,200;670,100;450,100;450,60;520,60])
add_line(sys,[580,190;600,190])
add_line(sys,[490,190;515,190])
add_line(sys,[160,195;300,195])
add_line(sys,[247,195;247,160;260,160])
add_line(sys,[160,255;300,255])
add_line(sys,[197,255;197,140;215,140])
add_line(sys,[160,225;300,225])
add_line(sys,[222,225;222,386;442,386;442,290;530,290])
add_line(sys,[450,100;90,100;100,240])

drawnow

% Return any arguments.
if (nargin | nargout)
	% Must use feval here to access system in memory
	if (nargin > 3)
		if (flag == 0)
			eval(['[ret,x0,str,ts,xts]=',sys,'(t,x,u,flag);'])
		else
			eval(['ret =', sys,'(t,x,u,flag);'])
		end
	else
		[ret,x0,str,ts,xts] = feval(sys);
	end
else
	drawnow % Flash up the model and execute load callback
end
