function [ret,x0,str,ts,xts]=sddemo4(t,x,u,flag);
%SDDEMO4	is the M-file description of the SIMULINK system named SDDEMO4.
%	The block-diagram can be displayed by typing: SDDEMO4.
%
%	SYS=SDDEMO4(T,X,U,FLAG) returns depending on FLAG certain
%	system values given time point, T, current state vector, X,
%	and input vector, U.
%	FLAG is used to indicate the type of output to be returned in SYS.
%
%	Setting FLAG=1 causes SDDEMO4 to return state derivatives, FLAG=2
%	discrete states, FLAG=3 system outputs and FLAG=4 next sample
%	time. For more information and other options see SFUNC.
%
%	Calling SDDEMO4 with a FLAG of zero:
%	[SIZES]=SDDEMO4([],[],[],0),  returns a vector, SIZES, which
%	contains the sizes of the state vector and other parameters.
%		SIZES(1) number of states
%		SIZES(2) number of discrete states
%		SIZES(3) number of outputs
%		SIZES(4) number of inputs
%		SIZES(5) number of roots (currently unsupported)
%		SIZES(6) direct feedthrough flag
%		SIZES(7) number of sample times
%
%	For the definition of other parameters in SIZES, see SFUNC.
%	See also, TRIM, LINMOD, LINSIM, EULER, RK23, RK45, ADAMS, GEAR.

% Note: This M-file is only used for saving graphical information;
%       after the model is loaded into memory an internal model
%       representation is used.

% the system will take on the name of this mfile:
sys = mfilename;
new_system(sys)
simver(1.3)
if (0 == (nargin + nargout))
     set_param(sys,'Location',[521,263,1026,533])
     open_system(sys)
end;
set_param(sys,'algorithm',     'RK-45')
set_param(sys,'Start time',    '0')
set_param(sys,'Stop time',     '9999999999')
set_param(sys,'Min step size', '0.01')
set_param(sys,'Max step size', '.1')
set_param(sys,'Relative error','1e-2')
set_param(sys,'Return vars',   '')
set_param(sys,'Compile command','!cmex4 $model.c')
set_param(sys,'Real-time build command','!download $model.c $model.h')


%     Subsystem  'UnNamed'.

new_system([sys,'/','UnNamed'])
set_param([sys,'/','UnNamed'],'Location',[103,257,832,567])

add_block('built-in/Fcn',[sys,'/','UnNamed/F1y'])
set_param([sys,'/','UnNamed/F1y'],...
		'orientation',2,...
		'Expr','u[1]*sin(u[2])/2',...
		'position',[160,85,200,105])

add_block('built-in/Fcn',[sys,'/','UnNamed/F2y'])
set_param([sys,'/','UnNamed/F2y'],...
		'orientation',2,...
		'Expr','u[1]*sin(u[3])/2',...
		'position',[160,165,200,185])

add_block('built-in/Fcn',[sys,'/','UnNamed/F2x'])
set_param([sys,'/','UnNamed/F2x'],...
		'orientation',2,...
		'Expr','u[1]*cos(u[3])/2',...
		'position',[160,125,200,145])

add_block('built-in/Fcn',[sys,'/','UnNamed/F1x'])
set_param([sys,'/','UnNamed/F1x'],...
		'orientation',2,...
		'Expr','u[1]*cos(u[2])/2',...
		'position',[160,45,200,65])

add_block('built-in/Fcn',[sys,'/','UnNamed/len'])
set_param([sys,'/','UnNamed/len'],...
		'orientation',2,...
		'Expr','sqrt( (u[1] - u[2])^2 + (u[3] - u[4])^2 )',...
		'position',[390,65,430,85])

add_block('built-in/Fcn',[sys,'/','UnNamed/Fmag'])
set_param([sys,'/','UnNamed/Fmag'],...
		'orientation',2,...
		'Expr','abs(SpringConst*(u - Springlength))',...
		'position',[320,65,360,85])

add_block('built-in/Mux',[sys,'/','UnNamed/Mux1'])
set_param([sys,'/','UnNamed/Mux1'],...
		'orientation',2,...
		'inputs','3',...
		'position',[255,41,285,239])

add_block('built-in/Mux',[sys,'/','UnNamed/Mux2'])
set_param([sys,'/','UnNamed/Mux2'],...
		'orientation',2,...
		'inputs','2',...
		'position',[395,120,425,160])

add_block('built-in/Mux',[sys,'/','UnNamed/Mux3'])
set_param([sys,'/','UnNamed/Mux3'],...
		'orientation',2,...
		'inputs','2',...
		'position',[395,185,425,225])

add_block('built-in/Fcn',[sys,'/','UnNamed/gamma'])
set_param([sys,'/','UnNamed/gamma'],...
		'orientation',2,...
		'Expr','atan2( (u[4] - u[3]) , abs(u[2] - u[1]) )',...
		'position',[470,95,510,115])

add_block('built-in/Fcn',[sys,'/','UnNamed/phi1'])
set_param([sys,'/','UnNamed/phi1'],...
		'orientation',2,...
		'Expr','u[1]+u[2]',...
		'position',[320,130,360,150])

add_block('built-in/Fcn',[sys,'/','UnNamed/phi2'])
set_param([sys,'/','UnNamed/phi2'],...
		'orientation',2,...
		'Expr','pi-(u[1]+u[2])',...
		'position',[320,195,360,215])

add_block('built-in/Inport',[sys,'/','UnNamed/in_1'])
set_param([sys,'/','UnNamed/in_1'],...
		'orientation',2,...
		'position',[685,65,705,85])


%     Subsystem  'UnNamed/demux'.

new_system([sys,'/','UnNamed/demux'])
set_param([sys,'/','UnNamed/demux'],'Location',[565,326,799,502])

add_block('built-in/Outport',[sys,'/','UnNamed/demux/out_1'])
set_param([sys,'/','UnNamed/demux/out_1'],...
		'orientation',2,...
		'position',[50,40,70,60])

add_block('built-in/Inport',[sys,'/','UnNamed/demux/in_1'])
set_param([sys,'/','UnNamed/demux/in_1'],...
		'orientation',2,...
		'position',[180,85,200,105])

add_block('built-in/Demux',[sys,'/','UnNamed/demux/Demux'])
set_param([sys,'/','UnNamed/demux/Demux'],...
		'orientation',2,...
		'position',[110,72,150,118])

add_block('built-in/Outport',[sys,'/','UnNamed/demux/out_2'])
set_param([sys,'/','UnNamed/demux/out_2'],...
		'orientation',2,...
		'Port','2',...
		'position',[50,100,70,120])
add_line([sys,'/','UnNamed/demux'],[105,100;90,100;90,50;75,50])
add_line([sys,'/','UnNamed/demux'],[105,110;75,110])
add_line([sys,'/','UnNamed/demux'],[175,95;155,95])


%     Finished composite block 'UnNamed/demux'.

set_param([sys,'/','UnNamed/demux'],...
		'orientation',2,...
		'position',[580,144,605,171])

add_block('built-in/Note',[sys,'/','UnNamed/alpha'])
set_param([sys,'/','UnNamed/alpha'],...
		'position',[540,135,545,140])

add_block('built-in/Note',[sys,'/','UnNamed/beta'])
set_param([sys,'/','UnNamed/beta'],...
		'position',[540,165,545,170])

add_block('built-in/Mux',[sys,'/','UnNamed/Mux'])
set_param([sys,'/','UnNamed/Mux'],...
		'orientation',2,...
		'position',[70,31,105,199])

add_block('built-in/Note',[sys,'/','UnNamed/Model for Spring force'])
set_param([sys,'/','UnNamed/Model for Spring force'],...
		'position',[345,15,350,20])

add_block('built-in/Outport',[sys,'/','UnNamed/out_1'])
set_param([sys,'/','UnNamed/out_1'],...
		'orientation',2,...
		'position',[10,105,30,125])

add_block('built-in/Fcn',[sys,'/','UnNamed/gamma1'])
set_param([sys,'/','UnNamed/gamma1'],...
		'orientation',2,...
		'Expr','atan2( u[1]/2*(sin(u[4]) - sin(u[3])) , (u[1]/2*(cos(u[4]) -  cos(u[3])) + u[2]) )',...
		'position',[575,235,615,255])


%     Subsystem  'UnNamed/[x1,x2,y1,y2]'.

new_system([sys,'/','UnNamed/[x1,x2,y1,y2]'])
set_param([sys,'/','UnNamed/[x1,x2,y1,y2]'],'Location',[194,102,433,351])

add_block('built-in/Fcn',[sys,'/','UnNamed/[x1,x2,y1,y2]/y2'])
set_param([sys,'/','UnNamed/[x1,x2,y1,y2]/y2'],...
		'orientation',2,...
		'Expr','-u(1)*cos(u(4))/2',...
		'position',[125,145,165,165])

add_block('built-in/Fcn',[sys,'/','UnNamed/[x1,x2,y1,y2]/y1'])
set_param([sys,'/','UnNamed/[x1,x2,y1,y2]/y1'],...
		'orientation',2,...
		'Expr','-u(1)*cos(u(3))/2',...
		'position',[125,110,165,130])

add_block('built-in/Mux',[sys,'/','UnNamed/[x1,x2,y1,y2]/Mux4'])
set_param([sys,'/','UnNamed/[x1,x2,y1,y2]/Mux4'],...
		'orientation',2,...
		'position',[65,30,100,175])

add_block('built-in/Fcn',[sys,'/','UnNamed/[x1,x2,y1,y2]/x1'])
set_param([sys,'/','UnNamed/[x1,x2,y1,y2]/x1'],...
		'orientation',2,...
		'Expr','-u(2)/2 + u(1)*sin(u(3))/2',...
		'position',[125,40,165,60])

add_block('built-in/Fcn',[sys,'/','UnNamed/[x1,x2,y1,y2]/x2'])
set_param([sys,'/','UnNamed/[x1,x2,y1,y2]/x2'],...
		'orientation',2,...
		'Expr','u(2)/2 + u(1)*sin(u(4))/2',...
		'position',[125,75,165,95])

add_block('built-in/Inport',[sys,'/','UnNamed/[x1,x2,y1,y2]/in_1'])
set_param([sys,'/','UnNamed/[x1,x2,y1,y2]/in_1'],...
		'orientation',2,...
		'position',[195,95,215,115])

add_block('built-in/Outport',[sys,'/','UnNamed/[x1,x2,y1,y2]/out_1'])
set_param([sys,'/','UnNamed/[x1,x2,y1,y2]/out_1'],...
		'orientation',2,...
		'position',[15,95,35,115])
add_line([sys,'/','UnNamed/[x1,x2,y1,y2]'],[190,105;175,105;170,50])
add_line([sys,'/','UnNamed/[x1,x2,y1,y2]'],[175,105;170,120])
add_line([sys,'/','UnNamed/[x1,x2,y1,y2]'],[175,105;170,85])
add_line([sys,'/','UnNamed/[x1,x2,y1,y2]'],[175,105;170,155])
add_line([sys,'/','UnNamed/[x1,x2,y1,y2]'],[120,155;105,155])
add_line([sys,'/','UnNamed/[x1,x2,y1,y2]'],[120,120;105,120])
add_line([sys,'/','UnNamed/[x1,x2,y1,y2]'],[120,85;105,85])
add_line([sys,'/','UnNamed/[x1,x2,y1,y2]'],[120,50;105,50])
add_line([sys,'/','UnNamed/[x1,x2,y1,y2]'],[60,105;40,105])


%     Finished composite block 'UnNamed/[x1,x2,y1,y2]'.

set_param([sys,'/','UnNamed/[x1,x2,y1,y2]'],...
		'orientation',2,...
		'position',[580,64,605,86])
add_line([sys,'/','UnNamed'],[65,115;35,115])
add_line([sys,'/','UnNamed'],[385,75;365,75])
add_line([sys,'/','UnNamed'],[315,75;290,75])
add_line([sys,'/','UnNamed'],[155,55;110,55])
add_line([sys,'/','UnNamed'],[155,95;110,95])
add_line([sys,'/','UnNamed'],[155,135;110,135])
add_line([sys,'/','UnNamed'],[155,175;110,175])
add_line([sys,'/','UnNamed'],[250,140;225,140;225,175;205,175])
add_line([sys,'/','UnNamed'],[225,140;225,135;205,135])
add_line([sys,'/','UnNamed'],[225,140;225,55;205,55])
add_line([sys,'/','UnNamed'],[225,95;205,95])
add_line([sys,'/','UnNamed'],[315,140;290,140])
add_line([sys,'/','UnNamed'],[315,205;290,205])
add_line([sys,'/','UnNamed'],[390,140;365,140])
add_line([sys,'/','UnNamed'],[390,205;365,205])
add_line([sys,'/','UnNamed'],[465,105;445,105;445,130;430,130])
add_line([sys,'/','UnNamed'],[445,130;445,195;430,195])
add_line([sys,'/','UnNamed'],[680,75;610,75])
add_line([sys,'/','UnNamed'],[575,75;435,75])
add_line([sys,'/','UnNamed'],[575,150;430,150])
add_line([sys,'/','UnNamed'],[575,165;515,165;515,215;430,215])
add_line([sys,'/','UnNamed'],[660,75;660,160;610,160])
add_line([sys,'/','UnNamed'],[535,75;535,105;515,105])
set_param([sys,'/','UnNamed'],...
		'Mask Display','Spring Model',...
		'Mask Type','SD/FAST Force model',...
		'Mask Dialogue','Two pendulum spring specs | Spring Constant: | Spring length (at rest):')
set_param([sys,'/','UnNamed'],...
		'Mask Translate','SpringConst = @1; Springlength = @2;',...
		'Mask Entries','10\/4\/')


%     Finished composite block 'UnNamed'.

set_param([sys,'/','UnNamed'],...
		'orientation',2,...
		'hide name',0,...
		'position',[95,97,180,123])


%     Subsystem  'UnNamed1'.

new_system([sys,'/','UnNamed1'])
set_param([sys,'/','UnNamed1'],'Location',[524,592,983,801])

add_block('built-in/Outport',[sys,'/','UnNamed1/Outport'])
set_param([sys,'/','UnNamed1/Outport'],...
		'position',[385,90,405,110])

add_block('built-in/Mux',[sys,'/','UnNamed1/Mux'])
set_param([sys,'/','UnNamed1/Mux'],...
		'position',[265,21,310,179])

add_block('built-in/Constant',[sys,'/','UnNamed1/Constant1'])
set_param([sys,'/','UnNamed1/Constant1'],...
		'Value','pd',...
		'position',[185,70,205,90])

add_block('built-in/Demux',[sys,'/','UnNamed1/Demux'])
set_param([sys,'/','UnNamed1/Demux'],...
		'outputs','3',...
		'position',[80,57,120,183])

add_block('built-in/Inport',[sys,'/','UnNamed1/Inport'])
set_param([sys,'/','UnNamed1/Inport'],...
		'position',[25,110,45,130])

add_block('built-in/Fcn',[sys,'/','UnNamed1/pl'])
set_param([sys,'/','UnNamed1/pl'],...
		'Expr','2*sqrt(u)',...
		'position',[180,30,220,50])
add_line([sys,'/','UnNamed1'],[50,120;75,120])
add_line([sys,'/','UnNamed1'],[210,80;260,80])
add_line([sys,'/','UnNamed1'],[315,100;380,100])
add_line([sys,'/','UnNamed1'],[125,120;260,120])
add_line([sys,'/','UnNamed1'],[125,160;260,160])
add_line([sys,'/','UnNamed1'],[125,80;150,80;175,40])
add_line([sys,'/','UnNamed1'],[225,40;260,40])
set_param([sys,'/','UnNamed1'],...
		'Mask Display','Paramters',...
		'Mask Type','Parameter block',...
		'Mask Dialogue','Weakly coupled pendulum parameters | Pendulum Displacement: ',...
		'Mask Translate','pd = @1;',...
		'Mask Entries','4\/')


%     Finished composite block 'UnNamed1'.

set_param([sys,'/','UnNamed1'],...
		'hide name',0,...
		'position',[160,166,225,194])


%     Subsystem  'demux'.

new_system([sys,'/','demux'])
set_param([sys,'/','demux'],'Location',[265,310,491,691])

add_block('built-in/Demux',[sys,'/','demux/Demux'])
set_param([sys,'/','demux/Demux'],...
		'position',[60,57,100,133])

add_block('built-in/Inport',[sys,'/','demux/in_1'])
set_param([sys,'/','demux/in_1'],...
		'position',[15,85,35,105])

add_block('built-in/Outport',[sys,'/','demux/out_2'])
set_param([sys,'/','demux/out_2'],...
		'Port','2',...
		'position',[120,115,140,135])

add_block('built-in/Outport',[sys,'/','demux/out_1'])
set_param([sys,'/','demux/out_1'],...
		'position',[155,95,175,115])
add_line([sys,'/','demux'],[40,95;55,95])
add_line([sys,'/','demux'],[105,105;150,105])
add_line([sys,'/','demux'],[105,125;115,125])
set_param([sys,'/','demux'],...
		'Mask Display','Demux',...
		'Mask Type','Demux (speical case)')


%     Finished composite block 'demux'.

set_param([sys,'/','demux'],...
		'hide name',0,...
		'position',[295,162,340,198])

add_block('built-in/Scope',[sys,'/',['ang position',13,'pendulum2']])
set_param([sys,'/',['ang position',13,'pendulum2']],...
		'Vgain','1.000000',...
		'Hgain','240.000000',...
		'Vmax','Inf',...
		'Hmax','436.363636',...
		'Window',[642,709,1060,824],...
		'position',[420,195,445,225])

add_block('built-in/S-Function',[sys,'/','sd4plot'])
set_param([sys,'/','sd4plot'],...
		'BackGround',7,...
		'hide name',0,...
		'function name','sd4plot',...
		'parameters','0',...
		'Mask Display','Animation',...
		'Mask Dialogue','eval(''global pendhands; pendhands = sd4ploti;'')')
set_param([sys,'/','sd4plot'],...
		'position',[400,97,460,123])

add_block('built-in/Scope',[sys,'/',['ang position',13,'pendulum1']])
set_param([sys,'/',['ang position',13,'pendulum1']],...
		'Vgain','1.000000',...
		'Hgain','240.000000',...
		'Vmax','Inf',...
		'Hmax','436.363636',...
		'Window',[592,645,1010,760],...
		'position',[420,135,445,165])

add_block('built-in/S-Function',[sys,'/','SD//FAST'])
set_param([sys,'/','SD//FAST'],...
		'function name','twopnd',...
		'parameters','4,3,[ 0  .2],[ 0  0 ],[0 0],[0 0],.001,.001',...
		'Mask Display','twopnd',...
		'Mask Type','SD/FAST Interface block')
set_param([sys,'/','SD//FAST'],...
		'Mask Dialogue','eval(''sdpanel('''''''');'');',...
		'Mask Help','twopnd.sd,twopndi.c,twopndo.c',...
		'position',[55,167,110,193])

add_block('built-in/Note',[sys,'/',['Do not double click',13,'during simulation.']])
set_param([sys,'/',['Do not double click',13,'during simulation.']],...
		'position',[425,63,430,68])

add_block('built-in/Note',[sys,'/',['This system models a pair of weakly coupled ',13,'pendulums.  Initially, one of the pendulums is at',13,'rest while the other has an angular displacement.',13,'During simulation, energy is slowly transferred ',13,'between the two.  ']])
set_param([sys,'/',['This system models a pair of weakly coupled ',13,'pendulums.  Initially, one of the pendulums is at',13,'rest while the other has an angular displacement.',13,'During simulation, energy is slowly transferred ',13,'between the two.  ']],...
		'position',[200,10,205,15])
add_line(sys,[115,180;155,180])
add_line(sys,[345,170;360,170;360,150;415,150])
add_line(sys,[345,190;360,190;360,210;415,210])
add_line(sys,[90,110;20,110;20,180;50,180])
add_line(sys,[230,180;290,180])
add_line(sys,[255,180;255,110;185,110])
add_line(sys,[255,110;395,110])

drawnow

% Return any arguments.
if (nargin | nargout)
	% Must use feval here to access system in memory
	if (nargin > 3)
		if (flag == 0)
			eval(['[ret,x0,str,ts,xts]=',sys,'(t,x,u,flag);'])
		else
			eval(['ret =', sys,'(t,x,u,flag);'])
		end
	else
		[ret,x0,str,ts,xts] = feval(sys);
	end
else
	drawnow % Flash up the model and execute load callback
end
