function [ret,x0,str,ts,xts]=sddemo5(t,x,u,flag);
%SDDEMO5	is the M-file description of the SIMULINK system named SDDEMO5.
%	The block-diagram can be displayed by typing: SDDEMO5.
%
%	SYS=SDDEMO5(T,X,U,FLAG) returns depending on FLAG certain
%	system values given time point, T, current state vector, X,
%	and input vector, U.
%	FLAG is used to indicate the type of output to be returned in SYS.
%
%	Setting FLAG=1 causes SDDEMO5 to return state derivatives, FLAG=2
%	discrete states, FLAG=3 system outputs and FLAG=4 next sample
%	time. For more information and other options see SFUNC.
%
%	Calling SDDEMO5 with a FLAG of zero:
%	[SIZES]=SDDEMO5([],[],[],0),  returns a vector, SIZES, which
%	contains the sizes of the state vector and other parameters.
%		SIZES(1) number of states
%		SIZES(2) number of discrete states
%		SIZES(3) number of outputs
%		SIZES(4) number of inputs
%		SIZES(5) number of roots (currently unsupported)
%		SIZES(6) direct feedthrough flag
%		SIZES(7) number of sample times
%
%	For the definition of other parameters in SIZES, see SFUNC.
%	See also, TRIM, LINMOD, LINSIM, EULER, RK23, RK45, ADAMS, GEAR.

% Note: This M-file is only used for saving graphical information;
%       after the model is loaded into memory an internal model
%       representation is used.

% the system will take on the name of this mfile:
sys = mfilename;
new_system(sys)
simver(1.3)
if (0 == (nargin + nargout))
     set_param(sys,'Location',[227,284,793,555])
     open_system(sys)
end;
set_param(sys,'algorithm',     'RK-45')
set_param(sys,'Start time',    '0.0')
set_param(sys,'Stop time',     '49')
set_param(sys,'Min step size', '0.0001')
set_param(sys,'Max step size', '.1')
set_param(sys,'Relative error','1e-3')
set_param(sys,'Return vars',   '')

add_block('built-in/Note',[sys,'/',['This system simulates a one degree of freedom',13,'pendulum that is hit at approximately t = 10 seconds. ',13,'A torsion spring friction model is used.']])
set_param([sys,'/',['This system simulates a one degree of freedom',13,'pendulum that is hit at approximately t = 10 seconds. ',13,'A torsion spring friction model is used.']],...
		'position',[265,1,270,6])

add_block('built-in/Scope',[sys,'/','input'])
set_param([sys,'/','input'],...
		'Vgain','200.000000',...
		'Hgain','50.000000',...
		'Vmax','400.000000',...
		'Hmax','100.000000',...
		'Window',[23,544,439,666],...
		'position',[225,75,250,105])

add_block('built-in/Mux',[sys,'/','Mux'])
set_param([sys,'/','Mux'],...
		'hide name',0,...
		'inputs','2',...
		'position',[195,120,225,155])

add_block('built-in/Gain',[sys,'/','Gain'])
set_param([sys,'/','Gain'],...
		'Gain','400',...
		'position',[115,114,155,146])

add_block('built-in/Scope',[sys,'/','ang velocity'])
set_param([sys,'/','ang velocity'],...
		'Vgain','2.000000',...
		'Hgain','50.000000',...
		'Vmax','3.333333',...
		'Hmax','87.719298',...
		'Window',[450,780,868,895],...
		'position',[490,155,515,185])

add_block('built-in/Scope',[sys,'/','ang position'])
set_param([sys,'/','ang position'],...
		'Vgain','2.000000',...
		'Hgain','50.000000',...
		'Vmax','4.000000',...
		'Hmax','100.000000',...
		'Window',[245,502,662,619],...
		'position',[490,85,515,115])

add_block('built-in/Demux',[sys,'/','Demux'])
set_param([sys,'/','Demux'],...
		'hide name',0,...
		'outputs','2',...
		'position',[400,120,440,155])

add_block('built-in/S-Function',[sys,'/','SD//FAST'])
set_param([sys,'/','SD//FAST'],...
		'function name','pend',...
		'parameters','2,2,[ 0 ],[ 0 ],[ 0 ],[ 0 ],.001,.001',...
		'Mask Display','pend',...
		'Mask Type','SD/FAST Interface block',...
		'Mask Dialogue','eval(''sdpanel('''''''');'');')
set_param([sys,'/','SD//FAST'],...
		'Mask Help','pend.sd,pendi.c,pendo.c',...
		'position',[275,128,335,152])

add_block('built-in/Fcn',[sys,'/','Fcn1'])
set_param([sys,'/','Fcn1'],...
		'orientation',2,...
		'hide name',0,...
		'Expr','-krotate*(u[1] - qbias) - ffrict*u[2]',...
		'Mask Display','Torsion Spring\nModel',...
		'Mask Type','Hinge Spring Friction Model')
set_param([sys,'/','Fcn1'],...
		'Mask Dialogue','Torque = -Krotate*(q - qbias) - Ffrict*u. | Krotate | Ffrict | qbias',...
		'Mask Translate','krotate = @1; ffrict = @2; qbias = @3;',...
		'Mask Entries','100\/10\/0\/')
set_param([sys,'/','Fcn1'],...
		'position',[260,196,350,224])

add_block('built-in/From Workspace',[sys,'/','Pulse'])
set_param([sys,'/','Pulse'],...
		'matl_expr','[T'', U'']',...
		'Mask Display','plot(T,U)',...
		'Mask Type','Look-up Table',...
		'Mask Dialogue','Input Flow|Time Values (t):|Pulse Values(U):',...
		'Mask Translate','T=@1;U=@2;')
set_param([sys,'/','Pulse'],...
		'Mask Entries','[0       9.9       10     10.1   50]\/[0        0           1       0       0]\/',...
		'position',[30,117,70,143])
add_line(sys,[75,130;110,130])
add_line(sys,[445,145;460,145;460,170;485,170])
add_line(sys,[255,210;170,210;170,145;190,145])
add_line(sys,[160,130;190,130])
add_line(sys,[170,130;170,90;220,90])
add_line(sys,[230,140;270,140])
add_line(sys,[340,140;395,140])
add_line(sys,[445,130;460,130;460,100;485,100])
add_line(sys,[365,140;355,210])

drawnow

% Return any arguments.
if (nargin | nargout)
	% Must use feval here to access system in memory
	if (nargin > 3)
		if (flag == 0)
			eval(['[ret,x0,str,ts,xts]=',sys,'(t,x,u,flag);'])
		else
			eval(['ret =', sys,'(t,x,u,flag);'])
		end
	else
		[ret,x0,str,ts,xts] = feval(sys);
	end
else
	drawnow % Flash up the model and execute load callback
end
