function sdedit(flagstring),
% sdedit() is the function that calls the appropriate editor 
%          for an SD/FAST control panel.  

%		Copyright (c) 1994 by The MathWorks, Inc.

% inputs:  none
% outputs: none

% this function:
%      (i)   determines which file is specified by getting the file name
%            which is one index up in the general handles vector
%      (ii)  checks the editor menu on the SD/FAST control panel to see which
%            type of editor is specified 
%      (iii) calls the above editor and opens the specified file

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% intialize usefull parameters
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
fig = gcf;
handles = get(fig,'UserData');
set(fig,'Pointer','Watch');
statush = handles(1);
previous_string = get(statush,'String');
editmodehand = handles(2);
comp = computer;
pc = strcmp(comp(1:2),'PC');
dirhand = handles(4);
filehand = handles(5);

if pc,
	DEFAULTEDITOR = 'edit';
	SLASH = '\';
	INFO = '_i';
	DYN  = '_d';
	SAR  = '_s';
else
	DEFAULTEDITOR = 'xterm -e vi';
	SLASH = '/';
	INFO = '_info';
	DYN  = '_dyn';
	SAR  = '_sar';	
end

% set status
set(handles(1),'String','Editing file...');
drawnow

% get handle to button
buthand = get(fig,'CurrentObject');


%                                     (i)                                   %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% find out which file to edit 
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
if  isempty(flagstring),
    % get handle to edit field
    ind = find(buthand==handles);
    filenamehand = handles(ind-1);

    % get filename
    filename = get(filenamehand,'String');

    % make sure that the file is good

    % get filepath from directory string
    filepath = get(handles(ind-2),'String');
else
    filename = get(filehand,'String');
    ind = findstr(lower(filename),'.sd');
    if  ~isempty(ind),
        filename = filename(1:ind(1)-1);
    end
    filepath = [cd,SLASH];

    if  strcmp(flagstring,'info'),
        filename = [filename,INFO];
    elseif strcmp(flagstring,'dyn'),
        filename = [filename,DYN,'.c'];
    elseif strcmp(flagstring,'sar'),
        filename = [filename,SAR,'.c'];
    end

    % check the current directory and search the matlab path if it isn't 
    % there
    path = findpath([filepath,filename]);
    if  isempty(path),
        filepath = findpath(filename);
    end

    if  isempty(filepath),
        errordlg(['"',filename,'" not found in current directory or MATLAB path - aborting...']);
        set(statush,'String',previous_string);
        set(fig,'Pointer','Arrow');
        return
    end
end

%                                    (ii)                                   %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% get editmode from editor menu 
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
editor = get(editmodehand,'String');
if isempty(editor),
	editor = DEFAULTEDITOR;
end

%                                   (iii)                                   %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% call editor on file
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
string = ['! ',editor,' ',filepath,filename,' &'];
eval(string);



set(handles(1),'String',previous_string);
set(fig,'Pointer','Arrow');
drawnow











