function [ret,x0,str,ts,xts]=sdfast(t,x,u,flag);
%SDFAST	is the M-file description of the SIMULINK system named SDFAST.
%	The block-diagram can be displayed by typing: SDFAST.
%
%	SYS=SDFAST(T,X,U,FLAG) returns depending on FLAG certain
%	system values given time point, T, current state vector, X,
%	and input vector, U.
%	FLAG is used to indicate the type of output to be returned in SYS.
%
%	Setting FLAG=1 causes SDFAST to return state derivatives, FLAG=2
%	discrete states, FLAG=3 system outputs and FLAG=4 next sample
%	time. For more information and other options see SFUNC.
%
%	Calling SDFAST with a FLAG of zero:
%	[SIZES]=SDFAST([],[],[],0),  returns a vector, SIZES, which
%	contains the sizes of the state vector and other parameters.
%		SIZES(1) number of states
%		SIZES(2) number of discrete states
%		SIZES(3) number of outputs
%		SIZES(4) number of inputs
%		SIZES(5) number of roots (currently unsupported)
%		SIZES(6) direct feedthrough flag
%		SIZES(7) number of sample times
%
%	For the definition of other parameters in SIZES, see SFUNC.
%	See also, TRIM, LINMOD, LINSIM, EULER, RK23, RK45, ADAMS, GEAR.

% Note: This M-file is only used for saving graphical information;
%       after the model is loaded into memory an internal model
%       representation is used.

% the system will take on the name of this mfile:
sys = mfilename;
new_system(sys)
simver(1.3)
if (0 == (nargin + nargout))
     set_param(sys,'Location',[292,197,637,351])
     open_system(sys)
end;
set_param(sys,'algorithm',     'RK-45')
set_param(sys,'Start time',    '0.0')
set_param(sys,'Stop time',     '999999')
set_param(sys,'Min step size', '0.0001')
set_param(sys,'Max step size', '10')
set_param(sys,'Relative error','1e-3')
set_param(sys,'Return vars',   '')
set_param(sys,'Real-time build command','!download $model.c $model.h $integrator $sfunctions')


%     Subsystem  ['Double click',13,'on this for demo.7'].

new_system([sys,'/',['Double click',13,'on this for demo.7']])
set_param([sys,'/',['Double click',13,'on this for demo.7']],'Location',[-10,380,117,533])
set_param([sys,'/',['Double click',13,'on this for demo.7']],...
		'Mask Display','sddemo4',...
		'Mask Dialogue','eval(''sddemo4'')')


%     Finished composite block ['Double click',13,'on this for demo.7'].

set_param([sys,'/',['Double click',13,'on this for demo.7']],...
		'BackGround',5,...
		'hide name',0,...
		'position',[257,107,319,135])


%     Subsystem  ['Double click',13,'on this for demo.6'].

new_system([sys,'/',['Double click',13,'on this for demo.6']])
set_param([sys,'/',['Double click',13,'on this for demo.6']],'Location',[-10,380,117,533])
set_param([sys,'/',['Double click',13,'on this for demo.6']],...
		'Mask Display','sddemo3',...
		'Mask Dialogue','eval(''sddemo3'')')


%     Finished composite block ['Double click',13,'on this for demo.6'].

set_param([sys,'/',['Double click',13,'on this for demo.6']],...
		'BackGround',5,...
		'hide name',0,...
		'position',[182,107,244,135])


%     Subsystem  ['Double click',13,'on this for demo.5'].

new_system([sys,'/',['Double click',13,'on this for demo.5']])
set_param([sys,'/',['Double click',13,'on this for demo.5']],'Location',[-10,380,117,533])
set_param([sys,'/',['Double click',13,'on this for demo.5']],...
		'Mask Display','sddemo2',...
		'Mask Dialogue','eval(''sddemo2'')')


%     Finished composite block ['Double click',13,'on this for demo.5'].

set_param([sys,'/',['Double click',13,'on this for demo.5']],...
		'BackGround',5,...
		'hide name',0,...
		'position',[107,107,169,135])


%     Subsystem  ['Double click',13,'on this for demo.4'].

new_system([sys,'/',['Double click',13,'on this for demo.4']])
set_param([sys,'/',['Double click',13,'on this for demo.4']],'Location',[-10,380,117,533])
set_param([sys,'/',['Double click',13,'on this for demo.4']],...
		'Mask Display','sddemo1',...
		'Mask Dialogue','eval(''sddemo1'')')


%     Finished composite block ['Double click',13,'on this for demo.4'].

set_param([sys,'/',['Double click',13,'on this for demo.4']],...
		'BackGround',5,...
		'hide name',0,...
		'position',[32,107,94,135])

add_block('built-in/Note',[sys,'/','Demos'])
set_param([sys,'/','Demos'],...
		'position',[170,80,175,85])

add_block('built-in/Note',[sys,'/','Blank System'])
set_param([sys,'/','Blank System'],...
		'position',[85,30,90,35])

add_block('built-in/S-Function',[sys,'/','SD//FAST'])
set_param([sys,'/','SD//FAST'],...
		'function name','',...
		'parameters','0,0,[ ],[ ],[ ],[ ],.001,.001',...
		'Mask Display','',...
		'Mask Type','SD/Fast interface block',...
		'Mask Dialogue','eval(''sdpanel(''''myemacs'''');'');')
set_param([sys,'/','SD//FAST'],...
		'position',[140,26,205,54])

drawnow

% Return any arguments.
if (nargin | nargout)
	% Must use feval here to access system in memory
	if (nargin > 3)
		if (flag == 0)
			eval(['[ret,x0,str,ts,xts]=',sys,'(t,x,u,flag);'])
		else
			eval(['ret =', sys,'(t,x,u,flag);'])
		end
	else
		[ret,x0,str,ts,xts] = feval(sys);
	end
else
	drawnow % Flash up the model and execute load callback
end
