function sdfndfil(),
%SDFNDFIL Finds the path to the file stored in the current objects string 
%		parameter of an SD/FAST Interface control panel and stuffs it in
%		its Directory: field.

%		Copyright (c) 1993 by The MathWorks, Inc.
%		Jay Torgerson

% inputs:  none
% outputs: none

% this function:
%      (i)   gets a handle to the object that called it
%      (ii)  gets the string value stored in that object
%      (iii) finds the path to the file 
%      (iv)  stuffs the path in the Directory: field whos index
%            in the general handles vector is one above the 
%            calling objects index in the general handles vector
%      (v)   make sure that the system still exists in SIMULINK
%      (vi)  checks to see if this is the .sd-file and augments the 
%            simulink system name if it is
%            If it's the inputs or outputs file, then update the Help mask

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% intialize usefull parameters
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
fig = gcf;
handles = get(fig,'UserData');
previous_string = get(handles(1),'String');
statush = handles(1);
set(statush,'String','Searching for file...');
sys = get(handles(3),'String');
comp = computer;
pc = strcmp(comp(1:2),'PC');
set(fig,'Pointer','Watch');
comma = ',';

if pc,
  SLASH = '\';
else
  SLASH = '/';
end

%                                     (i)                                   %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% get handles to current object and the directory text object
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
thishand = get(fig,'CurrentObject');

% find the handle to the directory field
ind = find(handles==thishand);
dirhand = handles(ind-1);

lookherefirst = get(dirhand,'String');

set(dirhand,'String','?');drawnow;


%                                     (ii)                                  %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% get the string value 
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
filename = get(thishand,'String');

% strip white space out
filename = dewhite(filename);

if isempty(filename),
	errordlg('No file specified.');
	set(statush,'String',previous_string);
	set(fig,'Pointer','Arrow');

	return
end

% take commas out as well, since they are the delimiters
filename(filename==comma) = [];

set(thishand,'String',filename); 

if ~isempty(filename),
filepath = '';

%                                     (iii)                                 %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% find path to the file and trap error if it doesn't exist
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% first check previous file's directory if an absolute path was not
%       specified, then search the matlabpath
if  isempty(findstr(filename,SLASH)),
    [filepath flnm] = findpath([lookherefirst,filename]);
	if ~isempty(filepath)
		filename = flnm;
	end
end

if  isempty(filepath),
    [filepath filename] = findpath(filename);
end

if  isempty(filepath),
    click = questdlg('File does not exist; create new file?','Yes','No');
    if  strcmp(click,'Yes'),
		success = touch(filename);
        if (success),
	         [filepath filename] = findpath(filename);
		else
			set(statush,'String','PERMISSION DENIED'); pause(2);
		end
    else
         oldfilename = get(thishand,'UserData');
         [filepath filename] = findpath(oldfilename);
    end
end

% update the UserData and String to filename
set(thishand,'UserData',[filepath,filename]);
set(thishand,'String',filename);

%                                     (iv)                                  %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% stuff this path into the Directory: text field
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
set(dirhand,'String',filepath);
set(statush,'String',previous_string);
set(fig,'Pointer','Arrow');


%                                     (v)                                   %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% check to see if this simulink system has been renamed or deleted before
% writing to it
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
locality = get_param(sys,'position');
if isempty(locality),
	errordlg('Error: SD/FAST block has been renamed or deleted.');
	return
end

ind = findstr(lower(filename),'.sd');
if ~isempty(ind)
    name = filename(1:ind(1)-1);
else
    name = filename;
	anotherind = findstr(lower(filename),'.c');
	if ~isempty(anotherind),
	    name = filename(1:anotherind(1)-1);		
	else
		errmsg = str2mat('Warning: ','The System Description should be a .sd-file.',...
				'The sdinputs() and sdoutputs() should be .c-files.');	
		disp(errmsg);
	end
end


%                                     (vi)                                  %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% check to see if this file is the .sd-file and update simulink mask if it
%       is otherwise, if its the input or output file, update the Mask Help
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

w = find(handles==thishand);
if (w(1) == 5),
    set_param(sys,'function name',name);
    set_param(sys,'Mask Display',name);
end

if (w(1) == 5) | (w(1) == 8) | (w(1) == 11),
    filename = get(handles(5),'String');
    filedir = get(handles(4),'String');
	if ~isempty(filename),
	    filename(filename==comma) = [];        % get rid of all commas
	end
    ind = findstr(filedir,SLASH);
    if ~isempty(ind),
        filename = [ filedir,filename ];
    end

    inname = get(handles(8),'String');
    innamedir = get(handles(7),'String');
	if ~isempty(inname),
	    inname(inname==comma) = [];        % get rid of all commas
	end
    ind = findstr(innamedir,SLASH);
    if ~isempty(ind),
        inname = [ innamedir,inname];
    end

    outname= get(handles(11),'String');
    outnamedir = get(handles(10),'String');
	if ~isempty(outname),
    	outname(outname==comma) = [];        % get rid of all commas
	end
    ind = findstr(outnamedir,SLASH);
    if ~isempty(ind),
        outname = [ outnamedir,outname];
    end
	FullNamePaths = [filename,comma,inname,comma,outname];
	FullNamePaths = strrep(FullNamePaths,'\','/');
    set_param(sys,'Mask Help',FullNamePaths);
end

end

end

    
set(statush,'String',previous_string);
set(fig,'Pointer','Arrow');








