function [success] = sdgen(flagstring),
%SDGEN Calls the SD/FAST rouitines and generates a C-file 
%		corresponding to the specified .sd-file in the SD/FAST 
%		Interface control panel.

%		Copyright (c) 1993 by The MathWorks, Inc.

fig = gcf;
set(fig,'Pointer','Watch');
drawnow
handles = get(fig,'UserData');

comp = computer;
pc = strcmp(comp(1:2),'PC');

if pc,
    SHELLSUFFIX = ' |';
else
    SHELLSUFFIX = ' ';
end

% get system name and handles to the edit and the status fields
sdname = get(handles(5),'String');
sddir = get(handles(4),'String');
sdstatush = handles(1);


% set sdstatush
previous_string = get(sdstatush,'String');
% set title to read generating <name>_dyn.c file
statusstring = 'Generating SD/FAST files in current directory...';
set(sdstatush,'String',statusstring);
drawnow

fullname = [sddir,sdname];
filepath = findpath(fullname);
% check to see that the .sd-file exists and is readable
if  isempty(filepath),
    success = 0;
    errordlg(['File, "',sddir,sdname,'", not found or is not writtable - aborting...']);
    set(sdstatush,'String',previous_string);
    set(fig,'Pointer','Arrow');
    return
else
    success = 1;
end

% test to see if directory is writtable
% status is nonzero if false and 0 if true 
if ~pc,
	[status junk] = unix(['test -w ',cd]);
else
	status  = 0;
end

if  status,  
    success = 0;
    errordlg(['Current directory, "',cd,'", not writtable - aborting...']);
    set(fig,'Pointer','Arrow');
    set(sdstatush,'String',previous_string);
    return
end
    
% strip the .sd off the system name for use with strings
i = findstr(lower(sdname),'.sd');
if ~isempty(i),
	name = sdname(1:i(1)-1);
else
	name = sdname;
end

if  strcmp(flagstring,'v'),
    verbose = 1;
else
    verbose = 0;
end

if verbose,    
    verbosetext = '-vv ';
    SHELLSUFFIX = '';
else
    verbosetext = '';
end

% call sdfast 
command = ['sdfast -lc ',verbosetext,fullname,SHELLSUFFIX];

if verbose,
   eval(['! ',command])
else
   unix(command);
end

set(sdstatush,'String',previous_string);
set(fig,'Pointer','Arrow');
drawnow







