function sdhelp(flag),
%SDHELP Returns a help screen for the SD/FAST Interface control panel.

%		Copyright (c) 1994 by The MathWorks, Inc.

% inputs:  flag = flag determining which help screen is to be displayed
% outputs: none

% this function:
%      (i)   brings up a certain help screen for SD/FAST 
%            depending on the flag passed in

fig = gcf;
handles = get(fig,'UserData');
statush = handles(1);

set(fig,'Pointer','Watch');drawnow
previous_string = get(statush,'String');drawnow
set(statush,'String','...');

nl = setstr(10);
if  flag == 1,
    title = 'System Description Help';
    helpstring = str2mat(...
    'The System Description file is a file written in SD/FAST      ',...
    'commands.  This file specifies the system configuration at    ',...
    'initialization time.  It is normally suffixed with a ".sd".   ',...
    '                                                              ',...
    'To select a System Description file for the SD/FAST interface,',...
    'type its name in the edit field entitled, "Filename:", under  ',...
    'System Description.  You may also use the "Select New" button ',...
    'to find the file you wish to use.                             ',...
    '                                                              ',...
    'See the SD/FAST User''s Manual for a detailed explanation of  ',...
    'the System Description file.                                  ');

elseif flag == 2, 
    title = 'sdinputs() Help';

    helpstring1 = str2mat( ...
    'The sdinputs() file contains a function named "sdinputs()" which is',...
    'written in C.  This function specifies the inputs to the SD/FAST   ',...
    'system defined by the System Description file.                     ',...
    '                                                                   ',...
    'The sdinputs() file is written by the user and has the following   ',...
    'form:                                                              ',...
    '                                                                   ',...
    '     sdinputs(t,q,u,qdot,udot,inputs)                              ',...
    '                                                                   ',...
    '     double t, *q, *u, *qdot, *udot, *inputs;                      ');

    helpstring2 = str2mat( ...
    '     {                                                             ',...
    '                                                                   ',...
    '          /*** USER WRITTEN CODE GOES HERE ***/                    ',...
    '                                                                   ',...
    '     }                                                             ',...
    '                                                                   ',...
    '                                                                   ',...
    'The user written code may contain calls to any SD/FAST functions.  ',...
    'The sdinputs() function is most commonly used to apply loads to    ',...
    'and prescribe motions on the SD/FAST system.                       ');

    helpstring3 = str2mat(...
    '                                                                   ',...
    'Some example functions are:                                        ',...
    '                                                                   ',...
    '     sdpointf();                                                   ',...
    '     sdhinget();                                                   ',...
    '     sdbodyt();                                                    ',...
    '                                                                   ',...
    'For more information on SD/FAST functions, see your SD/FAST        ',...
    'User''s Manual.                                                    ');

    helpstring4 = str2mat( ...
    '                                                                   ',...
    'Type "sddemo" at the MATLAB prompt to obtain a library of SD/FAST  ',...
    'blocks  which contain various examples of sdinputs() files.        ',...
    '                                                                   ',...
    '                                                                   ');

    helpstring = str2mat(helpstring1,helpstring2,helpstring3,helpstring4);

elseif flag == 3,
    title = 'sdoutputs() Help';

    helpstring1 = str2mat( ...
    'The sdoutputs() file contains a function named "sdoutputs()" which ',...
    'is written in C.  This function specifies the outputs of an SD/FAST',...
    'block in a SIMULINK system.                                        ',...
    '                                                                   ',...
    'The sdoutputs() file is written by the user and has the following  ',...
    'form:                                                              ',...
    '                                                                   ',...
    '     sdoutputs(outputs,t,q,u,inputs)                               ',...
    '                                                                   ',...
    '     double *outputs, t, *q, *u, *inputs;                          ');

    helpstring2 = str2mat( ...
    '     {                                                             ',...
    '                                                                   ',...
    '          /*** USER WRITTEN CODE GOES HERE ***/                    ',...
    '                                                                   ',...
    '     }                                                             ',...
    '                                                                   ',...
    '                                                                   ',...
    'The user written code may contain calls to any SD/FAST functions.  ',...
    'The sdoutputs() function is most commonly used to obtain the       ',...
    'position, orientation, velocity and acceleration of bodies in the  ',...
    'SD/FAST system.                                                    ');

    helpstring3 = str2mat( ...
    '                                                                   ',...
    'Some example functions are:                                        ',...
    '                                                                   ',...
    '     sdpos();                                                      ',...
    '     sdorient();                                                   ',...
    '     sdvel();                                                      ',...
    '     sdacc();                                                      ',...
    '     sdgetht();                                                    ',...
    '                                                                   ',...
    'For more information on SD/FAST functions, see your SD/FAST        ');

    helpstring4 = str2mat( ...
    'User''s Manual.                                                    ',...
    '                                                                   ',...
    'Type "sddemo" at the MATLAB prompt to obtain a library of SD/FAST  ',...
    'blocks  which contain various examples of sdoutputs() files.       ',...
    '                                                                   ',...
    '                                                                   ');

    helpstring = str2mat(helpstring1,helpstring2,helpstring3,helpstring4);

elseif flag == 4,
    title = 'System Parameters Help';
    helpstring1 = str2mat(...
    'The System Parameters for the SD/FAST Interface are as follows:       ',...
    '                                                                      ',...
    'q0:  the intial state vector for the position states                  ',...
    'u0:  the intial state vector for the velocity states                  ',...
    '                                                                      ',...
    'Size of Inputs vector:  the number of inputs to the SD/FAST block     ',...
    '                        from SIMULINK                                 ',...
    'Size of Outputs vector: the number of outputs from the SD/FAST block  ',...
    '                        to SIMULINK                                   ',...
    '                                                                      ');
helpstring1p5 = ...
    'locked q0''s: a vector containing only 1''s and 0''s which has the    ';

    helpstring2 = str2mat(...
    '              same dimension as q0, the 1''s indicate that the        ',...
    '              corresponding q0 state value is fixed and should not    ',...
    '              be changed by sdassemble() at initialization time       ',...
    'locked u0''s: a vector containing only 1''s and 0''s which has the    ',...
    '              same dimension as u0, the 1''s indicate that the        ',...
    '              corresponding u0 state value is fixed and should not    ',...
    '              be changed by sdinitvel() at initialization time        ',...
    '                                                                      ',...
    'qtolerance:   the maximum error that the sdassemble() function will  ',...
    '              allow when assembling the rigid body at initialization ');

    helpstring3 = str2mat(...
    '              time                                                    ',...
    'utolerance:   the maximum error that the sdinitvel() function will   ',...
    '              allow when computing the initial velocities for the    ',...
    '              rigid body at initialization time                      ',...
    '                                                                      ',...
    '(both qtolerance and utolerance are typically 10*tol, where tol is the',...
    '               simulation tolerance)                                  ',... 
    '                                                                      ',...
    'All the System Parameters may be changed without rebuilding the system',...
    'since they are set dynamically at simulation time.                    ',...
    '                                                                      ');

    helpstring = str2mat(helpstring1,helpstring1p5,helpstring2,helpstring3);

elseif flag == 5,
    title = 'General Help';
  
    helpstring1 = str2mat(...
    'The SD/FAST Interface is a product of The MathWorks, Inc.        ',...
    'It is designed to give easy and complete access to the SD/FAST language',...
    'and routines from within the MATLAB/SIMULINK analysis and simulation',...
    'environment.                                                        ');

    helpstring2 = str2mat(...
    '                                                                    ',...
    'MENU OPTIONS:                                                       ',...
    '                                                                    ',...
    'Commands:                                                           ',...
    'Generate SD/FAST files - this calls the sdfast script and generates ',...
    '                         the SD/FAST files: <sys>_info, <sys>_dyn.c ',...
    '                         and <sys>_sar.c from the specified .sd-file',...
    'Generate SD/FAST files verbose - performs a verbose version of the  ',...
    '                         above menu option                          ');
    helpstring3 = str2mat(...
    'BUILD - calls the sdfast script and then compiles the resulting     ',...
    '        .c-files into a MEX-file for use with SIMULINK              ',...
    'BUILD verbose - does a BUILD in verbose mode                        ',...
    'Show _info  file - edits the <sys>_info  file                       ',...
    'Show _dyn.c file - edits the <sys>_dyn.c file                       ',...
    'Show _sar.c file - edits the <sys>_sar.c file                       ',...
    '                                                                    ');
    helpstring4 = str2mat(...
    'Preferences:                                                        ',...
    'Set Default Editor... - brings up a dialog box to change the default',...
    '                        editor                                      ',...
    '                                                                    ',...
    'Help:                                                               ',...
    'Brings up various help dialogs.                                     ');
   
    helpstring = str2mat(helpstring1,helpstring2,helpstring3,helpstring4);
        
end


helpdlg(helpstring,title);
set(statush,'String',previous_string);drawnow
set(fig,'Pointer','Arrow');drawnow





