function sdinit(handles);
%SDINIT Sets up an SD/FAST Interface control panel by initializing all the parameters
%		and files.

%		Copyright (c) 1994 by The MathWorks, Inc.

% inputs:  handles = handles to all objects in that control panel
% outptus: none

% this function:
%      (i)   gets filenames for .sd-file, sdinputs() and sdoutputs() 
%             from Mask Help
%      (ii)  gets system parameters from s-function block
%      (iii) check to make sure tha editor is defined

% useful handles
sdfilehand = handles(5);
sdinputshand = handles(8);
sdoutputshand = handles(11);
statushand = handles(1);
edithand = handles(2);
fig = gcf;

% usefule variables
sys = get(handles(3),'String');
comp = computer;
pc = strcmp(comp(1:2),'PC');

if pc,
  DEFAULTEDITOR = 'edit';  
  SLASH = '\';
else
  DEFAULTEDITOR = 'xterm -e vi';
  SLASH = '/';
end

% set status string 
set(statushand,'String','Initializing System...');

%                                      (i)                                   %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% get filenames for .sd-file, sdinputs() and sdoutputs()
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
namevector = get_param(sys,'Mask Help');
namevector = dewhite(namevector);
namevector= namevector(:)';

% if it's a pc, you need to convert the /'s to \'s.
if pc,
	namevector = strrep(namevector,'/','\');
end

% make sure that namevector has something in it and find the commas
if ~isempty(namevector)
    ind = findstr(namevector,',');
else
    ind = [];
end

if  length(ind) == 2,
    sdnamesd = namevector(1:ind(1)-1);
    sdnamei  = namevector(ind(1)+1:ind(2)-1);
    sdnameo  = namevector(ind(2)+1:length(namevector));
else
    set(sdfilehand,'String','?');
    set(sdinputshand,'String','?'); 
    set(sdoutputshand,'String','?');
    set(sdfilehand,'UserData','?');
    set(sdinputshand,'UserData','?'); 
    set(sdoutputshand,'UserData','?');

    set(statushand,'String','READY');

    return
end


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
set(sdfilehand,'String',sdnamesd);
set(sdinputshand,'String',sdnamei); 
set(sdoutputshand,'String',sdnameo);
set(sdfilehand,'UserData',sdnamesd);
set(sdinputshand,'UserData',sdnamei); 
set(sdoutputshand,'UserData',sdnameo);

% now update them
set(fig,'CurrentObj',sdfilehand); 
sdfndfil;
set(fig,'CurrentObj',sdinputshand); 
sdfndfil;
set(fig,'CurrentObj',sdoutputshand);
sdfndfil;
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


%                                   (ii)                                     %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% load parameters 
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
sdloadpm;

%                                   (iii)                                    %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% check to see if editor has been specified
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
editor = get(edithand,'String');
if  isempty(editor),
    sdchgedt(DEFAULTEDITOR);  
end

set(statushand,'String','READY');











