function sdloadpm(),
%SDLOADPM Loads the extra parameters for the S-Function MEX-file 
%		associated with the SD/Fast Interface control panel into the
%		parameters dialog box for the S-Function.

%		Jay Torgerson
%		Copyright (c) 1993 by The MathWorks, Inc.

%   These parameters are:
%     (1)  the size of the inputs vector in sdinputs()
%     (2)  the size of the outputs vector in sdoutputs()
%     (3)  q0  (initial condition vector for the position state vector)
%     (4)  u0  (initial condition vector for the velocity state vector)
%     (5)  lockq0 (vector of locked q0 states )
%     (6)  locku0 (vector of locked u0 states )
%     (7)  tolq0  (tolerance value for lockq0 )
%     (8)  tolu0  (tolerance value for locku0 )

% get useful handles
fig = gcf;
handles = get(fig,'UserData');
sysname = get(handles(3),'String');

% get handles to q and u size specifications, and q0 and u0 init conditions
%     as well as num of inputs and outpus edit windows.
q0h = handles(13);
u0h = handles(14);
inputsh = handles(15);
outputsh = handles(16);
lockq0h = handles(17);
locku0h = handles(18);
tolq0h = handles(19);
tolu0h = handles(20);

% get the current string (which is delimited by commas)
string = get_param(sysname,'parameters');
commaind = findstr(string,',');

if length(commaind) < 7,
   disp('parameters not set properly')
else
   % extract the strings for each edit window
   ind1 = commaind+1;
   ind2 = commaind-1;
   inputshstr = string(1:ind2(1));
   outputshstr = string(ind1(1):ind2(2));
   q0hstr = string(ind1(2):ind2(3));
   u0hstr = string(ind1(3):ind2(4));
   lockq0str = string(ind1(4):ind2(5));
   locku0str = string(ind1(5):ind2(6));
   tolq0str = string(ind1(6):ind2(7));
   tolu0str = string(ind1(7):length(string));


   % stuff values into appropriate edit windows
   set(q0h,'String',q0hstr);
   set(u0h,'String',u0hstr);
   set(inputsh,'String',inputshstr);
   set(outputsh,'String',outputshstr);
   set(lockq0h,'String',lockq0str);
   set(locku0h,'String',locku0str);
   set(tolq0h,'String',tolq0str);
   set(tolu0h,'String',tolu0str);
end

