function sdsetedt(),
%SDSETEDT Sets the default editor for an SD/FAST Interface control panel.

%		Copyright (c) 1994 by The MathWorks, Inc.

% inputs:  none
% outputs: none

% this function:
%      (i)   brings up a dialog box requesting that the user 
%            specify a new editor and sets up the callback to 
%            sdchgedt 


% setup useuful handles
fig = gcf;
handles = get(fig,'UserData');
editmodehand = handles(2);
syshand = handles(3);
statushand = handles(1);
comp = computer;
pc = strcmp(comp(1:2),'PC');

% setup useful strings / variables
editmode = get(editmodehand,'String');
sysname = get(syshand,'String');
previous_string = get(statushand,'String');
figposi = get(fig,'Position');

% Use platform specific defaults
if isempty(editmode),
  if pc,
    editmode = 'notepad ';
  else
    editmode = 'xterm -e vi ';    
  end    
end  
  
% set status field and arrrow
set(fig,'Pointer','Watch');
set(statushand,'String','Opening...');

grey = [.75 .75 .75]


%                                     (i)                                   %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% bring up the dialog box
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
dialogfigposi = [ 100 100 300 100 ];
dialogfig = figure('Visible','Off',...
                   'Numbertitle','Off',...
                   'Menu','None',...
                   'NextPlot','New',...
                   'Name','SD/FAST: Default Editor',...
                   'Units','Pixels',...
                   'Color',grey,...
                   'Position',dialogfigposi);

set(dialogfig,'Units','Normal');
dialogfigposi = get(dialogfig,'Position');
set(dialogfig,'Position',[ figposi(1)+figposi(3)/2-dialogfigposi(3)/2, ...
                           figposi(1)+figposi(4)/2-dialogfigposi(4)/2, ...
                           dialogfigposi(3),...
                           dialogfigposi(4) ]);


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% setup global parameters for objects
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
x = .02;
y = x;

framew = 1-2*x;
textw = .15;
texth = .2;
butw = .3;
buth = texth;
yspace = (1-3*texth-2*y)/2.5;

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% define text object parameters
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
etextw = textw;
etexth = texth;
etextx = x;
etexty = .55;

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% define popup menu object parameters
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
editw = textw/2;
edith = texth;
editx = etextx+etextw;
edity = etexty;

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% define edit object parameters
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
neweditw = framew-etextw-editw;
newedith = texth;
neweditx = etextx+etextw;
newedity = edity;

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% define button object parameters
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
closebutw = butw;
closebuth = buth;
closebutx = 1-x-butw;
closebuty = .1;

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% define popupmenu objects
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
etexthand = uicontrol('Style','Text',...
                      'Units','Normal',...
                      'BackGroundColor',grey,...  
                      'ForeGroundColor','Black',...  
                      'HorizontalAlignment','Left',...
                      'String','Editor: ',...
                      'Position',[ etextx etexty ...
                                   etextw etexth]);

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% define Menu of Example Editors
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
hEditMenu = uimenu('Label','Examples');
if  ~pc,
  uimenu(hEditMenu,'Label','emacs','CallBack','sdchgedt(''emacs'');');
  uimenu(hEditMenu,'Label','lemacs','CallBack','sdchgedt(''lemacs'');');  
  uimenu(hEditMenu,'Label','xterm -e vi','CallBack','sdchgedt(''xterm -e vi'');');
  uimenu(hEditMenu,'Label','shelltool -e vi ','CallBack','sdchgedt(''shelltool -e vi '');');
  uimenu(hEditMenu,'Label','textedit -e vi','CallBack','sdchgedt(''textedit -e vi'');');
else
  uimenu(hEditMenu,'Label','edit','CallBack','sdchgedt(''edit'');');
  uimenu(hEditMenu,'Label','emacs','CallBack','sdchgedt(''emacs'');');    
  uimenu(hEditMenu,'Label','brief','CallBack','sdchgedt(''brief'');');  
  uimenu(hEditMenu,'Label','notepad','CallBack','sdchgedt(''notepad'');');  
end

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% define edit objects
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
newedithand = uicontrol(...
    'Style','Edit',...
    'Units','Normal',...
    'String',editmode,...
    'BackGroundColor','White',...  
    'ForeGroundColor','Black',...  
    'HorizontalAlignment','Left',...
    'Position',[ neweditx newedity neweditw newedith ] );

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% define button objects
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
closebuthand = uicontrol(...
    'Style','PushButton',...
    'Units','Normal',...
    'String','Done',...
    'Callback','sdchgedt('''');close',...
    'Position',[ closebutx closebuty closebutw closebuth]);

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% set userdata of the dialog figure to contain handles
%     currenttexthand and newedithand
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
set(dialogfig,'UserData',[handles;newedithand]);


set(fig,'Pointer','Arrow');
set(statushand,'String',previous_string);
set(dialogfig,'Visible','On');





