function handles = sdsetup(sys,figtitle,editstr),
%SDSETUP Setsup the SD/FAST Interface Control Panel

%		Copyright (c) 1993 by The MathWorks, Inc.

comp = computer;
pc = strcmp(comp(1:2),'PC');
darkgrey = 128/255*ones(1,3);
if get(0,'Screendepth') ~= 1,
    figcolor = [ .75 .75 .75];
    framecolor = figcolor;
    textcolor = framecolor;
    butcolor = textcolor;
    titleTextColor = 'white';    
    titlecolor = darkgrey;
else
    figcolor = 'white';
    framecolor = figcolor;
    textcolor = 'white';
    butcolor = textcolor;
    titlecolor = 'black';
end
editcolor = 'white';

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% setup figure window for control panel
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
figx = 100; figy = 100;  figw = 400; figh = 400;
configposi = [ figx figy figw figh ];
fig = figure(...
    'Numbertitle','Off',...
    'Menu','None',...
    'NextPlot','New',...
    'Name',figtitle,...
    'Units','Pixel',...
    'Position',configposi,...
    'Pointer','Watch',...
    'Color',figcolor);


hBuildingDisclaimer = uicontrol(...
    'Style','Text',...
    'Unit','Pixels',...
    'String','Building SD/FAST Control Panel...',...
    'BackGroundColor',figcolor,...
    'Position',[figw/5 figh/2 250 30]);
drawnow;

axis('off');

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% setup menu
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
sdcmdmenu = uimenu('Label','Commands');
            uimenu(sdcmdmenu,'Label','Generate SD/FAST files',...
                             'CallBack','sdgen('''');');
            uimenu(sdcmdmenu,'Label','Generate SD/FAST files verbose',...
                             'CallBack','sdgen(''v'');');
            uimenu(sdcmdmenu,'Label','Build',...
                             'CallBack','sdbuild('''')',...
                             'Interruptible','Yes');
            uimenu(sdcmdmenu,'Label','Build verbose',...
                             'CallBack','sdbuild(''v'')',...
                             'Interruptible','Yes');
            uimenu(sdcmdmenu,'Label','Show Info  file',...
                             'Callback','sdedit(''info'')');
            uimenu(sdcmdmenu,'Label','Show Dynamics file',...
                             'Callback','sdedit(''dyn'')');
            uimenu(sdcmdmenu,'Label','Show Analysis file',...
                             'Callback','sdedit(''sar'')');
mainedmenu = uimenu('Label','Preferences');
uimenu(mainedmenu,'Label','Set Default Editor...',...
                                       'Callback','sdsetedt;');
editmodehand = uicontrol('Style','Text',...
                         'Visible','Off',...
                         'String',editstr);

sdhpmenu = uimenu('Label','Help');
           uimenu(sdhpmenu,'Label','System Description','CallBack','sdhelp(1)');
           uimenu(sdhpmenu,'Label','sdinputs()','CallBack','sdhelp(2)');
           uimenu(sdhpmenu,'Label','sdoutputs()','CallBack','sdhelp(3)');           
           uimenu(sdhpmenu,'Label','System Parameters','CallBack','sdhelp(4)');           
           uimenu(sdhpmenu,'Label','General','Callback','sdhelp(5)');

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% setup global params
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
PIX = figw;
x = .01*PIX;                            % x margin = 1% of figw
y = x;
titleOffset = 6; % pixels
texth = .045*PIX;
textmargin = x/4;
frametextmargin = x/2;
titleh = texth+x;
framebuff = 2*x;
framew = PIX-1.5*x;
titlew = framew-5;
butw = .15*PIX;
buth = texth;
butx = PIX-3*x-butw;
butspaceing = 2*x;
fileframeh = .167*PIX;
filenamew = .2*PIX;
fileeditw = .3*PIX;
scalarw = fileeditw/3;
frametextw = framew-x;
dirwidth = .19*PIX;
selectnewbutw = butw*1.5;

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% define parameters for frame objects
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
statusframew = framew;
statusframeh = .063*PIX;
statusframex = x;
statusframey = x;

sdfileframew = framew;
sdfileframeh = fileframeh;
sdfileframex = x;
sdfileframey = PIX-x-sdfileframeh;

sdinputsframew = framew;
sdinputsframeh = fileframeh;
sdinputsframex = sdfileframex;
sdinputsframey = sdfileframey-framebuff-sdinputsframeh;

sdoutputsframew = framew;
sdoutputsframeh = fileframeh;
sdoutputsframex = sdfileframex;
sdoutputsframey = sdinputsframey-framebuff-sdoutputsframeh;

sdparamsframew = framew;
sdparamsframeh = 1.56*fileframeh;
sdparamsframex = sdfileframex;
sdparamsframey = sdoutputsframey-framebuff-sdparamsframeh;


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% define parameters for text objects
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
sdsimulinksysw = .0001*PIX;
sdsimulinksysh = .0001*PIX;
sdsimulinksysx = 10*PIX;
sdsimulinksysy = 10*PIX;

fixedstatustextw = .12*PIX;
fixedstatustexth = texth;
fixedstatustextx = statusframex+x/2;
fixedstatustexty = statusframey + (statusframeh-texth)/2;

statustextw = statusframew-x-fixedstatustextw;
statustexth = texth;
statustextx = fixedstatustextx + fixedstatustextw;
statustexty = fixedstatustexty;

sdfiletitlew = titlew;
sdfiletitleh = titleh;
sdfiletitlex = x+1+1;
sdfiletitley = sdfileframey+sdfileframeh-sdfiletitleh-2;

sdfiledumdirw = dirwidth;
sdfiledumdirh = texth;
sdfiledumdirx = fixedstatustextx;
sdfiledumdiry = sdfiletitley-texth-frametextmargin;

sdfilenamew = filenamew;
sdfilenameh = texth;
sdfilenamex = fixedstatustextx;
sdfilenamey = sdfiledumdiry-texth;

sdfiledirw = frametextw-sdfiledumdirw-x;
sdfiledirh = texth;
sdfiledirx = sdfilenamew+x;
sdfilediry = sdfiledumdiry;

sdinputstitlew = titlew;
sdinputstitleh = titleh;
sdinputstitlex = sdfiletitlex;
sdinputstitley = sdinputsframey+sdinputsframeh-sdinputstitleh-2;

sdinputsdumdirw = dirwidth;
sdinputsdumdirh = texth;
sdinputsdumdirx = fixedstatustextx;
sdinputsdumdiry = sdinputstitley-texth-frametextmargin;

sdinputsdirw = frametextw-sdfiledumdirw-x;
sdinputsdirh = texth;
sdinputsdirx = sdfilenamew+x;
sdinputsdiry = sdinputsdumdiry;

sdinputsnamew = filenamew;
sdinputsnameh = texth;
sdinputsnamex = fixedstatustextx;
sdinputsnamey = sdinputsdiry-texth;

sdoutputstitlew = titlew;
sdoutputstitleh = titleh;
sdoutputstitlex = sdinputstitlex;
sdoutputstitley = sdoutputsframey+sdoutputsframeh-sdoutputstitleh-2;

sdoutputsdumdirw = dirwidth;
sdoutputsdumdirh = texth;
sdoutputsdumdirx = fixedstatustextx;
sdoutputsdumdiry = sdoutputstitley-texth-frametextmargin;

sdoutputsdirw = frametextw-sdfiledumdirw-x;
sdoutputsdirh = texth;
sdoutputsdirx = sdfilenamew+x;
sdoutputsdiry = sdoutputsdumdiry;

sdoutputsnamew = filenamew;
sdoutputsnameh = texth;
sdoutputsnamex = fixedstatustextx;
sdoutputsnamey = sdoutputsdiry-texth;

sdparamstitlew = titlew;
sdparamstitleh = titleh;
sdparamstitlex = sdoutputstitlex;
sdparamstitley = sdparamsframey+sdparamsframeh-sdparamstitleh-2;

sdparamsq0w = .08*PIX;
sdparamsq0h = texth;
sdparamsq0x = fixedstatustextx;
sdparamsq0y = sdparamstitley-texth-frametextmargin;

sdparamsu0w = .08*PIX;
sdparamsu0h = texth;
sdparamsu0x = fixedstatustextx;
sdparamsu0y = sdparamsq0y-texth;

sdparamsinputsw = fileeditw*1.2;
sdparamsinputsh = texth;
sdparamsinputsx = framew/2;
sdparamsinputsy = sdparamstitley-texth-frametextmargin;

sdparamsoutputsw = fileeditw*1.2;
sdparamsoutputsh = texth;
sdparamsoutputsx = framew/2;
sdparamsoutputsy = sdparamsu0y;

sdparamslockqw = .22*PIX;
sdparamslockqh = texth;
sdparamslockqx = fixedstatustextx;
sdparamslockqy = sdparamsu0y-texth;

sdparamslockuw = sdparamslockqw;
sdparamslockuh = texth;
sdparamslockux = fixedstatustextx;
sdparamslockuy = sdparamslockqy-texth;

sdparamstolqw = .23*PIX;
sdparamstolqh = texth;
sdparamstolqx = .62*PIX;
sdparamstolqy = sdparamslockqy;

sdparamstoluw = sdparamstolqw;
sdparamstoluh = texth;
sdparamstolux = sdparamstolqx;
sdparamstoluy = sdparamstolqy - texth;


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% define parameters for edit objects
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
sdfileeditw = fileeditw;
sdfileedith = texth;
sdfileeditx = sdfilenamew+x;
sdfileedity = sdfilenamey;

sdinputseditw = fileeditw;
sdinputsedith = texth;
sdinputseditx = sdinputsnamew+x;
sdinputsedity = sdinputsnamey;

sdoutputseditw = fileeditw;
sdoutputsedith = texth;
sdoutputseditx = sdoutputsnamew+x;
sdoutputsedity = sdoutputsnamey;

sdparamsq0editw = fileeditw;
sdparamsq0edith = texth;
sdparamsq0editx = sdparamsq0x+sdparamsq0w;
sdparamsq0edity = sdparamsq0y;

sdparamsu0editw = fileeditw;
sdparamsu0edith = texth;
sdparamsu0editx = sdparamsu0x+sdparamsu0w;
sdparamsu0edity = sdparamsu0y;

sdparamsinputsedtw = scalarw;
sdparamsinputsedth = texth;
sdparamsinputsedtx = sdparamsinputsx + sdparamsinputsw;
sdparamsinputsedty = sdparamsinputsy;

sdparamsoutputsedtw = scalarw;
sdparamsoutputsedth = texth;
sdparamsoutputsedtx = sdparamsinputsedtx;
sdparamsoutputsedty = sdparamsoutputsy;

sdparamslockqeditw = fileeditw;
sdparamslockqedith = texth;
sdparamslockqeditx = sdparamslockqx+sdparamslockqw;
sdparamslockqedity = sdparamslockqy;

sdparamslockueditw = fileeditw;
sdparamslockuedith = texth;
sdparamslockueditx = sdparamslockux+sdparamslockuw;
sdparamslockuedity = sdparamslockuy;

sdparamstolqedtw = scalarw;
sdparamstolqedth = texth;
sdparamstolqedtx = sdparamsinputsedtx;
sdparamstolqedty = sdparamslockqedity;

sdparamstoluedtw = scalarw;
sdparamstoluedth = texth;
sdparamstoluedtx = sdparamsinputsedtx;
sdparamstoluedty = sdparamslockuedity;


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% define parameters for button objects
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
sdfilebutw = butw;
sdfilebuth = buth;
sdfilebutx = butx;
sdfilebuty = sdfileframey+y;

sdinputsbutw = butw;
sdinputsbuth = buth;
sdinputsbutx = butx;
sdinputsbuty = sdinputsframey+y;

sdoutputsbutw = butw;
sdoutputsbuth = buth;
sdoutputsbutx = butx;
sdoutputsbuty = sdoutputsframey+y;

sdbuildbutw = butw;
sdbuildbuth = buth;
sdbuildbutx = (PIX - (2*butw+butspaceing))/2;
sdbuildbuty = (sdparamsframey - (statusframey+statusframeh))/2 + statusframey+statusframeh - buth/2;

sddonebutw = butw;
sddonebuth = buth;
sddonebutx = sdbuildbutx + sdbuildbutw + butspaceing;
sddonebuty = sdbuildbuty;

sdfilefndbutw = selectnewbutw;
sdfilefndbuth = buth;
sdfilefndbutx = butx-selectnewbutw-frametextmargin;
sdfilefndbuty = sdfileframey+y;

sdinpfndbutw = selectnewbutw;
sdinpfndbuth = buth;
sdinpfndbutx = butx-selectnewbutw-frametextmargin;
sdinpfndbuty = sdinputsframey+y;

sdonpfndbutw = selectnewbutw;
sdonpfndbuth = buth;
sdonpfndbutx = butx-selectnewbutw-frametextmargin;
sdonpfndbuty = sdoutputsframey+y;

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% define frames objects
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
statusframehand = uicontrol('Style','Frame',...
                            'Units','Pixel',...
                            'BackGroundColor',darkgrey,...
                            'Position',[statusframex statusframey ...
                                        statusframew statusframeh]);

sdfileframehand = uicontrol('Style','Frame',...
                            'Units','Pixel',...
                            'BackGroundColor',framecolor,...
                            'Position',[sdfileframex sdfileframey ...
                                        sdfileframew sdfileframeh]);


sdinputsframehand = uicontrol('Style','Frame',...
                              'Units','Pixel',...
                              'BackGroundColor',framecolor,...
                              'Position',[sdinputsframex sdinputsframey ...
                                          sdinputsframew sdinputsframeh]);


sdoutputsframehand = uicontrol('Style','Frame',...
                               'Units','Pixel',...
                               'BackGroundColor',framecolor,...
                               'Position',[sdoutputsframex sdoutputsframey ...
                                           sdoutputsframew sdoutputsframeh]);

sdparamsframehand = uicontrol('Style','Frame',...
                              'Units','Pixel',...
                              'BackGroundColor',framecolor,...
                              'Position',[sdparamsframex sdparamsframey ...
                                          sdparamsframew sdparamsframeh]);


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% define text objects
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
sdsimulinksyshand = uicontrol('Style','Text',...
                              'Units','Pixel',...
                              'Visible','Off',...
                              'String',sys,...
                              'Position',[ sdsimulinksysx sdsimulinksysy ...
                                           sdsimulinksysw sdsimulinksysh ]);

fixedstatustexthnd = uicontrol('Style','Text',...
                               'Units','Pixel',...
                               'BackGroundColor',darkgrey,...
			       'ForeGroundColor','white',...
                               'String','Status: ',...
                               'HorizontalAlignment','Left',...
                               'Position',[ fixedstatustextx fixedstatustexty ...
                                            fixedstatustextw fixedstatustexth]);

statustexthand = uicontrol('Style','Text',...
                           'Units','Pixel',...
                           'BackGroundColor',darkgrey,...
			   'ForeGroundColor','white',...			   
                           'String','READY',...
                           'HorizontalAlignment','Left',...
                           'Position',[ statustextx statustexty ...
                                        statustextw statustexth]);

sdfiletitlehand = uicontrol('Style','Text',...
                            'Units','Pixel',...
                            'BackGroundColor',titlecolor,...
                            'ForeGroundColor',titleTextColor,...
                            'String','System Description',...
                            'HorizontalAlignment','Center',...
                            'Position',[ sdfiletitlex sdfiletitley ...
                                        sdfiletitlew sdfiletitleh]);

sdfiledirhand = uicontrol('Style','Text',...
                          'Units','Pixel',...
                          'BackGroundColor',textcolor,...
                          'String','',...
                          'HorizontalAlignment','Left',...
                          'Position',[ sdfiledirx sdfilediry ...
                                       sdfiledirw sdfiledirh]);

sdfiledumdirhand = uicontrol('Style','Text',...
                           'Units','Pixel',...
                           'BackGroundColor',textcolor,...
                           'String','Directory: ',...
                           'HorizontalAlignment','Left',...
                           'Position',[ sdfiledumdirx sdfiledumdiry ...
                                        sdfiledumdirw sdfiledumdirh]);

sdfilenamehand = uicontrol('Style','Text',...
                           'Units','Pixel',...
                           'BackGroundColor',textcolor,...
                           'String','Filename: ',...
                           'HorizontalAlignment','Left',...
                           'Position',[ sdfilenamex sdfilenamey ...
                                        sdfilenamew sdfilenameh]);

sdinputstitlehand = uicontrol('Style','Text',...
                              'Units','Pixel',...
                              'BackGroundColor',titlecolor,...
                              'ForeGroundColor',titleTextColor,...
                              'String','sdinputs()',...
                              'HorizontalAlignment','Center',...
                              'Position',[ sdinputstitlex sdinputstitley ...
                                           sdinputstitlew sdinputstitleh]);

sdinputsdirhand = uicontrol('Style','Text',...
                            'Units','Pixel',...
                            'BackGroundColor',textcolor,...
                            'String','',...
                            'HorizontalAlignment','Left',...
                             'Position',[ sdinputsdirx sdinputsdiry ...
                                          sdinputsdirw sdinputsdirh]);

sdinputsdumdirhand = uicontrol('Style','Text',...
                             'Units','Pixel',...
                             'BackGroundColor',textcolor,...
                             'String','Directory: ',...
                             'HorizontalAlignment','Left',...
                             'Position',[ sdinputsdumdirx sdinputsdumdiry ...
                                          sdinputsdumdirw sdinputsdumdirh]);

sdinputsnamehand = uicontrol('Style','Text',...
                             'Units','Pixel',...
                             'BackGroundColor',textcolor,...
                             'String','Filename: ',...
                             'HorizontalAlignment','Left',...
                             'Position',[ sdinputsnamex sdinputsnamey ...
                                          sdinputsnamew sdinputsnameh]);

sdoutputstitlehand = uicontrol('Style','Text',...
                               'Units','Pixel',...
                               'BackGroundColor',titlecolor,...
                               'ForeGroundColor',titleTextColor,...
                               'String','sdoutputs()',...			
                               'HorizontalAlignment','Center',...
                               'Position',[ sdoutputstitlex sdoutputstitley ...
                                            sdoutputstitlew sdoutputstitleh]);

sdoutputsdirhand = uicontrol('Style','Text',...
                             'Units','Pixel',...
                             'BackGroundColor',textcolor,...
                             'String','',...
                             'HorizontalAlignment','Left',...
                             'Position',[ sdoutputsdirx sdoutputsdiry ...
                                          sdoutputsdirw sdoutputsdirh]);

sdoputsdumdirhand = uicontrol('Style','Text',...
                              'Units','Pixel',...
                              'BackGroundColor',textcolor,...
                              'String','Directory: ',...
                              'HorizontalAlignment','Left',...
                              'Position',[ sdoutputsdumdirx sdoutputsdumdiry ...
                                           sdoutputsdumdirw sdoutputsdumdirh]);

sdoutputsnamehnd = uicontrol('Style','Text',...
                             'Units','Pixel',...
                             'BackGroundColor',textcolor,...
                             'String','Filename: ',...
                             'HorizontalAlignment','Left',...
                             'Position',[ sdoutputsnamex sdoutputsnamey ...
                                          sdoutputsnamew sdoutputsnameh]);

sdparamstitlehand = uicontrol('Style','Text',...
                              'Units','Pixel',...
                              'BackGroundColor',titlecolor,...
                              'ForeGroundColor',titleTextColor,...
                              'String','System Parameters',...
                              'HorizontalAlignment','Center',...
                              'Position',[ sdparamstitlex sdparamstitley ...
                                           sdparamstitlew sdparamstitleh]);

sdparamsq0hand = uicontrol('Style','Text',...
                           'Units','Pixel',...
                           'BackGroundColor',textcolor,...
                           'String','q0 = ',...
                           'HorizontalAlignment','Left',...
                           'Position',[ sdparamsq0x sdparamsq0y ...
                                        sdparamsq0w sdparamsq0h]);

sdparamsu0hand = uicontrol('Style','Text',...
                           'Units','Pixel',...
                           'BackGroundColor',textcolor,...
                           'String','u0 = ',...
                           'HorizontalAlignment','Left',...
                           'Position',[ sdparamsu0x sdparamsu0y ...
                                        sdparamsu0w sdparamsu0h]);

sdparamslockqhand = uicontrol('Style','Text',...
                              'Units','Pixel',...
                              'BackGroundColor',textcolor,...
                              'String','Locked q0''s: ',...
                              'HorizontalAlignment','Left',...
                              'Position',[ sdparamslockqx sdparamslockqy ...
                                           sdparamslockqw sdparamslockqh]);

sdparamslockuhand = uicontrol('Style','Text',...
                              'Units','Pixel',...
                              'BackGroundColor',textcolor,...
                              'String','Locked u0''s: ',...
                              'HorizontalAlignment','Left',...
                              'Position',[ sdparamslockux sdparamslockuy ...
                                           sdparamslockuw sdparamslockuh]);

sdparamsinputshnd = uicontrol('Style','Text',...
                               'Units','Pixel',...
                               'BackGroundColor',textcolor,...
                               'String','Size of inputs vector: ',...
                               'HorizontalAlignment','Left',...
                               'Position',[ sdparamsinputsx sdparamsinputsy ...
                                            sdparamsinputsw sdparamsinputsh]);

sdparamsoutputshnd = uicontrol('Style','Text',...
                                'Units','Pixel',...
                                'BackGroundColor',textcolor,...
                                'String','Size of outputs vector: ',...
                                'HorizontalAlignment','Left',...
                                'Position',[ sdparamsoutputsx sdparamsoutputsy ...
                                             sdparamsoutputsw sdparamsoutputsh]);

sdparamstolqhand = uicontrol('Style','Text',...
                             'Units','Pixel',...
                             'BackGroundColor',textcolor,...
                             'String','q0 Tolerance:',...
                             'HorizontalAlignment','Left',...
                             'Position',[ sdparamstolqx sdparamstolqy ...
                                          sdparamstolqw sdparamstolqh]);

sdparamstoluhand = uicontrol('Style','Text',...
                             'Units','Pixel',...
                             'BackGroundColor',textcolor,...
                             'String','u0 Tolerance:',...
                             'HorizontalAlignment','Left',...
                             'Position',[ sdparamstolux sdparamstoluy ...
                                          sdparamstoluw sdparamstoluh]);


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% define edit objects
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
sdfileedithand = uicontrol('Style','Edit',...
                           'Units','Pixel',...
                           'BackGroundColor',editcolor,...
                           'String','no file specified',...
                           'HorizontalAlignment','Left',...
                           'CallBack','sdfndfil',...
                           'Interruptible','Yes',...
                           'Position',[ sdfileeditx sdfileedity ...
                                        sdfileeditw sdfileedith]);

sdinputsedithand = uicontrol('Style','Edit',...
                             'Units','Pixel',...
                             'BackGroundColor',editcolor,...
                             'String','no file specified',...
                             'HorizontalAlignment','Left',...
                             'CallBack','sdfndfil',...
                             'Interruptible','Yes',...
                             'Position',[ sdinputseditx sdinputsedity ...
                                          sdinputseditw sdinputsedith]);

sdoutputsedithand = uicontrol('Style','Edit',...
                              'Units','Pixel',...
                              'BackGroundColor',editcolor,...
                              'String','no file specified',...
                              'HorizontalAlignment','Left',...
                              'CallBack','sdfndfil',...
                              'Interruptible','Yes',...
                              'Position',[ sdoutputseditx sdoutputsedity ...
                                           sdoutputseditw sdoutputsedith]);

sdparamsq0edithand = uicontrol('Style','Edit',...
                               'Units','Pixel',...
                               'BackGroundColor',editcolor,...
                               'String','[ ]',...
                               'HorizontalAlignment','Left',...
                               'CallBack','sdparams',...
                               'Interruptible','Yes',...
                               'Position',[ sdparamsq0editx sdparamsq0edity ...
                                            sdparamsq0editw sdparamsq0edith]);

sdparamsu0edithand = uicontrol('Style','Edit',...
                               'Units','Pixel',...
                               'BackGroundColor',editcolor,...
                               'String','[ ]',...
                               'HorizontalAlignment','Left',...
                               'CallBack','sdparams',...
                               'Interruptible','Yes',...
                               'Position',[ sdparamsu0editx sdparamsu0edity ...
                                            sdparamsu0editw sdparamsu0edith]);

sdparaminedthand = uicontrol('Style','Edit',...
                             'Units','Pixel',...
                             'BackGroundColor',editcolor,...
                             'String','?',...
                             'HorizontalAlignment','Left',...
                             'CallBack','sdparams',...
                             'Position',[ sdparamsinputsedtx sdparamsinputsedty ...
                                          sdparamsinputsedtw sdparamsinputsedth]);

sdparamoutedthand = uicontrol('Style','Edit',...
                              'Units','Pixel',...
                              'BackGroundColor',editcolor,...
                              'String','?',...
                              'HorizontalAlignment','Left',...
                              'CallBack','sdparams',...
                              'Position',[ sdparamsoutputsedtx sdparamsoutputsedty ...
                                           sdparamsoutputsedtw sdparamsoutputsedth]);

sdparmslckqedthand = uicontrol('Style','Edit',...
                                'Units','Pixel',...
                                'BackGroundColor',editcolor,...
                                'String','[ ]',...
                                'HorizontalAlignment','Left',...
                                'CallBack','sdparams',...
                                'Interruptible','Yes',...
                                'Position',[ sdparamslockqeditx sdparamslockqedity ...
                                             sdparamslockqeditw sdparamslockqedith]);

sdparmslckuedthand = uicontrol('Style','Edit',...
                                'Units','Pixel',...
                                'BackGroundColor',editcolor,...
                                'String','[ ]',...
                                'HorizontalAlignment','Left',...
                                'CallBack','sdparams',...
                                'Interruptible','Yes',...
                                'Position',[ sdparamslockueditx sdparamslockuedity ...
                                             sdparamslockueditw sdparamslockuedith]);

sdparmstolqedthand = uicontrol('Style','Edit',...
                               'Units','Pixel',...
                               'BackGroundColor',editcolor,...
                               'String','.001',...
                               'HorizontalAlignment','Left',...
                               'CallBack','sdparams',...
                               'Position',[ sdparamstolqedtx sdparamstolqedty ...
                                            sdparamstolqedtw sdparamstolqedth]);

sdparmstoluedthand = uicontrol('Style','Edit',...
                               'Units','Pixel',...
                               'BackGroundColor',editcolor,...
                               'String','.001',...
                               'HorizontalAlignment','Left',...
                               'CallBack','sdparams',...
                               'Position',[ sdparamstoluedtx sdparamstoluedty ...
                                            sdparamstoluedtw sdparamstoluedth]);


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% define button objects
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%  
sdfilebuthand = uicontrol('Style','PushButton',...
                          'Interruptible','Yes',...
                          'Units','Pixel',...
                          'BackGroundColor',butcolor,...
                          'String','Edit',...
                          'CallBack','sdedit('''')',...
                          'Position',[ sdfilebutx sdfilebuty ...
                                       sdfilebutw sdfilebuth ]);

sdinputsbuthand = uicontrol('Style','PushButton',...
                            'Interruptible','Yes',....
                            'Units','Pixel',...
                            'BackGroundColor',butcolor,...
                            'String','Edit',...
                            'CallBack','sdedit('''')',...
                            'Position',[ sdinputsbutx sdinputsbuty ...
                                         sdinputsbutw sdinputsbuth ]);

sdoutputsbuthand = uicontrol('Style','PushButton',...
                          'Interruptible','Yes',...
                             'Units','Pixel',...
                             'BackGroundColor',butcolor,...
                             'String','Edit',...
                             'CallBack','sdedit('''')',...
                             'Position',[ sdoutputsbutx sdoutputsbuty ...
                                          sdoutputsbutw sdoutputsbuth ]);

sdbuildbuthand = uicontrol('Style','PushButton',...
                           'Units','Pixel',...
                           'BackGroundColor',butcolor,...
                           'String','Build',...
                           'Interruptible','Yes',...
                           'CallBack','sdbuild(''not'')',...
                           'Position',[ sdbuildbutx sdbuildbuty ...
                                        sdbuildbutw sdbuildbuth ]);

sddonebuthand = uicontrol('Style','PushButton',...
                          'Units','Pixel',...
                          'BackGroundColor',butcolor,...
                          'String','Done',...
                          'CallBack','set(gcf,''Visible'',''Off'')',...
                          'Position',[ sddonebutx sddonebuty ...
                                       sddonebutw sddonebuth ]);

sdfilefndbuthand = uicontrol('Style','PushButton',...
                             'Interruptible','Yes',...
                             'Units','Pixel',...
                             'BackGroundColor',butcolor,...
                             'String','Select New',...
                             'CallBack','sdgetfil(''sd'')',...
                             'Position',[ sdfilefndbutx sdfilefndbuty ...
                                          sdfilefndbutw sdfilefndbuth ]);

sdinpfndbuthand = uicontrol('Style','PushButton',...
                             'Interruptible','Yes',...
                             'Units','Pixel',...
                             'BackGroundColor',butcolor,...
                             'String','Select New',...
                             'CallBack','sdgetfil(''i'')',...
                             'Position',[ sdinpfndbutx sdinpfndbuty ...
                                          sdinpfndbutw sdinpfndbuth ]);

sdonpfndbuthand = uicontrol('Style','PushButton',...
                             'Interruptible','Yes',...
                             'Units','Pixel',...
                             'BackGroundColor',butcolor,...
                             'String','Select New',...
                             'CallBack','sdgetfil(''o'')',...
                             'Position',[ sdonpfndbutx sdonpfndbuty ...
                                          sdonpfndbutw sdonpfndbuth ]);

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% stuff all handles into the UserData of the Control Panel
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

handles = [ statustexthand
            editmodehand
            sdsimulinksyshand
            sdfiledirhand
            sdfileedithand
            sdfilebuthand 
            sdinputsdirhand
            sdinputsedithand
            sdinputsbuthand 
            sdoutputsdirhand
            sdoutputsedithand
            sdoutputsbuthand            
            sdparamsq0edithand
            sdparamsu0edithand
            sdparaminedthand
            sdparamoutedthand
            sdparmslckqedthand
            sdparmslckuedthand
            sdparmstolqedthand
            sdparmstoluedthand            
];

set(fig,'UserData',handles);
set(fig,'Pointer','Arrow');
delete(hBuildingDisclaimer);
hPixObj = findobj(fig,'Unit','pixels');
drawnow;
set(hPixObj,'Unit','Normal');


