function [ret,x0,str,ts,xts]=s_h(t,x,u,flag);
%S_H	is the M-file description of the SIMULINK system named S_H.
%	The block-diagram can be displayed by typing: S_H.

%       Sample&Hold model created in February 1996 by:
%       Paul Popescu
%       Telecommunications and Signal Processing Laboratory
%       McGill University
%       3480 University st. Rm.751      
%       Montreal, Quebec, Canada  H3A 2A7      
%       Phone: (514)398-5486  
%       e-mail: popescu@tsp.ee.mcgill.ca       

%	SYS=S_H(T,X,U,FLAG) returns depending on FLAG certain
%	system values given time point, T, current state vector, X,
%	and input vector, U.
%	FLAG is used to indicate the type of output to be returned in SYS.
%
%	Setting FLAG=1 causes S_H to return state derivatives, FLAG=2
%	discrete states, FLAG=3 system outputs and FLAG=4 next sample
%	time. For more information and other options see SFUNC.
%
%	Calling S_H with a FLAG of zero:
%	[SIZES]=S_H([],[],[],0),  returns a vector, SIZES, which
%	contains the sizes of the state vector and other parameters.
%		SIZES(1) number of states
%		SIZES(2) number of discrete states
%		SIZES(3) number of outputs
%		SIZES(4) number of inputs
%		SIZES(5) number of roots (currently unsupported)
%		SIZES(6) direct feedthrough flag
%		SIZES(7) number of sample times
%
%	For the definition of other parameters in SIZES, see SFUNC.
%	See also, TRIM, LINMOD, LINSIM, EULER, RK23, RK45, ADAMS, GEAR.

% Note: This M-file is only used for saving graphical information;
%       after the model is loaded into memory an internal model
%       representation is used.

% the system will take on the name of this mfile:
sys = mfilename;
new_system(sys)
simver(1.3)
if (0 == (nargin + nargout))
     set_param(sys,'Location',[100,100,600,400])
     open_system(sys)
end;
set_param(sys,'algorithm',     'RK-45')
set_param(sys,'Start time',    '0.0')
set_param(sys,'Stop time',     '999999')
set_param(sys,'Min step size', '0.0001')
set_param(sys,'Max step size', '10')
set_param(sys,'Relative error','1e-3')
set_param(sys,'Return vars',   '')


%     Subsystem  'S&H'.

new_system([sys,'/','S&H'])
set_param([sys,'/','S&H'],'Location',[20,30081131,574,30081400])

add_block('built-in/Inport',[sys,'/','S&H/in_2'])
set_param([sys,'/','S&H/in_2'],...
		'Port','2',...
		'position',[30,115,50,135])

add_block('built-in/Outport',[sys,'/','S&H/out_1'])
set_param([sys,'/','S&H/out_1'],...
		'position',[505,115,525,135])

add_block('built-in/Inport',[sys,'/','S&H/in_1'])
set_param([sys,'/','S&H/in_1'],...
		'position',[95,55,115,75])

add_block('built-in/Memory',[sys,'/','S&H/Memory'])
set_param([sys,'/','S&H/Memory'],...
		'position',[425,110,465,140])

add_block('built-in/Switch',[sys,'/','S&H/Switch'])
set_param([sys,'/','S&H/Switch'],...
		'Threshold','0.1',...
		'position',[360,109,390,141])

add_block('built-in/Memory',[sys,'/','S&H/Memory1'])
set_param([sys,'/','S&H/Memory1'],...
		'position',[235,110,275,140])

add_block('built-in/Switch',[sys,'/','S&H/Switch1'])
set_param([sys,'/','S&H/Switch1'],...
		'Threshold','0.1',...
		'position',[170,109,200,141])

add_block('built-in/Memory',[sys,'/','S&H/Memory2'])
set_param([sys,'/','S&H/Memory2'],...
		'position',[190,180,230,210])

add_block('built-in/Constant',[sys,'/','S&H/Constant1'])
set_param([sys,'/','S&H/Constant1'],...
		'Value','0',...
		'position',[60,175,80,195])

add_block('built-in/Relational Operator',[sys,'/',['S&H/Relational',13,'Operator']])
set_param([sys,'/',['S&H/Relational',13,'Operator']],...
		'Operator','<=',...
		'position',[105,118,135,142])
add_line([sys,'/','S&H'],[470,125;485,125;485,160;340,160;340,135;355,135])
add_line([sys,'/','S&H'],[395,125;420,125])
add_line([sys,'/','S&H'],[280,125;305,125;305,160;150,160;150,135;165,135])
add_line([sys,'/','S&H'],[205,125;230,125])
add_line([sys,'/','S&H'],[305,125;305,115;355,115])
add_line([sys,'/','S&H'],[120,65;135,65;135,115;165,115])
add_line([sys,'/','S&H'],[85,185;90,185;100,135])
add_line([sys,'/','S&H'],[55,125;100,125])
add_line([sys,'/','S&H'],[70,125;70,160;100,160;100,195;185,195])
add_line([sys,'/','S&H'],[235,195;322,195;322,125;355,125])
add_line([sys,'/','S&H'],[140,130;145,130;145,125;165,125])
add_line([sys,'/','S&H'],[485,125;500,125])
set_param([sys,'/','S&H'],...
		'Mask Display','IN     \n\n     OUT\n\n^S /H    ',...
		'Mask Type','Sample and Hold',...
		'Mask Dialogue','S&H:',...
		'Mask Help','The circuit samples on the raising edge of the clock.')


%     Finished composite block 'S&H'.

set_param([sys,'/','S&H'],...
		'position',[195,131,245,209])

drawnow

% Return any arguments.
if (nargin | nargout)
	% Must use feval here to access system in memory
	if (nargin > 3)
		if (flag == 0)
			eval(['[ret,x0,str,ts,xts]=',sys,'(t,x,u,flag);'])
		else
			eval(['ret =', sys,'(t,x,u,flag);'])
		end
	else
		[ret,x0,str,ts,xts] = feval(sys);
	end
else
	drawnow % Flash up the model and execute load callback
end

