function [ret,x0,str,ts,xts]=s_h_test(t,x,u,flag);
%S_H_TEST	is the M-file description of the SIMULINK system named S_H_TEST.
%	The block-diagram can be displayed by typing: S_H_TEST.

%       Test circuit for S&H model created in February 1996 by:
%       Paul Popescu
%       Telecommunications and Signal Processing Laboratory
%       McGill University
%       3480 University st. Rm.751      
%       Montreal, Quebec, Canada  H3A 2A7      
%       Phone: (514)398-5486  
%       e-mail: popescu@tsp.ee.mcgill.ca       

%	SYS=S_H_TEST(T,X,U,FLAG) returns depending on FLAG certain
%	system values given time point, T, current state vector, X,
%	and input vector, U.
%	FLAG is used to indicate the type of output to be returned in SYS.
%
%	Setting FLAG=1 causes S_H_TEST to return state derivatives, FLAG=2
%	discrete states, FLAG=3 system outputs and FLAG=4 next sample
%	time. For more information and other options see SFUNC.
%
%	Calling S_H_TEST with a FLAG of zero:
%	[SIZES]=S_H_TEST([],[],[],0),  returns a vector, SIZES, which
%	contains the sizes of the state vector and other parameters.
%		SIZES(1) number of states
%		SIZES(2) number of discrete states
%		SIZES(3) number of outputs
%		SIZES(4) number of inputs
%		SIZES(5) number of roots (currently unsupported)
%		SIZES(6) direct feedthrough flag
%		SIZES(7) number of sample times
%
%	For the definition of other parameters in SIZES, see SFUNC.
%	See also, TRIM, LINMOD, LINSIM, EULER, RK23, RK45, ADAMS, GEAR.

% Note: This M-file is only used for saving graphical information;
%       after the model is loaded into memory an internal model
%       representation is used.

% the system will take on the name of this mfile:
sys = mfilename;
new_system(sys)
simver(1.3)
if (0 == (nargin + nargout))
     set_param(sys,'Location',[368,622,868,922])
     open_system(sys)
end;
set_param(sys,'algorithm',     'RK-45')
set_param(sys,'Start time',    '0.0')
set_param(sys,'Stop time',     '39e-6')
set_param(sys,'Min step size', '1e-7')
set_param(sys,'Max step size', '1e-7')
set_param(sys,'Relative error','1e-3')
set_param(sys,'Return vars',   '')


%     Subsystem  ['Repeating',13,'Sequence'].

new_system([sys,'/',['Repeating',13,'Sequence']])
set_param([sys,'/',['Repeating',13,'Sequence']],'Location',[5,40,315,196])

add_block('built-in/Outport',[sys,'/',['Repeating',13,'Sequence/out_1']])
set_param([sys,'/',['Repeating',13,'Sequence/out_1']],...
		'position',[285,60,305,80])

add_block('built-in/Look Up Table',[sys,'/',['Repeating',13,'Sequence/Look-Up Table']])
set_param([sys,'/',['Repeating',13,'Sequence/Look-Up Table']],...
		'Input_Values','t',...
		'Output_Values','y',...
		'position',[210,58,250,82])

add_block('built-in/Fcn',[sys,'/',['Repeating',13,'Sequence/Fcn1']])
set_param([sys,'/',['Repeating',13,'Sequence/Fcn1']],...
		'Expr','rem(u[1],period)',...
		'position',[110,60,150,80])

add_block('built-in/Clock',[sys,'/',['Repeating',13,'Sequence/Clock']])
set_param([sys,'/',['Repeating',13,'Sequence/Clock']],...
		'position',[45,60,65,80])
add_line([sys,'/',['Repeating',13,'Sequence']],[255,70;280,70])
add_line([sys,'/',['Repeating',13,'Sequence']],[70,70;105,70])
add_line([sys,'/',['Repeating',13,'Sequence']],[155,70;205,70])
set_param([sys,'/',['Repeating',13,'Sequence']],...
		'Mask Display','plot([t,t+period,t+2*period],[y,y,y])',...
		'Mask Type','Repeating table')
set_param([sys,'/',['Repeating',13,'Sequence']],...
		'Mask Dialogue','Repeating table.\nEnter values of time and output for first cycle.|Time values:|Output values:',...
		'Mask Translate','period = max(@1); t = @1; y = @2;')
set_param([sys,'/',['Repeating',13,'Sequence']],...
		'Mask Help','Repeats cycle given in table. Time values should be monotonically increasing.',...
		'Mask Entries','[0 1e-6 1.1e-6 2e-6 2.1e-6]\/[0 0 5 5 0]\/')


%     Finished composite block ['Repeating',13,'Sequence'].

set_param([sys,'/',['Repeating',13,'Sequence']],...
		'position',[95,117,130,153])


%     Subsystem  ['Display',13,''].

new_system([sys,'/',['Display',13,'']])
set_param([sys,'/',['Display',13,'']],'Location',[333,119,684,447])
open_system([sys,'/',['Display',13,'']])

add_block('built-in/Inport',[sys,'/',['Display',13,'/in_3']])
set_param([sys,'/',['Display',13,'/in_3']],...
		'Port','3',...
		'position',[75,240,95,260])

add_block('built-in/Inport',[sys,'/',['Display',13,'/in_2']])
set_param([sys,'/',['Display',13,'/in_2']],...
		'Port','2',...
		'position',[15,205,35,225])

add_block('built-in/Inport',[sys,'/',['Display',13,'/in_1']])
set_param([sys,'/',['Display',13,'/in_1']],...
		'position',[75,170,95,190])

add_block('built-in/Constant',[sys,'/',['Display',13,'/Constant']])
set_param([sys,'/',['Display',13,'/Constant']],...
		'Value','[5.1 0 -5.1]',...
		'position',[65,43,175,67])

add_block('built-in/Mux',[sys,'/',['Display',13,'/Mux']])
set_param([sys,'/',['Display',13,'/Mux']],...
		'inputs','3',...
		'position',[125,160,155,270])

add_block('built-in/Scope',[sys,'/',['Display',13,'/Scope']])
set_param([sys,'/',['Display',13,'/Scope']],...
		'Vgain','10.500000',...
		'Hgain','0.000039',...
		'Vmax','21.000000',...
		'Hmax','0.000081',...
		'Window',[153,322,818,457])
open_system([sys,'/',['Display',13,'/Scope']])
set_param([sys,'/',['Display',13,'/Scope']],...
		'position',[280,197,300,223])

add_block('built-in/Sum',[sys,'/',['Display',13,'/Sum']])
set_param([sys,'/',['Display',13,'/Sum']],...
		'position',[205,200,225,220])
add_line([sys,'/',['Display',13,'']],[100,250;120,250])
add_line([sys,'/',['Display',13,'']],[40,215;120,215])
add_line([sys,'/',['Display',13,'']],[100,180;120,180])
add_line([sys,'/',['Display',13,'']],[160,215;200,215])
add_line([sys,'/',['Display',13,'']],[230,210;275,210])
add_line([sys,'/',['Display',13,'']],[180,55;180,205;200,205])
set_param([sys,'/',['Display',13,'']],...
		'Mask Display','')


%     Finished composite block ['Display',13,''].

set_param([sys,'/',['Display',13,'']],...
		'position',[300,79,330,131])


%     Subsystem  'S&H'.

new_system([sys,'/','S&H'])
set_param([sys,'/','S&H'],'Location',[20,30081131,574,30081400])

add_block('built-in/Relational Operator',[sys,'/',['S&H/Relational',13,'Operator']])
set_param([sys,'/',['S&H/Relational',13,'Operator']],...
		'Operator','<=',...
		'position',[105,118,135,142])

add_block('built-in/Constant',[sys,'/','S&H/Constant1'])
set_param([sys,'/','S&H/Constant1'],...
		'Value','0',...
		'position',[60,175,80,195])

add_block('built-in/Memory',[sys,'/','S&H/Memory2'])
set_param([sys,'/','S&H/Memory2'],...
		'position',[190,180,230,210])

add_block('built-in/Switch',[sys,'/','S&H/Switch1'])
set_param([sys,'/','S&H/Switch1'],...
		'Threshold','0.1',...
		'position',[170,109,200,141])

add_block('built-in/Memory',[sys,'/','S&H/Memory1'])
set_param([sys,'/','S&H/Memory1'],...
		'position',[235,110,275,140])

add_block('built-in/Switch',[sys,'/','S&H/Switch'])
set_param([sys,'/','S&H/Switch'],...
		'Threshold','0.1',...
		'position',[360,109,390,141])

add_block('built-in/Memory',[sys,'/','S&H/Memory'])
set_param([sys,'/','S&H/Memory'],...
		'position',[425,110,465,140])

add_block('built-in/Inport',[sys,'/','S&H/in_1'])
set_param([sys,'/','S&H/in_1'],...
		'position',[95,55,115,75])

add_block('built-in/Outport',[sys,'/','S&H/out_1'])
set_param([sys,'/','S&H/out_1'],...
		'position',[505,115,525,135])

add_block('built-in/Inport',[sys,'/','S&H/in_2'])
set_param([sys,'/','S&H/in_2'],...
		'Port','2',...
		'position',[30,115,50,135])
add_line([sys,'/','S&H'],[470,125;485,125;485,160;340,160;340,135;355,135])
add_line([sys,'/','S&H'],[485,125;500,125])
add_line([sys,'/','S&H'],[140,130;145,130;145,125;165,125])
add_line([sys,'/','S&H'],[235,195;322,195;322,125;355,125])
add_line([sys,'/','S&H'],[55,125;100,125])
add_line([sys,'/','S&H'],[70,125;70,160;100,160;100,195;185,195])
add_line([sys,'/','S&H'],[85,185;90,185;100,135])
add_line([sys,'/','S&H'],[120,65;135,65;135,115;165,115])
add_line([sys,'/','S&H'],[280,125;305,125;305,160;150,160;150,135;165,135])
add_line([sys,'/','S&H'],[305,125;305,115;355,115])
add_line([sys,'/','S&H'],[205,125;230,125])
add_line([sys,'/','S&H'],[395,125;420,125])
set_param([sys,'/','S&H'],...
		'Mask Display','IN     \n\n     OUT\n\n^S /H    ',...
		'Mask Type','Sample and Hold',...
		'Mask Dialogue','S&H:',...
		'Mask Help','The circuit samples on the raising edge of the clock.')


%     Finished composite block 'S&H'.

set_param([sys,'/','S&H'],...
		'position',[195,76,245,154])

add_block('built-in/Signal Generator',[sys,'/',['Signal',13,'Generator']])
set_param([sys,'/',['Signal',13,'Generator']],...
		'Peak','1.000000',...
		'Peak Range','5.000000',...
		'Freq','628000.000000',...
		'Freq Range','Inf',...
		'Wave','Sin',...
		'Units','Rads',...
		'position',[70,48,115,82])
add_line(sys,[135,135;190,135])
add_line(sys,[120,65;150,65;150,95;190,95])
add_line(sys,[250,115;265,115;265,120;295,120])
add_line(sys,[155,135;155,170;275,170;275,90;295,90])
add_line(sys,[150,65;285,65;295,105])

drawnow

% Return any arguments.
if (nargin | nargout)
	% Must use feval here to access system in memory
	if (nargin > 3)
		if (flag == 0)
			eval(['[ret,x0,str,ts,xts]=',sys,'(t,x,u,flag);'])
		else
			eval(['ret =', sys,'(t,x,u,flag);'])
		end
	else
		[ret,x0,str,ts,xts] = feval(sys);
	end
else
	drawnow % Flash up the model and execute load callback
end

