function [ret,x0,str,ts,xts]=bussamp1(t,x,u,flag);
%BUSSAMP1	is the M-file description of the SIMULINK system named BUSSAMP1.
%	The block-diagram can be displayed by typing: BUSSAMP1.
%
%	SYS=BUSSAMP1(T,X,U,FLAG) returns depending on FLAG certain
%	system values given time point, T, current state vector, X,
%	and input vector, U.
%	FLAG is used to indicate the type of output to be returned in SYS.
%
%	Setting FLAG=1 causes BUSSAMP1 to return state derivatives, FLAG=2
%	discrete states, FLAG=3 system outputs and FLAG=4 next sample
%	time. For more information and other options see SFUNC.
%
%	Calling BUSSAMP1 with a FLAG of zero:
%	[SIZES]=BUSSAMP1([],[],[],0),  returns a vector, SIZES, which
%	contains the sizes of the state vector and other parameters.
%		SIZES(1) number of states
%		SIZES(2) number of discrete states
%		SIZES(3) number of outputs
%		SIZES(4) number of inputs
%		SIZES(5) number of roots (currently unsupported)
%		SIZES(6) direct feedthrough flag
%		SIZES(7) number of sample times
%
%	For the definition of other parameters in SIZES, see SFUNC.
%	See also, TRIM, LINMOD, LINSIM, EULER, RK23, RK45, ADAMS, GEAR.

% Note: This M-file is only used for saving graphical information;
%       after the model is loaded into memory an internal model
%       representation is used.

% the system will take on the name of this mfile:
sys = mfilename;
new_system(sys)
simver(1.3)
if (0 == (nargin + nargout))
     set_param(sys,'Location',[80,60,642,420])
     open_system(sys)
end;
set_param(sys,'algorithm',     'RK-45')
set_param(sys,'Start time',    '0.0')
set_param(sys,'Stop time',     '2')
set_param(sys,'Min step size', '1')
set_param(sys,'Max step size', '10')
set_param(sys,'Relative error','1e-3')
set_param(sys,'Return vars',   '')
set_param(sys,'AssignWideVectorLines','on');

add_block('built-in/To Workspace',[sys,'/','To Workspace4'])
set_param([sys,'/','To Workspace4'],...
		'hide name',0,...
		'Font Name','helvetica',...
		'mat-name','bus3_out',...
		'position',[470,130,530,150])

add_block('built-in/To Workspace',[sys,'/','To Workspace3'])
set_param([sys,'/','To Workspace3'],...
		'hide name',0,...
		'Font Name','helvetica',...
		'mat-name','bus2_out',...
		'position',[470,55,530,75])

add_block('built-in/To Workspace',[sys,'/','To Workspace6'])
set_param([sys,'/','To Workspace6'],...
		'hide name',0,...
		'Font Name','helvetica',...
		'mat-name','b_a_out',...
		'position',[470,255,530,275])

add_block('built-in/Constant',[sys,'/','beta'])
set_param([sys,'/','beta'],...
		'Font Name','helvetica',...
		'position',[30,242,75,268])

add_block('built-in/Mux',[sys,'/','mux'])
set_param([sys,'/','mux'],...
		'inputs','2',...
		'position',[400,239,430,286])

add_block('built-in/To Workspace',[sys,'/','To Workspace5'])
set_param([sys,'/','To Workspace5'],...
		'hide name',0,...
		'Font Name','helvetica',...
		'mat-name','bus1_out',...
		'position',[470,190,530,210])

add_block('built-in/Constant',[sys,'/','Delta'])
set_param([sys,'/','Delta'],...
		'Font Name','helvetica',...
		'Value','1:4',...
		'Mask Display','',...
		'position',[50,52,95,78])

add_block('built-in/Constant',[sys,'/','alpha'])
set_param([sys,'/','alpha'],...
		'Font Name','helvetica',...
		'Value','1:4',...
		'position',[30,177,75,203])


%     Subsystem  'Combine'.

new_system([sys,'/','Combine'])
set_param([sys,'/','Combine'],'Location',[21,53,271,199])

add_block('built-in/Inport',[sys,'/','Combine/I1'])
set_param([sys,'/','Combine/I1'],...
		'position',[15,35,35,55])

add_block('built-in/Inport',[sys,'/','Combine/I2'])
set_param([sys,'/','Combine/I2'],...
		'Port','2',...
		'position',[15,80,35,100])

add_block('built-in/Mux',[sys,'/','Combine/Mux'])
set_param([sys,'/','Combine/Mux'],...
		'inputs','2',...
		'Mask Display','Combine\nBuses',...
		'Mask Type','Combine Buses(Text)')
set_param([sys,'/','Combine/Mux'],...
		'Mask Dialogue','Combines (muxes) two SIMULINK DataBus vectors.|Output bus name:|Input bus names (separated by \|):|Show bus names(0 or 1):',...
		'Mask Translate',' ')
set_param([sys,'/','Combine/Mux'],...
		'Mask Entries','''bus3''\/''bus2|bus1''\/1\/',...
		'position',[70,35,125,75])

add_block('built-in/Outport',[sys,'/','Combine/O1'])
set_param([sys,'/','Combine/O1'],...
		'position',[155,45,175,65])
add_line([sys,'/','Combine'],[40,45;65,45])
add_line([sys,'/','Combine'],[130,55;150,55])
add_line([sys,'/','Combine'],[40,90;65,65])
set_param([sys,'/','Combine'],...
		'Mask Display','bus2   \n\n   bus3\n\nbus1   ',...
		'Mask Type','Combine Buses(Gui)',...
		'Mask Dialogue','eval(''busmuxui(''''Init'''')'')')


%     Finished composite block 'Combine'.

set_param([sys,'/','Combine'],...
		'Font Name','courier',...
		'position',[285,103,350,172])


%     Subsystem  'Bus1'.

new_system([sys,'/','Bus1'])
set_param([sys,'/','Bus1'],'Location',[26,62,296,301])

add_block('built-in/Mux',[sys,'/','Bus1/Mux'])
set_param([sys,'/','Bus1/Mux'],...
		'inputs','[15 4 1]',...
		'position',[90,39,115,151])

add_block('built-in/Inport',[sys,'/','Bus1/I3'])
set_param([sys,'/','Bus1/I3'],...
		'Port','2',...
		'position',[20,120,40,140])

add_block('built-in/Inport',[sys,'/','Bus1/I2'])
set_param([sys,'/','Bus1/I2'],...
		'position',[20,75,40,95])

add_block('built-in/Outport',[sys,'/','Bus1/O1'])
set_param([sys,'/','Bus1/O1'],...
		'position',[215,55,235,75])

add_block('built-in/State-Space',[sys,'/','Bus1/Bus'])
set_param([sys,'/','Bus1/Bus'],...
		'A','[] % ''bus 1''',...
		'B','[] % ''alpha|beta''',...
		'C','[] % [0; 1]',...
		'D','busdmat([16 17 18 19 5 6 20 8 9 10 11 12 13 14 15],20)',...
		'Mask Display','Insert\nSignal(s)')
set_param([sys,'/','Bus1/Bus'],...
		'Mask Type','Insert Signal(s)',...
		'Mask Dialogue','Insert Signal(s)|BusName|Selected|ShowSizes|ShowNames',...
		'Mask Entries','''bus1''\/''alpha|beta''\/1\/1\/',...
		'position',[135,41,190,89])

add_block('built-in/Constant',[sys,'/','Bus1/I1'])
set_param([sys,'/','Bus1/I1'],...
		'Value','[0; 0; 0; 0; 0; 0; 0; 0; 0; 0; 0; 0; 0; 0; 0]',...
		'position',[20,40,40,60])
add_line([sys,'/','Bus1'],[45,130;85,130])
add_line([sys,'/','Bus1'],[120,95;130,65])
add_line([sys,'/','Bus1'],[45,85;55,85;55,95;85,95])
add_line([sys,'/','Bus1'],[195,65;210,65])
add_line([sys,'/','Bus1'],[45,50;60,50;60,60;85,60])
set_param([sys,'/','Bus1'],...
		'Mask Display','alpha[4]\n\nbeta [1]',...
		'Mask Type','Insert Signal(s)(Gui)',...
		'Mask Dialogue','eval(''bussel(''''Init'''')'')')


%     Finished composite block 'Bus1'.

set_param([sys,'/','Bus1'],...
		'Font Name','courier',...
		'position',[155,170,215,250])


%     Subsystem  'Select1'.

new_system([sys,'/','Select1'])
set_param([sys,'/','Select1'],'Location',[3,63,361,247])

add_block('built-in/State-Space',[sys,'/','Select1/Bus'])
set_param([sys,'/','Select1/Bus'],...
		'A','[]',...
		'B','[]',...
		'C','[]',...
		'D','busdmat([1 2 3 4 7],15)',...
		'Mask Display','Select\nSignal(s)',...
		'Mask Type','Select Signal(s)')
set_param([sys,'/','Select1/Bus'],...
		'Mask Dialogue','Select Signal(s)|BusName|Selected|ShowSizes|ShowNames',...
		'Mask Entries','''bus1''\/''alpha|beta''\/1\/1\/',...
		'position',[80,61,135,99])

add_block('built-in/Inport',[sys,'/','Select1/I1'])
set_param([sys,'/','Select1/I1'],...
		'position',[30,70,50,90])

add_block('built-in/Demux',[sys,'/','Select1/Demux'])
set_param([sys,'/','Select1/Demux'],...
		'outputs','[4, 1]',...
		'position',[160,62,205,98])

add_block('built-in/Outport',[sys,'/','Select1/O1'])
set_param([sys,'/','Select1/O1'],...
		'position',[250,60,270,80])

add_block('built-in/Outport',[sys,'/','Select1/O2'])
set_param([sys,'/','Select1/O2'],...
		'Port','2',...
		'position',[250,80,270,100])
add_line([sys,'/','Select1'],[55,80;75,80])
add_line([sys,'/','Select1'],[140,80;155,80])
add_line([sys,'/','Select1'],[210,70;245,70])
add_line([sys,'/','Select1'],[210,90;245,90])
set_param([sys,'/','Select1'],...
		'Mask Display','  alpha[4]\n\n   beta[1]',...
		'Mask Type','Select Signal(s)(Gui)',...
		'Mask Dialogue','eval(''bussel(''''Init'''')'')')


%     Finished composite block 'Select1'.

set_param([sys,'/','Select1'],...
		'Font Name','courier',...
		'position',[290,263,360,312])


%     Subsystem  'Bus2'.

new_system([sys,'/','Bus2'])
set_param([sys,'/','Bus2'],'Location',[404,216,674,479])

add_block('built-in/State-Space',[sys,'/','Bus2/Bus'])
set_param([sys,'/','Bus2/Bus'],...
		'A','[] % ''bus 1''',...
		'B','[] % ''alpha|beta''',...
		'C','[] % [0; 1]',...
		'D','busdmat([1 2 3 4 5 6 22 23 24 25 11 12 13 14 15 16 17 18 19 20 21],25)',...
		'Mask Display','Insert\nSignal(s)')
set_param([sys,'/','Bus2/Bus'],...
		'Mask Type','Insert Signal(s)',...
		'Mask Dialogue','Insert Signal(s)|BusName|Selected|ShowSizes|ShowNames',...
		'Mask Entries','''bus2''\/''Delta''\/1\/1\/',...
		'position',[135,41,190,89])

add_block('built-in/Outport',[sys,'/','Bus2/O1'])
set_param([sys,'/','Bus2/O1'],...
		'position',[215,55,235,75])

add_block('built-in/Inport',[sys,'/','Bus2/I2'])
set_param([sys,'/','Bus2/I2'],...
		'position',[20,75,40,95])

add_block('built-in/Mux',[sys,'/','Bus2/Mux'])
set_param([sys,'/','Bus2/Mux'],...
		'inputs','[21 4]',...
		'position',[90,41,115,154])

add_block('built-in/Constant',[sys,'/','Bus2/I1'])
set_param([sys,'/','Bus2/I1'],...
		'Value','[0; 0; 0; 0; 0; 0; 0; 0; 0; 0; 0; 0; 0; 0; 0; 0; 0; 0; 0; 0; 0]',...
		'position',[20,40,40,60])
add_line([sys,'/','Bus2'],[195,65;210,65])
add_line([sys,'/','Bus2'],[45,85;55,85;55,125;85,125])
add_line([sys,'/','Bus2'],[120,100;130,65])
add_line([sys,'/','Bus2'],[45,50;60,50;60,70;85,70])
set_param([sys,'/','Bus2'],...
		'Mask Display','Delta[4]',...
		'Mask Type','Insert Signal(s)(Gui)',...
		'Mask Dialogue','eval(''bussel(''''Init'''')'')')


%     Finished composite block 'Bus2'.

set_param([sys,'/','Bus2'],...
		'Font Name','courier',...
		'position',[155,25,215,105])
add_line(sys,[100,65;150,65])
add_line(sys,[355,140;465,140])
add_line(sys,[435,265;465,265])
add_line(sys,[80,255;120,255;120,230;150,230])
add_line(sys,[365,300;370,300;370,250;395,250])
add_line(sys,[220,65;465,65])
add_line(sys,[220,210;255,210;255,290;285,290])
add_line(sys,[255,65;255,120;280,120])
add_line(sys,[365,275;395,275])
add_line(sys,[255,215;255,200;465,200])
add_line(sys,[255,200;255,155;280,155])
add_line(sys,[80,190;150,190])

drawnow

% Return any arguments.
if (nargin | nargout)
	% Must use feval here to access system in memory
	if (nargin > 3)
		if (flag == 0)
			eval(['[ret,x0,str,ts,xts]=',sys,'(t,x,u,flag);'])
		else
			eval(['ret =', sys,'(t,x,u,flag);'])
		end
	else
		[ret,x0,str,ts,xts] = feval(sys);
	end
else
	drawnow % Flash up the model and execute load callback
end
