function [ret,x0,str,ts,xts]=lbblock(t,x,u,flag);
%LBBLOCK	is the M-file description of the SIMULINK system named LBBLOCK.
%	The block-diagram can be displayed by typing: LBBLOCK.
%
%	SYS=LBBLOCK(T,X,U,FLAG) returns depending on FLAG certain
%	system values given time point, T, current state vector, X,
%	and input vector, U.
%	FLAG is used to indicate the type of output to be returned in SYS.
%
%	Setting FLAG=1 causes LBBLOCK to return state derivatives, FLAG=2
%	discrete states, FLAG=3 system outputs and FLAG=4 next sample
%	time. For more information and other options see SFUNC.
%
%	Calling LBBLOCK with a FLAG of zero:
%	[SIZES]=LBBLOCK([],[],[],0),  returns a vector, SIZES, which
%	contains the sizes of the state vector and other parameters.
%		SIZES(1) number of states
%		SIZES(2) number of discrete states
%		SIZES(3) number of outputs
%		SIZES(4) number of inputs
%		SIZES(5) number of roots (currently unsupported)
%		SIZES(6) direct feedthrough flag
%		SIZES(7) number of sample times
%
%	For the definition of other parameters in SIZES, see SFUNC.
%	See also, TRIM, LINMOD, LINSIM, EULER, RK23, RK45, ADAMS, GEAR.

% Note: This M-file is only used for saving graphical information;
%       after the model is loaded into memory an internal model
%       representation is used.

% the system will take on the name of this mfile:
sys = mfilename;
new_system(sys)
simver(1.3)
if (0 == (nargin + nargout))
     set_param(sys,'Location',[479,144,790,227])
     open_system(sys)
end;
set_param(sys,'algorithm',     'RK-45')
set_param(sys,'Start time',    '0.0')
set_param(sys,'Stop time',     '999999')
set_param(sys,'Min step size', '0.0001')
set_param(sys,'Max step size', '10')
set_param(sys,'Relative error','1e-3')
set_param(sys,'Return vars',   '')

add_block('built-in/S-Function',[sys,'/','Loop Breaker'])
set_param([sys,'/','Loop Breaker'],...
		'ForeGround',2,...
		'hide name',0,...
		'function name','loopbrk',...
		'Mask Display','Loop\nBreaker',...
		'Mask Type','Loop Breaker',...
		'Mask Dialogue','Breaks algebraic loops.  Use carefully.')
set_param([sys,'/','Loop Breaker'],...
		'Mask Help','Use this block carefully as it may cause your block diagram to produce inaccurate results.',...
		'position',[30,15,80,55])

add_block('built-in/Note',[sys,'/',['Only use this block on lines ',13,'which you are sure do not form',13,'algebraic loops fundamental to',13,'your system.']])
set_param([sys,'/',['Only use this block on lines ',13,'which you are sure do not form',13,'algebraic loops fundamental to',13,'your system.']],...
		'ForeGround',2,...
		'position',[190,10,195,15])

drawnow

% Return any arguments.
if (nargin | nargout)
	% Must use feval here to access system in memory
	if (nargin > 3)
		if (flag == 0)
			eval(['[ret,x0,str,ts,xts]=',sys,'(t,x,u,flag);'])
		else
			eval(['ret =', sys,'(t,x,u,flag);'])
		end
	else
		[ret,x0,str,ts,xts] = feval(sys);
	end
else
	drawnow % Flash up the model and execute load callback
end
