function [ret,x0,str,ts,xts]=buslib(t,x,u,flag);
%BUSLIB	is the M-file description of the SIMULINK system named BUSLIB.
%	The block-diagram can be displayed by typing: BUSLIB.
%
%	SYS=BUSLIB(T,X,U,FLAG) returns depending on FLAG certain
%	system values given time point, T, current state vector, X,
%	and input vector, U.
%	FLAG is used to indicate the type of output to be returned in SYS.
%
%	Setting FLAG=1 causes BUSLIB to return state derivatives, FLAG=2
%	discrete states, FLAG=3 system outputs and FLAG=4 next sample
%	time. For more information and other options see SFUNC.
%
%	Calling BUSLIB with a FLAG of zero:
%	[SIZES]=BUSLIB([],[],[],0),  returns a vector, SIZES, which
%	contains the sizes of the state vector and other parameters.
%		SIZES(1) number of states
%		SIZES(2) number of discrete states
%		SIZES(3) number of outputs
%		SIZES(4) number of inputs
%		SIZES(5) number of roots (currently unsupported)
%		SIZES(6) direct feedthrough flag
%		SIZES(7) number of sample times
%
%	For the definition of other parameters in SIZES, see SFUNC.
%	See also, TRIM, LINMOD, LINSIM, EULER, RK23, RK45, ADAMS, GEAR.

% Note: This M-file is only used for saving graphical information;
%       after the model is loaded into memory an internal model
%       representation is used.

% the system will take on the name of this mfile:
sys = mfilename;
new_system(sys)
simver(1.3)
if (0 == (nargin + nargout))
     set_param(sys,'Location',[23,94,374,279])
     open_system(sys)
end;
set_param(sys,'algorithm',     'RK-45')
set_param(sys,'Start time',    '0.0')
set_param(sys,'Stop time',     '999999')
set_param(sys,'Min step size', '0.0001')
set_param(sys,'Max step size', '10')
set_param(sys,'Relative error','1e-3')
set_param(sys,'Return vars',   '')


%     Subsystem  'Insert'.

new_system([sys,'/','Insert'])
set_param([sys,'/','Insert'],'Location',[170,430,440,630])

add_block('built-in/Mux',[sys,'/','Insert/Mux'])
set_param([sys,'/','Insert/Mux'],...
		'inputs','[15 4]',...
		'position',[85,47,115,83])

add_block('built-in/Inport',[sys,'/','Insert/I1'])
set_param([sys,'/','Insert/I1'],...
		'position',[20,30,40,50])

add_block('built-in/Inport',[sys,'/','Insert/I2'])
set_param([sys,'/','Insert/I2'],...
		'Port','2',...
		'position',[20,75,40,95])

add_block('built-in/Outport',[sys,'/','Insert/O1'])
set_param([sys,'/','Insert/O1'],...
		'position',[215,55,235,75])

add_block('built-in/State-Space',[sys,'/','Insert/Bus'])
set_param([sys,'/','Insert/Bus'],...
		'A','[]',...
		'B','[]',...
		'C','[]',...
		'D','busdmat([16 17 18 19 5 6 7 8 9 10 11 12 13 14 15],19)',...
		'Mask Display','Insert\nSignal(s)',...
		'Mask Type','Insert Signal(s)(Text)')
set_param([sys,'/','Insert/Bus'],...
		'Mask Dialogue','Set signal values on a SIMULINK DataBus vector.|Bus name:|Signal names(separated by \|):|Show signal sizes(0 or 1):|Show bus and signal names(0 or 1):')
set_param([sys,'/','Insert/Bus'],...
		'Mask Translate','SelSig=addtobus(@1,@2); ',...
		'Mask Entries','''bus1''\/''alpha''\/0\/0\/',...
		'position',[135,41,190,89])
add_line([sys,'/','Insert'],[120,65;130,65])
add_line([sys,'/','Insert'],[45,85;55,85;55,75;80,75])
add_line([sys,'/','Insert'],[195,65;210,65])
add_line([sys,'/','Insert'],[45,40;55,40;55,55;80,55])
set_param([sys,'/','Insert'],...
		'Mask Display','Insert\nSignal(s)',...
		'Mask Type','Insert Signal(s)(Gui)',...
		'Mask Dialogue','eval(''bussel(''''Init'''')'')')


%     Finished composite block 'Insert'.

set_param([sys,'/','Insert'],...
		'Font Name','courier',...
		'position',[20,40,95,80])


%     Subsystem  'Help'.

new_system([sys,'/','Help'])
set_param([sys,'/','Help'],'Location',[246,346,682,460])

add_block('built-in/Note',[sys,'/',['Help/Use the "Insert Signal(s)" block to "initialize" a DataBus and//or ',13,'insert signals to an existing DataBus.',13,'Use the "Select Signal(s)" block to choose and re-order signals.',13,'Use the "Combine Buses" block to Mux multiple DatBus vectors.']])
set_param([sys,'/',['Help/Use the "Insert Signal(s)" block to "initialize" a DataBus and//or ',13,'insert signals to an existing DataBus.',13,'Use the "Select Signal(s)" block to choose and re-order signals.',13,'Use the "Combine Buses" block to Mux multiple DatBus vectors.']],...
		'position',[209,16,214,21])

add_block('built-in/Note',[sys,'/','Help/See the file "readme.txt" for more information.'])
set_param([sys,'/','Help/See the file "readme.txt" for more information.'],...
		'position',[215,90,220,95])
set_param([sys,'/','Help'],...
		'Mask Display','Help')


%     Finished composite block 'Help'.

set_param([sys,'/','Help'],...
		'position',[30,101,87,137])


%     Subsystem  'Select'.

new_system([sys,'/','Select'])
set_param([sys,'/','Select'],'Location',[265,500,607,693])

add_block('built-in/Outport',[sys,'/','Select/O1'])
set_param([sys,'/','Select/O1'],...
		'position',[250,40,270,60])

add_block('built-in/Demux',[sys,'/','Select/Demux'])
set_param([sys,'/','Select/Demux'],...
		'outputs','1',...
		'position',[160,32,205,68])

add_block('built-in/Inport',[sys,'/','Select/I1'])
set_param([sys,'/','Select/I1'],...
		'position',[30,40,50,60])

add_block('built-in/State-Space',[sys,'/','Select/Bus'])
set_param([sys,'/','Select/Bus'],...
		'A','[]',...
		'B','[]',...
		'C','[]',...
		'D','busdmat([1 2 3 4],15)',...
		'Mask Display','Select\nSignal(s)',...
		'Mask Type','Select Signal(s)(Text)')
set_param([sys,'/','Select/Bus'],...
		'Mask Dialogue','Allows selection of signals from a SIMULINK DataBus vector.|Bus name:|Signal names(separated by \|):|Show signal sizes(0 or 1):|Show signal names(0 or 1):')
set_param([sys,'/','Select/Bus'],...
		'Mask Translate','SelSig=parsebus(@1,@2);',...
		'Mask Entries','''bus1''\/''alpha''\/0\/0\/',...
		'position',[80,31,135,69])
add_line([sys,'/','Select'],[210,50;245,50])
add_line([sys,'/','Select'],[140,50;155,50])
add_line([sys,'/','Select'],[55,50;75,50])
set_param([sys,'/','Select'],...
		'Mask Display','Select\nSignal(s)',...
		'Mask Type','Select Signal(s)(Gui)',...
		'Mask Dialogue','eval(''bussel(''''Init'''')'')')


%     Finished composite block 'Select'.

set_param([sys,'/','Select'],...
		'Font Name','courier',...
		'position',[150,40,220,80])


%     Subsystem  'Demos'.

new_system([sys,'/','Demos'])
set_param([sys,'/','Demos'],'Location',[44,136,318,290])


%     Subsystem  'Demos/Sample1'.

new_system([sys,'/','Demos/Sample1'])
set_param([sys,'/','Demos/Sample1'],'Location',[313,205,520,347])
set_param([sys,'/','Demos/Sample1'],...
		'Mask Display','',...
		'Mask Dialogue','eval(''bussamp1'')')


%     Finished composite block 'Demos/Sample1'.

set_param([sys,'/','Demos/Sample1'],...
		'position',[25,25,75,65])


%     Subsystem  'Demos/Sample2'.

new_system([sys,'/','Demos/Sample2'])
set_param([sys,'/','Demos/Sample2'],'Location',[313,205,520,347])
set_param([sys,'/','Demos/Sample2'],...
		'Mask Display','',...
		'Mask Dialogue','eval(''bussamp2'')')


%     Finished composite block 'Demos/Sample2'.

set_param([sys,'/','Demos/Sample2'],...
		'position',[95,25,145,65])
set_param([sys,'/','Demos'],...
		'Mask Display','Demos')


%     Finished composite block 'Demos'.

set_param([sys,'/','Demos'],...
		'position',[271,100,331,140])


%     Subsystem  'Combine'.

new_system([sys,'/','Combine'])
set_param([sys,'/','Combine'],'Location',[21,53,271,199])

add_block('built-in/Outport',[sys,'/','Combine/O1'])
set_param([sys,'/','Combine/O1'],...
		'position',[155,45,175,65])

add_block('built-in/Mux',[sys,'/','Combine/Mux'])
set_param([sys,'/','Combine/Mux'],...
		'inputs','2',...
		'Mask Display','Combine\nBuses',...
		'Mask Type','Combine Buses(Text)')
set_param([sys,'/','Combine/Mux'],...
		'Mask Dialogue','Combines (muxes) two SIMULINK DataBus vectors.|Output bus name:|Input bus names (separated by \|):|Show bus names(0 or 1):',...
		'Mask Translate',' ')
set_param([sys,'/','Combine/Mux'],...
		'Mask Entries','''bus3''\/''bus1|bus2''\/0\/',...
		'position',[70,35,125,75])

add_block('built-in/Inport',[sys,'/','Combine/I2'])
set_param([sys,'/','Combine/I2'],...
		'Port','2',...
		'position',[15,80,35,100])

add_block('built-in/Inport',[sys,'/','Combine/I1'])
set_param([sys,'/','Combine/I1'],...
		'position',[15,35,35,55])
add_line([sys,'/','Combine'],[40,90;65,65])
add_line([sys,'/','Combine'],[130,55;150,55])
add_line([sys,'/','Combine'],[40,45;65,45])
set_param([sys,'/','Combine'],...
		'Mask Display','Combine\nBuses',...
		'Mask Type','Combine Buses(Gui)',...
		'Mask Dialogue','eval(''busmuxui(''''Init'''')'')')


%     Finished composite block 'Combine'.

set_param([sys,'/','Combine'],...
		'Font Name','courier',...
		'position',[265,40,335,80])


%     Subsystem  'Select (muxed)'.

new_system([sys,'/','Select (muxed)'])
set_param([sys,'/','Select (muxed)'],'Location',[191,220,477,362])

add_block('built-in/Outport',[sys,'/','Select (muxed)/O1'])
set_param([sys,'/','Select (muxed)/O1'],...
		'position',[215,40,235,60])

add_block('built-in/State-Space',[sys,'/','Select (muxed)/Bus'])
set_param([sys,'/','Select (muxed)/Bus'],...
		'A','[]',...
		'B','[]',...
		'C','[]',...
		'D','busdmat([1 2 3 4 5 6 8 9 10 11 12 13 14 15],15)',...
		'Mask Display','Select\nSignal(s)',...
		'Mask Type','Select Signal(s)(Text)')
set_param([sys,'/','Select (muxed)/Bus'],...
		'Mask Dialogue','Allows selection of signals from a SIMULINK DataBus vector.|Bus name:|Signal names(separated by \|):|Show signal sizes(0 or 1):|Show signal names(0 or 1):')
set_param([sys,'/','Select (muxed)/Bus'],...
		'Mask Translate','SelSig=parsebus(@1,@2);',...
		'Mask Entries','''bus1''\/''alpha|gamma|delta''\/0\/0\/',...
		'position',[120,31,175,69])

add_block('built-in/Inport',[sys,'/','Select (muxed)/I1'])
set_param([sys,'/','Select (muxed)/I1'],...
		'position',[60,40,80,60])
add_line([sys,'/','Select (muxed)'],[85,50;115,50])
add_line([sys,'/','Select (muxed)'],[180,50;210,50])
set_param([sys,'/','Select (muxed)'],...
		'Mask Display','Select\nSignal(s)\n(Muxed)',...
		'Mask Type','Select Signal(s) (Muxed)',...
		'Mask Dialogue','eval(''bussel(''''Init'''')'')')


%     Finished composite block 'Select (muxed)'.

set_param([sys,'/','Select (muxed)'],...
		'Font Name','courier',...
		'position',[150,100,220,140])

add_block('built-in/Note',[sys,'/','DataBus Blockset V1.1a'])
set_param([sys,'/','DataBus Blockset V1.1a'],...
		'position',[185,10,190,15])

drawnow

% Return any arguments.
if (nargin | nargout)
	% Must use feval here to access system in memory
	if (nargin > 3)
		if (flag == 0)
			eval(['[ret,x0,str,ts,xts]=',sys,'(t,x,u,flag);'])
		else
			eval(['ret =', sys,'(t,x,u,flag);'])
		end
	else
		[ret,x0,str,ts,xts] = feval(sys);
	end
else
	drawnow % Flash up the model and execute load callback
end
