function [ret,x0,str,ts,xts]=bussamp2(t,x,u,flag);
%BUSSAMP2	is the M-file description of the SIMULINK system named BUSSAMP2.
%	The block-diagram can be displayed by typing: BUSSAMP2.
%
%	SYS=BUSSAMP2(T,X,U,FLAG) returns depending on FLAG certain
%	system values given time point, T, current state vector, X,
%	and input vector, U.
%	FLAG is used to indicate the type of output to be returned in SYS.
%
%	Setting FLAG=1 causes BUSSAMP2 to return state derivatives, FLAG=2
%	discrete states, FLAG=3 system outputs and FLAG=4 next sample
%	time. For more information and other options see SFUNC.
%
%	Calling BUSSAMP2 with a FLAG of zero:
%	[SIZES]=BUSSAMP2([],[],[],0),  returns a vector, SIZES, which
%	contains the sizes of the state vector and other parameters.
%		SIZES(1) number of states
%		SIZES(2) number of discrete states
%		SIZES(3) number of outputs
%		SIZES(4) number of inputs
%		SIZES(5) number of roots (currently unsupported)
%		SIZES(6) direct feedthrough flag
%		SIZES(7) number of sample times
%
%	For the definition of other parameters in SIZES, see SFUNC.
%	See also, TRIM, LINMOD, LINSIM, EULER, RK23, RK45, ADAMS, GEAR.

% Note: This M-file is only used for saving graphical information;
%       after the model is loaded into memory an internal model
%       representation is used.

% the system will take on the name of this mfile:
sys = mfilename;
new_system(sys)
simver(1.3)
if (0 == (nargin + nargout))
     set_param(sys,'Location',[45,53,546,358])
     open_system(sys)
end;
set_param(sys,'algorithm',     'RK-45')
set_param(sys,'Start time',    '0.0')
set_param(sys,'Stop time',     '2')
set_param(sys,'Min step size', '1')
set_param(sys,'Max step size', '1')
set_param(sys,'Relative error','1e-3')
set_param(sys,'Return vars',   '')
set_param(sys,'AssignWideVectorLines','on');


%     Subsystem  'Select'.

new_system([sys,'/','Select'])
set_param([sys,'/','Select'],'Location',[620,375,924,654])

add_block('built-in/Inport',[sys,'/','Select/I1'])
set_param([sys,'/','Select/I1'],...
		'position',[30,40,50,60])

add_block('built-in/Demux',[sys,'/','Select/Demux'])
set_param([sys,'/','Select/Demux'],...
		'outputs','[4, 2, 1, 8]',...
		'position',[160,32,205,68])

add_block('built-in/Outport',[sys,'/','Select/O1'])
set_param([sys,'/','Select/O1'],...
		'position',[250,40,270,60])

add_block('built-in/State-Space',[sys,'/','Select/Bus'])
set_param([sys,'/','Select/Bus'],...
		'A','[]',...
		'B','[]',...
		'C','[]',...
		'D','busdmat([1 2 3 4 5 6 7 8 9 10 11 12 13 14 15],15)',...
		'Mask Display','Select\nSignal(s)',...
		'Mask Type','Select Signal(s)(Text)')
set_param([sys,'/','Select/Bus'],...
		'Mask Dialogue','Allows selection of signals from a SIMULINK DataBus vector.|Bus name:|Signal names(separated by \|):|Show signal sizes(0 or 1):|Show signal names(0 or 1):')
set_param([sys,'/','Select/Bus'],...
		'Mask Translate','SelSig=parsebus(@1,@2);',...
		'Mask Entries','''bus1''\/''alpha|gamma|beta|delta''\/0\/1\/',...
		'position',[80,31,135,69])

add_block('built-in/Outport',[sys,'/','Select/O2'])
set_param([sys,'/','Select/O2'],...
		'Port','2',...
		'position',[250,80,270,100])

add_block('built-in/Outport',[sys,'/','Select/O3'])
set_param([sys,'/','Select/O3'],...
		'Port','3',...
		'position',[250,120,270,140])

add_block('built-in/Outport',[sys,'/','Select/O4'])
set_param([sys,'/','Select/O4'],...
		'Port','4',...
		'position',[250,160,270,180])
add_line([sys,'/','Select'],[55,50;75,50])
add_line([sys,'/','Select'],[140,50;155,50])
add_line([sys,'/','Select'],[210,35;245,50])
add_line([sys,'/','Select'],[210,45;220,45;220,90;245,90])
add_line([sys,'/','Select'],[210,55;220,55;220,130;245,130])
add_line([sys,'/','Select'],[210,65;215,65;215,170;245,170])
set_param([sys,'/','Select'],...
		'Mask Display','  alpha\n\n  gamma\n\n   beta\n\n  delta',...
		'Mask Type','Select Signal(s)(Gui)',...
		'Mask Dialogue','eval(''bussel(''''Init'''')'')')


%     Finished composite block 'Select'.

set_param([sys,'/','Select'],...
		'Font Name','courier',...
		'position',[225,17,290,103])

add_block('built-in/To Workspace',[sys,'/','to workspace'])
set_param([sys,'/','to workspace'],...
		'mat-name','alpha',...
		'position',[345,25,405,45])

add_block('built-in/To Workspace',[sys,'/','to workspace1'])
set_param([sys,'/','to workspace1'],...
		'mat-name','gamma',...
		'position',[345,65,405,85])

add_block('built-in/To Workspace',[sys,'/','to workspace2'])
set_param([sys,'/','to workspace2'],...
		'mat-name','beta',...
		'position',[345,105,405,125])

add_block('built-in/To Workspace',[sys,'/','to workspace3'])
set_param([sys,'/','to workspace3'],...
		'mat-name','delta',...
		'position',[345,150,405,170])


%     Subsystem  'Insert'.

new_system([sys,'/','Insert'])
set_param([sys,'/','Insert'],'Location',[580,429,850,708])

add_block('built-in/Outport',[sys,'/','Insert/O1'])
set_param([sys,'/','Insert/O1'],...
		'position',[215,55,235,75])

add_block('built-in/Inport',[sys,'/','Insert/I2'])
set_param([sys,'/','Insert/I2'],...
		'position',[20,75,40,95])

add_block('built-in/Mux',[sys,'/','Insert/Mux'])
set_param([sys,'/','Insert/Mux'],...
		'inputs','[15 4 2 1 8]',...
		'Mask Display','',...
		'position',[85,47,115,83])

add_block('built-in/State-Space',[sys,'/','Insert/Bus'])
set_param([sys,'/','Insert/Bus'],...
		'A','[]',...
		'B','[]',...
		'C','[]',...
		'D','busdmat([16 17 18 19 20 21 22 23 24 25 26 27 28 29 30],30)',...
		'Mask Display','Insert\nSignal(s)',...
		'Mask Type','Insert Signal(s)(Text)')
set_param([sys,'/','Insert/Bus'],...
		'Mask Dialogue','Set signal values on a SIMULINK DataBus vector.|Bus name:|Signal names(separated by \|):|Show signal sizes(0 or 1):|Show bus and signal names(0 or 1):')
set_param([sys,'/','Insert/Bus'],...
		'Mask Translate','SelSig=addtobus(@1,@2); ',...
		'Mask Entries','''bus1''\/''alpha|gamma|beta|delta''\/1\/1\/',...
		'position',[135,41,190,89])

add_block('built-in/Inport',[sys,'/','Insert/I3'])
set_param([sys,'/','Insert/I3'],...
		'Port','2',...
		'position',[20,120,40,140])

add_block('built-in/Inport',[sys,'/','Insert/I4'])
set_param([sys,'/','Insert/I4'],...
		'Port','3',...
		'position',[20,160,40,180])

add_block('built-in/Inport',[sys,'/','Insert/I5'])
set_param([sys,'/','Insert/I5'],...
		'Port','4',...
		'position',[20,200,40,220])

add_block('built-in/Constant',[sys,'/','Insert/I1'])
set_param([sys,'/','Insert/I1'],...
		'Value','[0; 0; 0; 0; 0; 0; 0; 0; 0; 0; 0; 0; 0; 0; 0]',...
		'position',[20,40,40,60])
add_line([sys,'/','Insert'],[195,65;210,65])
add_line([sys,'/','Insert'],[45,85;55,85;55,60;80,60])
add_line([sys,'/','Insert'],[120,65;130,65])
add_line([sys,'/','Insert'],[45,130;55,130;55,65;80,65])
add_line([sys,'/','Insert'],[45,170;55,170;55,70;80,70])
add_line([sys,'/','Insert'],[45,210;55,210;55,75;80,75])
add_line([sys,'/','Insert'],[45,50;55,50;55,55;80,55])
set_param([sys,'/','Insert'],...
		'Mask Display','alpha[4]\n\ngamma[2]\n\nbeta [1]\n\ndelta[8]',...
		'Mask Type','Insert Signal(s)(Gui)',...
		'Mask Dialogue','eval(''bussel(''''Init'''')'')')


%     Finished composite block 'Insert'.

set_param([sys,'/','Insert'],...
		'Font Name','courier',...
		'position',[135,30,205,150])

add_block('built-in/Constant',[sys,'/','gamma'])
set_param([sys,'/','gamma'],...
		'Value','[2 2]',...
		'position',[20,146,65,174])

add_block('built-in/Constant',[sys,'/','alpha'])
set_param([sys,'/','alpha'],...
		'Value','[1 1 1 1]',...
		'position',[15,95,75,125])

add_block('built-in/Constant',[sys,'/','beta'])
set_param([sys,'/','beta'],...
		'Value','[3]',...
		'position',[20,191,65,219])

add_block('built-in/Constant',[sys,'/','delta'])
set_param([sys,'/','delta'],...
		'Value','[4 4 4 4 4 4 4 4]',...
		'position',[20,247,135,273])
add_line(sys,[210,90;220,60])
add_line(sys,[295,30;340,35])
add_line(sys,[295,50;315,50;315,75;340,75])
add_line(sys,[295,70;310,70;310,115;340,115])
add_line(sys,[295,90;305,90;305,160;340,160])
add_line(sys,[80,110;100,110;100,45;130,45])
add_line(sys,[70,160;95,160;95,75;130,75])
add_line(sys,[70,205;95,205;95,105;130,105])
add_line(sys,[140,260;150,260;150,220;115,220;115,135;130,135])

drawnow

% Return any arguments.
if (nargin | nargout)
	% Must use feval here to access system in memory
	if (nargin > 3)
		if (flag == 0)
			eval(['[ret,x0,str,ts,xts]=',sys,'(t,x,u,flag);'])
		else
			eval(['ret =', sys,'(t,x,u,flag);'])
		end
	else
		[ret,x0,str,ts,xts] = feval(sys);
	end
else
	drawnow % Flash up the model and execute load callback
end
