function setnout(sys,outparam)
%SETNOUT Sets the number of outports connected to a block in a subsystem.
%
%For use only with the SIMULINK Bus connection blocks.
%
%See also SETNIN

%Copyright (c) 1995 by The MathWorks, Inc.
%$Revision: 1.5 $ $Date: 1995/12/11 21:49:30 $

% Parse the input 'outparam'.
siz = length(outparam);
if siz==1
  nout = outparam;
else
  nout = siz;
end

% Error checking.
if nout<=0
 error('Must pass SETNOUT 1 or more outputs.')
end

% What blockname to use
blkname='Demux';

% Determine whether the number of outports should be increased or decreased.
blks = get_param(sys,'blocks');
nblks = size(blks,1);

% Find the number of outports
cnt = 0;
for i=1:nblks
   cnt = cnt + any(findstr(blks(i,:),'O'));
end

% If outports are to be added...
if nout>cnt
  % Setup the default horizontal offset
  dx=250;
  % Setup the default vertical offset
  dy=40;

  % Set the number outputs
  set_param([sys '/' blkname],'outputs',outparam);

  % Add the blocks and lines.
  for i=(cnt+1):nout
    name = ['O' num2str(i)];
    add_block('built-in/Outport',[sys '/' name]);
    set_param([sys '/' name],'Port',i,'position',[dx,i*dy,dx+20,i*dy+20]);
    add_line(sys,[blkname '/' num2str(i)],[name '/1']);
  end
  % else if outports are to be deleted...
elseif nout<cnt
  % Delete the lines and blocks.
  for i=cnt:-1:(nout+1)
    name = ['O' num2str(i)];
    delete_line(sys,[blkname '/' num2str(i)],[name '/1']);
    delete_block([sys '/' name]);
  end

  % Set the number outputs
  set_param([sys '/' blkname],'outputs',outparam);
else
  % Set the number outputs
  set_param([sys '/' blkname],'outputs',outparam);
end

% End.

