function [strings, sizes, message] = busread(busfilename)
%BUSREAD Returns the Strings and Sizes for a given bus file.
%
%For use only with the SIMULINK Bus connection blocks.
%
%See also 'help simbus'

%Copyright (c) 1995 by The MathWorks, Inc.
%$Revision: 1.5 $ $Date: 1996/04/16 16:04:01 $

strings = '';
message = '';
sizes = [];
fid = fopen([busfilename '.txt'],'rt');
if fid < 0
%
% Can't open file
%
  message = ['Can''t open file ' busfilename '.txt'];
  return;
end
%
% Read in whole file
% 
[txt,count] = fread(fid,'char');
fclose(fid);
if count == 0
  %
  % Empty file
  %
  message=['Empty file ' busfilename '.txt'];
  return;
end

txt = setstr(txt);
%
BLANK = 32;
CRETURN = 13;
comp = computer;
if comp(1:3) == 'MAC'
  NEWLINE = 13;
else
  NEWLINE = 10;
end
%
nl = find(txt == NEWLINE);
lnl = length(nl);
%
% Be sure that the last line is covered in case NEWLINE
% is missing
%
if isempty(nl)
  nl = count;
  lnl = 1;
elseif nl(lnl) ~= count 
  nl = [ nl; count ];
  lnl = lnl + 1;
end
%
% Skip comments and blank lines
%
line = txt(1:nl(1)-1);
if isempty(line)
  flag=1;
elseif txt(nl(1)-1) == CRETURN
  line = txt(1:nl(1)-2);
  if isempty(line)
      flag = 1;
  else
      flag = strcmp(line(1),'%');
  end
else  
  flag = strcmp(line(1),'%');
end  
i = 1; 
while flag
  i = i + 1;
  if i > lnl
    %
    % No strings in file
    %
    message = ['No strings in file ' busfilename '.txt'];
    return;
  end
  line = txt(nl(i-1)+1:nl(i)-1);
  if isempty(line)
      flag = 1;
  elseif txt(nl(i)-1) == CRETURN    
      line = txt(nl(i-1)+1:nl(i)-2);
      if isempty(line)
	  flag = 1;
      else
          flag = strcmp(line(1),'%');
      end
  else    
      flag = strcmp(line(1),'%');
  end
end
%
astrings = '';
lstrings = [];
while 1
  [text,count] = sscanf(line, '%s %d%*');
  if count > 0
      len = length(text);
      lstrings = [lstrings; len-1];
      astrings = [astrings setstr(text(1:len-1)')];
      sizes = [sizes; text(len:len)];
  end  
  i = i + 1;
  if i > lnl
    %
    % Finished:
    % Build strings from size vector and one long string
    %
    len = length(lstrings);
    mx = max(lstrings);
    strings = setstr(ones(1,len * mx) * BLANK); 
    ssum = 1;
    asum = 1;
    for i=1:len
      strings(ssum:ssum+lstrings(i)-1) = astrings(asum:asum+lstrings(i)-1);
      ssum = ssum + mx;
      asum = asum + lstrings(i);
    end
    strings = reshape(strings,mx,len)';
    return;
  end
  if txt(nl(i)-1) ~= CRETURN
     line = txt(nl(i-1)+1:nl(i)-1);
  else
     line = txt(nl(i-1)+1:nl(i)-2);
  end
end

