function bussel(action,argument1,argument2)
%BUSSEL GUI Interface for selecting data off a bus line.
%
%Example:
% bussel('Init')
%
%Brings up the gui.  Enter the string:
%
% eval('bussel(''Init'')')
%
%in the dialog strings of the text based Selector block to use the gui.
%Be sure to name the selector block "Bus" before grouping and masking it.
%
%This also works with the Insert block and will likely work with any
%block that has the same underlying structure.

%William York, 11/95.
%Copyright (c) 1995 by The MathWorks, Inc.

%$Revision: 1.22 $ $Date: 1996/04/30 18:37:58 $

BusName=[];
FigureTag=[];
Action=[];
if (nargin > 3)
  error('Too many input arguments to bussel.')
end
if (nargin > 2)
  BusName=argument2;
end  
if (nargin > 1)
  FigureTag=argument1;
end  
if (nargin > 0)
  Action=action;
end  
if (nargin == 0)
  error('Not enough input arguements to bussel.')
end

if (strcmp(Action,'Init'))
  % Check if this was called as a redraw
  if (~isempty(BusName))
    % Get the handle to the current figure
    h_fig=findobj('Tag',FigureTag);
    % Get the handle to the current block
    h_cb=get(h_fig,'UserData');
    BlockType=get_param(h_cb,'Mask Type');
    sys=get_param(h_cb,'Parent');
    cb=get_param(h_cb,'Name');
    % Check if bus file is valid
    [Strings,Sizes,str]=busread(BusName);
    if (isempty(Strings))
      errstr=str2mat('Error bus file:',['- ' str]);
      errordlg(errstr,[gcb ' Error']);
      error(errstr)
    end  
    % Bus file is valid, clear the figure window
    delete(get(h_fig,'Children'))
    DataNames='';
    SizesFlag=0;
    NamesFlag=0;
  else
    % Get current system and block name
    blockname=gcb;
    h_cb=get_param(blockname,'Handle');
    % Check if figure already exists
    h_fig=findobj('Tag',blockname);
    if (~isempty(h_fig))
      figure(h_fig)
      return
    end
    % Get the parameters from the underlying Bus system
    h_bus=get_param([blockname '/Bus'],'Handle');
    BlockType=get_param(h_bus,'Mask Type');
    entries=mask2str(h_bus);
    % The mask should always contain at least these 4 entries, In this order
    BusName=deblank(strrep(entries(1,:),'''',''));
    DataNames=deblank(strrep(entries(2,:),'''',''));
    SizesFlag=str2num(deblank(strrep(entries(3,:),'''','')));
    NamesFlag=str2num(deblank(strrep(entries(4,:),'''','')));
    [Strings,Sizes,str]=busread(BusName);
    if (isempty(Strings))
      errstr=str2mat('Error loading bus file:',['- ' str]);
      errordlg(errstr,[blockname ' Warning']);
    end  
  end
  NumStrings=size(Strings,1);

  layout;  % This calls a script to setup some default spacing variables
  ScreenS=get(0,'ScreenSize');
  % Default spacing
  VerticalSpace=5;
  % Number of rows
  NumPush=1; % number of rows of pushbuttons (apply, close, etc)
  if (findstr('Insert Signal',BlockType))
    NumToggle=3; % number of rows of toggle buttons (show *)
  else
    NumToggle=2; % number of rows of toggle buttons (show *)
  end
  NumBlank=1; % number of blank rows between strings and the toggles
  NumButtons=NumStrings; % number of strings in bus
  NumText=1; % number of editable text blocks (bus name)
  NumControls=(NumPush + NumToggle + NumBlank + NumText); 
  % Figure positioning
  NumColumns=1;
  ButtonsPerColumn=ceil(NumButtons/NumColumns);
  ButtonHeight = ...
    ButtonsPerColumn*mStdButtonHeight + ...
    ButtonsPerColumn*VerticalSpace;
  ControlHeight = ...
    NumControls*mStdButtonHeight + ...
    (NumControls-1)*VerticalSpace;
  FigH = mFrameToText + ButtonHeight + ControlHeight + mFrameToText;
  % Check if the figure height is > the screen size
  %   setup screen size scale - if figure is > Scale% of screen, add another
  %   column
  Scale = .90;  
  if (FigH > Scale * ScreenS(4))
    % Reset figure height - this needs some work but it gets the job done
    NumColumns= ceil((2 - Scale)* ...
      (ButtonHeight/(ScreenS(4) - (FigH - ButtonHeight))));
    ButtonsPerColumn=ceil(NumButtons/NumColumns);
    ButtonHeight = ...
      ButtonsPerColumn*mStdButtonHeight + ...
      ButtonsPerColumn*VerticalSpace;
    FigH = mFrameToText + ButtonHeight + ControlHeight + mFrameToText;
  end
  NumObjects = ButtonsPerColumn + NumControls;  
  FigW=(2*mStdButtonWidth + 2*mFrameToText)*NumColumns;
  FigurePos=[(ScreenS(3)-FigW)/2 (ScreenS(4)-FigH)/2 FigW FigH];
  DefUIBgC = get(0,'DefaultUIControlBackgroundColor');
  % Place figures and UiControls  
  % Check if h_fig references a valid figure
  if (~isempty(h_fig) & ishandle(h_fig))
    set(h_fig,'Pos',FigurePos)
  else
  % Figure handle does not exist, create a new one
  h_fig=figure('Visible','off','Units','pixels','Pos',FigurePos, ...n
    'Color',DefUIBgC,'NumberTitle','off','Name',[blockname ],'Tag',[blockname ], ...
    'UserData',h_cb);
  end

  % Place push buttons
  Ind=1;
  Mul=NumObjects - NumToggle - NumBlank - ButtonsPerColumn - NumText - Ind;  
  ApplyCallback='bussel(''Apply'',get(gcf,''Tag''))';
  ApplyPos=[
    mFrameToText
    mFrameToText + Mul*VerticalSpace + Mul*mStdButtonHeight
    mStdButtonWidth*.9
    mStdButtonHeight
  ];
  ApplyPos=ApplyPos';
  h_apply=uicontrol('Visible','off','Parent',h_fig,'Units','pixels', ...
  'Enable','off','String','Apply','pos',ApplyPos, ...
  'Style','push','Tag','ApplyButton','CallBack',ApplyCallback);
  CloseCallback='bussel(''Close'',get(gcf,''Tag''))';
  ClosePos=ApplyPos+[
    ApplyPos(3)+ mStdButtonWidth*.2,
    0,
    0,
    0,
  ]';
  h_close=uicontrol('Visible','off','Parent',h_fig,'Units','pixels', ...
  'Enable','on','String','Close','pos',ClosePos, ...
  'Style','push','Tag','CloseButton','CallBack',CloseCallback);

  % Place radio buttons for toggling of signal show / sizes
  if (findstr('Insert Signal',BlockType))
    Ind=1; % Num buttons down from bottom of blank below radio buttons
    Mul=NumObjects - NumBlank - ButtonsPerColumn - NumText - Ind;  
    ShowBusFlag=1;
    ShowBusCallback='bussel(''EnableApply'',get(gcf,''Tag''))';
    ShowBusString='Show bus name?';
    h_toggle=uicontrol('Visible','off','Parent',h_fig,'Units','pixels', ...
    'Enable','on','String',ShowBusString,'pos',[ ...
      mFrameToText
      mFrameToText + Mul*VerticalSpace + Mul*mStdButtonHeight
      2*mStdButtonWidth
      mStdButtonHeight
    ], 'Style','radio','Value',ShowBusFlag,'Tag','ShowBusButton','CallBack',ShowBusCallback);
  else
    Ind=0;
  end
  Ind=Ind+1; % Num buttons down from bottom of blank below radio buttons
  Mul=NumObjects - NumBlank - ButtonsPerColumn - NumText - Ind;  
  NamesCallback=['h_fig=gcf;' ...
    'h_names=findobj(''Parent'',h_fig,''Tag'',''NamesButton'');' ...
    'h_sizes=findobj(''Parent'',h_fig,''Tag'',''SizesButton'');' ...
    'if (get(h_names,''Value'')),' ...
    '  set(h_sizes,''Enable'',''on'');' ...
    'else,' ...
    '  set(h_sizes,''Enable'',''off'');' ...
    'end;' ...
    'bussel(''EnableApply'',get(gcf,''Tag''))'];
  NamesString='Show signal names?';
  h_toggle=uicontrol('Visible','off','Parent',h_fig,'Units','pixels', ...
  'Enable','on','String',NamesString,'pos',[ ...
    mFrameToText
    mFrameToText + Mul*VerticalSpace + Mul*mStdButtonHeight
    2*mStdButtonWidth
    mStdButtonHeight
  ], 'Style','radio','Value',NamesFlag,'Tag','NamesButton','CallBack',NamesCallback);
  Ind=Ind+1; % Num buttons down from bottom of blank below radio buttons
  Mul=NumObjects - NumBlank - ButtonsPerColumn - NumText - Ind;   
  SizesCallback='bussel(''EnableApply'',get(gcf,''Tag''))';
  SizesString='Show signal sizes?';
  if (NamesFlag)
    SizesEnable='on';
  else
    SizesEnable='off';
  end
  h_toggle=uicontrol('Visible','off','Parent',h_fig,'Units','pixels', ...
  'Enable',SizesEnable,'String',SizesString,'pos',[ ...
    mFrameToText
    mFrameToText + Mul*VerticalSpace + Mul*mStdButtonHeight
    2*mStdButtonWidth
    mStdButtonHeight
  ], 'Style','radio','Value',SizesFlag,'Tag','SizesButton','CallBack',SizesCallback);

  % Blank space goes here
  
  % Place radio buttons for selecting signals
  RadioCallback='bussel(''EnableApply'',get(gcf,''Tag''))';
  ColumnNumber=1;
  ColumnOffset=0;
  Ind2=1;  
  for Ind1=1:NumButtons
    if (Ind1 > ColumnNumber * ButtonsPerColumn)
      ColumnOffset=(ColumnNumber)*(2*mFrameToText+2*mStdButtonWidth);
      ColumnNumber=ColumnNumber+1;
      Ind2=1;
    end
    Mul=NumObjects - NumText - Ind2;
    h_btn(Ind1)=uicontrol('Visible','off','Parent',h_fig,'Units','pixels', ...
      'Enable','on','HorizontalAlignment','left','pos',[ ...
      mFrameToText + ColumnOffset
      mFrameToText + Mul*VerticalSpace + Mul*mStdButtonHeight
      2*mStdButtonWidth
      mStdButtonHeight
      ], 'Style','radiobutton','Tag',['RadioButton_' num2str(Ind1)], ...
      'Callback',RadioCallback, ...
     'String',[Strings(Ind1,:) '[' num2str(Sizes(Ind1)) ']' ]);
    Ind2 = Ind2+1;    
  end
  Ind=1;
  Mul=NumObjects - Ind;
  h_text=uicontrol('Visible','off','Parent',h_fig,'Units','pixels', ...
    'BackgroundColor',DefUIBgC, 'pos',[ ...
    mFrameToText
    mFrameToText + Mul*VerticalSpace + Mul*mStdButtonHeight
    mStdButtonWidth
    mStdButtonHeight
    ], 'Style','text','String','Bus Name:','HorizontalAlignment','left');

  % Edit callback syntax: "bussel('Init',FigureHandle,BusName)"  
  EditCallback=[ 'bussel(''Init'',get(gcf,''Tag''),' ...
    'get(findobj(''Parent'',findobj(''Tag'',get(gcf,''Tag'')),', ...
    '''Tag'',''BusName''),''String''))'];
  h_edit=uicontrol('Visible','off','Parent',h_fig,'Units','pixels', ...
    'Callback',EditCallback,'BackgroundColor','white', 'pos',[ ...
    mStdButtonWidth + mFrameToText
    mFrameToText + Mul*VerticalSpace + Mul*mStdButtonHeight
    mStdButtonWidth
    mStdButtonHeight
    ], 'Style','edit','HorizontalAlignment','left','Tag','BusName','String',BusName);

  % Check if any strings are set
  if (~isempty(DataNames))
    % Find out which strings are currently set
    %   DataNames contains the clean names as stored in the Bus mask
    %   Strings   contains the space padded names as stored in the bus definition file
    % Loop through all the DataNames - this is a | delimited string
    PipeLocations=find(DataNames=='|');
    if (isempty(PipeLocations))
      WordDelimiters=[0 length(DataNames)+1];
    else
      WordDelimiters=[0 PipeLocations length(DataNames)+1];
    end
    for (Ind1=1:length(WordDelimiters)-1)
      Start=WordDelimiters(Ind1)+1;
      End=WordDelimiters(Ind1+1)-1;
      CurrentDataName=DataNames(Start:End);
      % Set a test flag to ensure that the underlying system matches the data from the bus definition file
      ValidDefinitionFile=0;
      % Loop through all the Strings - this is a space padded string matrix
      for (Ind2=1:size(Strings,1))
        CurrentString=deblank(Strings(Ind2,:));
        if (strcmp(CurrentDataName,CurrentString))
          % The data name appears in the Bus mask to this line is currently active.
          % Toggle the radio button to reflect that the line is active.
          set(h_btn(Ind2),'Value',1)
          ValidDefinitionFile=1;
        end
      end
      if (~ValidDefinitionFile)
        errordlg('WARNING - Bus definition file not in sync with the block diagram.');
      end
    end
  end  % if(~isempty(DataNames))

  % Make figure visible
  set(findobj(h_fig),'visible','on')
% end Action == Init
elseif (strcmp(Action,'Close'))
  if (isempty(FigureTag))
    error(['Action ' Action ' requires a second argument - the Figure tag'])
  end

  % Get handle to figure given tag
  h_fig=findobj('Tag',FigureTag);

  % Apply any pending changes if necessary
  if(strcmp(lower(get(findobj('Parent',h_fig,'Tag','ApplyButton'),'Enable')),'on'))
    bussel('Apply',FigureTag);
    % Check if the figure got closed
    if (~ishandle(findobj('Tag',FigureTag)))
      return
    end
  end

  % Delete the figure and its children
  delete(flipud(findobj('Tag',FigureTag)))
% end Action == Close
elseif (strcmp(Action,'Apply'))
  if (isempty(FigureTag))
    error(['Action ' Action ' requires a second argument - the Figure tag'])
  end

  % Get handle to figure given tag
  h_fig=findobj('Tag',FigureTag);

  % Get the name of the bus file from the dialog
  h_edit=findobj('Parent',h_fig,'Tag','BusName');
  BusName=get(h_edit,'String');

  % Get the handle to the current block
  h_cb=get(h_fig,'UserData');
  TestString='sys=get_param(h_cb,''Parent'');';
  ErrorString='sys=[];';
  eval(TestString,ErrorString);
  if (isempty(sys))
    errordlg('Block no longer exists - closing selector.');
    delete(flipud(findobj('Tag',FigureTag)))
    return
  end
  cb=get_param(h_cb,'Name');

  % Get the handle to the underlying Bus block
  h_bus=get_param([sys '/' cb '/Bus'],'Handle');
  BlockType=get_param(h_bus,'Mask Type');

  % Get the list of selected names - in order
  NumButtons=length(findobj('Parent',h_fig,'Style','radiobutton'));
  h_btn_all=0;
  for (Ind=1:NumButtons)
    h_btn_all(Ind)=findobj('Parent',h_fig,'Tag',['RadioButton_' num2str(Ind)]);
  end
  h_btn_sel=findobj('Parent',h_fig,'Style','radiobutton','Value',1);
  NumSelected=length(h_btn_sel);
  if (NumSelected==0)
    Strings='';
  elseif (NumSelected==1)
    RealStrings=get(h_btn_sel,'String');
    TempString=deblank(RealStrings);
    % Remove trailing [ size ]
    Strings=deblank(TempString(1:find(TempString == '[')-1));
  else
    Strings=[];
    for (Ind=1:length(h_btn_all))
      if (get(h_btn_all(Ind),'Value')==1)
        if (isempty(Strings))
          RealStrings=get(h_btn_all(Ind),'String');
          [TempString,TempSize]=strtok(RealStrings,'[');
          Strings=deblank(TempString);
          Sizes=str2num(strrep(strrep(TempSize,'[',''),']',''));
        else
          RealString=get(h_btn_all(Ind),'String');
          [TempString,TempSize]=strtok(RealString,'[');
          Strings=[Strings '|' deblank(TempString)];
          Sizes=[Sizes; str2num(strrep(strrep(TempSize,'[',''),']',''))];
          RealStrings=[RealStrings '|' RealString];
        end
      end
    end
  end

  % Set the data name parameters in the underlying Bus system
  if (findstr('Insert Signal',BlockType))
    h_busname=findobj('Parent',h_fig,'Tag','ShowBusButton');
    ShowBusFlag=get(h_busname,'Value') ;
  else
    ShowBusFlag=1;
  end
  h_names=findobj('Parent',h_fig,'Tag','NamesButton');
  DrawFlag=get(h_names,'Value') ;
  h_sizes=findobj('Parent',h_fig,'Tag','SizesButton');
  SizesFlag=get(h_sizes,'Value');
  NumNames=size(find(Strings=='|'),2) + 1;
  if (isempty(Strings))
    Strings='<none>';
    Sizes=0;
  end
  dbimdraw(h_cb,DrawFlag,BusName,Strings,Sizes*SizesFlag,ShowBusFlag);

  % Update the Mask
  NewMaskEntry=str2mat(['''' BusName ''''],['''' Strings ''''],num2str(SizesFlag),num2str(DrawFlag));
  str2mask(h_bus,NewMaskEntry);

  % Build the string to create the D matrix
  if (findstr('Insert Signal',BlockType))
    % Using Insert block  
    [Indices,VecSize] = addtobus(BusName,Strings);
  else
    [Indices,VecSize] = parsebus(BusName,Strings);
  end
  DmatrixString = ['busdmat(' mat2str(Indices) ',' mat2str(VecSize) ')'];
  set_param(h_bus,'D',DmatrixString);  
    

  % Disable Apply button
  set(findobj('Parent',h_fig,'Tag','ApplyButton'),'Enable','off')
% end Action == Apply
elseif (strcmp(Action,'EnableApply'))
  if (isempty(FigureTag))
    error(['Action ' Action ' requires a second argument - the Figure tag'])
  end

  % Get handle to figure given tag
  h_fig=findobj('Tag',FigureTag);

  % Enable the Apply button
  set(findobj('Parent',h_fig,'Tag','ApplyButton'),'Enable','on')  
% end Action == EnableApply
else
  error(['Invalid action for bussel.  Action was "' Action '"'])
end    


% EOF bussel.m  
