function status=str2mask(blockhandle,stringmatrix)
%STR2MASK Sets entries in a mask dialog from a space padded string matrix.
%
%Does error checking if nargout > 0.
%
%Example:
%
% str2mask(get_param(gcb,'Handle'),str2mat('''bus1''','''alpha''','0','0'))
%
%See mask2str to do the converse.


%William York, 12/95.
%Copyright (c) 1995 by The MathWorks, Inc.

%$Revision: 1.3 $ $Date: 1995/12/11 21:50:06 $

% Check the sizes if nargout > 0
if (nargout > 0)
  status=0;
  CurrentEntries=mask2str(blockhandle);
  if (size(CurrentEntries) ~= size(stringmatrix))
    status=-1;
    return;
  end
end

% Update the mask
entries = [ deblank(stringmatrix(1,:)) '\/' ];
for ind = 2:size(stringmatrix,1)
  entries=[entries deblank(stringmatrix(ind,:)) '\/' ];
end
set_param(blockhandle,'Mask Entries',entries);

% Check if the mask was set correctly if nargout is > 0
if (nargout > 0)
  status=0;
  NewEntries=get_param(blockhandle,'Mask Entries');
  if (~isequal(NewEntries,entries))
    status=-2;
    return;
  end
end  
