function [ret,x0,str,ts,xts]=test(t,x,u,flag);
%TEST	is the M-file description of the SIMULINK system named TEST.
%	The block-diagram can be displayed by typing: TEST.
%
%	SYS=TEST(T,X,U,FLAG) returns depending on FLAG certain
%	system values given time point, T, current state vector, X,
%	and input vector, U.
%	FLAG is used to indicate the type of output to be returned in SYS.
%
%	Setting FLAG=1 causes TEST to return state derivatives, FLAG=2
%	discrete states, FLAG=3 system outputs and FLAG=4 next sample
%	time. For more information and other options see SFUNC.
%
%	Calling TEST with a FLAG of zero:
%	[SIZES]=TEST([],[],[],0),  returns a vector, SIZES, which
%	contains the sizes of the state vector and other parameters.
%		SIZES(1) number of states
%		SIZES(2) number of discrete states
%		SIZES(3) number of outputs
%		SIZES(4) number of inputs
%		SIZES(5) number of roots (currently unsupported)
%		SIZES(6) direct feedthrough flag
%		SIZES(7) number of sample times
%
%	For the definition of other parameters in SIZES, see SFUNC.
%	See also, TRIM, LINMOD, LINSIM, EULER, RK23, RK45, ADAMS, GEAR.

% Note: This M-file is only used for saving graphical information;
%       after the model is loaded into memory an internal model
%       representation is used.

% the system will take on the name of this mfile:
sys = mfilename;
new_system(sys)
simver(1.3)
if (0 == (nargin + nargout))
     set_param(sys,'Location',[398,64,898,364])
     open_system(sys)
end;
set_param(sys,'algorithm',     'Euler')
set_param(sys,'Start time',    '0.0')
set_param(sys,'Stop time',     '2')
set_param(sys,'Min step size', '1')
set_param(sys,'Max step size', '1')
set_param(sys,'Relative error','1e-3')
set_param(sys,'Return vars',   't')

add_block('built-in/Constant',[sys,'/','Constant2'])
set_param([sys,'/','Constant2'],...
		'hide name',0,...
		'Value','zin',...
		'position',[75,207,105,233])

add_block('built-in/Constant',[sys,'/','Constant1'])
set_param([sys,'/','Constant1'],...
		'hide name',0,...
		'Value','yin',...
		'position',[75,162,105,188])

add_block('built-in/Constant',[sys,'/','Constant'])
set_param([sys,'/','Constant'],...
		'hide name',0,...
		'Value','xin',...
		'position',[75,115,105,145])

add_block('built-in/To Workspace',[sys,'/','To Workspace'])
set_param([sys,'/','To Workspace'],...
		'hide name',0,...
		'mat-name','yout',...
		'position',[355,167,405,183])


%     Subsystem  'Look-Up'.

new_system([sys,'/','Look-Up'])
set_param([sys,'/','Look-Up'],'Location',[130,225,490,415])

add_block('built-in/S-Function',[sys,'/','Look-Up/S-Function'])
set_param([sys,'/','Look-Up/S-Function'],...
		'hide name',0,...
		'function name','table3',...
		'parameters','x,y,z,tab',...
		'position',[185,69,245,101])

add_block('built-in/Outport',[sys,'/',['Look-Up/Interp',13,'Value']])
set_param([sys,'/',['Look-Up/Interp',13,'Value']],...
		'position',[285,75,305,95])

add_block('built-in/Mux',[sys,'/','Look-Up/Mux'])
set_param([sys,'/','Look-Up/Mux'],...
		'hide name',0,...
		'inputs','3',...
		'position',[95,16,145,154])

add_block('built-in/Inport',[sys,'/','Look-Up/X'])
set_param([sys,'/','Look-Up/X'],...
		'position',[40,30,60,50])

add_block('built-in/Inport',[sys,'/','Look-Up/Y'])
set_param([sys,'/','Look-Up/Y'],...
		'Port','2',...
		'position',[40,75,60,95])

add_block('built-in/Inport',[sys,'/','Look-Up/Z'])
set_param([sys,'/','Look-Up/Z'],...
		'Port','3',...
		'position',[40,120,60,140])
add_line([sys,'/','Look-Up'],[250,85;280,85])
add_line([sys,'/','Look-Up'],[150,85;180,85])
add_line([sys,'/','Look-Up'],[65,40;90,40])
add_line([sys,'/','Look-Up'],[65,85;90,85])
add_line([sys,'/','Look-Up'],[65,130;90,130])
set_param([sys,'/','Look-Up'],...
		'Mask Display','plot([0 2 2 0 0],[0 0 2 2 0],[0 2 2.9 0.95 0],[2 2 2.7 2.7 2],[2 2.9 2.9 2 2],[0 0.85 2.7 2 0])',...
		'Mask Type','1-2-3 Table')
set_param([sys,'/','Look-Up'],...
		'Mask Dialogue','3-D Table Look Up.  Enter monotonic X, Y and Z vectors and a matrix of 2-D tables.  See the help for more info. |X vector:|Y vector:|Z vector:|Table')
set_param([sys,'/','Look-Up'],...
		'Mask Translate','x=@1;y=@2;z=@3;tab=@4;')
set_param([sys,'/','Look-Up'],...
		'Mask Help','The X, Y and Z vectors must be monotonic.   The 3-D table is a horizontal concatenation of  2-D tables.  X  indexes into the columns of the 2-D tables & Y indexes into the rows of the 2-D tables.  Z indexes into the table levels (starting with the 1st 2-D table).   The input values are x, y and z respectively (e.g., top port = x).')
set_param([sys,'/','Look-Up'],...
		'Mask Entries','x\/y\/z\/tab\/')


%     Finished composite block 'Look-Up'.

set_param([sys,'/','Look-Up'],...
		'position',[175,107,265,243])
add_line(sys,[110,130;170,130])
add_line(sys,[110,175;170,175])
add_line(sys,[110,220;170,220])
add_line(sys,[270,175;350,175])

drawnow

% Return any arguments.
if (nargin | nargout)
	% Must use feval here to access system in memory
	if (nargin > 3)
		if (flag == 0)
			eval(['[ret,x0,str,ts,xts]=',sys,'(t,x,u,flag);'])
		else
			eval(['ret =', sys,'(t,x,u,flag);'])
		end
	else
		[ret,x0,str,ts,xts] = feval(sys);
	end
else
	drawnow % Flash up the model and execute load callback
end
