function [ret,x0,str,ts,xts]=dtvss(t,x,u,flag);
%DTVSS	is the M-file description of the SIMULINK system named DTVSS.
%	The block-diagram can be displayed by typing: DTVSS.
%
%	SYS=DTVSS(T,X,U,FLAG) returns depending on FLAG certain
%	system values given time point, T, current state vector, X,
%	and input vector, U.
%	FLAG is used to indicate the type of output to be returned in SYS.
%
%	Setting FLAG=1 causes DTVSS to return state derivatives, FLAG=2
%	discrete states, FLAG=3 system outputs and FLAG=4 next sample
%	time. For more information and other options see SFUNC.
%
%	Calling DTVSS with a FLAG of zero:
%	[SIZES]=DTVSS([],[],[],0),  returns a vector, SIZES, which
%	contains the sizes of the state vector and other parameters.
%		SIZES(1) number of states
%		SIZES(2) number of discrete states
%		SIZES(3) number of outputs
%		SIZES(4) number of inputs
%		SIZES(5) number of roots (currently unsupported)
%		SIZES(6) direct feedthrough flag
%		SIZES(7) number of sample times
%
%	For the definition of other parameters in SIZES, see SFUNC.
%	See also, TRIM, LINMOD, LINSIM, EULER, RK23, RK45, ADAMS, GEAR.

% Note: This M-file is only used for saving graphical information;
%       after the model is loaded into memory an internal model
%       representation is used.

% the system will take on the name of this mfile:
sys = mfilename;
new_system(sys)
simver(1.3)
if (0 == (nargin + nargout))
     set_param(sys,'Location',[367,196,989,630])
     open_system(sys)
end;
set_param(sys,'algorithm',     'RK-45')
set_param(sys,'Start time',    '0.0')
set_param(sys,'Stop time',     '10000')
set_param(sys,'Min step size', '0.0001')
set_param(sys,'Max step size', '.10')
set_param(sys,'Relative error','1e-3')
set_param(sys,'Return vars',   '')
set_param(sys,'AssignWideVectorLines','on');


%     Subsystem  ['Discrete Time Varying',13,'State-Space'].

new_system([sys,'/',['Discrete Time Varying',13,'State-Space']])
set_param([sys,'/',['Discrete Time Varying',13,'State-Space']],'Location',[130,309,819,730])


%     Subsystem  ['Discrete Time Varying',13,'State-Space/Subsystem1'].

new_system([sys,'/',['Discrete Time Varying',13,'State-Space/Subsystem1']])
set_param([sys,'/',['Discrete Time Varying',13,'State-Space/Subsystem1']],'Location',[579,383,930,533])

add_block('built-in/Mux',[sys,'/',['Discrete Time Varying',13,'State-Space/Subsystem1/Mux']])
set_param([sys,'/',['Discrete Time Varying',13,'State-Space/Subsystem1/Mux']],...
		'inputs','[n m*n]',...
		'position',[60,61,90,94])

add_block('built-in/S-Function',[sys,'/',['Discrete Time Varying',13,'State-Space/Subsystem1/S-Function']])
set_param([sys,'/',['Discrete Time Varying',13,'State-Space/Subsystem1/S-Function']],...
		'function name','stvmgain',...
		'parameters','K,Ts',...
		'position',[130,70,180,90])

add_block('built-in/Inport',[sys,'/',['Discrete Time Varying',13,'State-Space/Subsystem1/in_1']])
set_param([sys,'/',['Discrete Time Varying',13,'State-Space/Subsystem1/in_1']],...
		'position',[10,60,30,80])

add_block('built-in/Outport',[sys,'/',['Discrete Time Varying',13,'State-Space/Subsystem1/out_1']])
set_param([sys,'/',['Discrete Time Varying',13,'State-Space/Subsystem1/out_1']],...
		'position',[210,70,230,90])

add_block('built-in/Inport',[sys,'/',['Discrete Time Varying',13,'State-Space/Subsystem1/in_2']])
set_param([sys,'/',['Discrete Time Varying',13,'State-Space/Subsystem1/in_2']],...
		'Port','2',...
		'position',[10,75,30,95])
add_line([sys,'/',['Discrete Time Varying',13,'State-Space/Subsystem1']],[95,80;125,80])
add_line([sys,'/',['Discrete Time Varying',13,'State-Space/Subsystem1']],[35,70;55,70])
add_line([sys,'/',['Discrete Time Varying',13,'State-Space/Subsystem1']],[185,80;205,80])
add_line([sys,'/',['Discrete Time Varying',13,'State-Space/Subsystem1']],[35,85;55,85])
set_param([sys,'/',['Discrete Time Varying',13,'State-Space/Subsystem1']],...
		'Mask Display','Time Varying\nMatrix Gain',...
		'Mask Type','Time Varying Matrix Gain',...
		'Mask Dialogue','Matrix Gain|Initial Gain Matrix: |Update Sample Time')
set_param([sys,'/',['Discrete Time Varying',13,'State-Space/Subsystem1']],...
		'Mask Translate','K=@1;Ts=@2;[m,n]=size(@1);')
set_param([sys,'/',['Discrete Time Varying',13,'State-Space/Subsystem1']],...
		'Mask Help','This block implements a time-varying matrix gain. The intial gain K determines the resizing of the vector input gain. The gain matrix(m,n) will produce m outputs, the input u having n columns.')
set_param([sys,'/',['Discrete Time Varying',13,'State-Space/Subsystem1']],...
		'Mask Entries','A\/Ts\/')


%     Finished composite block ['Discrete Time Varying',13,'State-Space/Subsystem1'].

set_param([sys,'/',['Discrete Time Varying',13,'State-Space/Subsystem1']],...
		'position',[155,30,245,85])

add_block('built-in/Inport',[sys,'/',['Discrete Time Varying',13,'State-Space/A']])
set_param([sys,'/',['Discrete Time Varying',13,'State-Space/A']],...
		'Port','2',...
		'position',[105,60,125,80])

add_block('built-in/Note',[sys,'/',['Discrete Time Varying',13,'State-Space/x']])
set_param([sys,'/',['Discrete Time Varying',13,'State-Space/x']],...
		'position',[130,20,135,25])


%     Subsystem  ['Discrete Time Varying',13,'State-Space/Subsystem'].

new_system([sys,'/',['Discrete Time Varying',13,'State-Space/Subsystem']])
set_param([sys,'/',['Discrete Time Varying',13,'State-Space/Subsystem']],'Location',[579,383,930,533])

add_block('built-in/Inport',[sys,'/',['Discrete Time Varying',13,'State-Space/Subsystem/in_2']])
set_param([sys,'/',['Discrete Time Varying',13,'State-Space/Subsystem/in_2']],...
		'Port','2',...
		'position',[10,75,30,95])

add_block('built-in/Outport',[sys,'/',['Discrete Time Varying',13,'State-Space/Subsystem/out_1']])
set_param([sys,'/',['Discrete Time Varying',13,'State-Space/Subsystem/out_1']],...
		'position',[210,70,230,90])

add_block('built-in/Inport',[sys,'/',['Discrete Time Varying',13,'State-Space/Subsystem/in_1']])
set_param([sys,'/',['Discrete Time Varying',13,'State-Space/Subsystem/in_1']],...
		'position',[10,60,30,80])

add_block('built-in/S-Function',[sys,'/',['Discrete Time Varying',13,'State-Space/Subsystem/S-Function']])
set_param([sys,'/',['Discrete Time Varying',13,'State-Space/Subsystem/S-Function']],...
		'function name','stvmgain',...
		'parameters','K,Ts',...
		'position',[130,70,180,90])

add_block('built-in/Mux',[sys,'/',['Discrete Time Varying',13,'State-Space/Subsystem/Mux']])
set_param([sys,'/',['Discrete Time Varying',13,'State-Space/Subsystem/Mux']],...
		'inputs','[n m*n]',...
		'position',[60,61,90,94])
add_line([sys,'/',['Discrete Time Varying',13,'State-Space/Subsystem']],[35,85;55,85])
add_line([sys,'/',['Discrete Time Varying',13,'State-Space/Subsystem']],[185,80;205,80])
add_line([sys,'/',['Discrete Time Varying',13,'State-Space/Subsystem']],[35,70;55,70])
add_line([sys,'/',['Discrete Time Varying',13,'State-Space/Subsystem']],[95,80;125,80])
set_param([sys,'/',['Discrete Time Varying',13,'State-Space/Subsystem']],...
		'Mask Display','Time Varying\nMatrix Gain',...
		'Mask Type','Time Varying Matrix Gain',...
		'Mask Dialogue','Matrix Gain|Initial Gain Matrix: |Update Sample Time')
set_param([sys,'/',['Discrete Time Varying',13,'State-Space/Subsystem']],...
		'Mask Translate','K=@1;Ts=@2;[m,n]=size(@1);')
set_param([sys,'/',['Discrete Time Varying',13,'State-Space/Subsystem']],...
		'Mask Help','This block implements a time-varying matrix gain. The intial gain K determines the resizing of the vector input gain. The gain matrix(m,n) will produce m outputs, the input u having n columns.')
set_param([sys,'/',['Discrete Time Varying',13,'State-Space/Subsystem']],...
		'Mask Entries','B\/Ts\/')


%     Finished composite block ['Discrete Time Varying',13,'State-Space/Subsystem'].

set_param([sys,'/',['Discrete Time Varying',13,'State-Space/Subsystem']],...
		'position',[155,115,245,170])

add_block('built-in/Sum',[sys,'/',['Discrete Time Varying',13,'State-Space/Sum']])
set_param([sys,'/',['Discrete Time Varying',13,'State-Space/Sum']],...
		'position',[290,18,335,187])

add_block('built-in/Inport',[sys,'/',['Discrete Time Varying',13,'State-Space/B']])
set_param([sys,'/',['Discrete Time Varying',13,'State-Space/B']],...
		'Port','3',...
		'position',[105,145,125,165])

add_block('built-in/Inport',[sys,'/',['Discrete Time Varying',13,'State-Space/U']])
set_param([sys,'/',['Discrete Time Varying',13,'State-Space/U']],...
		'position',[20,120,40,140])


%     Subsystem  ['Discrete Time Varying',13,'State-Space/Subsystem2'].

new_system([sys,'/',['Discrete Time Varying',13,'State-Space/Subsystem2']])
set_param([sys,'/',['Discrete Time Varying',13,'State-Space/Subsystem2']],'Location',[579,383,930,533])

add_block('built-in/Inport',[sys,'/',['Discrete Time Varying',13,'State-Space/Subsystem2/in_2']])
set_param([sys,'/',['Discrete Time Varying',13,'State-Space/Subsystem2/in_2']],...
		'Port','2',...
		'position',[10,75,30,95])

add_block('built-in/Outport',[sys,'/',['Discrete Time Varying',13,'State-Space/Subsystem2/out_1']])
set_param([sys,'/',['Discrete Time Varying',13,'State-Space/Subsystem2/out_1']],...
		'position',[210,70,230,90])

add_block('built-in/Inport',[sys,'/',['Discrete Time Varying',13,'State-Space/Subsystem2/in_1']])
set_param([sys,'/',['Discrete Time Varying',13,'State-Space/Subsystem2/in_1']],...
		'position',[10,60,30,80])

add_block('built-in/S-Function',[sys,'/',['Discrete Time Varying',13,'State-Space/Subsystem2/S-Function']])
set_param([sys,'/',['Discrete Time Varying',13,'State-Space/Subsystem2/S-Function']],...
		'function name','stvmgain',...
		'parameters','K,Ts',...
		'position',[130,70,180,90])

add_block('built-in/Mux',[sys,'/',['Discrete Time Varying',13,'State-Space/Subsystem2/Mux']])
set_param([sys,'/',['Discrete Time Varying',13,'State-Space/Subsystem2/Mux']],...
		'inputs','[n m*n]',...
		'position',[60,61,90,94])
add_line([sys,'/',['Discrete Time Varying',13,'State-Space/Subsystem2']],[35,85;55,85])
add_line([sys,'/',['Discrete Time Varying',13,'State-Space/Subsystem2']],[185,80;205,80])
add_line([sys,'/',['Discrete Time Varying',13,'State-Space/Subsystem2']],[35,70;55,70])
add_line([sys,'/',['Discrete Time Varying',13,'State-Space/Subsystem2']],[95,80;125,80])
set_param([sys,'/',['Discrete Time Varying',13,'State-Space/Subsystem2']],...
		'Mask Display','Time Varying\nMatrix Gain',...
		'Mask Type','Time Varying Matrix Gain',...
		'Mask Dialogue','Matrix Gain|Initial Gain Matrix: |Update Sample Time')
set_param([sys,'/',['Discrete Time Varying',13,'State-Space/Subsystem2']],...
		'Mask Translate','K=@1;Ts=@2;[m,n]=size(@1);')
set_param([sys,'/',['Discrete Time Varying',13,'State-Space/Subsystem2']],...
		'Mask Help','This block implements a time-varying matrix gain. The intial gain K determines the resizing of the vector input gain. The gain matrix(m,n) will produce m outputs, the input u having n columns.')
set_param([sys,'/',['Discrete Time Varying',13,'State-Space/Subsystem2']],...
		'Mask Entries','C\/Ts\/')


%     Finished composite block ['Discrete Time Varying',13,'State-Space/Subsystem2'].

set_param([sys,'/',['Discrete Time Varying',13,'State-Space/Subsystem2']],...
		'position',[460,195,550,250])


%     Subsystem  ['Discrete Time Varying',13,'State-Space/Subsystem3'].

new_system([sys,'/',['Discrete Time Varying',13,'State-Space/Subsystem3']])
set_param([sys,'/',['Discrete Time Varying',13,'State-Space/Subsystem3']],'Location',[579,383,930,533])

add_block('built-in/Mux',[sys,'/',['Discrete Time Varying',13,'State-Space/Subsystem3/Mux']])
set_param([sys,'/',['Discrete Time Varying',13,'State-Space/Subsystem3/Mux']],...
		'inputs','[n m*n]',...
		'position',[60,61,90,94])

add_block('built-in/S-Function',[sys,'/',['Discrete Time Varying',13,'State-Space/Subsystem3/S-Function']])
set_param([sys,'/',['Discrete Time Varying',13,'State-Space/Subsystem3/S-Function']],...
		'function name','stvmgain',...
		'parameters','K,Ts',...
		'position',[130,70,180,90])

add_block('built-in/Inport',[sys,'/',['Discrete Time Varying',13,'State-Space/Subsystem3/in_1']])
set_param([sys,'/',['Discrete Time Varying',13,'State-Space/Subsystem3/in_1']],...
		'position',[10,60,30,80])

add_block('built-in/Outport',[sys,'/',['Discrete Time Varying',13,'State-Space/Subsystem3/out_1']])
set_param([sys,'/',['Discrete Time Varying',13,'State-Space/Subsystem3/out_1']],...
		'position',[210,70,230,90])

add_block('built-in/Inport',[sys,'/',['Discrete Time Varying',13,'State-Space/Subsystem3/in_2']])
set_param([sys,'/',['Discrete Time Varying',13,'State-Space/Subsystem3/in_2']],...
		'Port','2',...
		'position',[10,75,30,95])
add_line([sys,'/',['Discrete Time Varying',13,'State-Space/Subsystem3']],[95,80;125,80])
add_line([sys,'/',['Discrete Time Varying',13,'State-Space/Subsystem3']],[35,70;55,70])
add_line([sys,'/',['Discrete Time Varying',13,'State-Space/Subsystem3']],[185,80;205,80])
add_line([sys,'/',['Discrete Time Varying',13,'State-Space/Subsystem3']],[35,85;55,85])
set_param([sys,'/',['Discrete Time Varying',13,'State-Space/Subsystem3']],...
		'Mask Display','Time Varying\nMatrix Gain',...
		'Mask Type','Time Varying Matrix Gain',...
		'Mask Dialogue','Matrix Gain|Initial Gain Matrix: |Update Sample Time')
set_param([sys,'/',['Discrete Time Varying',13,'State-Space/Subsystem3']],...
		'Mask Translate','K=@1;Ts=@2;[m,n]=size(@1);')
set_param([sys,'/',['Discrete Time Varying',13,'State-Space/Subsystem3']],...
		'Mask Help','This block implements a time-varying matrix gain. The intial gain K determines the resizing of the vector input gain. The gain matrix(m,n) will produce m outputs, the input u having n columns.')
set_param([sys,'/',['Discrete Time Varying',13,'State-Space/Subsystem3']],...
		'Mask Entries','D\/Ts\/')


%     Finished composite block ['Discrete Time Varying',13,'State-Space/Subsystem3'].

set_param([sys,'/',['Discrete Time Varying',13,'State-Space/Subsystem3']],...
		'position',[460,300,550,355])

add_block('built-in/Inport',[sys,'/',['Discrete Time Varying',13,'State-Space/D']])
set_param([sys,'/',['Discrete Time Varying',13,'State-Space/D']],...
		'Port','5',...
		'position',[410,330,430,350])

add_block('built-in/Inport',[sys,'/',['Discrete Time Varying',13,'State-Space/C']])
set_param([sys,'/',['Discrete Time Varying',13,'State-Space/C']],...
		'Port','4',...
		'position',[410,225,430,245])

add_block('built-in/Sum',[sys,'/',['Discrete Time Varying',13,'State-Space/Sum1']])
set_param([sys,'/',['Discrete Time Varying',13,'State-Space/Sum1']],...
		'position',[595,174,625,381])

add_block('built-in/Outport',[sys,'/',['Discrete Time Varying',13,'State-Space/Y']])
set_param([sys,'/',['Discrete Time Varying',13,'State-Space/Y']],...
		'position',[660,270,680,290])

add_block('built-in/Unit Delay',[sys,'/',['Discrete Time Varying',13,'State-Space/Unit Delay']])
set_param([sys,'/',['Discrete Time Varying',13,'State-Space/Unit Delay']],...
		'Sample time','Tz',...
		'x0','x0',...
		'position',[360,97,410,113])
add_line([sys,'/',['Discrete Time Varying',13,'State-Space']],[45,130;150,130])
add_line([sys,'/',['Discrete Time Varying',13,'State-Space']],[85,130;85,315;455,315])
add_line([sys,'/',['Discrete Time Varying',13,'State-Space']],[415,105;435,105;435,5;115,5;115,45;150,45])
add_line([sys,'/',['Discrete Time Varying',13,'State-Space']],[435,105;435,210;455,210])
add_line([sys,'/',['Discrete Time Varying',13,'State-Space']],[250,60;285,60])
add_line([sys,'/',['Discrete Time Varying',13,'State-Space']],[250,145;285,145])
add_line([sys,'/',['Discrete Time Varying',13,'State-Space']],[555,225;590,225])
add_line([sys,'/',['Discrete Time Varying',13,'State-Space']],[555,330;590,330])
add_line([sys,'/',['Discrete Time Varying',13,'State-Space']],[130,70;150,70])
add_line([sys,'/',['Discrete Time Varying',13,'State-Space']],[435,235;455,235])
add_line([sys,'/',['Discrete Time Varying',13,'State-Space']],[630,280;655,280])
add_line([sys,'/',['Discrete Time Varying',13,'State-Space']],[130,155;150,155])
add_line([sys,'/',['Discrete Time Varying',13,'State-Space']],[435,340;455,340])
add_line([sys,'/',['Discrete Time Varying',13,'State-Space']],[340,105;355,105])
set_param([sys,'/',['Discrete Time Varying',13,'State-Space']],...
		'Mask Display','x(n+1)= A(t)x[n] + B(t)u[n] \n y(n) = C(t)x[n] + D(t)u[n]',...
		'Mask Type','Time Varying State Space Block')
set_param([sys,'/',['Discrete Time Varying',13,'State-Space']],...
		'Mask Dialogue','Initialize Values |Initial A:|Initial B:|Initial C:| Intial D:|x0:|Ts:')
set_param([sys,'/',['Discrete Time Varying',13,'State-Space']],...
		'Mask Translate','A=@1;B=@2;C=@3;D=@4; x0=@5; if length(@6)==2,Tz=@6(1);Ts=@6(2);, else Ts=@6; Tz=@6; end')
set_param([sys,'/',['Discrete Time Varying',13,'State-Space']],...
		'Mask Help','Inputs 1-4 are the A,B,C, & D matrices. Input 5 is the system input. Initial matrices determine sizes of variables being passed in. Unmask the block to see how is works. The delay time is the first element of Ts while the block update time is the second element. If they are')
set_param([sys,'/',['Discrete Time Varying',13,'State-Space']],...
		'Mask Entries','A\/B\/C\/D\/[0 0 0]''\/[.1 1]\/')


%     Finished composite block ['Discrete Time Varying',13,'State-Space'].

set_param([sys,'/',['Discrete Time Varying',13,'State-Space']],...
		'position',[155,40,340,180])

add_block('built-in/Sine Wave',[sys,'/','Sine Wave'])
set_param([sys,'/','Sine Wave'],...
		'amplitude','[1 2 3]',...
		'frequency','[3 2 1]',...
		'position',[35,32,65,58])

add_block('built-in/Constant',[sys,'/','D'])
set_param([sys,'/','D'],...
		'Value','K',...
		'Mask Display','D',...
		'Mask Type','Matrix Constant',...
		'Mask Dialogue','Matrix Constant:|Matrix Constant Value:',...
		'Mask Translate','K=@1(:);',...
		'Mask Entries','D\/')
set_param([sys,'/','D'],...
		'position',[60,158,85,182])

add_block('built-in/Discrete State-Space',[sys,'/','Discrete State-Space'])
set_param([sys,'/','Discrete State-Space'],...
		'A','A',...
		'B','B',...
		'C','C',...
		'D','D',...
		'position',[185,218,305,262])

add_block('built-in/To Workspace',[sys,'/','To Workspace'])
set_param([sys,'/','To Workspace'],...
		'mat-name','yout',...
		'position',[385,102,435,118])

add_block('built-in/To Workspace',[sys,'/','To Workspace1'])
set_param([sys,'/','To Workspace1'],...
		'mat-name','yout1',...
		'position',[370,232,420,248])

add_block('built-in/Constant',[sys,'/','B'])
set_param([sys,'/','B'],...
		'Value','K',...
		'Mask Display','B',...
		'Mask Type','Matrix Constant',...
		'Mask Dialogue','Matrix Constant:|Matrix Constant Value:',...
		'Mask Translate','K=@1(:);',...
		'Mask Entries','B\/')
set_param([sys,'/','B'],...
		'position',[60,98,85,122])

add_block('built-in/Constant',[sys,'/','C'])
set_param([sys,'/','C'],...
		'Value','K',...
		'Mask Display','C',...
		'Mask Type','Matrix Constant',...
		'Mask Dialogue','Matrix Constant:|Matrix Constant Value:',...
		'Mask Translate','K=@1(:);',...
		'Mask Entries','C\/')
set_param([sys,'/','C'],...
		'position',[35,128,60,152])

add_block('built-in/Constant',[sys,'/','A'])
set_param([sys,'/','A'],...
		'Value','K',...
		'Mask Display','A',...
		'Mask Type','Matrix Constant',...
		'Mask Dialogue','Matrix Constant:|Matrix Constant Value:',...
		'Mask Translate','K=@1(:);',...
		'Mask Entries','A\/')
set_param([sys,'/','A'],...
		'position',[40,68,65,92])

add_block('built-in/Note',[sys,'/',['This system requires two sample times, Tz, the unit delay sample time',13,'and Ts, the block update sample time. If the times are different, place the ',13,'unit delay time Tz as the first element and Ts as the second in the',13,'Ts box of the mask.']])
set_param([sys,'/',['This system requires two sample times, Tz, the unit delay sample time',13,'and Ts, the block update sample time. If the times are different, place the ',13,'unit delay time Tz as the first element and Ts as the second in the',13,'Ts box of the mask.']],...
		'position',[310,310,315,315])


%     Subsystem  'click here'.

new_system([sys,'/','click here'])
set_param([sys,'/','click here'],'Location',[345,359,629,518])

add_block('built-in/Constant',[sys,'/','click here/click here'])
set_param([sys,'/','click here/click here'],...
		'Value','K',...
		'Mask Display','A',...
		'Mask Type','Matrix Constant',...
		'Mask Dialogue','Matrix Constant:|Matrix Constant Value:',...
		'Mask Translate','K=@1(:);',...
		'Mask Entries','A\/')
set_param([sys,'/','click here/click here'],...
		'position',[55,46,180,104])
set_param([sys,'/','click here'],...
		'Mask Display','Load \nData',...
		'Mask Dialogue','eval(''[A B C D]=drmodel(3,1,3);'')')


%     Finished composite block 'click here'.

set_param([sys,'/','click here'],...
		'position',[450,165,560,211])

add_block('built-in/Scope',[sys,'/','Scope'])
set_param([sys,'/','Scope'],...
		'Vgain','10.000000',...
		'Hgain','20.000000',...
		'Vmax','20.000000',...
		'Hmax','40.000000',...
		'Window',[14,160,345,474],...
		'position',[405,35,435,65])
add_line(sys,[70,45;105,45;105,50;150,50])
add_line(sys,[90,170;150,170])
add_line(sys,[65,140;150,140])
add_line(sys,[90,110;150,110])
add_line(sys,[70,80;150,80])
add_line(sys,[345,110;380,110])
add_line(sys,[310,240;365,240])
add_line(sys,[105,50;105,240;180,240])

drawnow

% Return any arguments.
if (nargin | nargout)
	% Must use feval here to access system in memory
	if (nargin > 3)
		if (flag == 0)
			eval(['[ret,x0,str,ts,xts]=',sys,'(t,x,u,flag);'])
		else
			eval(['ret =', sys,'(t,x,u,flag);'])
		end
	else
		[ret,x0,str,ts,xts] = feval(sys);
	end
else
	drawnow % Flash up the model and execute load callback
end
