function [ret,x0,str,ts,xts]=stvss(t,x,u,flag);
%STVSS	is the M-file description of the SIMULINK system named STVSS.
%	The block-diagram can be displayed by typing: STVSS.
%
%	SYS=STVSS(T,X,U,FLAG) returns depending on FLAG certain
%	system values given time point, T, current state vector, X,
%	and input vector, U.
%	FLAG is used to indicate the type of output to be returned in SYS.
%
%	Setting FLAG=1 causes STVSS to return state derivatives, FLAG=2
%	discrete states, FLAG=3 system outputs and FLAG=4 next sample
%	time. For more information and other options see SFUNC.
%
%	Calling STVSS with a FLAG of zero:
%	[SIZES]=STVSS([],[],[],0),  returns a vector, SIZES, which
%	contains the sizes of the state vector and other parameters.
%		SIZES(1) number of states
%		SIZES(2) number of discrete states
%		SIZES(3) number of outputs
%		SIZES(4) number of inputs
%		SIZES(5) number of roots (currently unsupported)
%		SIZES(6) direct feedthrough flag
%		SIZES(7) number of sample times
%
%	For the definition of other parameters in SIZES, see SFUNC.
%	See also, TRIM, LINMOD, LINSIM, EULER, RK23, RK45, ADAMS, GEAR.

% Note: This M-file is only used for saving graphical information;
%       after the model is loaded into memory an internal model
%       representation is used.

% the system will take on the name of this mfile:
sys = mfilename;
new_system(sys)
simver(1.3)
if (0 == (nargin + nargout))
     set_param(sys,'Location',[62,382,830,682])
     open_system(sys)
end;
set_param(sys,'algorithm',     'RK-45')
set_param(sys,'Start time',    '0.0')
set_param(sys,'Stop time',     '1000')
set_param(sys,'Min step size', '0.0001')
set_param(sys,'Max step size', '.10')
set_param(sys,'Relative error','1e-3')
set_param(sys,'Return vars',   '')
set_param(sys,'AssignSampleTimeColors','on');
set_param(sys,'AssignWideVectorLines','on');

add_block('built-in/State-Space',[sys,'/','State-Space'])
set_param([sys,'/','State-Space'],...
		'A','A',...
		'B','B',...
		'C','C',...
		'D','D',...
		'position',[245,199,320,241])

add_block('built-in/To Workspace',[sys,'/','To Workspace1'])
set_param([sys,'/','To Workspace1'],...
		'mat-name','yout1',...
		'position',[405,212,455,228])


%     Subsystem  ['Time Varying',13,'State-Space'].

new_system([sys,'/',['Time Varying',13,'State-Space']])
set_param([sys,'/',['Time Varying',13,'State-Space']],'Location',[77,67,766,488])

add_block('built-in/Outport',[sys,'/',['Time Varying',13,'State-Space/Y']])
set_param([sys,'/',['Time Varying',13,'State-Space/Y']],...
		'position',[660,270,680,290])

add_block('built-in/Sum',[sys,'/',['Time Varying',13,'State-Space/Sum1']])
set_param([sys,'/',['Time Varying',13,'State-Space/Sum1']],...
		'position',[595,174,625,381])

add_block('built-in/Inport',[sys,'/',['Time Varying',13,'State-Space/C']])
set_param([sys,'/',['Time Varying',13,'State-Space/C']],...
		'Port','4',...
		'position',[410,225,430,245])

add_block('built-in/Inport',[sys,'/',['Time Varying',13,'State-Space/D']])
set_param([sys,'/',['Time Varying',13,'State-Space/D']],...
		'Port','5',...
		'position',[410,330,430,350])


%     Subsystem  ['Time Varying',13,'State-Space/Subsystem3'].

new_system([sys,'/',['Time Varying',13,'State-Space/Subsystem3']])
set_param([sys,'/',['Time Varying',13,'State-Space/Subsystem3']],'Location',[579,383,930,533])

add_block('built-in/Inport',[sys,'/',['Time Varying',13,'State-Space/Subsystem3/in_2']])
set_param([sys,'/',['Time Varying',13,'State-Space/Subsystem3/in_2']],...
		'Port','2',...
		'position',[10,75,30,95])

add_block('built-in/Outport',[sys,'/',['Time Varying',13,'State-Space/Subsystem3/out_1']])
set_param([sys,'/',['Time Varying',13,'State-Space/Subsystem3/out_1']],...
		'position',[210,70,230,90])

add_block('built-in/Inport',[sys,'/',['Time Varying',13,'State-Space/Subsystem3/in_1']])
set_param([sys,'/',['Time Varying',13,'State-Space/Subsystem3/in_1']],...
		'position',[10,60,30,80])

add_block('built-in/S-Function',[sys,'/',['Time Varying',13,'State-Space/Subsystem3/S-Function']])
set_param([sys,'/',['Time Varying',13,'State-Space/Subsystem3/S-Function']],...
		'function name','stvmgain',...
		'parameters','K,Ts',...
		'position',[130,70,180,90])

add_block('built-in/Mux',[sys,'/',['Time Varying',13,'State-Space/Subsystem3/Mux']])
set_param([sys,'/',['Time Varying',13,'State-Space/Subsystem3/Mux']],...
		'inputs','[n m*n]',...
		'position',[60,61,90,94])
add_line([sys,'/',['Time Varying',13,'State-Space/Subsystem3']],[35,85;55,85])
add_line([sys,'/',['Time Varying',13,'State-Space/Subsystem3']],[185,80;205,80])
add_line([sys,'/',['Time Varying',13,'State-Space/Subsystem3']],[35,70;55,70])
add_line([sys,'/',['Time Varying',13,'State-Space/Subsystem3']],[95,80;125,80])
set_param([sys,'/',['Time Varying',13,'State-Space/Subsystem3']],...
		'Mask Display','Time Varying\nMatrix Gain',...
		'Mask Type','Time Varying Matrix Gain',...
		'Mask Dialogue','Matrix Gain|Initial Gain Matrix: |Update Sample Time')
set_param([sys,'/',['Time Varying',13,'State-Space/Subsystem3']],...
		'Mask Translate','K=@1;Ts=@2;[m,n]=size(@1);')
set_param([sys,'/',['Time Varying',13,'State-Space/Subsystem3']],...
		'Mask Help','This block implements a time-varying matrix gain. The intial gain K determines the resizing of the vector input gain. The gain matrix(m,n) will produce m outputs, the input u having n columns.')
set_param([sys,'/',['Time Varying',13,'State-Space/Subsystem3']],...
		'Mask Entries','D\/Ts\/')


%     Finished composite block ['Time Varying',13,'State-Space/Subsystem3'].

set_param([sys,'/',['Time Varying',13,'State-Space/Subsystem3']],...
		'position',[460,300,550,355])


%     Subsystem  ['Time Varying',13,'State-Space/Subsystem2'].

new_system([sys,'/',['Time Varying',13,'State-Space/Subsystem2']])
set_param([sys,'/',['Time Varying',13,'State-Space/Subsystem2']],'Location',[579,383,930,533])

add_block('built-in/Mux',[sys,'/',['Time Varying',13,'State-Space/Subsystem2/Mux']])
set_param([sys,'/',['Time Varying',13,'State-Space/Subsystem2/Mux']],...
		'inputs','[n m*n]',...
		'position',[60,61,90,94])

add_block('built-in/S-Function',[sys,'/',['Time Varying',13,'State-Space/Subsystem2/S-Function']])
set_param([sys,'/',['Time Varying',13,'State-Space/Subsystem2/S-Function']],...
		'function name','stvmgain',...
		'parameters','K,Ts',...
		'position',[130,70,180,90])

add_block('built-in/Inport',[sys,'/',['Time Varying',13,'State-Space/Subsystem2/in_1']])
set_param([sys,'/',['Time Varying',13,'State-Space/Subsystem2/in_1']],...
		'position',[10,60,30,80])

add_block('built-in/Outport',[sys,'/',['Time Varying',13,'State-Space/Subsystem2/out_1']])
set_param([sys,'/',['Time Varying',13,'State-Space/Subsystem2/out_1']],...
		'position',[210,70,230,90])

add_block('built-in/Inport',[sys,'/',['Time Varying',13,'State-Space/Subsystem2/in_2']])
set_param([sys,'/',['Time Varying',13,'State-Space/Subsystem2/in_2']],...
		'Port','2',...
		'position',[10,75,30,95])
add_line([sys,'/',['Time Varying',13,'State-Space/Subsystem2']],[95,80;125,80])
add_line([sys,'/',['Time Varying',13,'State-Space/Subsystem2']],[35,70;55,70])
add_line([sys,'/',['Time Varying',13,'State-Space/Subsystem2']],[185,80;205,80])
add_line([sys,'/',['Time Varying',13,'State-Space/Subsystem2']],[35,85;55,85])
set_param([sys,'/',['Time Varying',13,'State-Space/Subsystem2']],...
		'Mask Display','Time Varying\nMatrix Gain',...
		'Mask Type','Time Varying Matrix Gain',...
		'Mask Dialogue','Matrix Gain|Initial Gain Matrix: |Update Sample Time')
set_param([sys,'/',['Time Varying',13,'State-Space/Subsystem2']],...
		'Mask Translate','K=@1;Ts=@2;[m,n]=size(@1);')
set_param([sys,'/',['Time Varying',13,'State-Space/Subsystem2']],...
		'Mask Help','This block implements a time-varying matrix gain. The intial gain K determines the resizing of the vector input gain. The gain matrix(m,n) will produce m outputs, the input u having n columns.')
set_param([sys,'/',['Time Varying',13,'State-Space/Subsystem2']],...
		'Mask Entries','C\/Ts\/')


%     Finished composite block ['Time Varying',13,'State-Space/Subsystem2'].

set_param([sys,'/',['Time Varying',13,'State-Space/Subsystem2']],...
		'position',[460,195,550,250])

add_block('built-in/Inport',[sys,'/',['Time Varying',13,'State-Space/U']])
set_param([sys,'/',['Time Varying',13,'State-Space/U']],...
		'position',[20,120,40,140])

add_block('built-in/Note',[sys,'/',['Time Varying',13,'State-Space/x''']])
set_param([sys,'/',['Time Varying',13,'State-Space/x''']],...
		'position',[354,78,359,83])

add_block('built-in/Integrator',[sys,'/',['Time Varying',13,'State-Space/Integrator']])
set_param([sys,'/',['Time Varying',13,'State-Space/Integrator']],...
		'Initial','x0',...
		'position',[385,95,405,115])

add_block('built-in/Inport',[sys,'/',['Time Varying',13,'State-Space/B']])
set_param([sys,'/',['Time Varying',13,'State-Space/B']],...
		'Port','3',...
		'position',[105,145,125,165])

add_block('built-in/Sum',[sys,'/',['Time Varying',13,'State-Space/Sum']])
set_param([sys,'/',['Time Varying',13,'State-Space/Sum']],...
		'position',[290,18,335,187])


%     Subsystem  ['Time Varying',13,'State-Space/Subsystem'].

new_system([sys,'/',['Time Varying',13,'State-Space/Subsystem']])
set_param([sys,'/',['Time Varying',13,'State-Space/Subsystem']],'Location',[579,383,930,533])

add_block('built-in/Mux',[sys,'/',['Time Varying',13,'State-Space/Subsystem/Mux']])
set_param([sys,'/',['Time Varying',13,'State-Space/Subsystem/Mux']],...
		'inputs','[n m*n]',...
		'position',[60,61,90,94])

add_block('built-in/S-Function',[sys,'/',['Time Varying',13,'State-Space/Subsystem/S-Function']])
set_param([sys,'/',['Time Varying',13,'State-Space/Subsystem/S-Function']],...
		'function name','stvmgain',...
		'parameters','K,Ts',...
		'position',[130,70,180,90])

add_block('built-in/Inport',[sys,'/',['Time Varying',13,'State-Space/Subsystem/in_1']])
set_param([sys,'/',['Time Varying',13,'State-Space/Subsystem/in_1']],...
		'position',[10,60,30,80])

add_block('built-in/Outport',[sys,'/',['Time Varying',13,'State-Space/Subsystem/out_1']])
set_param([sys,'/',['Time Varying',13,'State-Space/Subsystem/out_1']],...
		'position',[210,70,230,90])

add_block('built-in/Inport',[sys,'/',['Time Varying',13,'State-Space/Subsystem/in_2']])
set_param([sys,'/',['Time Varying',13,'State-Space/Subsystem/in_2']],...
		'Port','2',...
		'position',[10,75,30,95])
add_line([sys,'/',['Time Varying',13,'State-Space/Subsystem']],[95,80;125,80])
add_line([sys,'/',['Time Varying',13,'State-Space/Subsystem']],[35,70;55,70])
add_line([sys,'/',['Time Varying',13,'State-Space/Subsystem']],[185,80;205,80])
add_line([sys,'/',['Time Varying',13,'State-Space/Subsystem']],[35,85;55,85])
set_param([sys,'/',['Time Varying',13,'State-Space/Subsystem']],...
		'Mask Display','Time Varying\nMatrix Gain',...
		'Mask Type','Time Varying Matrix Gain',...
		'Mask Dialogue','Matrix Gain|Initial Gain Matrix: |Update Sample Time')
set_param([sys,'/',['Time Varying',13,'State-Space/Subsystem']],...
		'Mask Translate','K=@1;Ts=@2;[m,n]=size(@1);')
set_param([sys,'/',['Time Varying',13,'State-Space/Subsystem']],...
		'Mask Help','This block implements a time-varying matrix gain. The intial gain K determines the resizing of the vector input gain. The gain matrix(m,n) will produce m outputs, the input u having n columns.')
set_param([sys,'/',['Time Varying',13,'State-Space/Subsystem']],...
		'Mask Entries','B\/Ts\/')


%     Finished composite block ['Time Varying',13,'State-Space/Subsystem'].

set_param([sys,'/',['Time Varying',13,'State-Space/Subsystem']],...
		'position',[155,115,245,170])

add_block('built-in/Note',[sys,'/',['Time Varying',13,'State-Space/x']])
set_param([sys,'/',['Time Varying',13,'State-Space/x']],...
		'position',[130,20,135,25])

add_block('built-in/Inport',[sys,'/',['Time Varying',13,'State-Space/A']])
set_param([sys,'/',['Time Varying',13,'State-Space/A']],...
		'Port','2',...
		'position',[105,60,125,80])


%     Subsystem  ['Time Varying',13,'State-Space/Subsystem1'].

new_system([sys,'/',['Time Varying',13,'State-Space/Subsystem1']])
set_param([sys,'/',['Time Varying',13,'State-Space/Subsystem1']],'Location',[579,383,930,533])

add_block('built-in/Inport',[sys,'/',['Time Varying',13,'State-Space/Subsystem1/in_2']])
set_param([sys,'/',['Time Varying',13,'State-Space/Subsystem1/in_2']],...
		'Port','2',...
		'position',[10,75,30,95])

add_block('built-in/Outport',[sys,'/',['Time Varying',13,'State-Space/Subsystem1/out_1']])
set_param([sys,'/',['Time Varying',13,'State-Space/Subsystem1/out_1']],...
		'position',[210,70,230,90])

add_block('built-in/Inport',[sys,'/',['Time Varying',13,'State-Space/Subsystem1/in_1']])
set_param([sys,'/',['Time Varying',13,'State-Space/Subsystem1/in_1']],...
		'position',[10,60,30,80])

add_block('built-in/S-Function',[sys,'/',['Time Varying',13,'State-Space/Subsystem1/S-Function']])
set_param([sys,'/',['Time Varying',13,'State-Space/Subsystem1/S-Function']],...
		'function name','stvmgain',...
		'parameters','K,Ts',...
		'position',[130,70,180,90])

add_block('built-in/Mux',[sys,'/',['Time Varying',13,'State-Space/Subsystem1/Mux']])
set_param([sys,'/',['Time Varying',13,'State-Space/Subsystem1/Mux']],...
		'inputs','[n m*n]',...
		'position',[60,61,90,94])
add_line([sys,'/',['Time Varying',13,'State-Space/Subsystem1']],[35,85;55,85])
add_line([sys,'/',['Time Varying',13,'State-Space/Subsystem1']],[185,80;205,80])
add_line([sys,'/',['Time Varying',13,'State-Space/Subsystem1']],[35,70;55,70])
add_line([sys,'/',['Time Varying',13,'State-Space/Subsystem1']],[95,80;125,80])
set_param([sys,'/',['Time Varying',13,'State-Space/Subsystem1']],...
		'Mask Display','Time Varying\nMatrix Gain',...
		'Mask Type','Time Varying Matrix Gain',...
		'Mask Dialogue','Matrix Gain|Initial Gain Matrix: |Update Sample Time')
set_param([sys,'/',['Time Varying',13,'State-Space/Subsystem1']],...
		'Mask Translate','K=@1;Ts=@2;[m,n]=size(@1);')
set_param([sys,'/',['Time Varying',13,'State-Space/Subsystem1']],...
		'Mask Help','This block implements a time-varying matrix gain. The intial gain K determines the resizing of the vector input gain. The gain matrix(m,n) will produce m outputs, the input u having n columns.')
set_param([sys,'/',['Time Varying',13,'State-Space/Subsystem1']],...
		'Mask Entries','A\/Ts\/')


%     Finished composite block ['Time Varying',13,'State-Space/Subsystem1'].

set_param([sys,'/',['Time Varying',13,'State-Space/Subsystem1']],...
		'position',[155,30,245,85])

add_block('built-in/Scope',[sys,'/',['Time Varying',13,'State-Space/Scope']])
set_param([sys,'/',['Time Varying',13,'State-Space/Scope']],...
		'Vgain','2.000000',...
		'Hgain','12.000000',...
		'Vmax','4.000000',...
		'Hmax','24.000000',...
		'Window',[802,517,1133,831],...
		'position',[535,55,565,85])
add_line([sys,'/',['Time Varying',13,'State-Space']],[435,340;455,340])
add_line([sys,'/',['Time Varying',13,'State-Space']],[130,155;150,155])
add_line([sys,'/',['Time Varying',13,'State-Space']],[630,280;655,280])
add_line([sys,'/',['Time Varying',13,'State-Space']],[435,235;455,235])
add_line([sys,'/',['Time Varying',13,'State-Space']],[130,70;150,70])
add_line([sys,'/',['Time Varying',13,'State-Space']],[410,105;435,105;435,5;115,5;115,45;150,45])
add_line([sys,'/',['Time Varying',13,'State-Space']],[555,330;590,330])
add_line([sys,'/',['Time Varying',13,'State-Space']],[555,225;590,225])
add_line([sys,'/',['Time Varying',13,'State-Space']],[340,105;380,105])
add_line([sys,'/',['Time Varying',13,'State-Space']],[250,145;285,145])
add_line([sys,'/',['Time Varying',13,'State-Space']],[250,60;285,60])
add_line([sys,'/',['Time Varying',13,'State-Space']],[45,130;150,130])
add_line([sys,'/',['Time Varying',13,'State-Space']],[435,105;435,210;455,210])
add_line([sys,'/',['Time Varying',13,'State-Space']],[85,130;85,315;455,315])
set_param([sys,'/',['Time Varying',13,'State-Space']],...
		'Mask Display','x'' = A(t)x + B(t)u \n y = C(t)x + D(t)u',...
		'Mask Type','Time Varying State Space Block')
set_param([sys,'/',['Time Varying',13,'State-Space']],...
		'Mask Dialogue','Initial State Variables |Initial A:|Initial B:|Initial C:| Intial D:|Initial Conditions X0:|Ts:',...
		'Mask Translate','A=@1;B=@2;C=@3;D=@4; x0=@5;Ts=@6;')
set_param([sys,'/',['Time Varying',13,'State-Space']],...
		'Mask Help','Inputs 1-4 are the A,B,C, & D matrices. Input 5 is the system input. Initial matrices determine sizes of variables being passed in. Unmask the block to see how is works. ')
set_param([sys,'/',['Time Varying',13,'State-Space']],...
		'Mask Entries','A\/B\/C\/ D\/0\/-1\/')


%     Finished composite block ['Time Varying',13,'State-Space'].

set_param([sys,'/',['Time Varying',13,'State-Space']],...
		'position',[210,30,395,150])

add_block('built-in/Scope',[sys,'/','Scope'])
set_param([sys,'/','Scope'],...
		'Vgain','1.000000',...
		'Hgain','12.000000',...
		'Vmax','2.000000',...
		'Hmax','24.000000',...
		'Window',[526,102,857,416],...
		'position',[545,145,575,175])

add_block('built-in/Constant',[sys,'/','B'])
set_param([sys,'/','B'],...
		'Value','K',...
		'Mask Display','B',...
		'Mask Type','Matrix Constant',...
		'Mask Dialogue','Matrix Constant:|Matrix Constant Value:',...
		'Mask Translate','K=@1(:);',...
		'Mask Entries','B\/')
set_param([sys,'/','B'],...
		'position',[55,78,80,102])

add_block('built-in/Constant',[sys,'/','D'])
set_param([sys,'/','D'],...
		'Value','K',...
		'Mask Display','D',...
		'Mask Type','Matrix Constant',...
		'Mask Dialogue','Matrix Constant:|Matrix Constant Value:',...
		'Mask Translate','K=@1(:);',...
		'Mask Entries','D\/')
set_param([sys,'/','D'],...
		'position',[55,128,80,152])

add_block('built-in/Sine Wave',[sys,'/','Sine Wave'])
set_param([sys,'/','Sine Wave'],...
		'amplitude','ones(3)',...
		'frequency','ones(3)',...
		'position',[45,10,65,30])


%     Subsystem  ['Click',13,'Here'].

new_system([sys,'/',['Click',13,'Here']])
set_param([sys,'/',['Click',13,'Here']],'Location',[555,196,766,334])

add_block('built-in/Constant',[sys,'/',['Click',13,'Here/A1']])
set_param([sys,'/',['Click',13,'Here/A1']],...
		'Value','K',...
		'Mask Display','A',...
		'Mask Type','Matrix Constant',...
		'Mask Dialogue','Matrix Constant:|Matrix Constant Value:',...
		'Mask Translate','K=@1(:);',...
		'Mask Entries','A\/')
set_param([sys,'/',['Click',13,'Here/A1']],...
		'position',[55,53,125,97])
set_param([sys,'/',['Click',13,'Here']],...
		'Mask Display','Load \nVariables',...
		'Mask Dialogue','eval(''[A B C D] = rmodel(3,1,3);'')')


%     Finished composite block ['Click',13,'Here'].

set_param([sys,'/',['Click',13,'Here']],...
		'position',[597,190,665,236])

add_block('built-in/Constant',[sys,'/','A'])
set_param([sys,'/','A'],...
		'Value','K',...
		'Mask Display','A',...
		'Mask Type','Matrix Constant',...
		'Mask Dialogue','Matrix Constant:|Matrix Constant Value:',...
		'Mask Translate','K=@1(:);',...
		'Mask Entries','A\/')
set_param([sys,'/','A'],...
		'position',[30,53,55,77])

add_block('built-in/Constant',[sys,'/','C'])
set_param([sys,'/','C'],...
		'Value','K',...
		'Mask Display','C',...
		'Mask Type','Matrix Constant',...
		'Mask Dialogue','Matrix Constant:|Matrix Constant Value:',...
		'Mask Translate','K=@1(:);',...
		'Mask Entries','C\/')
set_param([sys,'/','C'],...
		'position',[30,103,55,127])

add_block('built-in/To Workspace',[sys,'/','To Workspace'])
set_param([sys,'/','To Workspace'],...
		'mat-name','yout',...
		'position',[480,82,530,98])
add_line(sys,[85,140;205,140])
add_line(sys,[325,220;400,220])
add_line(sys,[400,90;475,90])
add_line(sys,[70,20;130,20;130,40;205,40])
add_line(sys,[60,65;205,65])
add_line(sys,[85,90;205,90])
add_line(sys,[60,115;205,115])
add_line(sys,[130,40;130,220;240,220])

drawnow

% Return any arguments.
if (nargin | nargout)
	% Must use feval here to access system in memory
	if (nargin > 3)
		if (flag == 0)
			eval(['[ret,x0,str,ts,xts]=',sys,'(t,x,u,flag);'])
		else
			eval(['ret =', sys,'(t,x,u,flag);'])
		end
	else
		[ret,x0,str,ts,xts] = feval(sys);
	end
else
	drawnow % Flash up the model and execute load callback
end
