function [ret,x0,str,ts,xts]=tvgtest(t,x,u,flag);
%TVGTEST	is the M-file description of the SIMULINK system named TVGTEST.
%	TVGTEST has a the following characteristics:
%		0 continuous states
%		1 discrete states
%		0 outputs
%		0 inputs
%		does not have direct feedthrough
%		1 sample times
%
%	The block-diagram can be displayed by typing: TVGTEST.
%
%	SYS=TVGTEST(T,X,U,FLAG) returns depending on FLAG certain
%	system values given time point, T, current state vector, X,
%	and input vector, U.
%	FLAG is used to indicate the type of output to be returned in SYS.
%
%	Setting FLAG=1 causes TVGTEST to return state derivatives, FLAG=2
%	discrete states, FLAG=3 system outputs and FLAG=4 next sample
%	time. For more information and other options see SFUNC.
%
%	Calling TVGTEST with a FLAG of zero:
%	[SIZES]=TVGTEST([],[],[],0),  returns a vector, SIZES, which
%	contains the sizes of the state vector and other parameters.
%		SIZES(1) number of states
%		SIZES(2) number of discrete states
%		SIZES(3) number of outputs
%		SIZES(4) number of inputs
%		SIZES(5) number of roots (currently unsupported)
%		SIZES(6) direct feedthrough flag
%		SIZES(7) number of sample times
%
%	For the definition of other parameters in SIZES, see SFUNC.
%	See also, TRIM, LINMOD, LINSIM, EULER, RK23, RK45, ADAMS, GEAR.

% Note: This M-file is only used for saving graphical information;
%       after the model is loaded into memory an internal model
%       representation is used.

% the system will take on the name of this mfile:
sys = mfilename;
new_system(sys)
simver(1.3)
if (0 == (nargin + nargout))
     set_param(sys,'Location',[250,202,871,502])
     open_system(sys)
end;
set_param(sys,'algorithm',     'RK-45')
set_param(sys,'Start time',    '0.0')
set_param(sys,'Stop time',     '999999')
set_param(sys,'Min step size', '0.0001')
set_param(sys,'Max step size', '.10')
set_param(sys,'Relative error','1e-3')
set_param(sys,'Return vars',   '')
set_param(sys,'AssignWideVectorLines','on');

add_block('built-in/Constant',[sys,'/','Constant1'])
set_param([sys,'/','Constant1'],...
		'Value','K',...
		'Mask Display','',...
		'Mask Type','Matrix Constant',...
		'Mask Dialogue','Matrix Constant:|Matrix Constant Value:',...
		'Mask Translate','K=@1(:);',...
		'Mask Entries','rand(3,2)\/')
set_param([sys,'/','Constant1'],...
		'position',[110,137,170,163])

add_block('built-in/To Workspace',[sys,'/','To Workspace'])
set_param([sys,'/','To Workspace'],...
		'mat-name','yout',...
		'position',[415,112,465,128])

add_block('built-in/Scope',[sys,'/','Scope'])
set_param([sys,'/','Scope'],...
		'Vgain','10.000000',...
		'Hgain','12.000000',...
		'Vmax','20.000000',...
		'Hmax','24.000000',...
		'Window',[382,13,713,327],...
		'position',[480,60,510,90])


%     Subsystem  ['Time Varying',13,'Matrix Gain'].

new_system([sys,'/',['Time Varying',13,'Matrix Gain']])
set_param([sys,'/',['Time Varying',13,'Matrix Gain']],'Location',[579,383,930,533])

add_block('built-in/Mux',[sys,'/',['Time Varying',13,'Matrix Gain/Mux']])
set_param([sys,'/',['Time Varying',13,'Matrix Gain/Mux']],...
		'inputs','[n m*n]',...
		'position',[60,61,90,94])

add_block('built-in/S-Function',[sys,'/',['Time Varying',13,'Matrix Gain/S-Function']])
set_param([sys,'/',['Time Varying',13,'Matrix Gain/S-Function']],...
		'function name','stvmgain',...
		'parameters','K,Ts',...
		'position',[130,70,180,90])

add_block('built-in/Inport',[sys,'/',['Time Varying',13,'Matrix Gain/in_1']])
set_param([sys,'/',['Time Varying',13,'Matrix Gain/in_1']],...
		'position',[10,60,30,80])

add_block('built-in/Outport',[sys,'/',['Time Varying',13,'Matrix Gain/out_1']])
set_param([sys,'/',['Time Varying',13,'Matrix Gain/out_1']],...
		'position',[210,70,230,90])

add_block('built-in/Inport',[sys,'/',['Time Varying',13,'Matrix Gain/in_2']])
set_param([sys,'/',['Time Varying',13,'Matrix Gain/in_2']],...
		'Port','2',...
		'position',[10,75,30,95])
add_line([sys,'/',['Time Varying',13,'Matrix Gain']],[95,80;125,80])
add_line([sys,'/',['Time Varying',13,'Matrix Gain']],[35,70;55,70])
add_line([sys,'/',['Time Varying',13,'Matrix Gain']],[185,80;205,80])
add_line([sys,'/',['Time Varying',13,'Matrix Gain']],[35,85;55,85])
set_param([sys,'/',['Time Varying',13,'Matrix Gain']],...
		'Mask Display','K(t)',...
		'Mask Type','Time Varying Matrix Gain',...
		'Mask Dialogue','Matrix Gain|Initial Gain Matrix: |Update Sample Time')
set_param([sys,'/',['Time Varying',13,'Matrix Gain']],...
		'Mask Translate','K=@1;Ts=@2;[m,n]=size(@1);')
set_param([sys,'/',['Time Varying',13,'Matrix Gain']],...
		'Mask Help','This block implements a time-varying matrix gain. The intial gain K determines the resizing of the vector input gain. The gain matrix(m,n) will produce m outputs, the input u having n columns.')
set_param([sys,'/',['Time Varying',13,'Matrix Gain']],...
		'Mask Entries','ones(3,2)\/-1\/')


%     Finished composite block ['Time Varying',13,'Matrix Gain'].

set_param([sys,'/',['Time Varying',13,'Matrix Gain']],...
		'position',[270,90,360,145])

add_block('built-in/Sine Wave',[sys,'/','Sine Wave'])
set_param([sys,'/','Sine Wave'],...
		'amplitude','[1 3]',...
		'frequency','[3 1]',...
		'phase','[2 2]',...
		'position',[105,53,150,97])
add_line(sys,[365,120;410,120])
add_line(sys,[390,120;390,75;475,75])
add_line(sys,[175,150;215,150;215,130;265,130])
add_line(sys,[155,75;205,75;205,105;265,105])

drawnow

% Return any arguments.
if (nargin | nargout)
	% Must use feval here to access system in memory
	if (nargin > 3)
		if (flag == 0)
			eval(['[ret,x0,str,ts,xts]=',sys,'(t,x,u,flag);'])
		else
			eval(['ret =', sys,'(t,x,u,flag);'])
		end
	else
		[ret,x0,str,ts,xts] = feval(sys);
	end
else
	drawnow % Flash up the model and execute load callback
end
