function [ret,x0,str,ts,xts]=vco(t,x,u,flag);
%VCO	is the M-file description of the SIMULINK system named VCO.
%	The block-diagram can be displayed by typing: VCO.
%
%	SYS=VCO(T,X,U,FLAG) returns depending on FLAG certain
%	system values given time point, T, current state vector, X,
%	and input vector, U.
%	FLAG is used to indicate the type of output to be returned in SYS.
%
%	Setting FLAG=1 causes VCO to return state derivatives, FLAG=2
%	discrete states, FLAG=3 system outputs and FLAG=4 next sample
%	time. For more information and other options see SFUNC.
%
%	Calling VCO with a FLAG of zero:
%	[SIZES]=VCO([],[],[],0),  returns a vector, SIZES, which
%	contains the sizes of the state vector and other parameters.
%		SIZES(1) number of states
%		SIZES(2) number of discrete states
%		SIZES(3) number of outputs
%		SIZES(4) number of inputs
%		SIZES(5) number of roots (currently unsupported)
%		SIZES(6) direct feedthrough flag
%		SIZES(7) number of sample times
%
%	For the definition of other parameters in SIZES, see SFUNC.
%	See also, TRIM, LINMOD, LINSIM, EULER, RK23, RK45, ADAMS, GEAR.

% Note: This M-file is only used for saving graphical information;
%       after the model is loaded into memory an internal model
%       representation is used.

% the system will take on the name of this mfile:
sys = mfilename;
new_system(sys)
simver(1.3)
if (0 == (nargin + nargout))
     set_param(sys,'Location',[391,323,507,411])
     open_system(sys)
end;
set_param(sys,'algorithm',     'RK-45')
set_param(sys,'Start time',    '0.0')
set_param(sys,'Stop time',     '999999')
set_param(sys,'Min step size', '0.0001')
set_param(sys,'Max step size', '10')
set_param(sys,'Relative error','1e-3')
set_param(sys,'Return vars',   '')


%     Subsystem  'VCO'.

new_system([sys,'/','VCO'])
set_param([sys,'/','VCO'],'Location',[14,126,684,386])

add_block('built-in/Note',[sys,'/','VCO/Phase Integrator'])
set_param([sys,'/','VCO/Phase Integrator'],...
		'position',[370,55,375,60])

add_block('built-in/Fcn',[sys,'/','VCO/SIN'])
set_param([sys,'/','VCO/SIN'],...
		'Expr','sin(2*pi*u)',...
		'position',[480,104,550,136])

add_block('built-in/Sum',[sys,'/','VCO/Sum2'])
set_param([sys,'/','VCO/Sum2'],...
		'position',[315,94,350,141])

add_block('built-in/Memory',[sys,'/','VCO/Memory2'])
set_param([sys,'/','VCO/Memory2'],...
		'orientation',2,...
		'x0','Phase',...
		'position',[315,172,355,198])

add_block('built-in/Fcn',[sys,'/',['VCO/Modulo 1',13,'Integrator']])
set_param([sys,'/',['VCO/Modulo 1',13,'Integrator']],...
		'Expr','rem(u,1)',...
		'position',[370,108,430,132])

add_block('built-in/Product',[sys,'/','VCO/Product'])
set_param([sys,'/','VCO/Product'],...
		'position',[240,86,270,124])

add_block('built-in/Clock',[sys,'/','VCO/Clock'])
set_param([sys,'/','VCO/Clock'],...
		'position',[55,155,75,175])

add_block('built-in/Sum',[sys,'/','VCO/dt'])
set_param([sys,'/','VCO/dt'],...
		'inputs','+-',...
		'position',[190,157,210,188])

add_block('built-in/Gain',[sys,'/',['VCO/VCO',13,'gain']])
set_param([sys,'/',['VCO/VCO',13,'gain']],...
		'Gain','K0',...
		'position',[90,35,130,65])

add_block('built-in/Sum',[sys,'/','VCO/Sum1'])
set_param([sys,'/','VCO/Sum1'],...
		'position',[165,41,195,79])

add_block('built-in/Constant',[sys,'/',['VCO/Center',13,'frequency']])
set_param([sys,'/',['VCO/Center',13,'frequency']],...
		'Value','F0',...
		'position',[80,98,130,122])

add_block('built-in/Memory',[sys,'/','VCO/Memory1'])
set_param([sys,'/','VCO/Memory1'],...
		'position',[115,177,155,203])

add_block('built-in/Outport',[sys,'/','VCO/VCO_out'])
set_param([sys,'/','VCO/VCO_out'],...
		'position',[600,110,620,130])

add_block('built-in/Inport',[sys,'/','VCO/VCO_in'])
set_param([sys,'/','VCO/VCO_in'],...
		'position',[35,40,55,60])
add_line([sys,'/','VCO'],[555,120;595,120])
add_line([sys,'/','VCO'],[60,50;85,50])
add_line([sys,'/','VCO'],[435,120;475,120])
add_line([sys,'/','VCO'],[435,120;450,120;450,185;360,185])
add_line([sys,'/','VCO'],[310,185;295,185;295,130;310,130])
add_line([sys,'/','VCO'],[355,120;365,120])
add_line([sys,'/','VCO'],[160,190;170,190;170,180;185,180])
add_line([sys,'/','VCO'],[80,165;185,165])
add_line([sys,'/','VCO'],[80,165;95,165;95,190;110,190])
add_line([sys,'/','VCO'],[135,50;160,50])
add_line([sys,'/','VCO'],[135,110;145,110;145,70;160,70])
add_line([sys,'/','VCO'],[215,175;225,175;235,115])
add_line([sys,'/','VCO'],[200,60;215,60;215,95;235,95])
add_line([sys,'/','VCO'],[275,105;310,105])
set_param([sys,'/','VCO'],...
		'Mask Display','plot(sin(0:pi/8:2*pi),cos(0:pi/8:2*pi),[-1:1/8:1]*0.75,sin(0:pi/8:2*pi)*0.5)',...
		'Mask Type','VCO')
set_param([sys,'/','VCO'],...
		'Mask Dialogue','Voltage Controlled Oscillator.|Initial Frequency (Hz):|VCO Gain (Hz/V):|Initial Phase (rad):',...
		'Mask Translate','F0=@1; K0=@2; Phase=@3/2/pi;',...
		'Mask Help','Voltage Controlled Oscillator.')
set_param([sys,'/','VCO'],...
		'Mask Entries','1\/.5\/0\/')


%     Finished composite block 'VCO'.

set_param([sys,'/','VCO'],...
		'position',[30,14,70,56])

drawnow

% Return any arguments.
if (nargin | nargout)
	% Must use feval here to access system in memory
	if (nargin > 3)
		if (flag == 0)
			eval(['[ret,x0,str,ts,xts]=',sys,'(t,x,u,flag);'])
		else
			eval(['ret =', sys,'(t,x,u,flag);'])
		end
	else
		[ret,x0,str,ts,xts] = feval(sys);
	end
else
	drawnow % Flash up the model and execute load callback
end
