function [ret,x0,str,ts,xts]=vec(t,x,u,flag);
%VEC	is the M-file description of the SIMULINK system named VEC.
%	The block-diagram can be displayed by typing: VEC.
%
%	SYS=VEC(T,X,U,FLAG) returns depending on FLAG certain
%	system values given time point, T, current state vector, X,
%	and input vector, U.
%	FLAG is used to indicate the type of output to be returned in SYS.
%
%	Setting FLAG=1 causes VEC to return state derivatives, FLAG=2
%	discrete states, FLAG=3 system outputs and FLAG=4 next sample
%	time. For more information and other options see SFUNC.
%
%	Calling VEC with a FLAG of zero:
%	[SIZES]=VEC([],[],[],0),  returns a vector, SIZES, which
%	contains the sizes of the state vector and other parameters.
%		SIZES(1) number of states
%		SIZES(2) number of discrete states
%		SIZES(3) number of outputs
%		SIZES(4) number of inputs
%		SIZES(5) number of roots (currently unsupported)
%		SIZES(6) direct feedthrough flag
%		SIZES(7) number of sample times
%
%	For the definition of other parameters in SIZES, see SFUNC.
%	See also, TRIM, LINMOD, LINSIM, EULER, RK23, RK45, ADAMS, GEAR.

% Note: This M-file is only used for saving graphical information;
%       after the model is loaded into memory an internal model
%       representation is used.

% the system will take on the name of this mfile:
sys = mfilename;
new_system(sys)
simver(1.3)
if (0 == (nargin + nargout))
     set_param(sys,'Location',[391,78,891,378])
     open_system(sys)
end;
set_param(sys,'algorithm',     'RK-45')
set_param(sys,'Start time',    '0.0')
set_param(sys,'Stop time',     '999999')
set_param(sys,'Min step size', '0.1')
set_param(sys,'Max step size', '0.1')
set_param(sys,'Relative error','1e-3')
set_param(sys,'Return vars',   '')

add_block('built-in/Sine Wave',[sys,'/','Sine Wave'])
set_param([sys,'/','Sine Wave'],...
		'position',[90,105,110,125])

add_block('built-in/Sine Wave',[sys,'/','Sine Wave1'])
set_param([sys,'/','Sine Wave1'],...
		'phase','1',...
		'position',[90,160,110,180])


%     Subsystem  ['Vector',13,'Scope'].

new_system([sys,'/',['Vector',13,'Scope']])
set_param([sys,'/',['Vector',13,'Scope']],'Location',[0,54,1004,747])

add_block('built-in/Inport',[sys,'/',['Vector',13,'Scope/x1']])
set_param([sys,'/',['Vector',13,'Scope/x1']],...
		'position',[260,70,280,90])

add_block('built-in/Inport',[sys,'/',['Vector',13,'Scope/y1']])
set_param([sys,'/',['Vector',13,'Scope/y1']],...
		'Port','2',...
		'position',[260,140,280,160])

add_block('built-in/Mux',[sys,'/',['Vector',13,'Scope/Mux']])
set_param([sys,'/',['Vector',13,'Scope/Mux']],...
		'inputs','2',...
		'position',[365,80,395,115])

add_block('built-in/S-Function',[sys,'/',['Vector',13,'Scope/S-function',13,'M-file which plots',13,'lines',13,'']])
set_param([sys,'/',['Vector',13,'Scope/S-function',13,'M-file which plots',13,'lines',13,'']],...
		'function name','sfuncvec',...
		'parameters','ax, st',...
		'position',[465,85,515,105])
add_line([sys,'/',['Vector',13,'Scope']],[285,150;315,150;315,105;360,105])
add_line([sys,'/',['Vector',13,'Scope']],[285,80;360,90])
add_line([sys,'/',['Vector',13,'Scope']],[400,100;460,95])
set_param([sys,'/',['Vector',13,'Scope']],...
		'Mask Display','plot(0,0,100,100,[12,91,91,12,12],[90,90,45,45,90],[45,65],[70,80],[45 50],[70,85])',...
		'Mask Type','Vector Scope')
set_param([sys,'/',['Vector',13,'Scope']],...
		'Mask Dialogue','XY scope using MATLAB graph window.\nFirst input is used as time base.\nEnter plotting ranges.|x-min:|x-max:|y-min:|y-max:',...
		'Mask Translate','ax = [@1, @2, @3, @4];st=-1;')
set_param([sys,'/',['Vector',13,'Scope']],...
		'Mask Help','This block acts as a vector scope.',...
		'Mask Entries','-1\/1\/-1\/1\/')


%     Finished composite block ['Vector',13,'Scope'].

set_param([sys,'/',['Vector',13,'Scope']],...
		'position',[235,131,265,169])
add_line(sys,[115,115;165,115;165,140;230,140])
add_line(sys,[115,170;165,170;165,160;230,160])

drawnow

% Return any arguments.
if (nargin | nargout)
	% Must use feval here to access system in memory
	if (nargin > 3)
		if (flag == 0)
			eval(['[ret,x0,str,ts,xts]=',sys,'(t,x,u,flag);'])
		else
			eval(['ret =', sys,'(t,x,u,flag);'])
		end
	else
		[ret,x0,str,ts,xts] = feval(sys);
	end
else
	drawnow % Flash up the model and execute load callback
end

