function [ret,x0,str,ts,xts]=xyzdemo(t,x,u,flag);
%XYZDEMO	is the M-file description of the SIMULINK system named XYZDEMO.
%	The block-diagram can be displayed by typing: XYZDEMO.
%
%	SYS=XYZDEMO(T,X,U,FLAG) returns depending on FLAG certain
%	system values given time point, T, current state vector, X,
%	and input vector, U.
%	FLAG is used to indicate the type of output to be returned in SYS.
%
%	Setting FLAG=1 causes XYZDEMO to return state derivatives, FLAG=2
%	discrete states, FLAG=3 system outputs and FLAG=4 next sample
%	time. For more information and other options see SFUNC.
%
%	Calling XYZDEMO with a FLAG of zero:
%	[SIZES]=XYZDEMO([],[],[],0),  returns a vector, SIZES, which
%	contains the sizes of the state vector and other parameters.
%		SIZES(1) number of states
%		SIZES(2) number of discrete states
%		SIZES(3) number of outputs
%		SIZES(4) number of inputs
%		SIZES(5) number of roots (currently unsupported)
%		SIZES(6) direct feedthrough flag
%		SIZES(7) number of sample times
%
%	For the definition of other parameters in SIZES, see SFUNC.
%	See also, TRIM, LINMOD, LINSIM, EULER, RK23, RK45, ADAMS, GEAR.

% Note: This M-file is only used for saving graphical information;
%       after the model is loaded into memory an internal model
%       representation is used.

% the system will take on the name of this mfile:
sys = mfilename;
new_system(sys)
simver(1.3)
if (0 == (nargin + nargout))
     set_param(sys,'Location',[11,52,279,152])
     open_system(sys)
end;
set_param(sys,'algorithm',     'Euler')
set_param(sys,'Start time',    '0.0')
set_param(sys,'Stop time',     '60')
set_param(sys,'Min step size', '0.0001')
set_param(sys,'Max step size', '.1')
set_param(sys,'Relative error','1e-3')
set_param(sys,'Return vars',   '')
set_param(sys,'AssignWideVectorLines','on');

add_block('built-in/Sine Wave',[sys,'/',['Sine',13,'Wave']])
set_param([sys,'/',['Sine',13,'Wave']],...
		'amplitude','rand(1,3)*2',...
		'frequency','rand(1,3)*2',...
		'phase','rand(1,3)*pi',...
		'position',[15,30,45,60])


%     Subsystem  'XYZ Graph'.

new_system([sys,'/','XYZ Graph'])
set_param([sys,'/','XYZ Graph'],'Location',[8,52,282,245])

add_block('built-in/S-Function',[sys,'/',['XYZ Graph/S-function',13,'M-file which plots',13,'lines',13,'']])
set_param([sys,'/',['XYZ Graph/S-function',13,'M-file which plots',13,'lines',13,'']],...
		'function name','sfunxyz',...
		'parameters','xlim,ylim,zlim,view,st',...
		'position',[185,100,235,120])

add_block('built-in/Mux',[sys,'/','XYZ Graph/Mux'])
set_param([sys,'/','XYZ Graph/Mux'],...
		'inputs','3',...
		'position',[100,93,130,127])

add_block('built-in/Inport',[sys,'/','XYZ Graph/z'])
set_param([sys,'/','XYZ Graph/z'],...
		'Port','3',...
		'position',[10,155,30,175])

add_block('built-in/Inport',[sys,'/','XYZ Graph/y'])
set_param([sys,'/','XYZ Graph/y'],...
		'Port','2',...
		'position',[10,100,30,120])

add_block('built-in/Inport',[sys,'/','XYZ Graph/x'])
set_param([sys,'/','XYZ Graph/x'],...
		'position',[10,30,30,50])
add_line([sys,'/','XYZ Graph'],[35,165;70,165;70,120;95,120])
add_line([sys,'/','XYZ Graph'],[35,110;95,110])
add_line([sys,'/','XYZ Graph'],[35,40;70,40;70,100;95,100])
add_line([sys,'/','XYZ Graph'],[135,110;180,110])
set_param([sys,'/','XYZ Graph'],...
		'Mask Display','plot(0,0,100,100,[12,91,91,12,12],[90,90,45,45,90],[51,57,65,75,80,79,75,67,60,54,51,48,42,34,28,27,31,42,51],[71,68,66,66,72,79,83,84,81,77,71,60,54,54,58,65,71,74,71])')
set_param([sys,'/','XYZ Graph'],...
		'Mask Type','XYZ scope.',...
		'Mask Dialogue','XYZ scope using MATLAB graph window.\nEnter plotting ranges.|X [min,max]:|Y [min,max]:|Z [min,max]:|View:')
set_param([sys,'/','XYZ Graph'],...
		'Mask Translate','xlim=@1;ylim=@2;zlim=@3;view=@4;st=-1;',...
		'Mask Help','This block can be used to explore limit cycles. Look at the m-file sfunxyz.m to see how it works.')
set_param([sys,'/','XYZ Graph'],...
		'Mask Entries','[-2,2]\/[-2,2]\/[-2,2]\/[-37.5 30]\/')


%     Finished composite block 'XYZ Graph'.

set_param([sys,'/','XYZ Graph'],...
		'position',[215,26,245,64])

add_block('built-in/Demux',[sys,'/','demux'])
set_param([sys,'/','demux'],...
		'hide name',0,...
		'outputs','3',...
		'position',[100,20,150,70])
add_line(sys,[155,45;210,45])
add_line(sys,[155,30;180,30;180,35;210,35])
add_line(sys,[155,60;180,60;180,55;210,55])
add_line(sys,[50,45;95,45])

drawnow

% Return any arguments.
if (nargin | nargout)
	% Must use feval here to access system in memory
	if (nargin > 3)
		if (flag == 0)
			eval(['[ret,x0,str,ts,xts]=',sys,'(t,x,u,flag);'])
		else
			eval(['ret =', sys,'(t,x,u,flag);'])
		end
	else
		[ret,x0,str,ts,xts] = feval(sys);
	end
else
	drawnow % Flash up the model and execute load callback
end
