function [dhist,bins] = UniHist( data, step, dmin, dmax )
% [num,bins] = UniHist( data, <step, dmin, dmax>  )
% Generates a Histogram much faster than hist.m does, with the restriction
% that all bins must be the same size, width == step (default 1).
% dmin and dmax optionally define the range, which is min to max by default.
% bins shows the values at the center of the range, e.g. bin=3.5 for 
% range 3<=x<4.

% Mike Oliker May 19, 1995
% Adaptive Optics Associates, Inc.

data=data(:);
if nargin<2
	step=1;
end
if nargin<3
	dmin=min(data);
else
	f=find(data<dmin);
	data(f)=dmin(ones(size(f)),1);
end
if nargin<4
	dmax=max(data);
else
	f=find(data>dmax);
	data(f)=dmax(ones(size(f)),1);
end
if dmin~=0;
	data=data-dmin;
end
if step~=1
	data=data/step;
end
% data=floor(data);  % puts value at bottom of range, probably not necessary
if nargout~=1
	bins=[(dmin+step/2):step:(dmax+step/2)];
end
N=length(data);
mxD=floor((dmax-dmin)/step)+1;
i=[1:N]';
s=ones(N,1);
m = sparse(i,1+data,s,N,mxD);
dhist=full(sum(m));
if nargout==0
	bar(bins,dhist)
end





<<<<<< Attached TEXT file follows >>>>>>
function [dhist,bins] = UniHist( data, step, dmin, dmax )
% [num,bins] = UniHist( data, <step, dmin, dmax>  )
% Generates a Histogram much faster than hist.m does, with the restriction
% that all bins must be the same size, width == step (default 1).
% dmin and dmax optionally define the range, which is min to max by default.
% bins shows the values at the center of the range, e.g. bin=3.5 for 
% range 3<=x<4.

% Mike Oliker May 19, 1995
% Adaptive Optics Associates, Inc.

data=data(:);
if nargin<2
	step=1;
end
if nargin<3
	dmin=min(data);
else
	f=find(data<dmin);
	data(f)=dmin(ones(size(f)),1);
end
if nargin<4
	dmax=max(data);
else
	f=find(data>dmax);
	data(f)=dmax(ones(size(f)),1);
end
if dmin~=0;
	data=data-dmin;
end
if step~=1
	data=data/step;
end
% data=floor(data);  % puts value at bottom of range, probably not necessary
if nargout~=1
	bins=[(dmin+step/2):step:(dmax+step/2)];
end
N=length(data);
mxD=floor((dmax-dmin)/step)+1;
i=[1:N]';
s=ones(N,1);
m = sparse(i,1+data,s,N,mxD);
dhist=full(sum(m));
if nargout==0
	bar(bins,dhist)
end



