function d=dgaussum(x,a,m,b)
%DGAUSSUM Probability density of multivariate gaussian sum (pdf)
%	DGAUSSUM(X,ALPHA,MEAN,COV) returns the multivariate
%	pdf at the vector X, for the gaussian sum density with 
%	weighting factors ALPHA, mean vectors MEAN, and 
%	covariance matrices COV.
%
%	See also DGAUSS, DLN

% File:	dgaussum.m
%
% Copy:	Copyright(c) 1995 Claude D. Bilbo
%	Copy freely, but document any changes.
%
% Email:cbilbo@mindspring.com
%	bilboc02@eng.uab.edu
%
% Snail:Department of Electrical and Computer Engineering
%	University of Alabama at Birmingham
%	1150 10th Avenue South
%	UAB Station, Birmingham, AL 35294
%
% Desc:	Function to return the density at a point of a 
%	multivariate gaussian sum distribution.
%
% Use:	d = dgaussum(x,a,m,b)
%	  where,
%	x = random vector(s) at which to find density
%       a = weighting factors of the gaussians, vector
%       m = mean vectors of the gaussian sums
%	b = covariance matrices of the gaussian sums,
%	    stacked so that b = [b1 b2 ... bn]'
%	
% Author: Claude D. Bilbo
%

lx = size(x,1);
n = length(a);

d=zeros(1,size(x,2));
for i=1:n
  d = d + a(i)*dgauss(x,m((i-1)*lx+1:i*lx),b(((i-1)*lx+1):i*lx,:));
end
return
