function p = pgaussum(x,a,m,b)

%PGAUSSUM Distribution function of a univariate gaussian
%	sum probability density.
%	
%	P = PGAUSSUM(X,ALPHA,MEANS,VARS) yields the probability 
%	that X lies in the range (-Inf,X], for a gaussian 
%	sum density with vector of means MEANS, vector of 
%	variances VARS, and weighting factors ALPHA.
%
%	See also PLN, PGAUSS

% File:	pgaussum.m
%
% Copy:	Copyright(c) 1995 Claude D. Bilbo
%	Copy freely, but document any changes.
%
% Email:cbilbo@mindspring.com
%	bilboc02@eng.uab.edu
%
% Snail:Department of Electrical and Computer Engineering
%	University of Alabama at Birmingham
%	1150 10th Avenue South
%	UAB Station, Birmingham, AL 35294
%
% Desc:	Function to return the distribution function of
%       a univariate gaussian sum probability density.
%	
% Use:	p = pgaussum(x,a,m,b)
%	  where,
%	x = random variable at which to find distribution fcn.
%	a = weighting factors of the gaussian sum terms
%       m = mean vector of the gaussian sum distribution
%	b = variance vector of the distribution
%
% Author: Claude D. Bilbo
%

p = zeros(size(x));

for i = 1:prod(size(p))
  p(i) = sum( pgauss(x(i),m,b) .* a );
end

return
