function [b,mu,xtwx,devlist,l]=irls(y,x,m)
%IRLS Iteratively reweighted least squares for use with glmlab
%USE: [b,mu,xtwx,devlist,l]=irls(y,x,m)
%   where  y  is the vector of y-variables;
%          x  is the matrix of x-variables;
%          m  is the vector of sample sizes for a binomial distribution.
%             For other distributions, it is not needed (or use a dummy).
%          b  is the vector of parameter estimates
%          mu  is the fitted values
%          xtwx  is the matrix  X'*W*X
%          devlist  is the deviance for each iteration of the fit.
%          l  is the labels for linearly independent columns of x.

%Peter Dunn
%Last revision: 04/09/1996

%error checks
if size(y,1)~=size(x,1),error('x and y must have the same number of rows!');end;
%end error checks

clear paramtrs;[toler,maxits,illctol]=paramtrs; %load defaults:
global ERRDISFUNCTION LINKFUNCTION FORMAT WEIGHTS OFFSET FITVALS RECYCLE; 
distn=ERRDISFUNCTION;link=LINKFUNCTION;format=FORMAT;fitvals=FITVALS;
weights=WEIGHTS;offset=OFFSET;
if isstr(link),
   linkinfo=['l',link];
else
   linkinfo='lpower';
end;
distinfo=['d',ERRDISFUNCTION];

line=makeline('','-');
xx=x;oo=offset;mm=m; l=alias(x);x=x(:,l);
if any(weights==0),  %Removes weights==0 from fitting
   zeroind=find(weights==0);
   allmat=[y,m,weights,offset,x,fitvals]; allmat(zeroind,:)=[];
   if size(allmat,2)==6, fitvals=allmat(:,6); end;
   y=allmat(:,1);m=allmat(:,2);weights=allmat(:,3);
   offset=allmat(:,4); x=allmat(:,5:size(allmat,2)); l=alias(x);x=x(:,l);
end;
its=-1;devlist=[];clear allmat;
if RECYCLE&(~isempty(fitvals)),
   mu=fitvals;
else
   if strcmp(link,'logit')|strcmp(link,'complg'),
      mu= m.*(y+0.5)./(m+1); %over m+1 in the general case; McC and Nelder p 117
   elseif strcmp(link,'log')|strcmp(link,'recip'),
      mu=y+(y==0);
   else
      mu=y;
   end;
end;
rdev=sqrt(sum( y.^2)); rdev2=0;
b2=100*ones(size(x,2),1); b=[zeros(size(x,2),1)];b(1)=-10;
eta=feval(linkinfo,mu,m,'eta');%eta=Xb + offset
while ( ( abs(rdev-rdev2) > toler) )&(its<maxits),
   %while: (rdev is changing;or max its not reached) and b still changing
   detadmu=feval(linkinfo,mu,m,'detadmu');
   vfun=feval(distinfo,'varfn',y,mu,m,weights);
   fwts=( 1./( (detadmu).^2) ./ vfun).*weights;
   z=(eta-offset+(y-mu).*detadmu); xtwx=x'*diagm(fwts,x);
   b2=b; b=(xtwx)\( x'*diagm(fwts,z) ); eta=(x*b)+offset;
   mu=feval(linkinfo,eta,m,'mu'); rdev2=rdev;
   rdev=feval(distinfo,'scdev',y,mu,m,weights); 
   its=its+1; devlist=[devlist;rdev];
end;
if format(1),
if (rcond(xtwx)<illctol)|(its==maxits),
   disp(line); disp(' PLEASE NOTE: INACCURACIES MAY EXIST IN THE SOLUTION:');
end;
if (rcond(xtwx)<illctol), 
   disp('              * ILL-CONDITIONED COVARIATE MATRIX');
end;
if (its<maxits),
   tag='';if its~=1, tag='s';end;
   disp([blanks(14),'Convergence in:    ',num2str(its),' iteration',tag]);
else
   disp('              * MAXIMUM ITERATIONS REACHED WITHOUT CONVERGENCE');
   disp([blanks(16),'(This is currently set at ',num2str(maxits),')']);
end;
end;
x=xx(:,l); eta=(x*b)+oo; 
mu=feval(linkinfo,eta,mm,'mu');
