function rows=omit(oldmat, instr)
%OMIT Omits certain columns from the incidence matrix in glmlab
%USE: rows=omit(oldmat, instr)
%     where  rows  is the rows in  oldmat  to omit according to the
%            instructions in  instr.  In vector  instr, a number means 
%            to omit any rows with that value in that place.  A zero
%            means not to omit anything.  For example,
%            if    oldmat=[1 1 1;1 1 2;1 2 1; 1 2 2;2 1 1; 2 1 2; 2 2 2]
%            and   instr=[1 0 1],
%            then rows=omit(oldmat, instr) would omit all rows of the form
%            [1 ? 1], and so return
%                  rows=[1 3]'
%            indicating to omit the rows  [1 1 1]  and  [1 2 1]

%Peter Dunn
%29/05/1996

if length(instr)~=size(oldmat,2),
   error('instr  must contain the same as number of columns as the matrix');
end;
%Get trivial case out of the way
if all(instr==0), rows=[1:size(oldmat,1)]'; return; end;

test=ones(size(oldmat,1),1);
workrow=find(instr~=0);
for i=workrow,
   test=(test&(instr(i)==oldmat(:,i)));
end;
if all(test==0), 
   rows=[];%1:size(oldmat,1)]';
else
   rows=find(test);
end;
