function r=cont75(x,y,A,k,sym,h)

% CONT75      Kernel Density estimate 75% contour plot for bi-variate data.
%
%             CONT75(X,Y,A,K,SYM,H) splits the bi-variate data (X,Y) 
%             into 4 groups of equal size and displays a contour plot 
%             which illustrates the 75% contour.  Groups are fomed by 
%             ranking the data by kernel density estimate.
%
%             The rows of A contain the whole data-set.
% 
%             The kernel is given by the function in K.
%             'KNORM' is the multivariate normal distribution.
%
%             SYM defines the plotting symbol, see HELP PLOT for details.
%
%             The optional parameter H represents the window width.
%             If omitted, an 'optimal' value is used.
%
%             Christian C. Beardah 1994-95

if nargin==5,
  h=0;
end;

[n d]=size(A);

xrange=max(x)-min(x);
yrange=max(y)-min(y);

xa=linspace(min(x)-xrange/4,max(x)+xrange/4,40);
ya=linspace(min(y)-yrange/4,max(y)+yrange/4,40);

[X,Y]=meshgrid(xa,ya);

z=kdest2d(X,Y,A,k,h); 
r=kdest2d(x,y,A,k,h);

[order index]=sort(r);

m=floor(n/4);

for i=1:3,
  v(i)=(order(i*m)+order(i*m+1))/2;
end;

w=[v(1) Inf];

contour(xa,ya,z,w,sym);  

r=order;
