function m=dplots(x,y,n,f)

% DPLOTS      Density plots of 2D data based on simple box counting.
% 
%             DPLOTS(X,Y,N,F) outputs various graphical representations 
%             of the data (X,Y).  
%
%             N is the dimension of the square density matrix which 
%             results.  
%
%             If the optional argument F is specified then a movie of F frames 
%             is produced.
%
%             Christian C. Beardah 1993

xmin=min(x);
xmax=max(x);
xa=linspace(xmin,xmax,n);
ymin=min(y);
ymax=max(y);
ya=linspace(ymin,ymax,n);

l=length(x);
m=zeros(n,n);
xs=(x-xmin)/(xmax-xmin);
ys=(y-ymin)/(ymax-ymin);

tic

for i=1:l;
  ix=n*xs(i)-rem(n*xs(i),1)+1;
  if ix==(n+1),
 	  ix=n;
	end;	
  iy=n*ys(i)-rem(n*ys(i),1)+1;
	if iy==(n+1),
         iy=n;
	end;	
  m(ix,iy)=m(ix,iy)+1;
end;

toc

if nargin==3,
  figure;
  plot(x,y,'ro');
  xlabel('Component 1');
% ylabel('Component 2');

  pause;

  A=viewmtx(-45,60);

  figure;
  surf(xa,ya,m');
  shading interp;
  colormap(brighten(hot,0.5));
  xlabel('Component 1');
  ylabel('Component 2');
% zlabel('Frequency');
  view(A);

  pause;

  figure;
  pcolor(xa,ya,m');
  shading interp;
  xlabel('Component 1');
% ylabel('Component 2');
  hold on;
  contour(xa,ya,m','k');
  colormap(brighten(cool,-0.5));

  pause;

  figure;
  pcolor(xa,ya,m');
  colormap(brighten(hot,0.5));
  xlabel('Component 1');
% ylabel('Component 2');

  pause;
  close(1:4);
end;

if nargin==4,
  figure;
  M=moviein(f+1);
  for j=1:f+1,

%   Rotation 'up and over'.
%   A=viewmtx(90,(j-1)*90/f,10);

%   Roataion 'around and about'.  
    A=viewmtx((j-1)*360/f,45,10);  

    surfl(xa,ya,m,[0 45]);
    shading interp;
    view(A);
    axis('off');
    colormap(brighten(hot,0.5)); 
    M(:,j)=getframe;
  end;
  m=M;
end;