function r=kdcont(x,y,A,k,c,h)

% KDCONT      Kernel Density estimate contour plots for bi-variate data.
%
%             KDCONT(X,Y,A,K,C,H) splits the bi-variate data (X,Y) 
%             into C groups of equal size and displays a contour plot 
%             which illustrates the groups.  Groups are formed by 
%             ranking the data by ascending kernel density estimate value.
%             Using C=4, for example, splits the data by quartiles. 
%
%             The rows of A contain the whole data-set.
% 
%             The kernel is given by the function in K.
%             'KNORM' is the multivariate normal distribution.
%             'KEPAN' is the Epanechnikov kernel.
%
%             The optional parameter H represents the window width.
%             If omitted, a simplistic 'optimal' value is used.
%
%             Christian C. Beardah 1993

if nargin==5,
  h=0;
end;

[n d]=size(A);

xrange=max(x)-min(x); % Find the ranges of the data.
yrange=max(y)-min(y);

% Make the axes slightly bigger than the range.

xa=linspace(min(x)-xrange/4,max(x)+xrange/4,40); 
ya=linspace(min(y)-yrange/4,max(y)+yrange/4,40);

[X,Y]=meshgrid(xa,ya); % Set up the grid for the 3D contour plot.

z=kdest2d(X,Y,A,k,h); % Find the k.d. estimates at the grid points.
                      % (Needed to plot the k.d. function.)
r=kdest2d(x,y,A,k,h); % Find the k.d. estimates at the data points.
                      % (Needed to rank and therefore split the data.)   

[order index]=sort(r);  % Sort the data in ascending order by k.d. estimate.

m=floor(n/c);  % Find the splitting points by rounding towards zero.

for i=1:c-1,
  v(i)=(order(i*m)+order(i*m+1))/2;  % Find the heights at which the data is 
                                     % split into c groups.
end;

% contour(xa,ya,z,v,'w');  % Plot a 2D contour picture.

% figure;
contour3(X,Y,z,v,'w');   % Plot a 3D contour picture.