function [outl,index,haxis]=pclvl3(p,A,X,Y,Z,dgrid,ddata,sstr)

% PCLVL3      Kernel Density estimate p% contour plot for tri-variate data.
%
%             Example: 
%
%             PCLVL3(P,A,X,Y,Z,DGRID,DDATA) displays a surface which encloses P% 
%             of the data.  Groups are formed by ranking the data by 
%             kernel density estimate.
%
%             The rows of A contain the whole data-set.
% 
%             The kernel is given by the function in K.
%             'KMVN' is the multivariate normal distribution.
%
%             INC controls the granularity of the mesh.
%
%             The optional parameter H represents the window width.
%             If omitted, an 'optimal' value is used.
%
%             Christian C. Beardah 1996

n=length(ddata);

x=A(:,1);
y=A(:,2);
z=A(:,3);

w=zeros(length(p),2);

p=100-p;
p=sort(p);
p=p(length(p):-1:1);

[order index]=sort(ddata);

m=ceil(n*p/100);

if length(p)>1,
  col=['wbwbwb'];
  else,
    col=sstr;
end;

for i=1:length(p),
  if m(i)==0,
    v(i)=0.9*order(1); 
  end;

  if m(i)>0 & m(i)<n,
    v(i)=(order(m(i))+order(m(i)+1))/2;
  end;

  if m(i)==n,
    v(i)=(order(n-1)+order(n))/2;
  end;

  if i==1,
    dtest=(dgrid>v(i));
    else,
      dtest=(dgrid>v(i))&(dgrid<v(i-1));
  end;
  [ip,jp]=find(dtest);
  for k=1:length(ip),
    hpt(k,:)=[X(ip(k),jp(k)) Y(ip(k),jp(k)) Z(ip(k),jp(k))];
  end;

  plot3(hpt(1:length(ip),1),hpt(1:length(ip),2),hpt(1:length(ip),3),[col(i),'.']);
  if i==1,
    hold on;
  end;

end;

plot3(x(index(1:m(i))),y(index(1:m(i))),z(index(1:m(i))),'rx');
xlabel('x values');
ylabel('y values');
zlabel('z values');

for k=1:m(i),
  vec=ones(length(ip),1)*A(index(k),:)-hpt(1:length(ip),:);
  for l=1:length(ip),
    nvec(l,1)=norm(vec(l,:));
  end;
  mvec(k,1)=min(nvec);
end;

outl=[index(1:m(i)), x(index(1:m(i))), y(index(1:m(i))), z(index(1:m(i))), ddata(index(1:m(i))), mvec];

hpt=hpt(1:length(ip),:);
haxis=[min(hpt(:,1)) max(hpt(:,1)) min(hpt(:,2)) max(hpt(:,2)) min(hpt(:,3)) max(hpt(:,3))];

hold off;