function [B1,B2] = bins(A1,A2,m,n,minx,maxx,miny,maxy,draw)

% function [B1,B2] = BINS(A1,A2,m,n,minx,maxx,miny,maxy,draw) places 
% the x,y pairs in vectors A1(2,k) and A2(2,k) in arrays of mxn 
% equally spaced bins, and returns the contents of the bins as
% vectors B1 and B2.
% The range of the bins is given by minx etc.

% Version 1.0 RHS 12/11/93
% Version 1.1 RHS 17/11/93
%	Subplots added to show distributions

if nargin<9
	draw=0;	% default is do not plot
end
if nargin==6
	miny=minx;maxy=maxx;	% make limits square
end

if nargin<5
	mina=min(min(A1));minb=min(min(A2));
	minx=min([mina minb]);miny=minx;	% set limits
	maxa=max(max(A1));maxb=max(max(A2));
	maxx=max([maxa maxb]);maxy=maxx;
end

if nargin==3
	n=m;		% square array
end

if nargin==2
	m=10;n=10;		% default number of bins 10x10
end

B1=zeros(m,n);B2=zeros(m,n);

[c1,d1]=size(A1);[c2,d2]=size(A2);	% size of A1 and A2

minys=miny-0.0001;minxs=minx-0.0001;ms=m-0.01;ns=n-0.01;
rangex=maxx-minx;rangey=maxy-miny;

% find coordinates for each x,y pair
Ay1=floor((A1(1,:)-minys).*ms./rangey+1);
Ax1=floor((A1(2,:)-minxs).*ns./rangex+1);
Ay2=floor((A2(1,:)-minys).*ms./rangey+1);
Ax2=floor((A2(2,:)-minxs).*ns./rangex+1);

if draw==1
	axis1=[-5,5,-5,5];axis2=[1,m,1,m];	% set axis length
	figure(1);clf
	subplot(2,2,1);plot(A1(1,:),A1(2,:),'ro');axis('square');axis(axis1);grid on
	subplot(2,2,2);plot(Ay1,Ax1,'bo');axis('square');axis(axis2);grid on
	subplot(2,2,3);plot(A2(1,:),A2(2,:),'ro');axis('square');axis(axis1);grid on
	subplot(2,2,4);plot(Ay2,Ax2,'bo');axis('square');axis(axis2);grid on
end

% fill the bins

for k=1:d1
	B1(Ay1(k),Ax1(k))=B1(Ay1(k),Ax1(k))+1;
end
for k=1:d2
	B2(Ay2(k),Ax2(k))=B2(Ay2(k),Ax2(k))+1;
end
