function [d,prob,rr] = ks2d2s(data1,data2,option)

% function [d,prob,rr] = KS2D2S(data1,data2) is a two-dimensional 
% Kolmogorov-Smirnov test on two samples data1 and data2. 
% data1(2,n1) and data2(2,n2) contain the x,y coordinates
% for two distributions.  The K-S statistic d and the significance
% level prob for the null hypothesis that the data sets 
% data1 and data2 are drawn from the same distribution are 
% computed. Small values of prob show that the two samples
% are significantly different. The test is slightly distribution-
% dependent, so prob is only an estimate. Adapted from Press,
% Teukolsky, Vetterling and Flannery, Numerical Recipes in 
% Fortran p643. Generate test data using XKS2D2S.M
% Uses PROBKS and QUADCT

% Version 1.0 RHS 9/11/93
% Version 1.1 RHS 8/3/94
%	Faster search for maximum value of d
%	Option of only returning d added

if nargin<3
	option=1;	% default is return all variables
end

[m1,n1]=size(data1);[m2,n2]=size(data2);	% size of arrays
%d1=zeros(1,n1);d2=zeros(1,n2);			% initialise K-S statistic

flag=0;

for k=1:n1			% use coordinates in data1 as origin
	x=data1(1,k);y=data1(2,k);
	nf1(k,:)=quadct(data1,x,y);
	nf2(k,:)=quadct(data2,x,y);	
end

d1=max(max(abs(nf1-nf2)));

for k=1:n2			% use coordinates in data2 as origin
	x=data2(1,k);y=data2(2,k);
	nf1(k,:)=quadct(data1,x,y);
	nf2(k,:)=quadct(data2,x,y);
end
d2=max(max(abs(nf1-nf2)));

d=(d1+d2)/2;		% average K-S statistics
if option==1
	N=sqrt(n1*n2/(n1+n2));
	[r1,prob,z]=pearson(data1(1,:),data1(2,:));	% get linear correlation
	[r2,prob,z]=pearson(data2(1,:),data2(2,:));	% coefficient for each
	rr=sqrt(1-(r1^2+r2^2)/2);			% sample

	[prob,n]=probks(d*N/(1+rr*(0.25-0.75/N)));	% calculate probability
else
	prob=0;
	rr=0;
end