function [prob,Z] = ks2d2sb(data1,data2)

% function [prob,Z] = KS2S2B(data1,data2) is a two-dimensional 
% Kolmogorov-Smirnov test on two samples data1 and data2 where
% the data is in bins (ie pixelated data).
% data1(m1,n1) and data2(m2,n2) contain the two distributions. The
% K-S statistic d and the significance level prob for the null
% hypothesis that the data sets data1 and data2 are drawn from
% the same distribution are computed. Small values of prob show
% that the two samples are significantly different.
% The probability is calculated from a look-up table of values
% from curves fitted to the results of Monte-Carlo tests for
% 8x8, 16x16 and 32x32 arrays in the range 0.001<=p<=0.20.
% Adapted from Press, Teukolsky, Vetterling and Flannery,
% Numerical Recipes in Fortran p643. Use XKS2D2S to generate test
% data for KS2D2S, and BINS to place the same data in bins to
% test this program.

% Version 1.0 RHS 10/11/93
% Version 2.0 RHS 23/4/94
%	Single call to modified version of QUADCTB
%	which is 25% faster.
% Version 3.0 RHS 3/6/94
%	Completely re-written to make use of the results
%	of Monte-Carlo testing of the binned version of the
%	two-dimensional KS test.
% Version 3.1 RHS 11/6/94
%	Option of returning only Z added for testing of arrays
%	other than 8x8,16x16 and 32x32
% Version 3.2 RHS 13/1/95
%	Table look-up added for arrays other than 8x8,16x16
%	and 32x32

[m1,n1]=size(data1);[m2,n2]=size(data2);	% size of arrays
if m1~=m2 | n1~=n2
	error('data1 and data2 must have same dimensions')
end

s1=sum(sum(data1));s2=sum(sum(data2));	% number of data points

d=quadctb(data1,data2);		% get maximum difference
				% in cumulative distributions

N=sqrt(s1*s2/(s1+s2));
Z=d*N;				% size-independent statistic

% 	calculate probability

prob=kssignif(Z,[m1,n1]);
