function [nf] = quadct(A,x,y)

% function [nf] = QUADCT(A,x,y) - given an origin (x,y) in the 
% array of points A, return the normalised fraction of the points
% in each quadrant round the origin. A(2,n) contains the coordinates
% of n counts. The output array
% nf(4) contains the fraction in quadrants taken counterclockwise
% from top right. Adapted from Press, Teukolsky, Vetterling
% and Flannery, Numerical Recipes in Fortran p642.

% Version 1.0 RHS 9/11/93
% Version 2.0 RHS 8/3/94
%		Faster version of count routine

[m,n]=size(A);		% dimensions of A

nf=zeros(1,4);		% set normalised fractions to zero
origin=[x,y];

for k=1:n
	test=(A(:,k)'>origin)*[2,1]'+1;	% generate test vector
	nf(test)=nf(test)+1;		% and increment appropriate count
end

nf=nf/n;		% normalise fractions

if sum(nf)<0.99 | sum(nf)>1.01
	error('Incorrect normalised fraction')
end 
