function [D] = quadctb(A,B)

% function [D] = QUADCTB(A,B) is a modified version of QUADCT
% for use with arrays A(m1,n1) and B(m2,n2) containing sA and sB
% counts rather than from A(2,n) containing the coordinates of n
% counts. Given an origin (x,y) in the array, return the normalised
% fraction of the points in each quadrant round the origin.  The
% output array D contains the maximum value of this fraction 
% for all x,y. Adapted from Press, Teukolsky, Vetterling
% and Flannery, Numerical Recipes in Fortran p642.

% Version 1.0 RHS 23/4/94

sA=sum(sum(A));		% number of counts in A
sB=sum(sum(B));		% number of counts in B

A=A/sA;B=B/sB;		% reduce to normalised fractions

[m1,n1]=size(A);		% dimensions of A
[m2,n2]=size(B);		% dimensions of B

if m1~=m2 | n1~=n2
	error('Arrays must have same dimensions')
end

for x=1:m1-1
	for y=1:n1-1
		nfA(1)=sum(sum(A(1:x,1:y)));	% increment appropriate count
		nfA(2)=sum(sum(A(x+1:m1,1:y)));
		nfA(3)=sum(sum(A(x+1:m1,y+1:n1)));
		nfA(4)=1-(nfA(1)+nfA(2)+nfA(3));

		nfB(1)=sum(sum(B(1:x,1:y)));	% increment appropriate count
		nfB(2)=sum(sum(B(x+1:m1,1:y)));
		nfB(3)=sum(sum(B(x+1:m1,y+1:n1)));
		nfB(4)=1-(nfB(1)+nfB(2)+nfB(3));

		D(x,y)=max(abs(nfA-nfB));	% maximum difference for x,y
	end
end

D=max(max(D));		% overall maximum difference