function [data1,data2] = xks2d2s(n1,n2,shrink,bins)

% function [data1,data2] = xks2d2s(n1,n2,shrink,bins)
% generates 2-d random samples data1 and data2 to test
% ks2d2s.m. bins=1 is normally distributed, bins>1 is
% grouped in a (bins x bins) array.
% Shrink alters variance
% see Numerical Recipes Example Book p193

% Version 1.0 RHS 9/11/93
% Version 1.1 RHS 8/3/94
%	second mode added
% Version 2.0 RHS 23/3/94
%	Binning routine from BINS added

if nargin<4
	bins=1;		% default is ungrouped
end

n=max(n1,n2);
u=zeros(1,n);v=zeros(1,n);
data1=zeros(2,n1);data2=zeros(2,n2);

u=rand(1,n1);v=shrink*rand(1,n1);
data1(1,:)=u+v;data1(2,:)=u-v;

v=rand(1,n2);u=shrink*rand(1,n2);
data2(1,:)=u+v;data2(2,:)=u-v;

if bins~=1
% 			set limits
	mina1=min(min(data1(1,:)));minb1=min(min(data2(1,:)));
	minx=min([mina1 minb1]);
	mina2=min(min(data1(2,:)));minb2=min(min(data2(2,:)));
	miny=min([mina2 minb2]);

	maxa1=max(max(data1(1,:)));maxb1=max(max(data2(1,:)));
	maxx=max([maxa1 maxb1]);
	maxa2=max(max(data1(2,:)));maxb2=max(max(data2(2,:)));
	maxy=max([maxa2 maxb2]);

	n=bins;m=bins;		% square array

	[c1,d1]=size(data1);[c2,d2]=size(data2);
			% size of data1 and data2

	minys=miny-0.0001;minxs=minx-0.0001;ms=m-0.01;ns=n-0.01;
	rangex=maxx-minx;rangey=maxy-miny;

	% find coordinates for each x,y pair
	Ay1=floor((data1(2,:)-minys).*ms./rangey+1);	
	Ax1=floor((data1(1,:)-minxs).*ns./rangex+1);
	Ay2=floor((data2(2,:)-minys).*ms./rangey+1);
	Ax2=floor((data2(1,:)-minxs).*ns./rangex+1);

% fill the bins

	data1=zeros(m,n);data2=zeros(m,n);

	for k=1:d1
		data1(Ay1(k),Ax1(k))=data1(Ay1(k),Ax1(k))+1;
	end
	for k=1:d2
		data2(Ay2(k),Ax2(k))=data2(Ay2(k),Ax2(k))+1;
	end

end