function [mn,var]= lognstat(mu,sigma);
%LOGNSTAT Mean and variance for the normal distribution.
%	[MN,VAR] = LOGNSTAT(MU,SIGMA) returns the mean and variance of
%	the lognormal distribution with parameters MU and SIGMA.

%	Reference:
%	   [1]  Mood, Alexander M., Graybill, Franklin A. and Boes, Duane C.,
%	   "Introduction to the Theory of Statistics, Third Edition", McGraw Hill
%	   1974 p. 540-541.

%	Copyright (c) 1993 by The MathWorks, Inc.

if nargin < 2, 
    error('Requires two input arguments.'); 
end

[errorcode mu sigma] = distchck(2,mu,sigma);

if errorcode > 0
    error('The arguments must be the same size or be scalars.');
end

s2 = sigma .^ 2;

mn = exp(mu + 0.5 * s2);
var = exp(2*(mu + s2)) - exp(2*mu - s2);

% Return NaN if SIGMA is negative or zero.
k = find(sigma <= 0);
if any(k)
    x(k) = NaN * ones(size(k)); 
end
