function makeprm
% MAKEPRM - make a parameter file for PROGRESS.EXE

global PATH_Data PATH_Prg PATH_Demo

% length of file equals 2 when the user cancels
LEN_NoFileSel = 2;
LEN_MAX_Name = 10;
LEN_MAX_Title = 60;
DEFAULT = 1;


clc
% goto the data path
	eval(PATH_Data);

% load appropriate file using uicontrols
	FILE_Dat= ldfile('*.mlt;*.smp');

% check if user canceled, if so return
	if length(FILE_Dat) == LEN_NoFileSel
		return
	end

% otherwise get the number of variables from data file
	gcases

% make sure case values were added
if NUM_VARIABLES < 3
	err04
	return
end

% create input file pointer
	FID_DAT = fopen(FILE_Dat,'r');	

% Create the parameter file
	FILE_Prm = chgext(1, FILE_Dat, '.PRM');
	FID_Prm = fopen(FILE_Prm, 'wt');

% Create the output file
	FILE_Out = chgext(1, FILE_Dat, '.OUT');

% n by NUM_VARIABLES matrix
	xy=fscanf(FID_DAT,'%f',[NUM_VARIABLES, inf]);
	[NUM_OfVariables, NUM_OfCases] = size(xy);


	if NUM_VARIABLES ~= NUM_OfVariables
		erro4
		return
	end

	fprintf(FID_Prm, '%i\ny\n%i\n%i\n', NUM_OfCases, NUM_VARIABLES, NUM_VARIABLES);


disp('                Do you want to use the default paramaters:')
disp('                                 Y - Yes')
disp('                                 N - No')
disp(' ')

resp = input('>> ', 's');
resp = resp(1);

% +++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
% user will enter the paramaters starting here
% +++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++

if resp == 'N' | resp == 'n' 
 
   VAR_SIZE = 0;

   string = ['Enter the response variable name (maximum ' int2str(LEN_MAX_Name) ...
  		 ' characters):    '];
  
   disp(string)

   % get the variable name
   while VAR_SIZE == 0
	
	response = input('>>>...', 's');
	VAR_SIZE = length(response);
	   if VAR_SIZE == 0
		clc
		disp('Try Again...  Response variable name invalid.'); 
	   end
   end
	
	% truncate if too long
	if length(response) > LEN_MAX_Name
		response = [response(1:LEN_MAX_Name)];
	end

	fprintf(FID_Prm, '%s\n', response);

    % How many explanatory variables
       num_explanatory = NUM_VARIABLES;
        
	% don't use case numbers or dependant variables
	string = ['Enter number of explanatory variables to use in the'...
	          ' analysis? (at most ' int2str(NUM_VARIABLES-2) '):   '];


  if NUM_VARIABLES-2 ~= 1
    
       while num_explanatory > NUM_VARIABLES-2 | num_explanatory < 1 

         num_explanatory = input(string);
 	
         if num_explanatory > NUM_VARIABLES-2 | num_explanatory < 1 
	        clc
	        disp('Try Again...  Number of explanatory variables is out of range.');
         end
    end

  
  else 
      % simple regression no need to ask user
      num_explanatory = 1;
  end

	fprintf(FID_Prm, '%i\n', num_explanatory);
 
  % Get the postion and label of the desired explanatory variable(s)

      PositionMatrix = [];
      ExplanatoryMatrix = [];
   for index = 1:num_explanatory
        
	if num_explanatory ~= 1
            string = ['Enter position of explanatory variable #' int2str(index)   ':     '];
            position = [];
	      
		while position == []
	              position = input(string);
		      disp(' ')
		    	   if position == []
				clc
				disp('Try Again...')
			   end
		end
			
	else
	    position = 2;
	end
	
        string = ['Enter a label for explanatory variable #' int2str(index)   ':      '];

	VAR_SIZE = 0;
        while VAR_SIZE == 0
          explanatory = input(string, 's');
	  disp(' ')

          VAR_SIZE = length(explanatory);
     
          if VAR_SIZE == 0
	         clc
	         disp('Try Again... Invalid Variable Label');
          end
        end
	
	 if length(explanatory) > LEN_MAX_Name
		  explanatory = [ explanatory(1:LEN_MAX_Name) ];
         end
	 
		 PositionMatrix = [PositionMatrix; position];
	 	 ExplanatoryMatrix = str2mat(ExplanatoryMatrix, explanatory);
	   
   end

      for index = 1:num_explanatory
       fprintf(FID_Prm, '%i         %s\n', PositionMatrix(index), ExplanatoryMatrix(index+1,:) );
      end

       fprintf(FID_Prm, '2\n3\ny\n%s\n%s\n', FILE_Dat, FILE_Out);
		

       string = ['Please enter a title for the output (at most '...
                   int2str(LEN_MAX_Title) ' characters):    '];
   
    VAR_SIZE = 0;
    while VAR_SIZE == 0
             TITLE_Graph = input(string, 's');
	     VAR_SIZE = length(TITLE_Graph);
	     
             if VAR_SIZE == 0
		  clc
		  disp('Try Again...  Invalid Title.');
	     end
    end

	% truncate string if too long
	if length(TITLE_Graph) > LEN_MAX_Title
		TITLE_Graph = [ TITLE_Graph(1:LEN_MAX_Title)];
	end

	fprintf(FID_Prm, '%s\ny\ne\n0\ny', TITLE_Graph);


else

% +++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
% use default parameters start here
% +++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++

		fprintf(FID_Prm, 'n\n');
		fprintf(FID_Prm, '%i\n', NUM_VARIABLES - 2);

	for position = 2:NUM_VARIABLES - 1
		explanatory = int2str(position-1);
		explanatory = ['x' explanatory];
		fprintf(FID_Prm, '%i         %s\n', position, explanatory ); 
	end

		fprintf(FID_Prm, '2\n3\ny\n%s\n%s\n', FILE_Dat, FILE_Out);

	%Create graph title
		nameptr = findstr(FILE_Dat, '\');
		nameptr = max(nameptr);
		TITLE_Graph = chgext(nameptr+1, FILE_Dat, ' ');
	
		fprintf(FID_Prm, '%s\ny\ne\n0\ny', TITLE_Graph);

end


fclose(FID_DAT);
fclose(FID_Prm);
eval(PATH_Demo);
clc
