function uroot(z,k,tr)
% Augmented Dickey-Fuller test for unit roots
% by Nitinai Sirismatthakarn
% Department of Economics, Florida State University
%
% Usage: adf(z,k,tr)
%        z  - data series (column form)
%        k  - # of augmented terms [0=default]
%        tr - 0 = no included constant and trend 
%             1 = no included trend, but constant
%             2 = included constant and trend [default]
if nargin < 3, tr=2; end
if nargin < 2, k=0; end
[r,c]=size(z);
if c>1,disp('ERROR: series must be a column vector'),return,end
dz=diff(z);
w=[z(k+1:r-1)];
if k > 0
  for j = 1:k
    w=[w dz(k+1-j:r-1-j)];
  end
end
if tr > 0
  w=[w ones(r-k-1,1)];
end
if tr==2
  w=[w (1:r-k-1)'];
end
y=dz(k+1:r-1);
wwi=inv(w'*w);
beta=wwi*w'*y;                    
yh=w*beta;                        
e=y-yh;                          
ess=sum(e.^2);  
s2=ess/(length(y)-length(beta));     
seb=sqrt(diag(s2*wwi));  
tratio=beta./seb;   
if tr==0, disp('Rows present lagged z : dz-1 : ... : dz-k'),end
if tr==1, disp('Rows present lagged z : dz-1 : ... : dz-k : constant'),end
if tr==2, disp('Rows present lagged z : dz-1 : ... : dz-k : constant : trend'),end

disp('      beta    st.err   t-ratio')

disp([beta seb tratio])

disp('Augment Dickey Fuller Critical Value for the Coefficient of :')

if tr==0, disp('Lagged z at 95% = -1.95  :  at 99% = -2.60'),end

if tr==1, disp('Lagged z at 95% = -2.89  :  at 99% = -3.51'),
          disp('Constant at 95% =  2.54  :  at 99% =  3.22'),end

if tr==2, disp('Lagged z at 95% = -3.45  :  at 99% =-4.04'),
          disp('Constant at 95% =  3.11  :  at 99% = 3.78'),
          disp('Trend at 95%    =  2.79  :  at 99% = 3.53'),end
                                           
