function z = symconcat(A,B,axisIndex)
% symconcat(A,B,axisIndex)
% April 19, 1995, H. Gollwitzer
% Purpose: Generate the symbolic equivalent of [A;B] or [A,B]
%               according as axisIndex ==1 or axisIndex == 2, respectively.
%               The second alternative is used if axisIndex is omitted.
% Argument checking is carried out.
if ~(isstr(A)&isstr(B))
        disp('symconcat: Input arrays must be symbolic');
        return
end
if nargin == 3
        if ~((axisIndex==1)|(axisIndex==2))
                disp('symconcat: axis index error');
                return;
        end
else
        axisIndex = 2;
end
[rA,cA] = symsize(A); [rB,cB] = symsize(B);% Array size information
if (axisIndex == 1)&(cA ~= cB)
        disp('symconcat: Mismatched column counts.');
        return
end
if (axisIndex == 2)&(rA ~= rB)
        disp('symconcat: Mismatched row counts.');
        return
end
% **** End of argument checking ****
% Create output array.
if axisIndex == 1
        z = sym(rA+rB,cA,'1');
        for i = 1:rA
                for j = 1:cA
                        z = sym(z,i,j,sym(A,i,j));
                end
        end
        for i = (rA+1):(rA+rB)
                for j = 1:cA
                        z = sym(z,i,j,sym(B,i-rA,j));
                end
        end
else% axisIndex == 2
        z = sym(rA,cA+cB,'1');
        for i = 1:rA
                for j = 1:cA
                        z = sym(z,i,j,sym(A,i,j));
                end
        end
        for i = 1:rA
                for j = (cA+1):(cA+cB)
                        z = sym(z,i,j,sym(B,i,j-cA));
                end
        end
end

