function z = symextend(S,rowsTarget,columnsTarget,axisIndex)
% symextend(S,rowsTarget,columnsTarget,axisIndex)
% April 21, 1995, H. Gollwitzer
% Purpose: simulate an extend operation based on a
%                       cyclic reuse of the elements of S, if necessary.
%                       It makes sense even if
%                       prod(symsize(S)) ~= rowsTarget*columnsTarget

% Inputs:
%               S       - symbolic matrix
%               rowsTarget columnsTarget        - symsize of result z
%               axisIndex - optional argument: 1 means use column major
%                                       and 2 means row major order reuse of elements
%                                       in S.  The default is 2.
%       USES: isstr disp extend sym
if ~isstr(S)
        disp('symextend: Input array must be symbolic');
        return
end
if (nargin < 3)|(nargin > 4)
        disp('symextend needs 3 or 4 arguments');
        return
else 
        if nargin == 3
                coordIndex = 2;
        else
                if (axisIndex==1)|(axisIndex==2)
                        coordIndex = axisIndex;
                else
                        disp('symextend: The axis index must be 1 or 2');
                        return
                end
        end
end
% More argument checking is needed.
% ****** Input check is finished.
z = sym(rowsTarget,columnsTarget,'1');% Output array init
[sRows,sCols] = symsize(S);
sourceCount = sRows*sCols;
targetCount = rowsTarget*columnsTarget;
if coordIndex==1
        column = extend(1:columnsTarget,rowsTarget,columnsTarget,2);
        column = column(:);
        row = extend(1:rowsTarget,rowsTarget*columnsTarget,1,1);
        count = (column-1).*rowsTarget + row;
        R = rem(count,sourceCount);
        R = R + sourceCount.*(R==0);% modular count into S
        frac = R./sRows;
        colCount = fix(frac);
        columnIndexSource = colCount + (frac ~= colCount);
        rowIndexSource = R-(columnIndexSource-1).*sRows;
else %coordIndex==2
        column = extend(1:columnsTarget,rowsTarget*columnsTarget,1,1);
        row = extend(1:rowsTarget,columnsTarget,rowsTarget,2);
        row = row(:);
        count = (row-1).*columnsTarget + column;%Pointer into target
        R = rem(count,sourceCount);
        R = R + sourceCount.*(R==0);% modular count into S
        frac = R./sCols;
        rowCount = fix(frac);
        rowIndexSource = rowCount + (frac ~= rowCount);
        columnIndexSource = R-(rowIndexSource-1).*sCols;
end
for k=1:targetCount
        z = sym(z,row(k),column(k),...
                        sym(S,rowIndexSource(k),columnIndexSource(k)));
end

