function z = symreshape(S,rowsTarget,columnsTarget,axisIndex)
% symreshape(S,rowsTarget,columnsTarget,axisIndex)
% April 19, 1995, H. Gollwitzer
% Purpose: simulate a reshape operation for symbolic matrix S
% Inputs:
%               S       - symbolic matrix
%               rowsTarget columnsTarget        - symsize of result z
%               axisIndex is 1 for column major reshaping and 2 for
%               row major reshaping.
% Reshaping occurs in row major order if axisIndex is omitted.
if ~isstr(S)
        disp('symreshape: Input array must be symbolic');
        return
end
if (nargin < 3)|(nargin > 4)
        disp('symreshape needs 3 or 4 arguments');
        return
else 
        if nargin == 3
                coordIndex = 2;% This could be changed to 1
        else
                if (axisIndex==1)|(axisIndex==2)
                        coordIndex = axisIndex;
                else
                        disp('symreshape: The axis index must be 1 or 2');
                        return
                end
        end
end
[sRows,sCols] = symsize(S);
if (sRows*sCols)~=(rowsTarget*columnsTarget)
        disp('symreshape: Target shape isn''t correct.');
        return;
end
% More argument checking is needed.
% ****** Input check is finished.
z = sym(rowsTarget,columnsTarget,'1');% Output array initialization
sourceCount = 1:(sRows*sCols); % Count into source array
if coordIndex==1
        frac = sourceCount./rowsTarget;% Start target index calculation
        colCount = fix(frac);
        columnIndex = colCount + (frac ~= colCount);% Target index
        rowIndex = sourceCount-(columnIndex-1).*rowsTarget;% Target index
        for column=1:sCols
                for row = 1:sRows
                        k = (column-1)*sRows + row;
                        z = sym(z,rowIndex(k),columnIndex(k),sym(S,row,column));
                end
        end
else% reshape along rows instead
        frac = sourceCount./columnsTarget;% Start target index calculation
        rowCount = fix(frac);
        rowIndex = rowCount + (frac ~= rowCount);
        columnIndex = sourceCount-(rowIndex-1).*columnsTarget;
        for row = 1:sRows
                for column=1:sCols
                        k = (row-1)*sCols + column;% pointer into sourceCount
                        z = sym(z,rowIndex(k),columnIndex(k),sym(S,row,column));
                end
        end
end% else

% Comment:  This code can be arranged so that only one nested FOR
%                       loop is used.  The resulting code appears rather opaque
%                       and is not used herein. HEG 4/20/95

