function [U,D,UN,DN] = els2ls(UE,DE)

% FUNCTION	[U,D,UN,DN]=els2ls(UE,DE)
% PURPOSE	Convert ELS result to standard U,D format
% INPUTS	UE: parameter matrix for ELS
%		DE: loss function matrix for ELS
% OUTPUTS	U : parameter matrix
%		D : loss function matrix
%		UN: parameter matrix for noise model (ELS only);
%		DN: loss function matrix for noise model (ELS only);
% AUTHOR        Steve Niu (niu@isy.liu.se or niu@comet.eche.ualberta.ca)
% CHANGELOG	$Modified: Tue Mar 22 15:53:50 1994 by niu $
% REFERENCE	Niu, S., Augmented UD identification for process control,
%		PhD thesis, 1994, University of Alberta, Edmonton, Canada.


% Dimensions
	[me,nul]=size(UE);
	n  = (me-1)/3;
	m  = 2*n+1;
	mn = n;

% Initialization
	U  = zeros(m,m);
	D  = zeros(m,1);
	UN = zeros(mn,mn);
	DN = zeros(mn,1);

% Conversion

	U(1:2:m,1:2:m) = UE(1:3:me,1:3:me);
	U(1:2:m,2:2:m) = UE(1:3:me,3:3:me);
	U(2:2:m,1:2:m) = UE(3:3:me,1:3:me);
	U(2:2:m,2:2:m) = UE(3:3:me,3:3:me);

	D(1:2:m) = DE(1:3:me);	
	D(2:2:m) = DE(3:3:me);

	UN(1:mn,1:mn) = UE(2:3:me,2:3:me);
	DN(1:mn) = DE(2:3:me);
	DN       = 1.0./DN;

% back to calling function
	return

