function [L,U]=lu0(A)

% LU0     :  Find the LU factorization of matrix A.
%
% INPUT   :  A -  square matrix.
%
% OUTPUT  :  L -  unit lower-triangular matrix
%            U -       upper-trriangular matrix.
%
% SEE ALSO:  LDU decomposition.

[row,col] = size(A);
if row~=col
   disp(' Matrix A must be a square matrix'); break; end;

n=row; clear row; clear col;

L=eye(n); U=zeros(n,n); maxj=n;

for i=1:n
     for j=1:i-1
	   L0=0;
           for k=1:j-1
              L0=L0+L(i,k)*U(k,j);
	   end
	   if ((U(j,j)>eps)|(U(j,j)<-eps))
  	       L(i,j)=(A(i,j)-L0)/U(j,j);
           end
     end
     for j=i:n
	   U0=0;
	   for k=1:i-1
		 U0=U0+L(i,k)*U(k,j);
	   end
	   U(i,j)=A(i,j)-U0;
     end
end
