function coeff = nspline(x,y)     %<<last updated 10/7/90>>
%NSPLINE  The natural cubic spline to the data in vectors
%         x and y is computed. The x-values must be in increasing
%         order. The output is a table of coefficients for the
%         piecewise cubics. Sketching and evaluation options are
%         available.
%
%   Use in the form   --->  nspline(x,y)  <---
%
%        By: David R. Hill, Math Dept, Temple University,
%            Philadelphia, Pa. 19122
head='          <<<  Natural Cubic Splines with Plotting  >>>';
s0=' ';
mainmenu=['          MAIN Menu               ';
          '                                  ';
          '   1. See the Spline Coefficients.';
          '   2. Sketch the Spline.          ';
          '   3. Evaluate the Spline.        ';
          '                                  ';
          '   0. QUIT                        '];
menu=['   1. Use all of the domain of definition and entire range.';
      '   2. Use all of the domain of definition, but             ';
      '          enter a new range.                               ';
      '   3. Enter a subset of the domain, but                    ';
      '          keep the entire range.                           ';
      '   4. Enter both an x and y spread for sketching.          ';
      '                                                           ';
      '   0. Return to main menu.                                 '];
menu1=['   1. Choose a different sketching window.  ';
       '   2. Show the current sketch.              ';
       '   3. Save the data set used for the sketch.';
       '                                            ';
       '   0. Return to main menu.                  '];
menu2=['   1. Enter a set of values and compute   ';
       '          the corresponding spline values.';
       '                                          ';
       '   0. Return to main menu.                '];
menu3=['   1. See the table of values in a short format.';
       '   2. See the table of values in a long format. ';
       '   3. Evaluate the spline at other points.      ';
       '   4. Save the table of values.                 ';
       '                                                ';
       '   0. Return to main menu.                      '];
choice='   Enter your choice  -->  ';
enter='   Press ENTER to continue.';
n=length(x);m=length(y);
if n~=m
   disp('Error: input vectors of different lengths.')
end
if all(sort(x)~=x),n=0;disp('Error: x values out of order.'),end
[xm,xn]=size(x);if xm~=n | xn~=1,x=x';end
                             %make sure we have columns
[ym,yn]=size(y);if ym~=m | yn~=1,y=y';end
%Calculate the Natural Spline
   nm1=n-1;
   for j=1:nm1,h(j)=x(j+1)-x(j);end
   d=[1];d1=[0];d2=[];
   for j=1:n-2,d=[d 2*(h(j)+h(j+1))];d1=[d1 h(j+1)];d2=[d2 h(j)];end
   d=[d 1];d2=[d2 0];
   A=diag(d)+diag(d1,1)+diag(d2,-1);b=zeros(n,1);
   for j=2:n-1
      b(j)=(3/h(j))*(y(j+1)-y(j)) -(3/h(j-1))*(y(j)-y(j-1));
   end
   C=A\b;
   for j=nm1:-1:1
      B(j)=(y(j+1)-y(j))/h(j) - h(j)*(C(j+1)+2*C(j))/3;
      D(j)=(C(j+1)-C(j))/(3*h(j));
   end
   coeff=[D(1:nm1)' C(1:nm1) B(1:nm1)' y(1:nm1)];
%BEGIN ineractive part
main='N';
while main=='N'
   cla,disp(head),disp(s0),disp(mainmenu),disp(s0),mch=input(choice);
   if mch==0,main='Y';end
   if mch==1
      cla,disp(head),disp(s0)
      disp('The coefficients of the cubic pieces ')
      disp('D*(x-x(i))^3 + C*(x-x(i))^2 + B*(x-x(i)) + A are:')
      disp('   ')
      z='      i         x         D         ';
      z=[z 'C         B         A'];
      z  %display string containing column labels
      z=1:nm1;[z' x(1:nm1) coeff]
      disp(s0),disp(enter),pause
   end
   if mch==2
      disp('Enter interval [a,b] to sketch over')
      disp(['Data range is: [' num2str(x(1)) ',' num2str(x(n)) ']'])
      a=input('left end a = ');b=input('right end b = ');
      disp(s0)
      st=['     ^^* Be patient.  Evaluating over '];
      st=[st '[' num2str(a) ',' num2str(b) '] ^^*'];
      disp(st)
      t=a:(b-a)/50:b;t=[t x'];t=sort(t);
              %set 50 points in addition to the original data
      for k=1:length(t)
         for ks=1:nm1
            if t(k)>=x(ks) & t(k)<x(ks+1)
               ft=polyval(coeff(ks,:),t(k)-x(ks));
            end
         end
         if t(k)<x(1)
            ft=y(1)+B(1)*(t(k)-x(1));
         end
         if t(k)>=x(n)
            ft=(B(n-1)+2*C(n-1)*h(n-1)+3*D(n-1)*h(n-1)^2);
            ft=ft*(t(k)-x(n))+y(n);
         end
         xp(k)=t(k);yp(k)=ft;
      end
      window='N';
      while window == 'N'
         cla,disp(head),disp(s0),disp(setstr('*'*ones(1,50)))
      disp(['The spline is evaluated over [' num2str(a) ',' num2str(b) ']']);
         disp(s0), ysmall=min(yp);ylarge=max(yp);
      disp(['The range is from ' num2str(ysmall) ' to ' num2str(ylarge)])
         disp(s0),disp('Choose a graphing window:'),disp(s0)
         disp(menu),disp(s0),ch=input(choice);
         if ch==0,window = 'Y';end
         if ch==1,xs=a;xl=b;ys=ysmall;yl=ylarge;end
         if ch==2,xs=a;xl=b;
            ys=input('Smallest y to use = ');yl=input('Largest y to use = ');
         end
         if ch==3,ys=ysmall;yl=ylarge;
            xs=input('Smallest x to use = ');xl=input('Largest x to use = ');
         end
         if ch==4
            xs=input('Smallest x to use = ');xl=input('Largest x to use = ');
            ys=input('Smallest y to use = ');yl=input('Largest y to use = ');
         end
         if ch==1 | ch==2 | ch==3 | ch==4
            clg,axis([xs xl ys yl]),plot(x,y,'+',xp,yp,':')
            lgd=['original data +   spline data is dotted '];title(lgd)
            xlabel(enter),pause,axis;
            skwindow='N';
            while skwindow=='N'
               cla,disp(head),disp(s0),disp(menu1);ch=input(choice);
               if ch==1 skwindow='Y';end
               if ch==2,shg,pause,end
               if ch==3,splset=[xp' yp'];
              name=input('Between single quotes enter a name for the table: ');
                  eval(['save ' name ' splset'])
                  disp(['Saved as file ' name ' in variable splset.'])
                  disp(enter),pause
               end
               if ch==0,skwindow='Y';window='Y';end
            end % skwindow
         end
      end %end of sketching window loop
   end % sketch spline loop
   if mch==3
      speval='N';
      while speval=='N'
         cla,disp(head),disp(s0),disp(menu2),ch=input(choice);disp(s0)
         if ch==0,speval='Y';end
         if ch==1,disp('Enter a vector of values between square brackets.')
            t=input('values = ');t=t(:);vxp=[];vyp=[];
            t=sort(t);
            for k=1:length(t)
               for ks=1:nm1
                  if t(k)>=x(ks) & t(k)<x(ks+1)
                     ft=polyval(coeff(ks,:),t(k)-x(ks));
                  end
               end
               if t(k)<x(1)
                  ft=y(1)+B(1)*(t(k)-x(1));
               end
               if t(k)>=x(n)
                  ft=(B(n-1)+2*C(n-1)*h(n-1)+3*D(n-1)*h(n-1)^2);
                  ft=ft*(t(k)-x(n))+y(n);
               end
                  vxp(k)=t(k);vyp(k)=ft;
            end
            valtab=[vxp' vyp'];
            speval1='N';
            while speval1=='N'
               cla,disp(head),disp(s0),disp(menu3)
               vch=input(choice);disp(s0)
               if vch==0,speval='Y';ch=0;speval1='Y';end
               if vch==1 | vch==2
                  if vch==1,format short e,else,format long e,end
                  disp(valtab),format short,disp(enter),pause
               end
               if vch==3,speval1='Y';ch=0;end
               if vch==4
              name=input('Between single quotes enter a name for the table: ');
                  eval(['save ' name ' valtab'])
                  disp(['Saved as file ' name ' in variable valtab.'])
                  disp(enter),pause
               end
            end %while speval1
         end %ch=1
      end %evaluate spline
   end %mch=3
end %main
disp(s0),disp('SPLINE ROUTINE is over!')
