function [t,x,tcpu]=fhrmck(m,c,k,f1,f2,w,t0,x0,v0,tf,h)
% [t,x,tcpu]=fhrmck(m,c,k,f1,f2,w,t0,x0,v0,tf,h)
%
% This function integrates mx"+cx'+kx = f1 cos(wt)+f2 sin(wt)
% over t0:h:tf. The matrices m,c,and k are constant. Vectors
% f1 and f2 as well as the forcing frquency w are constant.
% Initial conditions are x(t0)=x0 and v(t0)=v0. Values returned
% are
%    [t,x,tcpu] <==> [time,displacement,cputime]
% where t is a column of time values and x is a matrix in which
% row j represents the system position at time t(j). The clock
% time needed to perform the calculations is returned in tcpu.

%    by Howard Wilson, U. of Alabama, Spring 1989

tcpu=clock; f1=f1(:); f2=f2(:); x0=x0(:); v0=v0(:);
n=length(x0); t=0:h:(tf-t0); coswt=cos(w*t); sinwt=sin(w*t);

% First construct the particular solution for harmonic response

kwm=k-(w*w)*m; wc=w*c; x12=[[kwm,wc];[-wc,kwm]]\[f1;f2];
x1=x12([1:n],1); x2=x12([n+1:n+n],1);

% Next determine the solution of the homogeneous equation

a=[[zeros(n),eye(n)];-m\[k,c]]; [u,eigval]=eig(a);

% Weight the eigenvalues properly to satisfy modified
% initial conditions

u=u*diag(u\[(x0-x1);(v0-w*x2)]);
xv=real(u*exp(diag(eigval)*t));

x=x1*coswt+x2*sinwt;
x=x'+xv([1:n],:)';%  v=v'+xv([n+1:n+n],:)'
t=(t+t0)'; tcpu=etime(clock,tcpu);
