%------------------------------------------------------------------
% Keywords: "The Limits of Growth", Forrester, MIT,
%	    "The Club if Rome", 1970, "Zero Growth"
%
% Title of book:
% "World Dynamics", Jay W. Forrester, Wright-Allen Press Inc.,
% 238 Main Street, Cambridge, Massachusetts 02142, Second Edition,
% 1973, Appendix B, Equations of the World Model, Page 136 till 138
% written in language "DYNAMO" 
%
% Below it is 
% written in language "MATLAB" Version 4.0, Students Edition
% on 951001, 23:46
% by Michael Nowak, Email address: 100533.2037@compuserve.com
% 
% Many tables has been extended otherwise Mr. Jay Forresters
% "World Model: World Dynamics W5" is not running 
% for some extremely politics expressed by "Clipping Parameter".
%
% Title: World Dynamics W5I2
%
% Follwing settings has been
% 
% actual setting for ORIG:
% ========================
%
% tested: Chapter Four, Page: 70,  Fig.: 4-1, 4-2 
%	  ORIG-A + ORIG-B
%
% tested: Chapter Four, Page: 75,  Fig.: 4-5, 4-6
% 	  PRESENT : NRUN1 = 0.25
% 	  ORIGINAL: NRUN1 = 1.00
%
% tested: Chapter Four, Page: 108, Fig.: 5-11
% 	  PRESENT : NRUN1 = 0.25, POLN1 = 0.700, FC1 = 1.250
% 	  ORIGINAL: NRUN1 = 1.00, POLN1 = 1.000, FC1 = 1.000
%------------------------------------------------------------------

	clear all;
	texec = cputime;
	telap = clock;
	
% Clipping Parameter:
%---------------------

	swt0    = 1970;%1995;

	brn     = 0.04;%0.04;
	brn1    = 0.04;%0.03;
	swt1    = swt0;

	nrun    = 1.00;%1;
	nrun1   = 1.00;%1.20;
	swt2    = swt0;
	
	drn     = .028;%0.028;
	drn1    = .028;%0.012;
	swt3    = swt0;

	cign    = .05;%.05;
	cign1   = .05;%.15;
	swt4    = swt0;

	cidn    = .025;%.025;
	cidn1   = .025;%.050;
	swt5    = swt0;

	poln    = 1.0;%1
	poln1	= 1.0;%0.7;
	swt6    = swt0;

	fc      = 1.0;%1;
	fc1	= 1.0;%1.3;
	fn      = 1;
	swt7    = swt0;

% For reduction of elapsed time: dt=1.00 
% but has nearly no effect on results.
% Orignal is dt = 0.25

dt        = 1;
ttime     = 1900;
length    = 2100;%2200;

ninterval = size(ttime:dt:length);
n         = ninterval(2);

init = zeros(ninterval); time = init;
p    = init; nr  = init; ciaf = init; ci = init; pol = init;

% Initial values for k=1;

	pi      = 1.65e9;
	p(1)    = pi;
	nri     = 900e9;
	nr(1)   = nri;
	la      = 135e6;
	pdn     = 26.5;
	cr(1)   = p(1) / (la * pdn);
	time(1) = ttime;
	cii     = .4e9;
	ci(1)   = cii;
	cir(1)  = ci(1) / p(1);
	poli    = .2e9;
	pol(1)  = poli;
	pols    = 3.6e9;
	polr(1) = pol(1) / pols;
	ciafi   = .2; 
	ciaft   = 15;
	ciaf(1) = ciafi;
	
	k       = 1;
	kl      = 1;

	nrfr(k) = nr(k) / nri;
	nremt   = [ 0 .15 .5 .85 1 ];
	nrem(k) = interp1(0:.25:1, nremt, nrfr(k));
	ecirn   = 1.0;
	ciafn   = 0.3;
	ecir(k) = cir(k) * (1.0-ciaf(k)) * nrem(k) / (1.0-ciafn);

	msl(k)  = (ecir(k) / ecirn);

	%nrmmt  = [0 1 1.8 2.4 2.9 3.3 3.6 3.8 3.9 3.95 4];
	%nrmm(k)= interp1(0:1:10, nrmmt, msl(k));
	nrmmt   = [0 1 1.8 2.4 2.9 3.3 3.6 3.8 3.9 3.95 4.0...
		   4.05 4.05 4.05 4.1 4.1 4.1 4.1 4.1 4.1 4.1];
	nrmm(k) = interp1(0:1:20, nrmmt, msl(k));
%	nrun    = 1;
%	%nrun1  = 1;
%	nrun1   = 0.25;
%	swt2    = 1970;

	nrur(kl)= p(k) * (nrun*(swt2>=time(k))+nrun1*(swt2<time(k)))...
		  * nrmm(k);

	cira(k) = cir(k) * ciaf(k) /  ciafn;
	%fpcit  = [.5 1 1.4 1.7 1.9 2.05 2.2];
	%fpci(k)= interp1(0:1:6, fpcit, cira(k));
	fpcit   = [.5 1 1.4 1.7 1.9 2.05 2.2 2.4 2.6 2.8...
		   3.0 3.2 3.4 3.6 3.8 4.0 4.2 4.4 4.6 4.8...
		   5.0 5.2 5.4 5.6 5.8 6.0 6.2 6.4 6.6 6.8...
		   7.0 7.2 7.4 7.6 7.8 8.0 8.2 8.4 8.6 8.8...
		   9.0 9.2 9.4 9.6 9.8 10.0 10.2 10.4 10.6 10.8...
		   11.0 11.2 11.4 11.6 11.8 12.0 12.2 12.4 12.6 12.8...
		   13.0 13.2 13.4 13.6 13.8 14.0 14.2 14.4 14.6 14.8];
	fpci(k) = interp1(0:1:69, fpcit, cira(k));
	fcmt    = [2.4 1 .6 .4 .3 .2];
	fcm(k)  = interp1(0:1:5, fcmt, cr(k));
	fpmt    = [1.02 .9 .65 .35 .2 .1 .05...
		   0.0 0.0 0.0 0.0 0.0 0.0];
	fpm(k)  = interp1(0:10:120, fpmt, polr(k));
%	fc      = 1;
%	%fc1    = 1;
%	fc1	= 1.25;
%	fn      = 1;
%	swt7    = 1970;

	fr(k)   = fpci(k) * fcm(k) * fpm(k) *...
		  (fc*(swt7>=time(k))+fc1*(swt7<time(k))) / fn;
	
	brcmt   = [1.05 1 .9 .7 .6 .55];
	brcm(k) = interp1(0:1:5, brcmt, cr(k));
	%brfmt  = [0 1 1.6 1.9 2];
	%brfm(k)= interp1(0:1:4, brfmt, fr(k));
	brfmt   = [0 1 1.6 1.9 2.0...
		    2.05 2.1 2.15 2.2 2.2 2.2 2.2];
	brfm(k) = interp1(0:1:11, brfmt, fr(k));
	%brmmt  = [1.2 1  .85 .75 .7 .7];
	%brmm(k)= interp1(0:1:5, brmmt, msl(k));
	brmmt   = [1.2 1  .85 .75 .7 .7...
		   .7 .7 .7 .7 .7 .7 .7 .7 .7 .7 .7 .7 .7 .7 .7];
	brmm(k) = interp1(0:1:20, brmmt, msl(k));
	brpmt   = [1.02 .9 .7 .4 .25 .15 .1...
		   0.05 0.00 0.0 0.0 0.0 0.0];
	brpm(k) = interp1(0:10:120, brpmt, polr(k));
%	swt1    = 1970;
%	brn     = 0.04;
%	brn1    = 0.04;

	br(kl)  = p(k) * (brn*(swt1>=time(k))+brn1*(swt1<time(k)))...
		  * brfm(k) * brmm(k) * brcm(k) * brpm(k);

	%drmmt  = [3 1.8 1 .8 .7 .6 .53 .5 .5 .5 .5 ];
	%drmm(k)= interp1(0:0.5:5,drmmt,msl(k));
	drmmt   = [3 1.8 1 .8 .7 .6 .53 .5 .5 .5 .5...
		   .5 .5 .5 .5 .5 .5 .5 .5 .5 .5...
		   .5 .5 .5 .5 .5 .5 .5 .5 .5 .5...
		   .5 .5 .5 .5 .5 .5 .5 .5 .5 .5 ];
	drmm(k) = interp1(0:0.5:20,drmmt,msl(k));
%--------------------------------------------------------------
%  x=0:10:60;  fit=polyfit(x,drpmt,2)
%  fit =
%        0.0021    0.0137    0.9271
%  Meaning: p(x) = 0.0021 * x**2 + 0.0137 * x + 0.9271
%  drpmtfit=polyval(fit,x);
%  table=[x; drpmt; drpmtfit; drpmt-drpmtfit]'; 
%  figure(3); plot(x,drpmt,x,drpmtfit); 
%  x=0:10:120; drpmtfit=polyval(fit,x);
%-------------------------------------------------------------
	drpmt   = [.92 1.3 2 3.2 4.8 6.8 9.2...
		   12.0 15.3 18.9 23.0 27.5 32.4];
	drpm(k) = interp1(0:10:120,drpmt,polr(k));
	%drfmt  = [30 3 2 1.4 1 .7 .6 .5 .5];
	%drfm(k)= interp1(0:0.25:2,drfmt,fr(k));
	drfmt   = [30 3 2 1.4 1 .7 .6 .5 .5...
		   .5 .5 .5 .5 .5 .5 .5 .5 .5 .5 .5 .5...
		   .5 .5 .5 .5 .5 .5 .5 .5 .5 .5 .5 .5...
		   .5 .5 .5 .5 .5 .5 .5 .5 .5 .5 .5 .5];
	drfm(k) = interp1(0:0.25:11,drfmt,fr(k));
	drcmt   = [.9 1 1.2 1.5 1.9 3];
	drcm(k) = interp1(0:1:5,drcmt,cr(k));
%	drn     = .028;
%	drn1    = .028;
%	swt3    = 1970;

	dr(kl)  = p(k) * (drn*(swt3>=time(k))+drn1*(swt3<time(k)))...
		  * drmm(k) * drpm(k) * drfm(k) * drcm(k);      

	%qlmt  = [.2 1 1.7 2.3 2.7 2.9];
	%qlm(k)= interp1(0:1:5, qlmt, msl(k));
	qlmt   = [.2 1 1.7 2.3 2.7 2.9...
		  3.0 3.05 3.1 3.125 3.15 3.15 3.15 3.15 3.15 3.15...
		  3.15 3.15 3.15 3.15 3.15 ];
	qlm(k) = interp1(0:1:20, qlmt, msl(k));
	qlct    = [2 1.3 1 .75 .55 .45 .38 .3 .25 .22 .2];
	qlc(k)  = interp1(0:.5:5, qlct, cr(k));
	%qlft   = [0 1 1.8 2.4 2.7];
	%qlf(k) = interp1(0:1:4, qlft, fr(k));
	qlft    = [0 1 1.8 2.4 2.7...
		   3.0 3.2 3.3 3.4 3.45 3.5 3.55];
	qlf(k)  = interp1(0:1:11, qlft, fr(k));
	qlpt    = [1.04 .85 .6 .3 .15 .05 .02...
		  0.0 0.0 0.0 0.0 0.0 0.0];
	qlp(k)  = interp1(0:10:120, qlpt, polr(k));        
	qls     = 1 ;

	ql(k)   = qls * qlm(k) * qlc(k) * qlf(k) * qlp(k);

	%ciqrt  = [.7 .8 1 1.5 2];  
	%ciqr(k)= interp1(0:.5:2, ciqrt, qlm(k)/qlf(k));
	ciqrt   = [.7 .8 1 1.5 2 2.5 3 3.5 4.0 4.5 5.0];  
	ciqr(k) = interp1(0:.5:5, ciqrt, qlm(k)/qlf(k));
	
	%cfifrt  = [1 .6 .3 .15 .1];
	%cfifr(k)= interp1(0:.5:2, cfifrt, fr(k));
	cfifrt   = [1 .6 .3 .15 .1...
		    0.075  0.05   0.04   0.03   0.02    0.01...
		    0.005  0.005  0.0025 0.0025 0.00125 0.00125...
		    0.00   0.00   0.00   0.00   0.00    0.00];
	cfifr(k) = interp1(0:.5:11, cfifrt, fr(k));
	
	%cimt   = [ .1 1 1.8 2.4 2.8 3];
	%cim(k) = interp1(0:1:5, cimt, msl(k));
	cimt    = [ .1 1 1.8 2.4 2.8 3.0...
		    3.1 3.15 3.2 3.25 3.3 3.35 3.4 3.45 3.5 3.5...
		    3.5 3.5 3.5 3.5 3.5];
	cim(k)  = interp1(0:1:20, cimt, msl(k));
%	cign    = .05;
%	cign1   = .05;
%	swt4    = 1970;

	cig(kl) = p(k) * cim(k) *...
		  (cign*(swt4>=time(k))+cign1*(swt4<time(k))); 

%	cidn    = .025;
%	cidn1   = .025;
%	swt5    = 1970;
	cid(kl) = ci(k) * (cidn*(swt5>=time(k))+cidn1*(swt5<time(k)));
	
	%polcmt  = [ .05 1 3 5.4 7.4 8 ];
	%polcm(k)= interp1(0:1:5, polcmt, cir(k));
	polcmt   = [ .05 1 3 5.4 7.4 8 8.2 8.2 8.2 8.2 8.2...
		    8.2 8.2 8.2 8.2 8.2 8.2 8.2 8.2 8.2 8.2...
 		    8.2 8.2 8.2 8.2 8.2 8.2 8.2 8.2 8.2 8.2...
 		    8.2 8.2 8.2 8.2 8.2 8.2 8.2 8.2 8.2 8.2];
	polcm(k) = interp1(0:1:40, polcmt, cir(k));
%	poln    = 1;
%	%poln1  = 1;
%	poln1	= 0.7;
%	swt6    = 1970;

	polg(kl)= p(k) * (poln*(swt6>=time(k))+poln1*(swt6<time(k)))...
		  * polcm(k); 
	
	polatt  = [ .6 2.5 5 8 11.5 15.5 20.0...
		   25 30.5 36.6 43.2 50.3 57.9];
	polat(k)= interp1(0:10:120, polatt, polr(k));

	pola(kl)= pol(k) / polat(k);

	ecputime(k) = cputime-texec; 
 	fprintf(1,'time = %5.0f, ',time(k:k))
	fprintf(1,'Init: Elapsed cputime = %6.1f (sec), ',ecputime(k:k))
	fprintf(1,'Elapsed time = %6.1f (sec) \n',etime(clock,telap))
	
for k=2:n
	texec   = cputime;
	j       = (k-1) * (k>1)  + 1 * (k<=1);
	l       = (k+1) * (k>=1) + 1 * (k<=0);
	jk      = (k-j) * (k>j)  + 1 * (k<=j);
	kl      = (l-k) * (l>k)  + 1 * (l<=k);

	time(k) = time(j) + dt;

	p(k)    = p(j)    +  dt 	* (br(jk)  - dr(jk));
	ci(k)   = ci(j)   +  dt 	* (cig(jk) - cid(jk));
	nr(k)   = nr(j)   +  dt 	* (-nrur(jk));
	pol(k)  = pol(j)  +  dt 	* (polg(jk) - pola(jk));
	ciaf(k) = ciaf(j) + (dt/ciaft)  * (cfifr(j) * ciqr(j) - ciaf(j));

	cr(k)   = p(k)   / (la * pdn);
	polr(k) = pol(k) / pols;
	cir(k)  = ci(k)  / p(k);
	nrfr(k) = nr(k)  / nri;
	cira(k) = cir(k) * ciaf(k) / ciafn;

	nrem(k) = interp1(0:.25:1,nremt,nrfr(k));
	ecir(k) = cir(k)  * (1-ciaf(k)) * nrem(k) / (1-ciafn);
	msl(k)  = ecir(k) / ecirn;

	%fpci(k)= interp1(0:1:6,   fpcit,cira(k));
	fpci(k) = interp1(0:1:69,  fpcit,cira(k));
	fcm(k)  = interp1(0:1:5,   fcmt,cr(k));
	fpm(k)  = interp1(0:10:120,fpmt,polr(k));
	fr(k)   = fpci(k) * fcm(k) * fpm(k) *...
		  (fc*(swt7>=time(k))+fc1*(swt7<time(k))) / fn;
	
	brcm(k) = interp1(0:1:5,   brcmt, cr(k));
	%brfm(k)= interp1(0:1:4,   brfmt, fr(k));
	brfm(k) = interp1(0:1:11,  brfmt, fr(k));
	%brmm(k)= interp1(0:1:5,   brmmt, msl(k));
	brmm(k) = interp1(0:1:20,  brmmt, msl(k));
	brpm(k) = interp1(0:10:120,brpmt, polr(k));
	br(kl)  = p(k) * (brn*(swt1>=time(k))+brn1*(swt1<time(k)))...
		  * brfm(k) * brmm(k) * brcm(k) * brpm(k);

	%drmm(k)= interp1(0:0.5:5,  drmmt, msl(k));
	drmm(k) = interp1(0:0.5:20, drmmt, msl(k));
	drpm(k) = interp1(0:10:120, drpmt, polr(k));
	%drfm(k)= interp1(0:0.25:2, drfmt, fr(k));
	drfm(k) = interp1(0:0.25:11,drfmt, fr(k));
	drcm(k) = interp1(0:1:5,    drcmt, cr(k));
	dr(kl)  = p(k) * (drn*(swt3>=time(k))+drn1*(swt3<time(k)))...
		  * drmm(k) * drpm(k) * drfm(k) * drcm(k);

	%qlm(k) = interp1(0:1:5,   qlmt,   msl(k));
	qlm(k)  = interp1(0:1:20,  qlmt,   msl(k));     
	qlc(k)  = interp1(0:.5:5,  qlct,   cr(k));   
	%qlf(k) = interp1(0:1:4,   qlft,   fr(k)); 
	qlf(k)  = interp1(0:1:11,  qlft,   fr(k)); 
	qlp(k)  = interp1(0:10:120,qlpt,   polr(k));                 
	ql(k)   = qls * qlm(k) * qlc(k) * qlf(k) * qlp(k);
	
	%nrmm(k)= interp1(0:1:10, nrmmt, msl(k));
	nrmm(k) = interp1(0:1:20, nrmmt, msl(k));
	nrur(kl)= p(k) * (nrun*(swt2>=time(k))+nrun1*(swt2<time(k)))...
		  * nrmm(k);

	%ciqr(k) = interp1(0:.5:2,  ciqrt,  qlm(k)/qlf(k));
	ciqr(k)  = interp1(0:.5:5,  ciqrt,  qlm(k)/qlf(k));
	%cfifr(k)= interp1(0:.5:2,  cfifrt, fr(k));
	cfifr(k) = interp1(0:.5:11, cfifrt, fr(k));

	%cim(k) = interp1(0:1:5,  cimt, msl(k));
	cim(k)  = interp1(0:1:20, cimt, msl(k));
	cig(kl) = p(k) * cim(k) *...
		  (cign*(swt4>=time(k))+cign1*(swt4<time(k))); 

	cid(kl) = ci(k) * (cidn*(swt5>=time(k))+cidn1*(swt5<time(k)));
	
	%polcm(k)= interp1(0:1:5, polcmt, cir(k));
	polcm(k) = interp1(0:1:40, polcmt, cir(k));
	polg(kl) = p(k) * (poln * (swt6>=time(k))+poln1*(swt6<time(k)))...
		   * polcm(k); 
	
	polat(k) = interp1(0:10:120,polatt, polr(k));
	pola(kl) = pol(k) / polat(k);

	ecputime(k) = ecputime(j) + cputime-texec;
	
	if rem(time(k:k),10)==0
	 %fprintf(1,'k    = %5.0f \n',k)
 	  fprintf(1,'time = %5.0f, ',time(k:k))
	  fprintf(1,'Loop: Elapsed cputime = %6.1f (sec), ',ecputime(k:k))
	  fprintf(1,'Elapsed time = %6.1f (sec) \n',etime(clock,telap))	
	end

	if rem(time(k:k),2000)==0 |...
	   rem(time(k:k),2050)==0 |...
 	   rem(time(k:k),2100)==0 |...
	   rem(time(k:k),2200)==0
	  figure(1); 	
	  subplot(2,3,1);
	  plot(time(1:k), p(1:k),    'r'); title('p');    grid
	  subplot(2,3,2);
	  plot(time(1:k), nr(1:k),   'c'); title('nr');   grid
	  subplot(2,3,3);
	  plot(time(1:k), ql(1:k),   'y'); title('ql');   grid
	  subplot(2,3,4);
	  plot(time(1:k), polr(1:k), 'w'); title('polr'); grid
	  subplot(2,3,5);
	  plot(time(1:k), ci(1:k),   'm'); title('ci');   grid

	  subplot(2,3,6);
	  plot(time(1:k), init(1:k),'k'); axis('off'); 
	  d   = -1.1;
	  if rem(time(k:k),2000)==0 |...
	     rem(time(k:k),2050)==0 |...
 	     rem(time(k:k),2100)==0
	     t = 1900;
	  else   
	     t = 1800;
	  end

 	  str = [ 'brn1            = ', num2str(brn1),',',num2str(swt1)];
	  text(t, d+8*.25, str); clear str;
 	  str = [ 'nrun1          = ', num2str(nrun1),',',num2str(swt2)];
	  text(t, d+7*.25, str); clear str;
 	  str = [ 'drn1            = ', num2str(drn1),',',num2str(swt3)];
	  text(t, d+6*.25, str); clear str;
 	  str = [ 'cign1          = ', num2str(cign1),',',num2str(swt4)];
	  text(t, d+5*.25, str); clear str;
 	  str = [ 'cidn1          = ', num2str(cidn1),',',num2str(swt5)];
	  text(t, d+4*.25, str); clear str;
 	  str = [ 'poln1          = ', num2str(poln1),',',num2str(swt6)];
	  text(t, d+3*.25, str); clear str;
 	  str = [ 'fc1              = ', num2str(fc1),',',num2str(swt7)];
	  text(t, d+2*.25, str); clear str;
 	  str = [ 'swt1234567 = ', num2str(swt0)];
	  text(t, d+1*.25, str); clear str;
	  str = [ 'ecputime     = ', num2str(ecputime(k:k))];
	  text(t, d+0*.25, str); clear str;

	  fprintf(1,'pause\n'); pause

	  figure(2);
	  subplot(2,3,1);
	  plot(time(1:k), fr(1:k),  'r'); title('fr');   grid
	  subplot(2,3,2);
	  plot(time(1:k), msl(1:k), 'c'); title('msl');  grid
	  subplot(2,3,3);
	  plot(time(1:k), qlc(1:k), 'y'); title('qlc');  grid
	  subplot(2,3,4);
	  plot(time(1:k), qlp(1:k), 'w'); title('qlp');  grid
	  subplot(2,3,5);
	  plot(time(1:k), ciaf(1:k),'m'); title('ciaf'); grid

	  subplot(2,3,6);
	  plot(time(1:k), init(1:k),'k'); axis('off'); 
 	  str = [ 'brn1            = ', num2str(brn1),',',num2str(swt1)];
	  text(t, d+8*.25, str); clear str;
 	  str = [ 'nrun1          = ', num2str(nrun1),',',num2str(swt2)];
	  text(t, d+7*.25, str); clear str;
 	  str = [ 'drn1            = ', num2str(drn1),',',num2str(swt3)];
	  text(t, d+6*.25, str); clear str;
 	  str = [ 'cign1          = ', num2str(cign1),',',num2str(swt4)];
	  text(t, d+5*.25, str); clear str;
 	  str = [ 'cidn1          = ', num2str(cidn1),',',num2str(swt5)];
	  text(t, d+4*.25, str); clear str;
 	  str = [ 'poln1          = ', num2str(poln1),',',num2str(swt6)];
	  text(t, d+3*.25, str); clear str;
 	  str = [ 'fc1              = ', num2str(fc1),',',num2str(swt7)];
	  text(t, d+2*.25, str); clear str;
 	  str = [ 'swt1234567 = ', num2str(swt0)];
	  text(t, d+1*.25, str); clear str;
	  str = [ 'ecputime     = ', num2str(ecputime(k:k))];
	  text(t, d+0*.25, str); clear str;

	  fprintf(1,'pause\n'); pause
	end
end