/*************************************************************
  AI-2-MIF   Version 1.0                     DATE:  5/6/94

	BY:  Deron Jackson
    E-mail:  (djackson@mit.edu)
  Platform:  Windows/DOS
  Compiler:  Borland C++ Version 2.0

  This code is written explicitly for converting MATLAB 4.2's
  Adobe Illustrator output into Frame MIF (Maker Interchange
  Format).  This allows MATLAB graphics to be imported into
  Frame.  The resulting importing graphic is then EDITABLE in
  Frame.

  NOTES:
  -----
  1) This code is a quick and somewhat dirty solution
  to the problem of imporing MATLAB graphics.  The code
  should support any MATLAB "line" graphic.  This includes
  any 2D, 3D, mesh and contour plots consisting only of lines
  and text.  However any SURFACE or BITMAPS graphics are not
  supported.

  2) The code contains almost no error checking so
  use it at your own risk.

  3) I am quite certain that this code will NOT WORK with
  anything other than a MATLAB AI file.  I wrote the program
  by deciphering the symbol meanings from a number of MATLAB
  outputs.  I had no references to the TRUE AI format.

  4) Object clipping is rather crudely implemented.  This
  keeps graphs from exceeding their axis edges.  However I have
  not accounted for a few unlikely possibilities.

  5) Matlab plots using NON-SOLID linetypes (dashed, dotted,
  etc.) which have a LARGE number of points will appear
  solid in FRAME.  You can fix this by ungrouping the graphic
  after it is imported and using the Frame SMOOTH command on
  the individual traces.  Frame seems to display the linetype
  correctly when the POLYLINE is smoothed.

  6) You will notice that if you SCALE the graphic once
  imported into Frame the text size will not scale with it.
  This is anoying but I don't know a way around it.  You
  can easily scale the text manually using the "character
  designer" menu.

  7) All colors are mapped to Frame BLACK or NONE.  Color
  support would not be to bad to add but I have no need for
  it.
*************************************************************/

#include <stdio.h>
#include <stdlib.h>
#include <math.h>

#define PPI   72.0
#define TRUE    1
#define FALSE   0

/* Make these GLOBALS */
FILE *aifile;
FILE *miffile;
int finished=TRUE;
int need_start=FALSE;
int need_finish=FALSE;
int grp=3;
int pen=0;
int points=1;
int rec_bound=FALSE;
int clip_in=FALSE;
int clip_out=FALSE;
float minx,maxx,miny,maxy;
float xoffset=0,yoffset=0;

/***********************************************************
CHECK_FINISH()
This procedure finishes a polyline command before adding
anything else to the MIF file.
************************************************************/
void check_finish()
{
   if(finished==FALSE && need_start==FALSE)
   {
      if(points==2)     /* All 2 pt. lines go in group 3 */
	 grp=3;
      else
	 grp=1;     /* Multiple point lines go in group 1 */
      fprintf(miffile,"   <GroupID %d> <NumPoints %d>>\n",grp,points);
      finished=TRUE;
   }
}


/***********************************************************
REC_PROCEDURE()
This procedure records the limits of the current bounding
box.  This is used to CLIP data.
************************************************************/
void rec_procedure(x,y,start)
float x,y;
int start;
{
   if(start)
   {
      minx=x;
      maxx=x;
      miny=y;
      maxy=y;
   }
   else
   {
      if(x<minx)
	 minx=x;
      if(x>maxx)
	 maxx=x;
      if(y<miny)
	 miny=y;
      if(y>maxy)
	 maxy=y;
   }
}


/***********************************************************
CLIP_END()
This procedure clips the end point of a line to the endge
of the bounding box.
************************************************************/
void clip_end(xs,ys,xe,ye)
float xs,ys;
float *xe,*ye;
{
   float xn,yn;
   if(!rec_bound)
   {
      if(*xe>maxx)
      {
	 if(*xe!=xs)
	    yn=((maxx-xs)/(*xe-xs))*(*ye-ys)+ys;
	 xn=maxx;
      }
      if(*xe<minx)
      {
	 if(*xe!=xs)
	    yn=((xs-minx)/(xs-*xe))*(*ye-ys)+ys;
	 xn=minx;
      }
      if(*ye>maxy)
      {
	 if(*ye!=ys)
	    xn=((maxy-ys)/(*ye-ys))*(*xe-xs)+xs;
	 yn=maxy;
      }
      if(*ye<miny)
      {
	 if(*ye!=ys)
	    xn=((ys-miny)/(ys-*ye))*(*xe-xs)+xs;
	 yn=miny;
      }
      *xe=xn;
      *ye=yn;
   }
}

/***********************************************************
CLIP_START()
This procedure clips the start point of a line to the endge
of the bounding box.
************************************************************/
void clip_start(xs,ys,xe,ye)
float *xs,*ys;
float xe,ye;
{
   float xn,yn;
   if(!rec_bound)
   {
      if(*xs>maxx)
      {
	 if(*xs!=xe)
	    yn=((*xs-maxx)/(*xs-xe))*(ye-*ys)+*ys;
	 xn=maxx;
      }
      if(*xs<minx)
      {
	 if(*xs!=xe)
	    yn=((minx-*xs)/(xe-*xs))*(ye-*ys)+*ys;
	 xn=minx;
      }
      if(*ys>maxy)
      {
	 if(*ys!=ye)
	    xn=((*ys-maxy)/(*ys-ye))*(xe-*xs)+*xs;
	 yn=maxy;
      }
      if(*ys<miny)
      {
	 if(*ys!=ye)
	    xn=((miny-*ys)/(ye-*ys))*(xe-*xs)+*xs;
	 yn=miny;
      }
      *xs=xn;
      *ys=yn;
   }
}


/***********************************************************
IN_BOUNDS()
This procedure checks to see if a point is inside the
bounding box.
************************************************************/
int in_bounds(x,y)
float x,y;
{
   if(x>=minx && x<=maxx && y>=miny && y<=maxy)
	 return(TRUE);
   return(FALSE);
}


/***********************************************************
DRAW_LINE()
This procedure actually writes the MIF POLYLINE command.
************************************************************/
void draw_line(xs,ys,xe,ye)
float xs,ys;
float xe,ye;
{
   if(need_start)
   {
      printf("POLYLINE\n");
      printf("  Start Point==> X: %f  Y: %f",xs,ys);
      fprintf(miffile,"<PolyLine <Pen %d> <Fill 15>\n",pen);
      fprintf(miffile,"   <Point %f%c %f%c>",(xs+xoffset)/PPI,34,(-ys+yoffset)/PPI,34);
      if(clip_in)
      {
	 printf("  CLIPPED\n");
	 fprintf(miffile," # CLIPPED\n");
      }
      else
      {
	 printf("\n");
	 fprintf(miffile,"\n");
      }
      need_start=FALSE;
      finished=FALSE;
   }
   printf("  Next Point==> X: %f  Y: %f",xe,ye);
   fprintf(miffile,"   <Point %f%c %f%c>",(xe+xoffset)/PPI,34,(-ye+yoffset)/PPI,34);
   if(clip_out)
   {
      printf("  CLIPPED\n");
      fprintf(miffile," # CLIPPED\n");
   }
   else
   {
      printf("\n");
      fprintf(miffile,"\n");
   }
   if(need_finish)
   {
      if(points==2)     /* All 2 pt. lines go in group 3 */
	 grp=3;
      else
	 grp=1;     /* Multiple point lines go in group 1 */
      fprintf(miffile,"   <GroupID %d> <NumPoints %d>>\n",grp,points);
      need_finish=FALSE;
      finished=TRUE;
      need_start=TRUE;
      points=1;
   }
}


/*******************************************/
/*            Main                         */
/*******************************************/
main (int argc, char* argv[])
{

   char temp,c;
   char inname[20];
   char outname[20];
   char msg5[256];
   char msg4[256];
   char msg3[256];
   char msg2[256];
   char msg1[256];
   char msg[256];
   char ffamily[256];
   char talign[10];
   float fsize;
   float lwidth=0.5;
   float p_maxx,p_minx,p_maxy,p_miny;
   float lastx,lasty,newx,newy,tempx,tempy;
   float textx,texty;
   float seg1,seg2,seg3,seg4;
   float tempf,tempf2;
   int tlength=1;
   int tangle=0;
   int i;
   int skip_line=FALSE;

   strcpy(talign,"Left"); /* Default LEFT text alignment */
   if (argc > 1)
   {
      sprintf(inname,"%s",argv[1]);
      if((aifile=fopen(inname,"r"))==NULL)
      {
	 printf("\nUNABLE TO OPEN INPUT FILE!\n\n");
	 exit(0);
      }
      if(argc==2)
	 sprintf(outname,"%s","default.mif");
      else
	 sprintf(outname,"%s",argv[2]);
      miffile=fopen(outname, "w+b");
   }
   else
   {
      printf("\nUSAGE:  ai2mif infile {outfile}\n\n");
      exit(0);
   }

   printf("\nReading from %s\nWriting to %s\n\n",inname,outname);

   fputs("<MIFFile 4.00> # Generated by AI2MIF\n",miffile);
   fputs("# AI2MIF Written by D. Jackson\n",miffile);
   fputs("# If you have comments e-mail djackson@mit.edu\n",miffile);
   fputs("<PenWidth 0.500>\n",miffile);
   fputs("<HeadCap Round>\n",miffile);
   fputs("<TailCap Round>\n",miffile);


   /* Read through HEADER.  Pull out the BOUNDING BOX */
   while(!feof(aifile) && strncmp("%%EndComments",msg,13))
   {
      fscanf(aifile,"%s", msg);
      if(!strncmp("%%BoundingBox:",msg,14))
      {
	 fscanf(aifile,"%f",&minx);
	 fscanf(aifile,"%f",&miny);
	 fscanf(aifile,"%f",&maxx);
	 fscanf(aifile,"%f",&maxy);
	 xoffset=-(minx+maxx)/2.0;
	 yoffset=(miny+maxy)/2.0;
	 p_minx=minx;                 /* Hold on to these for later */
	 p_maxx=maxx;
	 p_miny=miny;
	 p_maxy=maxy;
      }
   }

   /* Now LOOP through each string and interpret */
   while(!feof(aifile))
   {
      strcpy(msg5,msg4);
      strcpy(msg4,msg3);
      strcpy(msg3,msg2);
      strcpy(msg2,msg1);
      strcpy(msg1,msg);

      if (fscanf(aifile, "%s", msg))
      {
   /* Set the font */
	 if(!strncmp("z",msg,1) && !strncmp("/_",msg5,2))
	 {
	    sprintf(ffamily,"%s",msg5+2);  /* Grab Font FAMILY */
	    sscanf(msg4,"%f",&fsize);      /* Grab Font Size */
	    sscanf(msg1,"%f",&tempf);      /* Find alignment */
	    if(tempf>0)
	       strcpy(talign,"Center");
	    else
	       strcpy(talign,"Left");
	    printf("FONT CHANGE ==> %s, %f, %s\n",ffamily,fsize,talign);
	 }
   /* This sets the pen width */
	 if(!strncmp("w",msg1,1))
	 {
	    check_finish();
	    sscanf(msg2,"%f",&lwidth);
	    fprintf(miffile,"<PenWidth %f>\n",lwidth);
	    printf("LINWIDTH ==> %f\n",lwidth);
	 }
   /* This means a change in linestyle */
	 if(!strncmp("d",msg,1))
	 {
	    check_finish();
	    fputs("<DashedPattern <DashedStyle ",miffile);
	    if(!strncmp("[]",msg2,2))
	    {
	       fputs("Solid>>\n",miffile);
	       printf("LINESTYLE ==> Solid\n");
	    }
	    else if(!strncmp("[",msg2,1))
	    {
	       sscanf(msg2,"[%f]",&seg1);
	       fprintf(miffile,"Dashed> <NumSegments 2> <DashSegment %f pt> <DashSegment %f pt>>\n",seg1,seg1);
	       /* Notice that I repeated the dash segment twice.  Frame will BOMB with a FATAL ERROR */
	       /* if you try define only 1 segment.                                                  */
	       printf("LINESTYLE ==> Dashed\n");
	    }
	    else if(!strncmp("[",msg3,1))
	    {
	       sscanf(msg2,"%f]",&seg2);
	       sscanf(msg3,"[%f",&seg1);
	       fprintf(miffile,"Dashed> <NumSegments 2> <DashSegment %f pt> <DashSegment %f pt>>\n",seg1,seg2);
	       printf("LINESTYLE ==> Dotted\n");
	    }
	    else if(!strncmp("[",msg5,1))
	    {
	       sscanf(msg2,"%f]",&seg4);
	       sscanf(msg3,"%f",&seg3);
	       sscanf(msg4,"%f",&seg2);
	       sscanf(msg5,"[%f",&seg1);
	       fprintf(miffile,"Dashed> <NumSegments 4> <DashSegment %f pt> <DashSegment %f pt> <DashSegment %f pt> <DashSegment %f pt>>\n",seg1,seg2,seg3,seg4);
	       printf("LINESTYLE ==> Dash-Dot\n");
	    }
	 }
   /* This comes after the text position */
	 if(!strncmp("]e",msg1,2))
	 {
	    check_finish();
	    sscanf(msg5,"%f",&tempf);   /* Find text angle */
	       if(tempf==-1)
		  tangle=90;
	       else
		  tangle=0;
	    sscanf(msg3,"%f",&textx);
	    sscanf(msg2,"%f",&texty);
	    sscanf(msg,"%d",&tlength);

	    /* Place all text on GROUP 2 */
	    fprintf(miffile,"<TextLine <GroupID 2> <Angle %d>\n",tangle);
	    fprintf(miffile,"   <Font <FFamily `%s'> <FSize %f> <FPlain Yes> <FBold No>>\n",
		    ffamily,fsize);
	    fprintf(miffile,"   <TLOrigin %f%c %f%c> <TLAlignment %s> <String `",
		    (textx+xoffset)/PPI,34,(-texty+yoffset)/PPI,34,talign);

	    c=fgetc(aifile);   /* Toss away a blank space */
	    c=fgetc(aifile);   /* Toss away a ( character */
	    printf("TEXT STRING ==> ");
	    for(i=0;i<tlength;i++)  /* Read text string */
	    {
	       c=fgetc(aifile);
	       if(c==92)
		  i--;            /* Toss out any slash characters */
	       else
	       {
		  fputc(c,miffile);
		  printf("%c",c);
	       }
	    }
	    fprintf(miffile,"'>>\n");
	    printf("\n  Location==> X: %f  Y: %f\n",textx,texty);
	 }
   /* This is a color definition.  I map everything to BLACK */
	 if(!strncmp("k",msg1,1) || !strncmp("K",msg1,1))
	 {
	    tempf2=0;
	    sscanf(msg5,"%f",&tempf);
	    tempf2=tempf2+tempf;
	    sscanf(msg4,"%f",&tempf);
	    tempf2=tempf2+tempf;
	    sscanf(msg3,"%f",&tempf);
	    tempf2=tempf2+tempf;
	    sscanf(msg2,"%f",&tempf);
	    tempf2=tempf2+tempf;

	    if(tempf2==0)
	       pen=15;
	    else
	       pen=0;
	 }
   /* This moves the marker to start a line */
	 if(!strncmp("m",msg1,1))
	 {
	    check_finish();
	    sscanf(msg3,"%f",&lastx);
	    sscanf(msg2,"%f",&lasty);
	    if(rec_bound)                /* Record bounding box */
	       rec_procedure(lastx,lasty,1);
	    need_start=TRUE;
	    points=1;
	 }
   /* This means draw a line between this point and the marker */
	 if(!strncmp("L",msg1,1))
	 {
	    sscanf(msg3,"%f",&newx);
	    sscanf(msg2,"%f",&newy);
	    tempx=newx;
	    tempy=newy;
	    if(rec_bound)
	       rec_procedure(newx,newy,0);
	    clip_in=!in_bounds(lastx,lasty); /* If not in bounds need to clip */
	    clip_out=!in_bounds(newx,newy);   /* TRUE if not in bounds */
	    if(clip_in && clip_out)
	    {
	       skip_line=TRUE;
	    }
	    else if(clip_in)
	    {
	       clip_start(&lastx,&lasty,newx,newy);
	    }
	    else if(clip_out)
	    {
	       clip_end(lastx,lasty,&newx,&newy);
	       need_finish=TRUE;
	    }
	    if(skip_line==FALSE)
	    {
	       points++;
	       draw_line(lastx,lasty,newx,newy);
	    }
	    else
	       skip_line=FALSE;
	    lastx=tempx;
	    lasty=tempy;
	 }
	 if(!strncmp("q",msg1,1))   /* Start bound box */
	 {
	    rec_bound=TRUE;
	    pen=15;
	 }
	 if(!strncmp("W",msg1,1))   /* End bound box */
	 {
	    rec_bound=FALSE;
	    check_finish();
	    printf("BOUNDING BOX: X: %f %f  Y: %f %f\n",minx,maxx,miny,maxy);
	    fprintf(miffile,"# BOUNDING BOX: X: %f %f  Y: %f %f\n",
		    (minx+xoffset)/PPI,(maxx+xoffset)/PPI,(-miny+yoffset)/PPI,(-maxy+yoffset)/PPI);
	 }
	 if(!strncmp("Q",msg1,1))   /* This means reset the bounding box */
	 {
	    maxx=p_maxx;
	    minx=p_minx;
	    maxy=p_maxy;
	    miny=p_miny;
	    check_finish();
	    printf("BOUNDING BOX: X: %f %f  Y: %f %f\n",minx,maxx,miny,maxy);
	    fprintf(miffile,"# BOUNDING BOX: X: %f %f  Y: %f %f\n",
		    (minx+xoffset)/PPI,(maxx+xoffset)/PPI,(-miny+yoffset)/PPI,(-maxy+yoffset)/PPI);
	 }
      }
      else
      {
	 printf("\nError reading from AI file.\n");
	 exit(1);
      }
   }

   /* This catches the last grouping since there are no more M's */
   if(finished==FALSE && need_start==FALSE)
   {
      if(points==2)     /* All 2 pt. lines go in group 3 */
	 grp=3;
      else
	 grp=1;     /* Multiple point lines go in group 1 */
      fprintf(miffile,"<GroupID %d> <NumPoints %d>>\n",grp,points);
      finished=TRUE;
   }

   /* Now group the TEXT, SINGLE LINES, and then the whole thing */
   fprintf(miffile,"<Group <ID 2> <GroupID 1>>\n");
   fprintf(miffile,"<Group <ID 3> <GroupID 1>>\n");
   fprintf(miffile,"<Group <ID 1>>\n");

   fclose(aifile);
   fclose(miffile);
}
