#!/usr/local/bin/perl
#
# Usage: audit.pl [-display|-nomatlab] <filename>
#
# 	The -display option adds the code to 'audit_display.m' that
#	displays the full-colour text of the file.
#
# 	The -nomatlab option allows the script to be run without MATLAB
#	being present (it can do a limited job of interpreting an m-file)

#       This file is provided to you by Ahlea Systems Corp., makers of the
#       Pattern Recognition Toolbox for MATLAB.  Please visit our web site at
#               http://vvv.com/~caughey/ahlea
#
#       Comments, bug reports, etc. can be made to Dave Caughey at
#               caughey@ahlea.com
#
#       (c) Copyright 1996 by Ahlea Systems Corp.  All rights reserved.
#
#       This file may not be included in any commecially distributed without
#       the express written permission of the author.


if ( $#ARGV == 1 ) {
    if ( $ARGV[0] eq "-nomatlab" ) {
	$nomatlab = 1;
    } elsif ( $ARGV[0] eq "-display" ) {
	$display = 1;
    } else {
	die "audit.pl: invalid option '$ARGV[0]'\n";
    }
    shift( @ARGV );
}

open( FIN, "<$ARGV[0]" );
$firstline = 1;
@p = split('/',$ARGV[0]);
($functionname) = split(/\./,$p[$#p]);
@m = ();
$l = "";

@outs = ();
@ins = ();
@variables = ();
@functions = ();
@globals = ();

while ( <FIN> ) {

    chop $_;

#
# expand tabs
#
    while ( $_ =~ /(\t)/ ) {
	$filler = ' ' x (8-((length($`)+8)%8));
	$_ =~ s/\t/$filler/;
    }

    @src = (@src, $_);		# record for silk-screening

#
# strip out strings
#
    while ( $_ =~ /[^a-zA-Z0-9_.\]\)]('[^']*')/ ) {
	$_ =~ s/[^a-zA-Z0-9_.\]\)]('[^']*')/ /;	# strip out strings
    }

    $_ =~ s/(%.*)//;				# strip out comments
    $_ =~ s/\s+$//;				# strip out trailing spaces
    $l .= $_;					# append to l.u.t.

    next if ( $l =~ s/\s*\.\.\.$// );		# continued lines?

    $l =~ s/,$//;				# strip out trailing comma

#
# parse the first line if necessary
#
    if ( $firstline ) {
	$firstline = 0;
	if ( $l =~ s/^\s*function\s//i ) {
	    $isfunction = 1;
            if ( $l =~ /\s*([^=]+)=/ ) {	# extract output args
                @outs = grep(/^[_A-Za-z]/,split(/[^_A-Za-z0-9]+/,$1));
		$l =~ s/\s*([^=]+)=//;
	    }
            if ( $l =~ /\(([^)]*)\)/ ) {	# extract input args
                @ins = grep(/^[_A-Za-z]/,split(/[^_A-Za-z0-9]+/,$1));
            }
	    $l = "";
	    next;
	}
    }

#
# break each line into statements, where semicolons delimit statements
#
    foreach $lt ( split( /\s*;\s*/, $l ) ) {
	$lti = $lt;
#
# strip out square bracket pairs (which might contain semicolons);
#
	while ( $lti =~ /(\[[^\[\]]+\])/ ) {
	    $filler = ' ' x length($1);
	    $lti =~ s/(\[[^\[\]]+\])/$filler/;
	}
	while ( $lti =~ /(\([^\(\)]+\))/ ) {
	    $filler = ' ' x length($1);
	    $lti =~ s/(\([^\(\)]+\))/$filler/;
	}
	while ( $lti =~ /([^,]*)(,\s+)(.+)/ ) {
	    $first = $1; $comma = $2; $rest = $3;
	    $line = substr( $lt, 0, length($first) );
	    if ( $line =~ /^\s*([A-Za-z][A-Za-z0-9_]*)(.*)/ ) {
		if ($1 eq "if"||$1 eq "else"||$1 eq "elseif"||$1 eq "while"||$1 eq "for") {
		    @m = (@m,$1);
		    $line = $2;
		}
	    }
	    @m = ( @m, $line );
	    substr($lt,0,length($first)+length($comma))
	        = ' ' x (length($first)+length($comma));
	    $lti =~ s/([^,]*)(,\s+)(.+)/($first) ($rest)/;	# mask comma
	}
	if ( $lt =~ /^\s*([A-Za-z][A-Za-z0-9_]*)(.*)/ ) {
	    if ($1 eq "if"||$1 eq "else"||$1 eq "elseif"||$1 eq "while"||$1 eq "for") {
		@m = (@m,$1);
		$lt = $2;
	    }
	}
	@m = ( @m, $lt );
    }
    $l = "";
}

#
# Now we ought to have one MATLAB command per line
# Let's strip out everything that isn't a MATLAB name
#
for ( $i = 0; $i <= $#m; $i++ ) {
    $l = $m[$i];
    $l =~ s/^\s+//;			# strip off leading whitespace
    if ( $l =~ s/\s*global\s+(.+)$// ) {	# if is global command
	@globals = (@globals,split(/\s/,$l));	# record names and delete
    }
    $l =~ s/([A-Za-z]\w+)\s+\w.+/$1/; 	# strip off string arguments
    $l =~ s/\(\s+\)//;			# strip off empty parentheses
#
# strip off all delimiters, except '.+-' which could be used in exponentials
#
    $l =~ s/[><=~]=/ /g;		# strip off inequalities (part 1)
    $l =~ s/[><]/ /g;			# strip off inequalities (part 2)
    while ( $l =~ s/(\.[*\/\\^']|[^a-zA-Z0-9_ \t\.\+\-=]+)/ / ) {
	;
    }
#
# now numbers either start at beginning of line, or follow whitespace
# first, do exponentials (to get rid of "e" as potential functions)
# then do remaining numbers
#
    while ( $l =~ s/(^|\s+)((\d+\.?\d*|\.?\d+)[eE][\-\+]?\d+)/ / ) {
	;
    }
    while ( $l =~ s/(^|\s+)((\d+\.?\d*|\.?\d+))/ / ) {
	;
    }
    $l =~ s/(^|\s+|[+\-])(\d+)/ /g;	# strip off normal numbers
    $l =~ s/[.+\-]/ /g;			# strip off remaining delimeters

    $l =~ s/[^a-zA-Z0-9_=]+/ /g;	# strip off non-tokens
    $m[$i] = $l;			# stuff back into list
    #printf STDERR "%2d: %s\n", $i, $l;
}

#
# First, grab all assignments, because LHS's must be variables
#
foreach $l ( grep( /=/, @m ) ) {
    $l = (split('=',$l))[0];		# just keep LHS;
    while ( $l =~ s/\s*(\S+)\s*// ) {
	if ( ! grep( /^$1$/, (@ins,@outs,@globals,@variables) ) ) {
	    @variables = (@variables, $1 );	# record the token
	}
    }
}
#
# Then all remaining tokens must be functions... maybe.
#	If running from within MATLAB, you can always do a WHICH to find
#	out that, say, "ans" is really an implicitly assigned variable.
#
foreach $l ( @m ) {
    $l =~ s/[^=]+=//;			# we've already processed LHS's
    while ( $l =~ s/\s*(\S+)\s*// ) {
	if (! grep( /^$1$/, (@ins,@outs,@globals,@variables,@functions))) {
	    @functions = (@functions, $1 );	# record the token
	}
    }
}

#
# Now create silk screens
#
for ( $i = 0; $i <= $#src; $i++ ) {

    $l = $src[$i];
    $l =~ s/
//;

#
# define silk screens
#
    $filler = ' ' x (length($l)+1);
    $ss_comments[$i]  = $filler;
    $ss_strings[$i]   = $filler;
    $ss_variables[$i] = $filler;
    $ss_globals[$i]   = $filler;
    $ss_arguments[$i] = $filler;
    $ss_unknowns[$i]  = $filler;
    $ss_default[$i]   = $filler;

#
# transfer strings
#
    while ( $l =~ /(^|[^a-zA-Z0-9_.\]\)])('[^']*')/ ) {
	substr($ss_strings[$i],length($`)+length($1),length($2) ) = $2;
	substr($l,length($`)+length($1),length($2) ) = ' ' x (length($2));
    }

#
# transfer comments, including post-% contents of ss_strings
#
    if ( $l =~ /(%.*)/ ) {
	substr($ss_comments[$i],length($`),length($1) ) = $1;
	substr($l,length($`),length($1) ) = ' ' x length($1);
	for ( $j = length($`); $j <= length($l); $j++ ) {
	    if ( substr($ss_strings[$i],$j,1) ne " " ) {
		substr($ss_comments[$i],$j,1) = substr($ss_strings[$i],$j,1);
		substr($ss_strings[$i],$j,1) = ' ';
	    }
	}
    }
#
# transfer all delimiters, except '.+-' which could be used in exponentials
#
    while ( $l =~ /((\.[*\/\\^']|[^a-zA-Z0-9_ \t\.\+\-]+))/ ) {
	substr($ss_default[$i],length($`),length($1) ) = $1;
	substr($l,length($`),length($1) ) = ' ' x length($1);
    }
#
# now numbers either start at beginning of line, or follow whitespace
# first, do exponentials (to get rid of "e" as potential functions)
# then do remaining numbers
#
    while ( $l =~ /(^|\s+)((\d+\.?\d*|\.?\d+)[eE][\-\+]?\d+)/ ) {
	substr($ss_default[$i],length($`)+length($1),length($2) ) = $2;
	substr($l,length($`)+length($1),length($2) ) = ' ' x length($2);
    }
    while ( $l =~ /(^|\s+)((\d+\.?\d*|\.?\d+))/ ) {
	substr($ss_default[$i],length($`)+length($1),length($2) ) = $2;
	substr($l,length($`)+length($1),length($2) ) = ' ' x length($2);
    }
    while ( $l =~ /(^\d+|\s+\d+|[+\-]\s*\d+)/ ) {
	$pre = length($`);
	$post = $1;
	$post =~ /(\S.*)/;
	substr($ss_default[$i],$pre+length($`),length($1) ) = $1;
	substr($l,$pre+length($`),length($1) ) = ' ' x length($1);
    }
#
# transfer remaining delimiters 
#
    while ( $l =~ /([^a-zA-Z0-9_ \t]+)/ ) {
	substr($ss_default[$i],length($`),length($1) ) = $1;
	substr($l,length($`),length($1) ) = ' ' x length($1);
    }

#
# transfer text, checking type of each word
#
    while ( $l =~ /(\S+)/ ) {
	if ( grep( /^$1$/, (@ins,@outs)) ) {
	    substr($ss_arguments[$i],length($`),length($1) ) = $1;
	} elsif ( grep( /^$1$/, (@globals) ) ) {
	    substr($ss_globals[$i],length($`),length($1) ) = $1;
	} elsif ( grep( /^$1$/, (@variables,'nargin','nargout','ans') ) ) {
	    substr($ss_variables[$i],length($`),length($1) ) = $1;
	} elsif ( grep( /^$1$/, (@functions,$functionname,'function') ) ) {
	    substr($ss_unknowns[$i],length($`),length($1) ) = $1;
	} else {
	    substr($ss_default[$i],length($`),length($1) ) = $1;
	}
	substr($l,length($`),length($1) ) = ' ' x length($1);
    }
}

@controls = ('help','function','for','while','if','else','elseif','end','break','return','exit');

if ( $nomatlab ) {

    if ( $isfunction ) {
	printf "FUNCTION  = %s%s\n", $functionname,
	    (grep(/$functionname/,@functions)>0)?" (RECURSES)":"";
	printf "INPUTS    = %s\n", join(' ',@ins );
	printf "OUTPUTS   = %s\n", join(' ',@outs );
    } else {
	printf "SCRIPT    = %s%s\n", $functionname,
	    (grep(/$functionname/,@functions)>0)?" (RECURSES)":"";
    }
    printf "GLOBALS   = %s\n", join(' ',@globals );
    printf "VARIABLES = %s\n", join(' ',@variables );
    printf "UNKNOWNS  = %s\n", join(' ',@functions );

} else {

    %code = ('args',1,'globals',2,'variables',3,'mfiles',4,'builtins',5,'comments',6,'strings',7,'unknowns',9,'default',10);

    $color{'args'} = "[0 1 1]";
    $color{'globals'} = "[0 0 1]";
    $color{'variables'} = "[0 1 0]";
    $color{'mfiles'} = "[1 1 0]";
    $color{'builtins'} = "[1 1 0]";
    $color{'comments'} = "[1 0 1]";
    $color{'strings'} = "[1 1 1]";
    $color{'unknowns'} = "[1 0 0]";
    $color{'default'} = "[1 1 1]";

    $weight{'args'} = "'normal'";
    $weight{'globals'} = "'bold'";
    $weight{'variables'} = "'normal'";
    $weight{'mfiles'} = "'bold'";
    $weight{'builtins'} = "'normal'";
    $weight{'comments'} = "'normal'";
    $weight{'strings'} = "'bold'";
    $weight{'unknowns'} = "'bold'";
    $weight{'default'} = "'normal'";

    $angle{'args'} = "'normal'";
    $angle{'globals'} = "'normal'";
    $angle{'variables'} = "'normal'";
    $angle{'mfiles'} = "'normal'";
    $angle{'builtins'} = "'normal'";
    $angle{'comments'} = "'italic'";
    $angle{'strings'} = "'italic'";
    $angle{'unknowns'} = "'italic'";
    $angle{'default'} = "'normal'";

    @m = `cat $ARGV[0]`;

    open( FOUT, ">audit_display.m" );
    print FOUT "function h=audit_display( verbose )\n";

    if ( defined( @functions ) ) {
	printf FOUT "funcs = str2mat('%s'", $functions[0];
	for ( $i = 1; $i <= $#functions; $i++ ) {
	    printf FOUT ",str2mat('%s'", $functions[$i];
	}
	printf FOUT "%s);\n", ")" x $#functions;
    
	print FOUT <<EOF;
h=[];for hi=1:size(funcs,1),
    w=which(funcs(hi,funcs(hi,:)~=' '));
    if isstr(w), h(hi) = 2; else h(hi) = w; end;
end;
unknowns = funcs(h==0,:);
variables = funcs(h==1,:);
mfiles = funcs(h==2|h==3|h==4,:);
builtins = funcs(h==5,:);
EOF
    } else {
	print FOUT <<EOF;
unknowns = [];
variables = [];
mfiles = [];
builtins = [];
EOF
    }

    printf FOUT "if verbose>=0,\n";
    if ( $isfunction ) {
	printf FOUT "fprintf('%s%s%s%s');\n",
	    sprintf( "\\nFUNCTION  = %s%s\\n", $functionname,
		(grep(/$functionname/,@functions)>0)?" (RECURSES)":"" ),
	    defined(@ins)?sprintf( "INPUTS    = %s\\n", join(' ',@ins) ):"",
	    defined(@outs)?sprintf( "OUTPUTS   = %s\\n", join(' ',@outs) ):"",
	    defined(@globals)?sprintf( "GLOBALS   = %s\\n", join(' ',@globals) ):"";
    } else {
	printf FOUT "fprintf('%s%s');\n",
	    sprintf( "\\nSCRIPT    = %s%s\\n", $functionname,
		(grep(/$functionname/,@functions)>0)?" (RECURSES)":"" ),
	    defined(@globals)?sprintf( "GLOBALS   = %s\\n", join(' ',@globals) ):"";
    }

    printf FOUT "fprintf('VARIABLES =');\n";
    printf FOUT "for t=variables',t=t(t~=' ')';fprintf(' %%s',t);;end;\n";
    printf FOUT "fprintf(' %s\\n');\n", join(' ',@variables);
    printf FOUT "end;\n";

    if ( defined( @variables ) ) {
	printf FOUT "funcs = str2mat('%s'", $functions[0];
	for ( $i = 1; $i <= $#functions; $i++ ) {
	    printf FOUT ",str2mat('%s'", $functions[$i];
	}
	printf FOUT "%s);\n", ")" x $#functions;
    }

    printf FOUT "controls = str2mat('%s'", $controls[0];
    for ( $i = 1; $i <= $#controls; $i++ ) {
	printf FOUT ",str2mat('%s'", $controls[$i];
    }
    printf FOUT "%s);\n", ")" x $#controls;

    print FOUT <<EOF;
if verbose>=0,
fprintf('\\nBUILT-INS =');
for t=builtins',t=t(t~=' ')';hi=1;
 while hi<=size(controls,1),
  if strcmp(t,controls(hi,controls(hi,:)~=' ')),break;end;
  hi=hi+1;end;
 if hi>size(controls,1),fprintf(' %s',t);end;
end;

fprintf('\\nM-FILES   ='); out=[];
if ~isempty(mfiles),
for t=mfiles',t=t(t~=' ')';
    if verbose==0,out=str2mat(out,t); else out=str2mat(out,which(t)); end;
end; out(1,:)=[];

if verbose,for h=size(out,2):-1:1, [v,hi]=sort(out(:,h));out=out(hi,:);end;end;

if verbose,\n  fprintf(' %s\\n', out(1,:) );
    for i=2:size(out,1), fprintf('            %s\\n',out(i,:)); end;
else, for hi=1:size(out,1),
    fprintf(' %s',out(hi,out(hi,:)~=' '));
end;fprintf('\\n'); end;
else fprintf('\\n'); end;
end;
EOF
    exit if ( ! $display );

    printf FOUT "builtins = str2mat( builtins, 'function', '%s' );\n",
        $functionname;

    printf FOUT "ismfile = 'for hi = 1:size(mfiles,1),if strcmp(tok,mfiles(hi,mfiles(hi,:)~='' '')), set(h,''color'',%s,''fontweight'','%s',''fontangle'','%s'); break; end; end;';\n",
        $color{'mfiles'},$weight{'mfiles'},$angle{'mfiles'};
    printf FOUT "isbuiltin = 'for hi = 1:size(builtins,1),if strcmp(tok,builtins(hi,builtins(hi,:)~='' '')), set(h,''color'',%s,''fontweight'','%s',''fontangle'','%s'); break; end; end;';\n",
        $color{'builtins'},$weight{'builtins'},$angle{'builtins'};
    printf FOUT "isvariable = 'for hi = 1:size(variables,1),if strcmp(tok,variables(hi,variables(hi,:)~='' '')), set(h,''color'',%s,''fontweight'','%s',''fontangle'','%s'); break; end; end;';\n",
        $color{'variables'},$weight{'variables'},$angle{'variables'};
    printf FOUT "isunknown = 'for hi = 1:size(unknowns,1),if strcmp(tok,unknowns(hi,unknowns(hi,:)~='' '')), set(h,''color'',%s,''fontweight'','%s',''fontangle'','%s'); break; end; end;';\n",
        $color{'unknowns'},$weight{'unknowns'},$angle{'unknowns'};

    print FOUT <<EOF;
figure; set(gcf,'units','pixels','numbertitle','off');
set(gcf,'name','Ahlea Systems Corp.: AUDIT ${functionname}.m');
set(gca,'defaulttextfontname','courier','defaulttextfontsize',10);
h=text(0,0,' ','units','pixels'); e0=get(h,'extent'); delete(h);
set(gca,'ydir','reverse','units','pixels'); axis off;
set(gca,'position',get(gcf,'position').*[0 0 1 1]+[25 35 -50 -50]);
ym=get(gca,'position')*[0;0;0;1]; xm=get(gcf,'position')*[0;0;1;0];
set(gca,'userdata',[0 e0]);

set(gcf,'WindowButtonUpFcn','cp=get(gcf,''currentpoint'');yoffe0=get(gca,''userdata'');yoff=yoffe0(1);e0=yoffe0(2:5);cp(1)=cp(1)-25;cp(2)=35+get(gca,''position'')*[0;0;0;1]+yoff-cp(2);row=round(cp(2)/e0(4));col=floor(cp(1)/(e0(3)+2*e0(1)));t=get(gcf,''userdata'');tokloc=t(:,1:3)-0;tokens=t(:,4:size(t,2));m=find(col>=tokloc(:,1)&col<=tokloc(:,2)&row==tokloc(:,3));if ~isempty(m),m=tokens(m,:);m=m(m~='' '');if strcmp(get(gcf,''selectiontype''),''normal''),help(m);else,audit(m,''silent'',''display'');end;else,fprintf(''audit: no function at that location\\n'');end;');

h=uicontrol(gcf,'style','pushbutton','position',[0 0 100 25],...
    'string','About','callback','help audit');

h=uicontrol(gcf,'style','pushbutton','position',[100 0 xm-250 25],...
    'string','Dismiss','callback','delete(gcf)');

h=uicontrol(gcf,'style','pushbutton','position',[xm-150 0 25 25],...
    'string','v','callback','for hi=get(gca,''children'')'';if strcmp(get(hi,''type''),''text''),set(hi,''position'',get(hi,''position'')+[0 25]);end;end;set(gca,''userdata'',get(gca,''userdata'')+[25 0 0 0 0]);');
h=uicontrol(gcf,'style','pushbutton','position',[xm-125 0 25 25],...
    'string','^','callback','for hi=get(gca,''children'')'';if strcmp(get(hi,''type''),''text'');set(hi,''position'',get(hi,''position'')-[0 25]);end;end;set(gca,''userdata'',get(gca,''userdata'')-[25 0 0 0 0]);');

h=uicontrol(gcf,'style','pushbutton','position',[xm-100 0 50 25],...
    'string','PgDn','callback','for hi=get(gca,''children'')'';if strcmp(get(hi,''type''),''text'');ym=get(gca,''position'')*[0;0;0;1];set(hi,''position'',get(hi,''position'')+[0 ym]);end;end;set(gca,''userdata'',get(gca,''userdata'')+[ym 0 0 0 0]);');
h=uicontrol(gcf,'style','pushbutton','position',[xm-50 0 50 25],...
    'string','PgUp','callback','for hi=get(gca,''children'')'';if strcmp(get(hi,''type''),''text'');ym=get(gca,''position'')*[0;0;0;1];set(hi,''position'',get(hi,''position'')-[0 ym]);end;end;set(gca,''userdata'',get(gca,''userdata'')-[ym 0 0 0 0]);');
EOF


    printf FOUT "tokloc=[0;0;0];\n";
    for ( $i = 0; $i <= $#src; $i++ ) {
	if ( $ss_comments[$i] =~ /\S+/ ) {
	    $ss_comments[$i] =~ s/'/''/g;
	    printf FOUT "h=text(0,ym-e0(4)*%d,' ','units','pixels');\n", $i;
	    printf FOUT "set(h,'string','%s');\n", $ss_comments[$i];
	    printf FOUT "set(h,'color',%s,'fontweight',%s,'fontangle',%s);\n",
		$color{'comments'}, $weight{'comments'}, $angle{'comments'}; 
	}
	if ( $ss_strings[$i] =~ /\S+/ ) {
	    $ss_strings[$i] =~ s/'/''/g;
	    printf FOUT "h=text(0,ym-e0(4)*%d,' ','units','pixels');\n", $i;
	    printf FOUT "set(h,'string','%s');\n", $ss_strings[$i];
	    printf FOUT "set(h,'color',%s,'fontweight',%s,'fontangle',%s);\n",
		$color{'strings'}, $weight{'strings'}, $angle{'strings'}; 
	}
	if ( $ss_arguments[$i] =~ /\S+/ ) {
	    printf FOUT "h=text(0,ym-e0(4)*%d,' ','units','pixels');\n", $i;
	    printf FOUT "set(h,'string','%s');\n", $ss_arguments[$i];
	    printf FOUT "set(h,'color',%s,'fontweight',%s,'fontangle',%s);\n",
		$color{'args'}, $weight{'args'}, $angle{'args'}; 
	}
	if ( $ss_globals[$i] =~ /\S+/ ) {
	    printf FOUT "h=text(0,ym-e0(4)*%d,' ','units','pixels');\n", $i;
	    printf FOUT "set(h,'string','%s');\n", $ss_globals[$i];
	    printf FOUT "set(h,'color',%s,'fontweight',%s,'fontangle',%s);\n",
		$color{'globals'}, $weight{'globals'}, $angle{'globals'}; 
	}
	if ( $ss_variables[$i] =~ /\S+/ ) {
	    printf FOUT "h=text(0,ym-e0(4)*%d,' ','units','pixels');\n", $i;
	    printf FOUT "set(h,'string','%s');\n", $ss_variables[$i];
	    printf FOUT "set(h,'color',%s,'fontweight',%s,'fontangle',%s);\n",
		$color{'variables'}, $weight{'variables'}, $angle{'variables'}; 
	}
	if ( $ss_default[$i] =~ /\S+/ ) {
	    $ss_default[$i] =~ s/'/''/g;
	    printf FOUT "h=text(0,ym-e0(4)*%d,' ','units','pixels');\n", $i;
	    printf FOUT "set(h,'string','%s');\n", $ss_default[$i];
	    printf FOUT "set(h,'color',%s,'fontweight',%s,'fontangle',%s);\n",
		$color{'default'}, $weight{'default'}, $angle{'default'}; 
	}
	if ( $ss_unknowns[$i] =~ /\S+/ ) {
	    while ( $ss_unknowns[$i] =~ /(\S+)/ ) {
		substr($ss_unknowns[$i],length($`),length($1))=' ' x length($1);
		printf FOUT "h=text((e0(3)+2*e0(1))*%d,ym-e0(4)*%d,' ','units','pixels');\n", length($`), $i;
		printf FOUT "tok = '%s'; set(h,'string',tok);\n", $1;
		printf FOUT "eval([ismfile isbuiltin isvariable isunknown])\n";
		printf FOUT "tokens=str2mat(tokens,tok);\n";
		printf FOUT "tokloc=[tokloc [%d;%d;%d]];\n",
		    length($`), length($`)+length($1)-1, $i;

	    } # end for each unknown token in line
	} # end if unknowns
    } # end for all lines
    printf FOUT "if exist('tokens')==1,tokens(1,:)=[]; tokloc(:,1)=[];\n";
    printf FOUT "set(gcf,'userdata',[tokloc' tokens]);\n";
    printf FOUT "else,set(gcf,'userdata',[[0 0 Inf] 'garbage']); end;\n";

    printf FOUT "h=gcf;\n";			# set return value

    close( FOUT );

} # end if linked to matlab
