function cont2mif(filename,section,rtf)
% CONT2MIF  Prettyprint Contents.m files to MIF or RTF file.
%
%   CONT2MIF(FILENAME) reads all of the Contents.m files in the current
%                      path and creates a FrameMaker MIF (Maker Interchange
%                      Format) file with the results.  For example,
%                      CONT2MIF('contents.mif') will create an MIF file
%                      with the filename 'contents.mif'.
%
%   CONT2MIF(FILENAME,SECTION) will do the same but restrict its search to
%                              paths that end in SECTION.  For example, to
%                              convert just the Control Toolbox Contents.m
%                              file, use CONT2MIF('control.mif','control').
%
%   CONT2MIF(...,'rtf') will instead produce RTF (Rich Text Format) text
%                       (e.g., suitable for importing into MS Word).

% Copyright (c) 1995, Erik A. Johnson <johnsone@uxh.cso.uiuc.edu>, 5/17/95

%MIFDATA
%<MIFFile 4.00>
%<PgfCatalog 
% <Pgf 
%  <PgfTag `Body'>
%  <PgfAlignment LeftRight >
%  <PgfFIndent  0.125">
%  <PgfLIndent  0.812">
%  <PgfRIndent  0.0">
%  <PgfSpBefore  0.0 pt>
%  <PgfSpAfter  0.0 pt>
%  <PgfWithPrev Yes >
%  <PgfWithNext No >
%  <PgfBlockSize 1>
%  <PgfFont <FTag `'> <FPlatformName `M.Times.P'> <FFamily `Times'>
%   <FPostScriptName `Times-Roman'> <FSize  8.0 pt> >
%  <PgfLineSpacing Fixed >
%  <PgfLeading  0.0 pt>
%  <PgfNumTabs 2> <TabStop <TSX  0.8125"> <TSType Left > <TSLeaderStr ` '> >
%                 <TabStop <TSX  2.75">   <TSType Left > <TSLeaderStr ` '> >
% > # end of Pgf
% <Pgf 
%  <PgfTag `Copyright'>
%  <PgfUseNextTag Yes >
%  <PgfNextTag `Body'>
%  <PgfAlignment Left >
%  <PgfFIndent  0.0">
%  <PgfLIndent  0.0">
%  <PgfRIndent  0.0">
%  <PgfSpBefore  0.0 pt>
%  <PgfSpAfter  0.0 pt>
%  <PgfWithPrev No >
%  <PgfWithNext Yes >
%  <PgfBlockSize 1>
%  <PgfFont <FTag `'> <FPlatformName `M.Times.P'> <FFamily `Times'>
%   <FPostScriptName `Times-Roman'> <FSize  9.0 pt> >
%  <PgfLineSpacing Fixed >
%  <PgfLeading  -1.0 pt>
%  <PgfNumTabs 1> <TabStop <TSX  0.8125"> <TSType Left > <TSLeaderStr ` '> >
% > # end of Pgf
% <Pgf 
%  <PgfTag `Filename'>
%  <PgfUseNextTag Yes >
%  <PgfNextTag `Title'>
%  <PgfAlignment Left >
%  <PgfFIndent  0.0">
%  <PgfLIndent  0.0">
%  <PgfRIndent  0.0">
%  <PgfPlacement ColumnTop >
%  <PgfSpBefore  0.0 pt>
%  <PgfSpAfter  0.0 pt>
%  <PgfWithPrev No >
%  <PgfWithNext Yes >
%  <PgfBlockSize 1>
%  <PgfFont <FTag `'> <FPlatformName `M.Courier.P'> <FFamily `Courier'>
%   <FPostScriptName `Courier'> <FSize  9.0 pt> >
%  <PgfLineSpacing Fixed >
%  <PgfLeading  -1.0 pt>
%  <PgfNumTabs 1> <TabStop <TSX  0.8125"> <TSType Left > <TSLeaderStr ` '> >
% > # end of Pgf
% <Pgf 
%  <PgfTag `Filename0'>
%  <PgfUseNextTag Yes >
%  <PgfNextTag `Title0'>
%  <PgfAlignment Left >
%  <PgfFIndent  0.0">
%  <PgfLIndent  0.0">
%  <PgfRIndent  0.0">
%  <PgfPlacement Anywhere >
%  <PgfSpBefore  25.0 pt>
%  <PgfSpAfter  -17.0 pt>
%  <PgfWithPrev No >
%  <PgfWithNext Yes >
%  <PgfBlockSize 1>
%  <PgfFont <FTag `'> <FPlatformName `M.Courier.P'> <FFamily `Courier'>
%   <FPostScriptName `Courier'> <FSize  9.0 pt> >
%  <PgfLineSpacing Fixed >
%  <PgfLeading  -1.0 pt>
%  <PgfNumTabs 1> <TabStop <TSX  0.8125"> <TSType Left > <TSLeaderStr ` '> >
% > # end of Pgf
% <Pgf 
%  <PgfTag `Footer'>
%  <PgfAlignment LeftRight >
%  <PgfFIndent  0.0">
%  <PgfLIndent  0.0">
%  <PgfRIndent  0.0">
%  <PgfPlacement Anywhere >
%  <PgfSpBefore  0.0 pt>
%  <PgfSpAfter  0.0 pt>
%  <PgfWithPrev No >
%  <PgfWithNext Yes >
%  <PgfBlockSize 1>
%  <PgfFont <FTag `'> <FPlatformName `M.Times.P'> <FFamily `Times'>
%   <FPostScriptName `Times-Roman'> <FSize  10.0 pt> >
%  <PgfLineSpacing Fixed >
%  <PgfLeading  2.0 pt>
%  <PgfNumTabs 1> <TabStop <TSX  10.0"> <TSType Right > <TSLeaderStr ` '> >
% > # end of Pgf
% <Pgf 
%  <PgfTag `Header'>
%  <PgfAlignment LeftRight >
%  <PgfFIndent  0.0">
%  <PgfLIndent  0.0">
%  <PgfRIndent  0.0">
%  <PgfSpBefore  0.0 pt>
%  <PgfSpAfter  0.0 pt>
%  <PgfWithPrev No >
%  <PgfWithNext Yes >
%  <PgfBlockSize 1>
%  <PgfFont <FTag `'> <FPlatformName `M.Times.B'> <FFamily `Times'>
%   <FWeight `Bold'> <FPostScriptName `Times-Bold'> <FSize  10.0 pt> >
%  <PgfLineSpacing Fixed >
%  <PgfLeading  2.0 pt>
%  <PgfAutoNum No >
%  <PgfNumTabs 2> <TabStop <TSX  5.0"> <TSType Center > <TSLeaderStr ` '> >
%                 <TabStop <TSX  10.0"> <TSType Right > <TSLeaderStr ` '> >
% > # end of Pgf
% <Pgf 
%  <PgfTag `Section'>
%  <PgfUseNextTag Yes >
%  <PgfNextTag `Body'>
%  <PgfAlignment LeftRight >
%  <PgfFIndent  0.0">
%  <PgfLIndent  0.0">
%  <PgfRIndent  0.0">
%  <PgfSpBefore  8.0 pt>
%  <PgfSpAfter  0.0 pt>
%  <PgfWithPrev No >
%  <PgfWithNext Yes >
%  <PgfBlockSize 1>
%  <PgfFont <FTag `'> <FPlatformName `M.Times.I'> <FFamily `Times'>
%   <FAngle `Italic'> <FPostScriptName `Times-Italic'> <FSize  9.0 pt> >
%  <PgfLineSpacing Fixed >
%  <PgfLeading  -1.0 pt>
%  <PgfAutoNum No >
%  <PgfNumTabs 1> <TabStop <TSX  0.8125"> <TSType Left > <TSLeaderStr ` '> >
% > # end of Pgf
% <Pgf 
%  <PgfTag `SubTitle'>
%  <PgfUseNextTag Yes >
%  <PgfNextTag `Body'>
%  <PgfAlignment Left >
%  <PgfFIndent  0.0">
%  <PgfLIndent  0.0">
%  <PgfRIndent  0.0">
%  <PgfSpBefore  0.0 pt>
%  <PgfSpAfter  0.0 pt>
%  <PgfWithPrev No >
%  <PgfWithNext Yes >
%  <PgfBlockSize 1>
%  <PgfFont <FTag `'> <FPlatformName `M.Times.BI'> <FFamily `Times'>
%   <FWeight `Bold'> <FAngle `Italic'> <FPostScriptName `Times-BoldItalic'>
%   <FSize  9.0 pt> >
%  <PgfLineSpacing Fixed >
%  <PgfLeading  -1.0 pt>
%  <PgfAutoNum No >
%  <PgfNumTabs 1> <TabStop <TSX  0.8125"> <TSType Left > <TSLeaderStr ` '> >
% > # end of Pgf
% <Pgf 
%  <PgfTag `Title'>
%  <PgfUseNextTag Yes >
%  <PgfNextTag `Version'>
%  <PgfAlignment Left >
%  <PgfFIndent  0.0">
%  <PgfLIndent  0.0">
%  <PgfRIndent  0.0">
%  <PgfPlacementStyle SideheadFirstBaseline >
%  <PgfSpBefore  0.0 pt>
%  <PgfSpAfter  0.0 pt>
%  <PgfWithPrev No >
%  <PgfWithNext Yes >
%  <PgfBlockSize 1>
%  <PgfFont <FTag `'> <FPlatformName `M.Times.B'> <FFamily `Times'>
%   <FWeight `Bold'> <FPostScriptName `Times-Bold'> <FSize  8.0 pt>
%   <FColor `White'> >
%  <PgfLineSpacing Fixed >
%  <PgfLeading  -8.0 pt>
%  <PgfNumTabs 0>
% > # end of Pgf
% <Pgf 
%  <PgfTag `Title0'>
%  <PgfUseNextTag Yes >
%  <PgfNextTag `Version'>
%  <PgfAlignment Left >
%  <PgfFIndent  0.0">
%  <PgfLIndent  0.0">
%  <PgfRIndent  0.0">
%  <PgfPlacementStyle SideheadFirstBaseline >
%  <PgfSpBefore  -17.0 pt>
%  <PgfSpAfter  6.0 pt>
%  <PgfWithPrev No >
%  <PgfWithNext Yes >
%  <PgfBlockSize 1>
%  <PgfFont <FTag `'> <FPlatformName `M.Times.B'> <FFamily `Times'>
%   <FWeight `Bold'> <FPostScriptName `Times-Bold'> <FSize  10.0 pt>
%   <FColor `Black'> >
%  <PgfLineSpacing Fixed >
%  <PgfLeading  0.0 pt>
%  <PgfNumTabs 0>
% > # end of Pgf
% <Pgf 
%  <PgfTag `Version'>
%  <PgfUseNextTag Yes >
%  <PgfNextTag `Copyright'>
%  <PgfAlignment Left >
%  <PgfFIndent  0.0">
%  <PgfLIndent  0.0">
%  <PgfRIndent  0.0">
%  <PgfPlacementStyle Normal >
%  <PgfSpBefore  0.0 pt>
%  <PgfSpAfter  0.0 pt>
%  <PgfWithPrev No >
%  <PgfWithNext Yes >
%  <PgfBlockSize 1>
%  <PgfFont <FTag `'> <FPlatformName `M.Times.P'> <FFamily `Times'>
%   <FPostScriptName `Times-Roman'> <FSize  9.0 pt>
%   <FColor `Black'> >
%  <PgfLineSpacing Fixed >
%  <PgfLeading  -1.0 pt>
%  <PgfNumTabs 1> <TabStop <TSX  0.8125"> <TSType Left > <TSLeaderStr ` '> >
% > # end of Pgf
%> # end of PgfCatalog
%<FontCatalog 
% <Font <FTag `Emphasis'> <FAngle `Italic'> >
% <Font <FTag `matlab command'> <FFamily `Courier'> <FSize  7.0 pt> >
%> # end of FontCatalog
%<VariableFormats 
% <VariableFormat <VariableName `Page Count'> <VariableDef `<$lastpagenum\>'> >
% <VariableFormat <VariableName `Running H/F 1'> <VariableDef `<$paratext[Title,Title0]\>'> >
% <VariableFormat <VariableName `Running H/F 2'> <VariableDef `<$paratext[+,Title,Title0]\>'> >
% <VariableFormat <VariableName `Current Page #'> <VariableDef `<$curpagenum\>'>>
%> # end of VariableFormats
%<Document <DPageSize  11.0" 8.5"> <DBordersOn Yes > >
%<Page 
% <PageType RightMasterPage >
% <PageTag `Right'>
% <PageSize  11.0" 8.5">
% <PageOrientation Landscape >
% <TextRect <ID 5> <Pen 15> <Fill 15> <ShapeRect  5.618" 0.5" 4.88194" 0.13889">
%  <BRect  5.618" 0.5" 4.88194" 0.13889"> <TRNext 0> >
% <TextRect <ID 6> <ShapeRect  0.5" 7.861" 10.0" 0.13889">
%  <BRect  0.5" 7.861" 10.0" 0.13889"> <TRNext 0> >
% <TextRect <ID 7> <ShapeRect  0.5" 0.725" 4.875" 7.05">
%  <BRect  0.5" 0.725" 4.875" 7.05"> <TRNext 8> >
% <TextRect <ID 8> <ShapeRect  5.625" 0.725" 4.875" 7.05">
%  <BRect  5.625" 0.725" 4.875" 7.05"> <TRNext 0> >
% <TextRect <ID 9> <ShapeRect  0.499" 0.5" 4.875" 0.13889">
%  <BRect  0.499" 0.5" 4.875" 0.13889"> <TRNext 0> >
%> # end of Page
%<Page 
% <PageType BodyPage >
% <PageNum `1'>
% <PageSize  11.0" 8.5">
% <PageOrientation Landscape >
% <PageBackground `Default'>
% <TextRect <ID 10> <ShapeRect  0.5" 0.725" 4.875" 7.05">
%  <BRect  0.5" 0.725" 4.875" 7.05"> <TRNext 11> >
% <TextRect <ID 11> <ShapeRect  5.625" 0.725" 4.875" 7.05">
%  <BRect  5.625" 0.725" 4.875" 7.05"> <TRNext 0> >
%> # end of Page
%<TextFlow 
% <Para 
%  <PgfTag `Header'>
%  <ParaLine <TextRectID 5> <Variable <VariableName `Running H/F 2'> > >
% > # end of Para
%> # end of TextFlow
%<TextFlow 
% <Para 
%  <PgfTag `Footer'>
%  <ParaLine 
%   <TextRectID 6>
%   <Font <FTag `Emphasis'> > <String `Matlab Commands, by subject'>
%   <Font <FTag `'> > <Char Tab > <String `p. '>
%   <Variable  <VariableName `Current Page #'> >
%  >
% > # end of Para
%> # end of TextFlow
%<TextFlow 
% <Para 
%  <PgfTag `Header'>
%  <ParaLine <TextRectID 9> <Variable <VariableName `Running H/F 1'> > >
% > # end of Para
%> # end of TextFlow
%<TextFlow 
% <TFTag `A'>
% <TFAutoConnect Yes >
%MIFDATA
%> # end of TextFlow
%# End of MIFFile
%MIFDATA

%RTFDATA
%{\rtf1\mac\deff2
%{\fonttbl{\f20\froman Times;}{\f22\fmodern Courier;}}
%{\stylesheet
%{\sbasedon222\snext0 Normal;}
%{\s1\fi-980\li1169\sl-160\keepn\tx1170\tx3960 \f20\fs16 \sbasedon222\snext1 Body;}
%{\s2\sb140\sl-160\keepn\tx1170\tx3960 \i\f20\fs18 \sbasedon1\snext2 Section;}
%{\s3\sl-160\tx1170\tx3960 \f22\fs18 \sbasedon1\snext3 Filename;}
%{\s4\fi0\li0\sl-200\sb120\tx1170\tx3960 \b\f20\fs20 \sbasedon1\snext4 Title;}
%{\s5\fi0\li0\sl-160\tx1170\tx3960 \f20\fs18 \sbasedon1\snext5 Version;}
%{\s6\fi0\li0\sl-160\tx1170\tx3960 \f20\fs18 \sbasedon1\snext6 Copyright;}
%{\s7\fi0\li0\sl-20\tx1170\tx3960 \f20\fs8 \sbasedon2\snext7 Presection;}
%{\s8\fi0\li0\sl-240\tqr\tx14400 \f20\fs20 \sbasedon1\snext8 Footer;}}
%\paperw15840\paperh12240\margl720\margr720\margt720\margb1080\ftnbj\linestart0\fracwidth
%\pard\plain \s1\fi-980\li1169\sl-160\tx1170\tx3960 \f20\fs16
%RTFDATA
%}
%RTFDATA

if (nargin<1),
	error('CONT2MIF requires at least one input argument.');
elseif (nargin>3),
	error('CONT2MIF takes at most three input arguments.');
elseif (nargout~=0),
	error('CONT2MIF produces no output arguments.');
end;

% check default arguments
if (~isstr(filename)),
	error('CONT2MIF requires that the filename be a string.');
end;
if (nargin==1),
	section='';
	rtf=0;
elseif (nargin==2),
	if (isstr(section)),
		if (strcmp(lower(section),'rtf')),
			rtf=1;
			section='';
		else,
			rtf=0;
		end;
	else,
		rtf = all(rtf~=0);
	end;
elseif (nargin==3),
	if (~isstr(section)),
		error('CONT2MIF requires that the section name be a string.');
	end;
	if (isstr(rtf)),
		rtf = strcmp(lower(rtf),'rtf');
	else,
		rtf = all(rtf~=0);
	end;
end;

% path separation code following is borrowed from VER.M and thus is
% Copyright (c) 1984-1994 by The MathWorks, Inc.
p = path;
pathsep = ':';
filesep = '/';
c = computer;
sys = 'u';
if strcmp(c(1:2),'PC')
   pathsep = ';';
   filesep = '\';
   sys = 'p';
elseif strcmp(c(1:2),'MA')
   pathsep = ';';
   filesep = ':';
   sys = 'm';
elseif isvms
   pathsep = ',';
   filesep = '.';
   sys = 'v';
   disp('WARNING: CONT2MIF will not work properly on VMS systems.');
   disp('         If you want it to do so, I need help with VMS filenames;');
   disp('         Please send me mail.  Erik A. Johnson <johnsone@uiuc.edu>');
end
seps = find(p == pathsep);
first = [1 seps+1];
last = [seps-1 length(p)];
n = length(first);

% check section
if (all(size(section))),
	p = [p pathsep];
	section = section(:)';
	k = findstr(p,[section pathsep]);
	p(length(p))=[];
	if (all(size(k))),
		if (n==1),
			f2 = [first;first];
		else,
			f2 = first';
		end;
		ii = sum( f2(:,ones(1,length(k))) <= k(ones(length(f2),1),:) )';
		first = first(ii);
		last  = last(ii);
		n = length(ii);
	else,
		error(['CONT2MIF did not find any "' section '" section.']);
	end;
end;

% sort path
if (any(sys=='mp')),
	pp = abs(lower(p));
else,
	pp = abs(p);
end;
f2=first;
while (all(pp(f2)==pp(f2(1)))&all(f2<last)),
	f2=f2+1;
end;
disp('Sorting pathnames ...');
for k=1:n-1,
	for kk=k:n,
		sk = pp(f2(k):last(k));
		skk = pp(f2(kk):last(kk));
		if (length(skk)>length(sk)),
			sk = [sk -ones(1,length(skk)-length(sk))];
		elseif (length(sk)>length(skk)),
			skk = [skk -ones(1,length(sk)-length(skk))];
		end;
		z = skk-sk;
		if (z(min([find(z~=0) length(z)]))<0),
			first([k kk]) = first([kk k]);
			f2(   [k kk]) = f2(   [kk k]);
			last( [k kk]) = last( [kk k]);
		end;
	end;
end;

% return character
cr = sprintf('\n');
disp(' ');
oldsprintf = (length(sprintf('a%sa',''))<2);

% open the mif files
[miffid,msg] = fopen(filename,'wt');
if (miffid==-1),
	msg1 = ['CONT2MIF unable to open file "' filename '".'];
	if (length(msg)>0), msg1=str2mat(msg1,['(' msg ')']); end;
	error(msg1);
end;
cont2mifstr = which('cont2mif');
[myfid,msg]=fopen(cont2mifstr,'rt');
if (myfid==-1),
	fclose(miffid);
	msg1 = ['CONT2MIF unable to open the CONT2MIF data file "' cont2mifstr '".'];
	if (length(msg)>0), msg1=[msg1 '  (' msg ')']; end;
	error(msg1);
end;
mif=setstr(fread(myfid)');
fclose(myfid);
if (rtf),
	searchstr = setstr([cr '%RTFDATA' cr]);
else,
	searchstr = setstr([cr '%MIFDATA' cr]);
end;
ii=findstr(mif,searchstr);
if (length(ii)~=3), error('CONT2MIF is corrupted.'); end;
tail = mif(ii(2)+length(searchstr)-1:ii(3));
tail(find((setstr([cr tail])==cr)&(setstr([tail 0])=='%'))) = [];
tail(1) = [];
mif = mif(ii(1)+length(searchstr)-1:ii(2));
mif(find((setstr([cr mif])==cr)&(setstr([mif 0])=='%'))) = [];
mif(1) = [];
% transfer the intro
if (fwrite(miffid,mif)~=length(mif)),
	fclose(miffid);
	error(['CONT2MIF was unable to write to the file "' filename '".']);
end;

% set up the output strings
if (rtf),
	miffilename1 = '{\\s3\\fi0\\li0 \\f22\\fs18 %s\\par }\n';
	miffilename  = '{\\s3\\fi0\\li0 \\f22\\fs18 %s\\par }\n';
	miftitle1    = ['\\sectd \\sbkcol\\linemod0\\linex0\\headery0\\cols2\\endnhere\n' ...
                    '{\\footer \\pard\\plain \\s8\\sl-240\\tqr\\tx14400 \\f20\\fs20 {\\i Matlab Commands, by subject}\\tab p. \\chpgn \\par }\n' ...
                    '{\\s4\\fi0\\li0\\sl-200\\sb120 \\b\\fs20 %s\\par }\n'];
	miftitle     = ['{\\keepn \\sect \\sectd \\sbkcol\\linemod0\\linex0\\headery0\\cols2\\endnhere\n' ...
                    '{\\footer \\pard\\plain \\s8\\sl-240\\tqr\\tx14400 \\f20\\fs20 {\\i Matlab Commands, by subject}\\tab p. \\chpgn \\par }}\n' ...
                    '{\\s4\\fi0\\li0\\sl-200\\sb120 \\b\\fs20 %s\\par }\n'];
	mifversion   = '{\\s5\\fi0\\li0 \\fs18 %s\\par }\n';
	mifcopyright = '{\\s6\\fi0\\li0 \\fs18 Copyright \\''a9%s\\par }\n';
	mifallrights = '{\\s6\\fi0\\li0 \\fs18 %s\\par }\n';
	mifsection   = '{\\s7\\fi0\\li0\\sl-20 \\fs8 \\par }\n{\\s2\\fi0\\li0\\sb140\\keepn \\i\\fs18 %s\\par }\n';
	mifbody      = '{\\keepn {\\f22\\fs14 %s}\\tab %s\\par }\n';
	mifops       = '{\\keepn {\\f22\\fs14 %s}\\tab %s\\tab %s\\par }\n';
else,
	miffilename1 = ' <Para <PgfTag `Filename''> <ParaLine <TextRectID 10> <String `%s''> > >\n';
	miffilename  = ' <Para <PgfTag `Filename''> <ParaLine <String `%s''> > >\n';
	miftitle1    = ' <Para <PgfTag `Title''> <ParaLine <String `%s''> > >\n';
	miftitle     = ' <Para <PgfTag `Title''> <ParaLine <String `%s''> > >\n';
	mifversion   = ' <Para <PgfTag `Version''> <ParaLine <String `%s''> > >\n';
	mifcopyright = ' <Para <PgfTag `Copyright''> <ParaLine <String `Copyright \\xa9%s''> > >\n';
	mifallrights = ' <Para <PgfTag `Copyright''> <ParaLine <String `%s''> > >\n';
	mifsection   = ' <Para <PgfTag `Section''> <ParaLine <String `%s''> > >\n';
	mifbody      = ' <Para <PgfTag `Body''> <ParaLine <Font <FTag `matlab command''> > <String `%s''> <Font <FTag `''> > <Char Tab > <String `%s''> > >\n';
	mifops       = ' <Para <PgfTag `Body''> <ParaLine <Font <FTag `matlab command''> > <String `%s''> <Font <FTag `''> > <Char Tab > <String `%s''> <Char Tab > <String `%s''> > >\n';
end;

% cycle through all of the directories
firstone=1;
for k=1:n,
	curdir = p(first(k):last(k));
	curcont = [curdir filesep 'Contents.m'];
	if (exist(curcont)==2),
		disp(curcont);
		[contfid,msg] = fopen(curcont,'rt');
		if (contfid==-1),
			msg1 = ['CONT2MIF unable to open the contents file "' curcont '".'];
			if (length(msg)>0), msg1=[msg1 '  (' msg ')']; end;
			disp(msg1);
		else,
			% is 'toolbox/matlab/ops/Contents.m'
			opsdir = ['toolbox' filesep 'matlab' filesep 'ops'];
			isops = 0;
			if (length(curdir)>=length(opsdir)),
				isops=all(opsdir==curdir(length(curdir)+(1-length(opsdir):0)));
			end;
			% read the file
			cf = setstr([curcont cr fread(contfid)']);
			fclose(contfid);
			if (cf(length(cf))~=cr), cf=setstr([cf cr]); end;
			% convert tabs
			tablength=8;
			ii=find(cf=='	');
			if (all(size(ii))),
				jj=[0 find((cf=='	')|(cf==cr)) length(cf)+2]';
				kk = sum(jj(:,ones(1,length(ii)))<ii(ones(length(jj),1),:));
				jj=tablength-rem(ii-jj(kk')'-1,tablength);
				cf(ii)=ones(1,length(ii))*' ';
				numreps = ones(1,length(cf));
				numreps(ii) = jj;
				ii=zeros(1,sum(numreps));
				ii([1 cumsum(numreps(1:length(numreps)-1))+1])=ones(1,length(numreps));
				cf = setstr(cf(cumsum(ii)));
			end;
			% convert special MIF or RTF characters
			if (rtf),
				ii=find((cf=='''')|(cf=='`')|(cf=='\')|(cf=='{')|(cf=='}'));
				if (all(size(ii))),
					cf2 = setstr(NaN*ones(3,length(cf)));
					ii = find((cf=='\')|(cf=='{')|(cf=='}'));
					if (all(size(ii))),
						cf2(1,ii) = cf(ii);
						cf(ii) = ones(1,length(ii))*'\';
					end;
					ii = find((cf=='''')|(cf=='`'));
					if (all(size(ii))),
						cf2(1:2,ii) = ['\''']'*ones(1,length(ii));
						cf2(3,ii) = setstr('4'*ones(1,length(ii))+cf(ii)=='''');
						cf(ii) = ones(1,length(ii))*'\';
					end;
					cf = [cf; cf2];
					cf = setstr(cf(find(~isnan(cf(:))))');
				end;
			else,
				ii=find((cf=='''')|(cf=='`')|(cf=='\')|(cf=='>'));
				if (all(size(ii))),
					cf2 = setstr(NaN*ones(size(cf)));
					cf2(ii) = (cf(ii)=='''')*'q' ...
					        + (cf(ii)=='`' )*'Q' ...
					        + (cf(ii)=='\' )*'\' ...
					        + (cf(ii)=='>' )*'>';
					cf(ii) = ones(1,length(ii))*'\';
					cf = [cf; cf2];
					cf = setstr(cf(find(~isnan(cf(:))))');
				end;
			end;
			% find line starts and ends
			cf1 = find(cf==cr);
			if (all(size(cf1))),
				if (max(cf1)<length(cf)),
					cf1=[cf1 length(cf)+1];
				end;
			else,
				cf1 = length(cf)+1;
			end;
			cf0=[1 cf1(1:length(cf1)-1)+1];
			cf1=cf1-1;
			numlines = length(cf0);
			cf = [cf cr cr];
			% strip <whitespace>[%<whitspace>]
			ii=find(cf(cf1)==' ');while(all(size(ii))),cf1(ii)=cf1(ii)-1;ii=find(cf(cf1)==' ');end;
			cf0s = cf0;
			ii=find(cf(cf0s)==' ');while(all(size(ii))),cf0s(ii)=cf0s(ii)+1;ii=find(cf(cf0s)==' ');end;
			ii=find(cf(cf0s)=='%');if(all(size(ii))),cf0s(ii)=cf0s(ii)+1;end;
			ii=find(cf(cf0s)==' ');while(all(size(ii))),cf0s(ii)=cf0s(ii)+1;ii=find(cf(cf0s)==' ');end;
			% find command endings, correcting for '\\ and ', '( )', '[ ]', and '< >'
			cmdend = cf0s;
			ii=find((cf(cmdend)~=' ')&(cf(cmdend)~='-')&(cmdend<=cf1));while(all(size(ii))),cmdend(ii)=cmdend(ii)+1;ii=find((cf(cmdend)~=' ')&(cf(cmdend)~='-')&(cmdend<=cf1));end;
			ii=findstr(cf,'\\ and /');
			if (all(size(ii))),
				if (length(ii)==1), ii=[ii;ii]; else, ii=ii'; end;
				ii=find(any(ii(:,ones(1,numlines))==cf0s(ones(length(ii),1),:)));
				cmdend(ii) = cf0s(ii) + 8;
			end;
			ii=find(any([1;1;1]*cf(cf0s)==['([<']'*ones(1,numlines))&...
			        cf(cf0s+1)==' '&...
					any([1;1;1]*cf(cf0s+2)==[')]>']'*ones(1,numlines)));
			cmdend(ii) = cf0s(ii)+3;
			% find string starts
			strstart = cmdend;
			ii=find(cmdend>cf0s); cmdend(ii)=cmdend(ii)-1;
			ii=find((cf(strstart)==' ')|(cf(strstart)=='-'));while(all(size(ii))),strstart(ii)=strstart(ii)+1;ii=find((cf(strstart)==' ')|(cf(strstart)=='-'));end;
			% allocate enough memory
			mif = setstr(zeros(1,length(cf)+256*numlines));
			offset = 0;
			if (rtf),
				% title
				if (firstone), fnmif=miftitle1; else, fnmif=miftitle; end;
				if (numlines>=2), str=cf(cf0s(2):cf1(2)); else, str=''; end;
				if ((~all(size(str)))&oldsprintf), str=' '; end;
				mif2 = sprintf(fnmif,str);
				mif(offset+(1:length(mif2)))=mif2; offset=offset+length(mif2);
				% filename
				if (firstone), fnmif=miffilename1; else, fnmif=miffilename; end;
				str = cf(cf0s(1):cf1(1));
				if ((~all(size(str)))&oldsprintf), str=' '; end;
				mif2 = sprintf(fnmif,str);
				mif(offset+(1:length(mif2)))=mif2; offset=offset+length(mif2);
			else,
				% filename
				if (firstone), fnmif=miffilename1; else, fnmif=miffilename; end;
				str = cf(cf0s(1):cf1(1));
				if ((~all(size(str)))&oldsprintf), str=' '; end;
				mif2 = sprintf(fnmif,str);
				mif(offset+(1:length(mif2)))=mif2; offset=offset+length(mif2);
				% title
				if (firstone), fnmif=miftitle1; else, fnmif=miftitle; end;
				if (numlines>=2), str=cf(cf0s(2):cf1(2)); else, str=''; end;
				if ((~all(size(str)))&oldsprintf), str=' '; end;
				mif2 = sprintf(fnmif,str);
				mif(offset+(1:length(mif2)))=mif2; offset=offset+length(mif2);
			end;
			% version
			if (numlines>=3), str=cf(cf0s(3):cf1(3)); else, str=''; end;
			if ((~all(size(str)))&oldsprintf), str=' '; end;
			mif2 = sprintf(mifversion,str);
			mif(offset+(1:length(mif2)))=mif2; offset=offset+length(mif2);
			% rest of the file
			for ln=4:numlines,
				if (cf1(ln)>=cf0s(ln)),
					cfline   = cf(cf0(ln):cf1(ln));
					cflines  = cf(cf0s(ln):cf1(ln));
					cflinesb = [lower(cflines) '                   '];
					cflineb  = [cfline '  '];
					if (all(cflinesb(1:13)=='copyright (c)')),
						str = cflines(14:length(cflines));
						if ((~all(size(str)))&oldsprintf), str=' '; end;
						mif2 = sprintf(mifcopyright,str);
						mif(offset+(1:length(mif2)))=mif2; offset=offset+length(mif2);
					elseif (all(cflinesb(1:19)=='all rights reserved')|...
					        all(cflinesb(1:6)=='$revis')),
						if ((~all(size(cflines)))&oldsprintf), cflines=' '; end;
						mif2 = sprintf(mifallrights,cflines);
						mif(offset+(1:length(mif2)))=mif2; offset=offset+length(mif2);
					elseif ((cf0s(ln)-cf0(ln)<=2)&all(cflineb(1:2)=='% ')),
						if ((~all(size(cflines)))&oldsprintf), cflines=' '; end;
						mif2 = sprintf(mifsection,cflines);
						mif(offset+(1:length(mif2)))=mif2; offset=offset+length(mif2);
					else,
						cmd = cf(cf0s(ln):cmdend(ln));
						str = cf(strstart(ln):cf1(ln));
						if ((~all(size(str)))&(cf0s(ln)-cf0(ln)>=9)),
							tmp=str; str=cmd; cmd=tmp;
						end;
						if (isops&(length(str)>0)&(length(cmd)>0)&(str(max(1,length(str)):length(str))~='.')&any(str==' ')),
							ii=max(find(str==' '));
							if (length(str)>=length('help topic')),
								if (all(lower(str(length(str)+(-9:0)))=='help topic')),
									ii = length(str)-10;
								end;
							end;
							str1 = deblank(str(1:ii));
							str2 = str(ii+1:length(str));
							if ((~all(size(cmd)))&oldsprintf), cmd=' '; end;
							if ((~all(size(str1)))&oldsprintf), str1=' '; end;
							if ((~all(size(str2)))&oldsprintf), str2=' '; end;
							mif2 = sprintf(mifops,cmd,str1,str2);
						else,
							if ((~all(size(cmd)))&oldsprintf), cmd=' '; end;
							if ((~all(size(str)))&oldsprintf), str=' '; end;
							mif2 = sprintf(mifbody,cmd,str);
						end;
						mif(offset+(1:length(mif2)))=mif2; offset=offset+length(mif2);
					end;
				end;
			end;
			if (fwrite(miffid,mif(1:offset))~=offset),
				fclose(miffid);
				error(['CONT2MIF was unable to write to the file "' filename '".']);
			end;
			firstone=0;
		end;
	end;

end;

% transfer the tail
writelen = fwrite(miffid,tail);
fclose(miffid);
if (writelen~=length(tail)),
	error(['CONT2MIF was unable to write to the file "' filename '".']);
end;
