function flist(name)
%FLIST	List the contents of a Mat-file.
%	The command flist foo will list the contents of foo.mat in a format
%	similiar to whos.

% open file read only
nl = length(name);
if nl <= 4, 
	name = [name '.mat']; 
elseif ~strcmp('.mat',name((nl-3):nl)) 
	name = [name '.mat'];
end
fid=fopen(name,'r');
if ~fid, disp(['Unable to open file ' name '.']), return, end

% header
disp(' ')
disp(['Contents of file ' name])
disp(' ')
disp(['              Name        Size       Elements     Bytes    Density' ...
		'   Complex'])
disp(' ')

% read through mat file listing the variables name and size
while 1
	% read type, m, n, imag, namelen
	[d,c] = fread(fid,5,'int32');
	if c ~= 5, break, end

	type = d(1);  m = d(2);  n = d(3);  imag = d(4);  namelen = d(5);
	mn = m*n;
	t = rem(type,10);	% 0 - normal, 1 - text, 2 - sparse
	if imag, complex = 'Yes'; else  complex = 'No'; end

	% run some tests on m, n, imag, t, and namelen to verify they have 
	% reasonable values
	if m < 0  |  n < 0  |  mn < 0, break, end
	if imag ~= 0  &  imag ~= 1, break, end
	if t < 0  |  t > 2, break, end
	if namelen < 1  |  namelen > 20, break, end

	% read name and reformat
	[name,c]=fread(fid,namelen,'uchar');
	if c ~= namelen, break, end
	name = setstr(name(1:namelen-1)');

	% skip data
	if t < 2
		% dense data
		if fseek(fid,mn*8,'cof'), break, end

		if imag
			if fseek(fid,mn*8,'cof'), break, end
		end

		density = 'Full';
	else
		% sparse data
		if fseek(fid,(m-1)*8,'cof'), break, end
		[mm,c]=fread(fid,1,'double');
		if c ~= 1, break, end

		if fseek(fid,(m-1)*8,'cof'), break, end
		[nn,c]=fread(fid,1,'double');
		if c ~= 1, break, end

		if fseek(fid,m*8,'cof'), break, end

		if imag
			if fseek(fid,m*8,'cof'), break, end
		end

		density = sprintf('%8.4f',(m-1)/(mm*nn));
		mn = m-1;
		m = mm; n = nn;
	end

	% write name and size of variable

	namespace = ones(1,19-namelen)*' ';

	mnstr = int2str(mn);

	mstr = int2str(m);  mspace = ones(1,8-length(mstr))*' ';
	nstr = int2str(n);  nspace = ones(1,15-length(nstr)-length(mnstr))*' ';

	bytestr = int2str(mn*8*(1+imag));  
	bytespace = ones(1,10-length(bytestr))*' ';


	denspace = ones(1,11-length(density))*' ';

	compspace = ones(1,6)*' ';

	disp([namespace name mspace mstr ' by ' nstr nspace ...
			mnstr  bytespace bytestr denspace density compspace  complex])
end

disp(' ')

fclose(fid);
