% This file has a slightly different
% call syntax than the ordinary
% readad() function.  The difference
% is in the last parameter, where
% channels are specified by letting
% multiple channels be specified in a
% vector, instead of just giving a
% start- and stop channel.

function y=d_readad( count, dt, channels ) 
outfilestr = 'c:\matlab\dap\readad.dap';
datfilestr = 'c:\matlab\dap\dap.dat';
readadprog = 'c:\matlab\dap\dap_ad';

outfile = fopen(outfilestr,'wt');
cmdstr = ['!' readadprog ' ' outfilestr ' ' datfilestr];
bstr = 'PDEFINE B\nPRINT\nEND\nSTART READAD, B\n';

if  nargin == 0 
	% create command string
	s = ['IDEFINE READAD 1\n' ...
	     'SET CHANNEL 0 D0'];
	% use only first entry in gain list
	gain = dap_gain;
	if (gain ~= []) & any( gain ~= 1 )
		s = [ s ' ' int2str(gain(1)) ];
	end
	s = [s '\n'];
	if dap_trig
		s = [ s 'HTRIGGER ONESHOT\n'];
	end
	s = [s  'COUNT 2\n' ...
		'END\n' ...
		bstr ];
	fprintf(outfile, s);
	dimension = 1;
	cmdstr = [cmdstr ' 2 1'];       
elseif nargin == 1
	% readad( count )
	% create command string
	s = ['IDEFINE READAD 1\n' ...
	     'SET CHANNEL 0 D' int2str(count)];
	gain = dap_gain;
	if (gain ~= []) & any( gain ~= 1 )
		s = [ s ' ' int2str(gain(1)) ];
	end
	s = [s '\n'];
	if dap_trig
		s = [ s 'HTRIGGER ONESHOT\n'];
	end
	s = [s 'COUNT 2\n' ...
	       'END\n' ...
		bstr];
	fprintf( outfile, s );
	dimension = 1;
	cmdstr = [cmdstr ' 2 1'];
elseif nargin == 2
	% readad( count, dt )
	% create command string
	s = ['IDEFINE READAD 1\n' ...
	     'SET CHANNEL 0 D0'];
	gain = dap_gain;
	if (gain ~= []) & any( gain ~= 1 )
		s = [ s ' ' int2str(gain(1)) ];
	end
	s = [s '\n'];
	if dap_trig
		s = [ s 'HTRIGGER ONESHOT\n'];
	end
	if dap_clk == 1
		s = [ s 'CLOCK EXTERNAL\n' ];
	end
	s = [s 'COUNT ' int2str(count) '\n' ];
	if dap_clk ~= 1
	  s = [s 'TIME ' int2str(dt*1E6) '\n' ];
	else
	  s = [s 'TIME 10\n' ];
	end
	s = [s 'END\n' ...
	     bstr];
	fprintf(outfile, s );
	dimension = count;
	cmdstr = [cmdstr ' ' int2str(count) ' 1'];
elseif( nargin == 3 )
	% readad( count, dt, channels )
	% create command string
	no_of_channels = length( channels );
	s = ['IDEFINE READAD ' int2str( no_of_channels ) '\n'];
	gain = dap_gain;
	if (length(gain)==1) & (no_of_channels>1)
		gain = gain*ones(1,no_of_channels);                        
	end
	for i=1:no_of_channels
		s = [s 'SET CHANNEL ' int2str(i-1) ...
		     ' D' int2str(channels(i)) ];
		if (gain ~= []) & any( gain ~= 1 )
			s = [ s ' ' int2str(gain(i)) ];
		end
		s = [s '\n'];
	end
	if dap_trig
		s = [ s 'HTRIGGER ONESHOT\n'];
	end
	if dap_clk == 1
		s = [ s 'CLOCK EXTERNAL\n' ];
	end
	s = [s 'COUNT ' int2str(count*no_of_channels) '\n' ];
	if dap_clk ~= 1
	  s = [s 'TIME ' int2str(dt*1E6/no_of_channels) '\n' ];
	else
	  s = [s 'TIME 10\n' ];
	end
	s = [s 'END\n' ...
	       bstr];
	fprintf(outfile, s);
	if no_of_channels > 1
		dimension = [no_of_channels count];
	else
		dimension = count;
	end
	cmdstr = [cmdstr ' ' int2str(count) ' ' int2str(no_of_channels)];
else
	error('illegal number of parameters');
end

fclose( outfile );
%disp( cmdstr )
%sprintf(s)
% run sampling program
eval( cmdstr );
% load data file
fid = fopen( datfilestr, 'rb' );
y = fread( fid, dimension, 'short' );
fclose( fid );
if length(dimension) > 1
	y = y';
end
y = y ./ 32768 * 10;

% Now handle any gain
if ( gain ~= [] )  &  any( gain ~= 1 ) 
  [r,c] = size(y);
  if c > 1
    y = y ./ (ones(r,1)*gain);
  else
    y = y ./ gain;
  end
end
