#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include "dapio.h"

/* This program has as its primary purpose to write data
   to the D/A converters.  It may however be used by any
   application that needs to download and execute a DAP
   command file, and then read (preferrably) 16-bit data
   from the input pipe. */


/* dap_da cmd_file data_file rows cols */
int main ( int argc, char *argv[] )
    {
    FILE *DapBinOut, *DapTextOut, *DapBinIn, *DapTextIn;
    FILE *data_file;
    int rows, cols, items_read;
    int *data;

    if( argc != 5 )  {
	puts( "Usage: dap_da cmd_file data_file rows cols\n" );
	exit(1);
    }
    /* Open ACCEL1 (binary) used to transfer data to an from the DAP, and   */
    /* ACCEL0 (text) used to send commands to the DAP.                      */
    if( (DapBinOut = fopen("ACCEL1","wb")) == NULL )  {
	puts( "Could not open binary file to Dap\n" );
	exit(1);
    }
    if( (DapBinIn = fopen("ACCEL1","rb")) == NULL )  {
	puts( "Could not open binary file from Dap\n" );
	exit(1);
    }
    if( (DapTextOut = fopen("ACCEL0","wt")) == NULL) {
	puts( "Could not open text file to Dap\n" );
	exit(1);
    }
    if( (DapTextIn = fopen("ACCEL0","rb")) == NULL) {
	puts( "Could not open text file from Dap\n" );
	exit(1);
    }
    
    if( strcmp(argv[2],"NOFILE") )  {
        if( (data_file = fopen(argv[2],"rb")) == NULL )  {
	    puts( "Could not open data file\n" );
	    exit(1);
        }
    }
    else  data_file = NULL;

    fBinaryMode(DapBinOut);
    fBinaryMode(DapBinIn);
    fBinaryMode(DapTextIn);
    fBinaryMode(DapTextOut);

    setvbuf(DapTextOut,NULL,_IONBF,0);/* Turn off output stream buffering   */

    fWriteIoCtlStr(DapBinIn,"S,M00"); /* Set up ACCEL device driver mode    */

    fprintf(DapTextOut, "RESET\n");   /* Send a command to reset the DAP    */

    fFlushDap(DapBinIn);              /* Flush old DAP data                 */
    fFlushDap(DapTextIn);

    /* Configure the DAP using the DAPL command file SENDDAP.DAP            */
    if (fConfigDap(DapTextOut, argv[1]) >= 200)
	{
	printf("Error while configuring DAP\n");
	exit(2);
	}

    rows = atoi( argv[3] );
    cols = atoi( argv[4] );
/*    printf("DAP file: %s\n", argv[1] );
    printf("Data file: %s\n", argv[2] );
    printf("Rows: %d\n", rows );
    printf("Cols: %d\n", cols );*/
    if( data_file != NULL )  {
        data = malloc( sizeof(int)*rows*cols );
        if( data == NULL )  {
	    puts( "Could not allocate data memory\n" );
    	    exit(1);
        }
        items_read = fread(data,sizeof(int),rows*cols,data_file);
        if( items_read != (rows*cols) )  {
	    printf("Only read %d data items\n", items_read );
	    exit(1);
        }
        fclose( data_file );
        /* Send N integers in the array Data to the DAP for processing      */
        fPutDapBuf(data, sizeof(int), rows*cols, DapBinOut);
        fflush(DapBinOut);
        free( data );
        /*puts("Press a key...\n");
        getchar();*/
    }
/*    fprintf(DapTextOut, "STOP\n"); */   /* Send a command to stop the DAP     */
    fWriteIoCtlStr(DapBinIn,"R");     /* Restore ACCEL device driver mode   */
    fclose(DapBinIn);                 /* Close files                        */
    fclose(DapBinOut);
    fclose(DapTextOut);
    fclose(DapTextIn);
    /*puts("DONE\n");*/
    return(0);
    }
