#include <math.h>
#include <stddef.h>
#include <conio.h>
#include <bios.h>
#include <dos.h>
#include <time.h>
#include <stdlib.h>
#include "mex.h"


/* I/O port addresses */
static int CADR = 0x2ED;
static int DADR = 0x2EC;

static double TIME_BASE = 2.5E-6;

static int DT2801_gain = 1;
static int trig=0; /*bit7=ext.trig. (0=no,1=yes). bit6=ext.clock. */

/* Commands */
#define CRESET 0
#define CCLEAR 1
#define CERROR 2
#define CCLOCK 3
#define CDAOUT 8
#define CSDA 9
#define CWDA 0xA
#define CADIN 0xC
#define CSETUP_AD 0xD
#define CRAD 0xE
#define CSTOP 0xF


#define D2I(X)  (int)(((X)+10.0)*4096.0/20.0)
/* handshaking */
#define WAIT4CMD while(!(_inp(CADR)&4))
#define WAIT4READ while(!(_inp(CADR)&5))
#define DT_ERROR (_inp(CADR)&0x80)
#define WAIT4WRITE while((_inp(CADR)&2))

void WRT_CMD(int C)
{
	int i = 20;
	long delay = 900000;

	_outp(CADR,C);
	while( delay > 0 ) delay--;
}

static void stop( void )
{
	WRT_CMD(CSTOP);
	_inp(DADR);
}


static unsigned read_error( void )
{
	int low, high;

	stop();
	WAIT4CMD;
	WRT_CMD(CERROR);
	WAIT4READ;
	low = _inp(DADR);
	WAIT4READ;
	high = _inp(DADR);
	return( (high<<8) + low );
}

void wrt_err( char *str, unsigned err )
{
	static char s1[] = "Error 1: New command issued while a previous command was still executing.\n";
	static char s2[] = "Error 2: Clock period too low - increase sampling time.\n";
	static char s3[] = "Error 3: Illegal digital port value.\n";
	static char s4[] = "Error 4: Tried to read from an outport, or other way around.\n";
	static char s5[] = "Error 5: Illegal D/A channel value.\n";
	static char s6[] = "Error 6: Clock period too short for this machine - slow down.\n";
	static char s7[] = "Error 7: Too few conversions. Minimum is 3.\n";
	static char s8[] = "Error 8: Illegal A/D channel value.\n";
	static char s9[] = "Error 9: Illegal A/D gain value.  Use 1,2,4, or 8.\n";
	static char s10[] = "Error 10: Clock period too short for this machine - slow down.\n";
	static char s11[] = "Error 11: A/D mux lagging behind. Slow down.\n";
	static char s12[] = "Error 12: Too few conversions. Minimum is 3.\n";
	static char s13[] = "Error 13: Data where command expected.\n";

	printf(str);
	if( err & 2 )  printf( s1 );
	if( err & 4 )  printf( s2 );
	if( err & 8 )  printf( s3 );
	if( err & 0x10 )  printf( s4 );
	if( err & 0x20 )  printf( s5 );
	if( err & 0x40 )  printf( s6 );
	if( err & 0x80 )  printf( s7 );
	if( err & 0x100 )  printf( s8 );
	if( err & 0x200 )  printf( s9 );
	if( err & 0x400 )  printf( s10 );
	if( err & 0x800 )  printf( s11 );
	if( err & 0x1000 )  printf( s12 );
	if( err & 0x2000 )  printf( s13 );
	mexErrMsgTxt("Bye...");
}


static unsigned setda( unsigned int count, int chan )
{
	WAIT4WRITE;
	WAIT4CMD;
	WRT_CMD(CSDA);
	WAIT4WRITE;
	_outp(DADR,chan);
	WAIT4WRITE;
	_outp(DADR,count & 0xFF );
	WAIT4WRITE;
	_outp(DADR,count >> 8 );
	WAIT4CMD;
	if( DT_ERROR ) return( read_error());
	else return(0);
}


static unsigned da_imm( int *data, int channel, int cmd )
{
	/* Write the da_imm command */
	WAIT4WRITE;
	WAIT4CMD;
	WRT_CMD(cmd);
	WAIT4WRITE;
	_outp(DADR,channel);
	/* output data */
	WAIT4WRITE;
	_outp(DADR,*data & 0xFF);
	WAIT4WRITE;
	_outp(DADR,*data >> 8 );
	if( channel == 2 )  {
		WAIT4WRITE;
		data++;
		_outp(DADR,*data & 0xFF);
		WAIT4WRITE;
		_outp(DADR,*data >> 8);
	}
	WAIT4WRITE;
	WAIT4CMD;
	if( DT_ERROR ) return( read_error());
	else return(0);
}


static unsigned writeda( char *arr, unsigned size, int cmd )
{
	register unsigned int sz;
	int mask;

	/* Multiply size by 2, since the no of char points is
	   twice that the size of the int array */
	sz = size << 1;
	/* Write the writeda command */
	WAIT4WRITE;
	WAIT4CMD;

	/* output data */
	/*mask = _inp(0x21);
	_outp(0x21,mask & 0xFE);*/
	_disable();
	_outp(CADR,cmd);
	while( sz-- )  {
		WAIT4WRITE;
		_outp(DADR,*arr++);
	}
	/*_outp(0x21,mask);*/        /* Turn clock on again */
	_enable();
	WAIT4CMD;
	if( DT_ERROR ) return( read_error());
	else return(0);
}

static void mat2int( int *data, double *mat, int m, int n )
{
	int count, row,col;
	double *rowptr=mat;

	/*count = m*n;
	while( count-- )
		*data++ = D2I(*mat++);*/
	/* Since MATLAB stores matrices row-wise and C column-wise,
	   we have to transpose the matrix while converting it. */
	for(row=0;row<m;row++)  {
		/* Convert one Matlab row */
		for( col=0,rowptr=mat; col<n; col++ )  {
			*data++ = D2I( *rowptr );
			rowptr += m;
		}
		mat++;
	}
}


static unsigned ad_clock( double sample_time )
{
	unsigned long divisor;
	unsigned err;

	if( DT_ERROR )  {
		err = read_error();
		return(err);
	}
	divisor = (long)(sample_time / TIME_BASE);
	if( divisor > 0xFFFFL ) return(1);
	/* Write the set clock rate command */
	WAIT4CMD;
	WRT_CMD(CCLOCK);
	/* Write the clock rate LSB and MSB */
	WAIT4WRITE;
	_outp(DADR,(int)(divisor & 0xFF) );
	WAIT4WRITE;
	_outp(DADR,(int)(divisor >> 8) );
	/* Check for error */
	WAIT4CMD;
	if( DT_ERROR )  {
		err = read_error();
		return(err);
	}
	else return(0);
}



/* writeda_fcn(data)  writes to ch0 using daimm if one data value is given,
   and to ch0 and ch1 if 2 data points are given.
   writeda_fcn(data,chan) writes to the channel given by chan. If chan==2,
   both channels are written to. If only one data value is given, and chan==2,
   that data value is duplicated to both channels.
   writeda_fcn(data,chan,dt) uses the on-board pacer clock to write an array
   (or two) to one (or two) channels.  The array size must be larger than 3.
   For two-channel output, column vectors should be used.  */

static void writeda_fcn(int nlhs, Matrix *plhs[], int nrhs,
		   Matrix *prhs[])
{
	int status=0, chan=0, m, n, *data;
	unsigned size;

	m = (int) mxGetM( prhs[0] );  n = (int) mxGetN( prhs[0] );
	if( nrhs == 2 )  {
		chan = (int) mxGetPr( prhs[1] )[0];
		if( (chan>2) || (chan<0) ) mexErrMsgTxt("Illegal channel value");
	}
	else if( nrhs == 1 )  {
		nrhs = 2;
		if( (m==1) && (n==1) ) chan = 0;
		else if( (m==1)&&(n==2) || (m==2)&&(n==1) ) chan = 2;
		else mexErrMsgTxt("Illegal data vector format");
	}
	if( nrhs == 2 )  {
		if( chan == 2 )  {
			data = (int *) mxCalloc( 2, sizeof(int) );
			*data = D2I(mxGetPr( prhs[0] )[0]);
			if( (m==1) && (n==1) )
				*(data+1) = D2I(mxGetPr( prhs[0] )[0]);
			else    *(data+1) = D2I(mxGetPr( prhs[0] )[1]);
		}
		else  {
			data = (int *) mxCalloc(1, sizeof(int) );
			*data = D2I(mxGetPr( prhs[0] )[0]);
		}
		status = da_imm( data, chan, CDAOUT | trig );
		if( status )  {
			wrt_err("Error during da_imm() in WRITEDA\n",status);
			return;
		}
	}
	else if( nrhs == 3 )  {
		/* Use writeda */
		chan = (int) mxGetPr(prhs[1])[0];
		if( (chan<0) || (chan>2) )
			mexErrMsgTxt("Illegal channel number");
		size = m * n;
		data = (int *) mxCalloc( size, sizeof(int) );
		/* Convert Matlab double format to Int */
		mat2int(data, mxGetPr(prhs[0]), m, n );
		/* Set D/A parameters */
		status = setda( max(m,n) , chan );
		if( status )  {
			wrt_err("Error during setda() in WRITEDA\n",status);
			return;
		}
		status = ad_clock( mxGetPr(prhs[2])[0] );
		if( status )  {
			wrt_err("Error during ad_clock() in WRITEDA\n",status);
			return;
		}
		/* Write array */
		status = writeda( (char *)data, size, CWDA | trig );
		if( status )  {
			wrt_err("Error during writeda() in WRITEDA\n",status);
			return;
		}
	}
	else mexErrMsgTxt("Illegal number of input arguments");
}




int gain2dt( int gain )
{
	switch( gain )  {
		case 1: gain = 0; break;
		case 2: gain = 1; break;
		case 4: gain = 2; break;
		case 8: gain = 3; break;
		default:gain = 0;
	}
	return(gain);
}


static int ad_imm(int trig, int channel, double *result)
{
	int data;

	WAIT4WRITE;
	WAIT4CMD;
	WRT_CMD(CADIN | trig);
	WAIT4WRITE;
	_outp(DADR, gain2dt(DT2801_gain) );
	WAIT4WRITE;
	_outp(DADR,channel);
	WAIT4READ;
	data = _inp(DADR);
	WAIT4READ;
	data |= (_inp(DADR)<<8);
	WAIT4WRITE;
	WAIT4CMD;
	if( DT_ERROR ) return( read_error());
	*result =  (data*20.0/4096.0 - 10.0) / DT2801_gain;
	return(0);
}

void int2mat( double *mat, int *data, int rows, int cols )
{
	int i,j;
	int *data_ofs;
	int swapped_data;

	/* Transpose matrix and convert to volts */
	for( i=0;i<cols;i++ )  {
		data_ofs = data + i;
		for( j=0;j<rows;j++ )  {
		/*        swapped_data = *((char *)data_ofs) << 8;
			swapped_data |= *(((char *)data_ofs)+1);*/
			*mat++ = (*data_ofs * 20.0/4096.0 -
				  10.0) / DT2801_gain;
			data_ofs += cols;
		}
	}
}


/* Count is per channel */
unsigned setad( unsigned int count, int gain, int start_chan, int end_chan )
{
	if( DT_ERROR )  return( read_error() );
	/* First convert gain to machine readable format */
	switch( gain ){
		case 1: gain = 0; break;
		case 2: gain = 1; break;
		case 4: gain = 2; break;
		case 8: gain = 3; break;
		default: gain = 0;
	}
	/* Expand count to DT2801 format (total no of convs.) */
	count = count * ( end_chan - start_chan + 1);
	/* Write the setup command */
	WAIT4CMD;
	WRT_CMD(CSETUP_AD);
	/* write gain byte */
	WAIT4WRITE;
	_outp(DADR,gain);
	/* Write start channel byte */
	WAIT4WRITE;
	_outp(DADR,start_chan);
	/* Write end channel byte */
	WAIT4WRITE;
	_outp(DADR,end_chan);
	/* Write number of conversions */
	WAIT4WRITE;
	_outp(DADR,count & 0xFF);
	WAIT4WRITE;
	_outp(DADR,count>>8);
	/* check for errors */
	WAIT4CMD;
	if( DT_ERROR )
		return( read_error() );
	else return(0);
}


unsigned readad( char *arr, int cmd, unsigned size )
{
	unsigned int sz;
	int mask;

	/* Multiply size by 2, since the no of char points is
	   twice that the size of the int array */
	sz = size << 1;
	sz--;
	if( DT_ERROR )  return( read_error() );
	/* For max. speed, turn interrupts off */
	/* Write the readad command */
	WAIT4CMD;
	/* collect data */
	/*mask = _inp(0x21);
	_outp(0x21,mask & 0xFE);*/
	_disable();
	_outp(CADR,cmd);
	/* For the first sample, it is bloody important not to check the
	   READY bit in the status register. A 386 computer is so fast that
	   this bit has not had time to clear after the command write, before
	   the register is accessed.  Thus only test the DATA OUT bit. */
	while( !(_inp(CADR) & 1) );
	*(arr++) = (char) _inp(DADR);
	/* Now the READY bit oughta be cleared,so run as usual */
	while( sz-- )  {
		WAIT4READ;
		*(arr++) = (char) _inp(DADR);
	}
	/*_outp(0x21,mask);*/
	_enable();
	/*WAIT4WRITE;
	WAIT4CMD;*/
	if( DT_ERROR )  return( read_error() );
	else return(0);
}


static void readad_fcn(int nlhs, Matrix *plhs[],
		       int nrhs,Matrix *prhs[])
{
	int status = 0;
	unsigned count;
	double dt;
	int *data, chan, end_chan, channels;

	/* Check arguments! */
	if( nrhs == 0 )  {
		plhs[0] = mxCreateFull(1,1,REAL);
		/* ad_imm from channel 0 */
		status = ad_imm( trig, 0, mxGetPr(plhs[0]) );
		if( status )
			wrt_err("Error during ad_imm() in READAD\n",status);
	}
	else if( nrhs == 1 )  {
		/* ad_imm from chan */
		plhs[0] = mxCreateFull(1,1,REAL);
		status = ad_imm( trig, (int) mxGetPr(prhs[0])[0],
				 mxGetPr(plhs[0]) );
		if( status )
			wrt_err("Error during ad_imm() in READAD\n",status);
	}
	else if( nrhs == 2 )  {
		/* read ch0 */
		count = (unsigned) mxGetPr( prhs[0] )[0];
		dt = mxGetPr( prhs[1] )[0];
		status = setad(  count, DT2801_gain, 0, 0 );
		if( status )
			wrt_err("Error during setad() in READAD\n",status);
		status = ad_clock( dt );
		if( status )
			wrt_err("Error during ad_clock() in READAD\n",status);
		/* Create memory */
		data = (int *) mxCalloc(count,sizeof(int));
		plhs[0] = mxCreateFull(count,1,REAL);
		if( (data == NULL)  ||  (plhs[0] == NULL)  )
			mexErrMsgTxt("Cannot allocate READAD memory");
		status = readad( (char *) data, CRAD | trig, count );
		if( status )
			wrt_err("Error during readad() in READAD\n",status);
		/* Convert from int to double format */
		int2mat( mxGetPr(plhs[0]), data, count, 1 );
	}
	else if( nrhs == 3 )  {
		/* readad(count,dt,chan) */
		count = (unsigned) mxGetPr( prhs[0] )[0];
		dt = mxGetPr( prhs[1] )[0];
		chan = (int) mxGetPr( prhs[2] )[0];
		status = setad(  count, DT2801_gain, chan, chan );
		if( status )
			wrt_err("Error during setad() in READAD\n",status);
		status = ad_clock( dt );
		if( status )
			wrt_err("Error during ad_clock() in READAD\n",status);
		/* Create memory */
		data = (int *) mxCalloc(count,sizeof(int));
		plhs[0] = mxCreateFull(count,1,REAL);
		if( (data == NULL)  ||  (plhs[0] == NULL)  )
			mexErrMsgTxt("Cannot allocate READAD memory");
		status = readad( (char *) data, CRAD | trig, count );
		if( status )
			wrt_err("Error during readad() in READAD\n",status);
		/* Convert from int to double format */
		int2mat( mxGetPr(plhs[0]), data, count, 1 );
	}
	else if( nrhs == 4 )  {
		/* readad(count,dt,startchan,endchan) */
		count = (unsigned) mxGetPr( prhs[0] )[0];
		dt = mxGetPr( prhs[1] )[0];
		chan = (int) mxGetPr( prhs[2] )[0];
		end_chan = (int) mxGetPr( prhs[3] )[0];
		channels = end_chan - chan + 1;
		/* Compensate sample time for more channels */
		dt /= channels;
		status = setad(  count, DT2801_gain, chan, end_chan );
		if( status )
			wrt_err("Error during setad() in READAD\n",status);
		status = ad_clock( dt );
		if( status )
			wrt_err("Error during ad_clock() in READAD\n",status);
		/* Create memory */
		data = (int *) mxCalloc(count*channels,sizeof(int));
		plhs[0] = mxCreateFull(count,channels,REAL);
		if( (data == NULL)  ||  (plhs[0] == NULL)  )
			mexErrMsgTxt("Cannot allocate READAD memory");
		status = readad( (char *) data, CRAD | trig,
			  count*channels );
		if( status )
			wrt_err("Error during readad() in READAD\n",status);
		/* Convert from int to double format */
		int2mat( mxGetPr(plhs[0]), data, count, channels );
	}
	else mexErrMsgTxt("Illegal number of parameters for DT2801 readad command" );
}


static void digout_fcn(int nlhs, Matrix *plhs[],
		     int nrhs, Matrix *prhs[])
{
}

static void digin_fcn(int nlhs, Matrix *plhs[],
		     int nrhs, Matrix *prhs[])
{
}

static void setgain_fcn(int nlhs, Matrix *plhs[],
			int nrhs, Matrix *prhs[])
{
	DT2801_gain = (int) mxGetPr( prhs[0] )[0];
}


static void settrig_fcn(int nlhs, Matrix *plhs[],
			int nrhs, Matrix *prhs[])
{
	int trig_cmd;

	trig_cmd = (int) mxGetPr( prhs[0] )[0];
	if( trig_cmd )  trig |= 0x80;
	else trig &= 0x7F;
}

static void setextclock_fcn(int nlhs, Matrix *plhs[],
			    int nrhs, Matrix *prhs[])
{
	int clock_cmd;

	clock_cmd = (int) mxGetPr( prhs[0] )[0];
	if( clock_cmd )  trig |= 0x40;
	else trig &= 0xBF;
}

static void set_io_port_fcn(int nlhs, Matrix *plhs[],
			int nrhs, Matrix *prhs[])
{
	DADR = (int) mxGetPr( prhs[0] )[0] ;
}

/* Return the status address value */
static void read_status_fcn( int nlhs, Matrix *plhs[],
			     int nrhs, Matrix *prhs[])
{
	plhs[0] = mxCreateFull(1,1,REAL);
	if( plhs[0] == NULL )  
		mexErrMsgTxt("Could not allocate memory\n");
	mxGetPr( plhs[0] )[0] = (double) _inp(CADR);
}


void init_fcn(int nlhs, Matrix *plhs[],
	      int nrhs, Matrix *prhs[])
{
	mexPrintf("Initializing DT2801 A/D card\n" );
	WRT_CMD(CSTOP);
	_inp(DADR);
	if( DT_ERROR )  {
		WAIT4CMD;
		WRT_CMD(CCLEAR);
	}
	WAIT4CMD;
	WRT_CMD(CRESET);
	_inp(DADR);
	if( DT_ERROR )
		wrt_err("Error after GP_INIT\n",read_error());
	WAIT4CMD;
}




void mexFunction( int nlhs, Matrix *plhs[], int nrhs, Matrix *prhs[] )
{
       static void (*fcn[])() = { writeda_fcn,
				  readad_fcn,
				  init_fcn,
				  digout_fcn,
				  digin_fcn,
				  setgain_fcn,
				  settrig_fcn,
				  setextclock_fcn,
				  set_io_port_fcn,
				  read_status_fcn,
				  NULL };
	int mode;

	if( nrhs == 0 ) mexErrMsgTxt("Input args, please\n" );
	mode = (int)  mxGetPr(prhs[0])[0];
	fcn[mode](nlhs,plhs,nrhs-1,prhs+1);
/*      init_fcn( nlhs, plhs, nrhs, prhs );*/
}
