function eos_out(eos1,eos2)
%EOS_OUT --
%
%eos_out(eos)   modifies the EOS character appended to the output string sent
%               to the GPIB bus during SEND calls.
%
% Example:
%
%       eos_out(3)
%
%               sets the EOS character to ETX (=3 decimal).
%
%eos_out(eos1,eos2)     uses two EOS chars (typical combination: CR/LF)
%
% Example:
%
%       eos_out(13,10)  will set the EOS chars to be CR followed by LF
%
%
%See also SEND, ENTER, EOS_IN.

if (nargin<1) | (nargin>2)
	error( 'eos_out: wrong number of input parameters');
end

board = gp_board;
[f, msg] = fopen( gp_dev(board), 'w+' );
if f == -1
	error( ['eos_out fopen() error: ' msg] );
end

if board == 1
	% CEC
	if nargin == 1
		if eos1 == 10
			s = 'OUTTERM LF\r\n';
		elseif eos1 == 13
			s = 'OUTTERM CR\r\n';
		else
			s = ['OUTTERM "' eos1 '"\r\n'];
			%s = sprintf('OUTTERM "%1.0f"\r\n',eos1);
		end
	else
		if (eos1==13) & (eos2==10)
			s = 'OUTTERM CRLF\r\n';
		else
			s = ['OUTTERM "' eos1 eos2 '"\r\n'];
		end
	end
elseif board == 2
	% National
	if nargin == 1
		if eos1 == 10
			s = 'GPIBEOS OUT LF\r\n';
		elseif eos1 == 13
			s = 'GPIBEOS OUT CR\r\n';
		else
			s = sprintf('GPIBEOS OUT CHR(%1.0f)\r\n',eos1);
		end
	else
		if (eos1==13) & (eos2==10)
			s = 'GPIBEOS OUT CR LF\r\n';
		else
			s = sprintf('GPIBEOS OUT CHR(%1.0f) chr(%1.0f)\r\n',eos1, eos2);
		end
	end
else
	error('Wrong board number');
end

fprintf(f,s);
fclose(f);