function ren(addr_vec)
%ren --  Remote Enable
%
%ren          Asserts the REN line. Note that the instruments will not
%             be put in the remote mode until they are addressed as
%             listeners.
%
%ren(addr_vec)  Sends the listener addresses given in addr_vec onto the bus
%               prior to asserting the REN line.
%
%Example:     ren( [3 4 7] )  will set the instruments with
%	      addresses 3, 4, and 7 in the remote state.
%
%See also GTL.

board = gp_board;
[f, msg] = fopen( gp_dev(board), 'w+' );
if f == -1
	error( ['ren fopen() error: ' msg] );
end

if( nargin == 0 )
        fprintf(f,'REMOTE\r\n');
else
	if board == 1
		format_str = ' %1.0f';
	else
		format_str = ',%1.0f';
	end
        s = 'REMOTE';
        s = [s sprintf(' %1.0f',addr_vec(1))];
        for k=2:length(addr_vec)
                s = [s sprintf(format_str,addr_vec(k))];
        end
        s = [s '\r\n'];
        fprintf(f,s);        
end
fclose(f);