function send(addr_vec,string)
%SEND --
%
%send(ADDR_VEC,STRING)  sends the MATLAB string STRING to the GPIB device
%                       specified by ADDRESS.  An EOS character is appended
%                       to the string, and EOI is asserted.
%
%send(STRING)   assumes that listeners have already been assigned.
%
%Note: By default the EOS character is LF.  When an instrument does not accept
%      this as a message delimiter (our Philips function generator must have
%      an ETX, for example) use the EOS_OUT command to change the EOS char.
%
%Example:       to send a string to the Philips function generator, the lines
%
%       ETX=3;
%       eos_out(ETX);
%       send(7,'Halavah');
%
%       would do the trick.
%
%See also ENTER, EOS_OUT, EOS_IN

board = gp_board;
[f,msg] = fopen( gp_dev(board), 'w+' );
if f == -1
	error( ['send fopen() error: ' msg] );
end

if board == 1
	%CEC
	format_str = ' %1.0f';
elseif board == 2
	% National
	format_str = ',%1.0f';
else
	error('Illegal board');
end

if nargin == 1
        fprintf(f,['OUTPUT;' addr_vec '\r\n']);
elseif nargin == 2
        s = 'OUTPUT';
        s = [s sprintf(' %1.0f',addr_vec(1))];
        for k=2:length(addr_vec)
                s = [s sprintf(format_str,addr_vec(k))];
        end
        s = [s ';' string '\r\n'];
        fprintf(f,s);
else
        error( 'Too many arguments' )
end
fclose(f);