function y=writeda(data,chan,dt)
%writeda(data) writes the voltage in data to channel 0
%writeda(data,chan) writes the voltage in data to channel chan
%writeda(data,chan,dt) writes the array data to channel chan,
%                      using the sample period dt

board = ad_board;

if board == 0
	error('No A/D board selected')
elseif board == 1
	% DT2801
	if nargin == 1
		y=dt2801(0,data);
	elseif nargin == 2
		y = dt2801(0,data,chan);
	elseif nargin == 3
		% Check min sampling time
		if dt < 0.7E-4
			error('Minimum sampling time on this machine is 0.7E-4 s.');
                end
		if (chan == 2) & ((dt/2) < 0.7E-4)
			error('Minimum sampling time/channel is 0.7E-4 s.');
                end
		y = dt2801(0,data,chan,dt);
	else
		error('Illegal number of parameters for DT2801 board');
	end
elseif board  == 2
	% PCL-714
	if nargin == 1
		y=pcl714(0,data);
	elseif nargin == 2
		y=pcl714(0,data);
	else
		error('Illegal number of parameters for PCL714 board');
	end
elseif board == 3
	% DAP series
	outfilestr = 'c:\matlab\dap\writeda.dap';
	writedaprog = 'c:\matlab\dap\dap_da';
	datfilestr = 'c:\matlab\dap\dap.dat';

	if nargin < 3
		dt = 1E-3;
	end
	if nargin < 2
		chan = 0;
	end
	cmdstr = 'PDEF A\n';
	if chan == 2
		cmdstr = [cmdstr 'SEPARATE ($BININ, OPIPE0, OPIPE1)\n'];
	else
		cmdstr = [cmdstr 'COPY ($BININ, OPIPE0)\n'];
	end
	cmdstr = [cmdstr 'END\n'];
	cmdstr = [cmdstr 'ODEF B '];
	if chan == 2
		cmdstr = [cmdstr '2\n'];
	else
		cmdstr = [cmdstr '1\n'];
	end
	cmdstr = [cmdstr 'SET OPIPE0 A'];
	if chan == 1
		cmdstr = [cmdstr '1\n'];
	else
		cmdstr = [cmdstr '0\n'];
	end
	if chan == 2
		cmdstr = [cmdstr 'SET OPIPE1 A1\n'];
	end
	[rows,cols] = size(data);
	if (cols == 1) & (chan == 2)
		cols = 2;
		data = [data data];
	end
	if ((chan<2) & (cols ~= 1)) | ((chan == 2) & (cols ~= 2))
		error('Wrong number of columns in data');
	end
	if rows == 1 
		rows = 2;
		data = [data ; data];
	end
	cmdstr = [cmdstr 'COUNT ' int2str(rows*cols) '\n'];
	if dap_trig
		cmdstr = [cmdstr 'HTRIGGER ONESHOT\n'];
	end
        if dap_clk == 1
                cmdstr = [ cmdstr 'CLOCK EXTERNAL\n' ];
        end
	cmdstr = [cmdstr 'TIME ' int2str( dt*1E6/cols ) '\n'];
	cmdstr = [cmdstr 'END\nSTART A,B\n'];
	%sprintf(cmdstr)
	% Command string creation finished.  Save it
	fid = fopen(outfilestr, 'wt');
	fprintf(fid, cmdstr );
	fclose(fid);
	% write data file
	data = data' / 10 * 32768;
	fid = fopen( datfilestr, 'wb' );
	fwrite(fid, data, 'short');
	fclose( fid );
	% create program string
	cmdstr = ['!' writedaprog ' ' outfilestr ' ' datfilestr ' ' ...
		 int2str( rows ) ' ' int2str( cols )];
	eval( cmdstr );
else
	error('Illegal board number');
end
