
////////////////////////////////////////////////////////////////////////
//
//		C++ - Matlab eXternal Engine programming interface
//
//      File    :       mm_engine.h
//
//	MM_engine is a specialized MX_engine tailored to MM matrices
//
//	Author	:	Copyright (c) 1993,1994 by Bart P.O. van Tongeren
//			Delft University of Technology,
//			Applied Physics Department - Spin Imaging Group,
//			P.O.box 5046, 2600 GA Delft, The Netherlands
//
//	Email	:	tong@si.tn.tudelft.nl
//
//	Date	:	Sat Jun 18 16:03:14 MET DST 1994
//
////////////////////////////////////////////////////////////////////////

#ifndef MM_ENGINE_H
#define MM_ENGINE_H

#include <MXE/mx_engine.h>
#include <dcomplex.h>

class MM_double_1D;
class MM_double_2D;
class MM_dcomplex_1D;
class MM_dcomplex_2D;

//----------------------------------------------------------------------
// class MM_engine - class defining My MX_engine Programming Interface
//----------------------------------------------------------------------
class MM_engine : public MX_engine
{
public:
	//----------------------------------------------------------------------
	// constructors
	//----------------------------------------------------------------------
	MM_engine() { }
	MM_engine(const char* startcmd) : MX_engine(startcmd) { };

public:
	//----------------------------------------------------------------------
	// get/put mm_matrices from/to the MATLAB Engine's workspace
	//----------------------------------------------------------------------
	double		get_double(const char* name);
	MM_double_1D	get_double_1D(const char* name);
	MM_double_2D	get_double_2D(const char* name);

	dcomplex	get_dcomplex(const char* name);
	MM_dcomplex_1D	get_dcomplex_1D(const char* name);
	MM_dcomplex_2D	get_dcomplex_2D(const char* name);

	MM_engine& put_double(const double x, const char* name);
	MM_engine& put_double_1D(const MM_double_1D& M, const char* name);
	MM_engine& put_double_2D(const MM_double_2D& M, const char* name);

	MM_engine& put_dcomplex(const dcomplex x, const char* name);
	MM_engine& put_dcomplex_1D(const MM_dcomplex_1D& M, const char* name);
	MM_engine& put_dcomplex_2D(const MM_dcomplex_2D& M, const char* name);
};

//----------------------------------------------------------------------
// predefined global MM_engine 'matlab', initialized by 'mm_engine_init'
//----------------------------------------------------------------------
class MM_engine_init
{
	static	int	count;

public:			MM_engine_init();
			~MM_engine_init();

};

extern	MM_engine	matlab;
static	MM_engine_init	mm_engine_init;

#endif
