
////////////////////////////////////////////////////////////////////////
//
//		C++ - Matlab eXternal Engine programming interface
//
//      File    :       mm_matrix.h
//
//			conversions between MX and MM (My Matrix classlib) 
//
//	Author	:	Copyright (c) 1993,1994 by Bart P.O. van Tongeren
//			Delft University of Technology,
//			Applied Physics Department - Spin Imaging Group,
//			P.O.box 5046, 2600 GA Delft, The Netherlands
//
//	Email	:	tong@si.tn.tudelft.nl
//
//	Date	:	Sat Jun 18 16:03:13 MET DST 1994
//
////////////////////////////////////////////////////////////////////////

#ifndef MM_MATRIX_H
#define MM_MATRIX_H

#include <MXE/mx_matrix.h>	/* MX: Matlab eXternal interface matrices */

#ifndef NO_MM
#include <MM/mm_dcomplex.h>	/* MM: My Matrix class library */
#else				/* MM not available, define some dummies */
class MM_double_1D	{ /* ... your code here ... */ };
class MM_double_2D	{ /* ... your code here ... */ };
class MM_dcomplex_1D	{ /* ... your code here ... */ };
class MM_dcomplex_2D	{ /* ... your code here ... */ };
#endif

/*
	(your favourite)	(mxe)			(your conversions)
	MM matrices :		MX matrices :		MM <=> MX :

	MM_double_1D		MX_double_1D		MM_double_1D_MX
	MM_double_2D		MX_double_2D		MM_double_2D_MX
	MM_dcomplex_1D		MX_complex_1D		MM_dcomplex_1D_MX
	MM_dcomplex_2D		MX_complex_2D		MM_dcomplex_2D_MX

	The MX_engine works with the MX_ matrices. These matrices are
	merely a typesafe interface to the Matrix struct and do not
	have features such as operator overloading, smart copying etc.
	You can make conversions between the MX_ matrices and
	your favourite matrix class library (here named with prefix MM_).
	Then it is possible to derive a class MM_engine from MX_engine,
	that works with your own MM_ matrices.
	The mm_ files demonstrate how this can be done. This mechanism
	is to avoid any dependencies of this C++ - MATLAB interface
	on a particular matrix library.
*/


class MM_double_1D_MX : public MM_double_1D		// MM_.._MX => MM
{
public:	MM_double_1D_MX(const MM_double_1D& mm);	// MM => MM_.._MX

	MM_double_1D_MX(const MX_double_1D& mx);	// MX => MM_.._MX

	MX_double_1D make_mx(const char* name = 0);	// MM_.._MX => MX
};

class MM_double_2D_MX : public MM_double_2D		// MM_.._MX => MM
{
public:	MM_double_2D_MX(const MM_double_2D& mm);	// MM => MM_.._MX

	MM_double_2D_MX(const MX_double_2D& mx);	// MX => MM_.._MX

	MX_double_2D make_mx(const char* name = 0);	// MM_.._MX => MX
};

class MM_dcomplex_1D_MX : public MM_dcomplex_1D		// MM_.._MX => MM
{
public:	MM_dcomplex_1D_MX(const MM_dcomplex_1D& mm);	// MM => MM_.._MX

	MM_dcomplex_1D_MX(const MX_complex_1D& mx);	// MX => MM_.._MX

	MX_complex_1D make_mx(const char* name = 0);	// MM_.._MX => MX
};

class MM_dcomplex_2D_MX : public MM_dcomplex_2D		// MM_.._MX => MM
{
public:	MM_dcomplex_2D_MX(const MM_dcomplex_2D& mm);	// MM => MM_.._MX

	MM_dcomplex_2D_MX(const MX_complex_2D& mx);	// MX => MM_.._MX

	MX_complex_2D make_mx(const char* name = 0);	// MM_.._MX => MX
};

#endif
