
////////////////////////////////////////////////////////////////////////
//
//		C++ - Matlab eXternal Engine programming interface
//
//      File    :       mm_example.cc
//
//	Author	:	Copyright (c) 1993,1994 by Bart P.O. van Tongeren
//			Delft University of Technology,
//			Applied Physics Department - Spin Imaging Group,
//			P.O. box 5046, 2600 GA Delft, The Netherlands
//
//	Email	:	tong@si.tn.tudelft.nl
//
//	Date	:	Sat Jun 18 16:03:11 MET DST 1994
//
//	Note	:	This example (but for MATLAB 3.5) is described in
//
//	B.P.O. van Tongeren, e.a.,
//	"Embedding of PRO-MATLAB into NMR Signal Processing Applications",
//	Journal of Magnetic Resonance, 100/3, dec. 1992, p. 619-624.
//
////////////////////////////////////////////////////////////////////////

#ifdef NO_MM /* MM matrices not available. Use the MX_engine */
#else

#include <MXE/mm_engine.h>
#include <MM/mm_dcomplex.h>
#include <strstream.h>

int main(int argc, char* argv[])
{
	// record what happens
	matlab	<< "diary " << argv[0] << ".diary" << eval;

	const int M = 32;	// size of 2D model function X
	const int N = 32;	//	i.e. the number of time domain samples
	const int K = 3;	// number of poles in k direction
	const int L = 2;	// number of poles in l direction

	MM_dcomplex_1D	Pk(K),	// complex poles, where
			Pl(L);	//	realpart=damping, imagpart=frequency
	MM_dcomplex_2D	C(K,L);	// complex amplitude matrix

	// insert complex values into the pole matrices
	istrstream("(-0.04, -2) (-0.02, 1) (-0.06, 2)")	>> Pk;
	istrstream("(-0.02, -2) (-0.06, 1)")		>> Pl;

	// let all peaks have the same amplitude and no phase shift
	C = 1;

	// transport the matrices to the matlab process
	matlab	.put_dcomplex_1D(Pk, "Pk")
		.put_dcomplex_1D(Pl, "Pl")
		.put_dcomplex_2D(C, "C")
		.put_double(M, "M")
		.put_double(N, "N");

	// compute time domain reconstruction in matlab; make a surface plot
	matlab	<< "Zk = exp(Pk).';"
		<< "Zl = exp(Pl);"

		<< "U = ones(size(Zk));"

		<< "for k = 2:M;"
		<< "	U(k,:) = U(k-1,:) .* Zk;"
		<< "end"
		<< eval

		<< "V = ones(size(Zl));"
		<< "for l = 2:N;"
		<< "	V(:,l) = V(:,l-1) .* Zl;"
		<< "end"
		<< eval

		<< "X = U * C * V;"

		<< "surfl(abs(fftshift(fft2(X))));"
		<< "view(-30, 10);"
		<< "title('modulus fft');"
		<< flush
		;

	// return the matrix X from matlab to C++ for further processing
	MM_dcomplex_2D	X = matlab.get_dcomplex_2D("X");

	// for later inspection
	matlab	<< "save " << argv[0] << eval;

	cout	<< "Hit return to quit.." << flush;
	cin.get();

	return 0;
}

#endif
