
////////////////////////////////////////////////////////////////////////
//
//		C++ - Matlab eXternal Engine programming interface
//
//      File    :       mm_matrix.cc
//
//			conversions between MX and MM (My Matrix classlib) 
//
//	Author	:	Copyright (c) 1993,1994 by Bart P.O. van Tongeren
//			Delft University of Technology,
//			Applied Physics Department - Spin Imaging Group,
//			P.O.box 5046, 2600 GA Delft, The Netherlands
//
//	Email	:	tong@si.tn.tudelft.nl
//
//	Date	:	Sat Jun 18 16:03:08 MET DST 1994
//
////////////////////////////////////////////////////////////////////////


#include <MXE/mm_matrix.h>


#ifndef NO_MM /* is MM (My Matrix class library) available? */

MM_double_1D_MX::MM_double_1D_MX(const MM_double_1D& mm) :
	MM_double_1D(mm) {
}

MM_double_1D_MX::MM_double_1D_MX(const MX_double_1D& mx) :
	MM_double_1D(mx.getM()*mx.getN()) {
		import(mx.getPr());
}

MX_double_1D
MM_double_1D_MX::make_mx(const char* name) {
	double		*pr = new double[size(0)];
	export(pr);
	MX_double_1D	mx(size(0), pr, name);
	delete [] pr;
	return mx;
}


MM_double_2D_MX::MM_double_2D_MX(const MM_double_2D& mm) :
	MM_double_2D(mm) {
}

MM_double_2D_MX::MM_double_2D_MX(const MX_double_2D& mx) :
	MM_double_2D(mx.getM(), mx.getN()) {
	import(mx.getPr());
}

MX_double_2D
MM_double_2D_MX::make_mx(const char* name) {
	double		*pr = new double[size(0)*size(1)];
	export(pr);
	MX_double_2D	mx(size(0), size(1), pr, name);
	delete [] pr;
	return mx;
}


MM_dcomplex_1D_MX::MM_dcomplex_1D_MX(const MM_dcomplex_1D& mm) :
	MM_dcomplex_1D(mm) {
}

MM_dcomplex_1D_MX::MM_dcomplex_1D_MX(const MX_complex_1D& mx) :
	MM_dcomplex_1D(mx.getM()*mx.getN()) {
	if (mx.getPi() == 0)
		fill(0);
	else	import(mx.getPi(), imagpart);
	import(mx.getPr(), realpart);
}

MX_complex_1D
MM_dcomplex_1D_MX::make_mx(const char* name) {
	double		*pr = new double[size(0)],
			*pi = new double[size(0)];
	export(pr, realpart);
	export(pi, imagpart);
	MX_complex_1D	mx(size(0), pr, pi, name);
	delete [] pr;
	delete [] pi;
	return mx;
}


MM_dcomplex_2D_MX::MM_dcomplex_2D_MX(const MM_dcomplex_2D& mm) :
	MM_dcomplex_2D(mm) {
}

MM_dcomplex_2D_MX::MM_dcomplex_2D_MX(const MX_complex_2D& mx) :
	MM_dcomplex_2D(mx.getM(), mx.getN()) {
	if (mx.getPi() == 0)
		fill(0);
	else	import(mx.getPi(), imagpart);
	import(mx.getPr(), realpart);
}

MX_complex_2D
MM_dcomplex_2D_MX::make_mx(const char* name) {
	double		*pr = new double[size(0)*size(1)],
			*pi = new double[size(0)*size(1)];
	export(pr, realpart);
	export(pi, imagpart);
	MX_complex_2D	mx(size(0), size(1), pr, pi, name);
	delete [] pr;
	delete [] pi;
	return mx;
}

#endif /* NO_MM */
