
/* Matlab MEX-file to implement  ' [ a,b,c, ... ] = loadop4( fn, {#} )'
   in Matlab 4.2c on DEC Alpha.  See loadop4.m for usage instructions.  
   v 2.0: Read one col at a time, no longer using RdOP4Data for reading
   OP4Bin data --> significant improvement in performance ! 
   v 3.0: Determine OP4 type from input file; fn extension not used anymore.
   v 3.1: Warn that only 5E16.9 OP4Bcd type is supported.
*/


#define  __STDC__        /* >>>>>>> loadop4.31.c <<<<<<< */
#include <math.h>
#include <stdlib.h>
#include <stdio.h>
#include "nr/nrutil.c"
#include "op4.c"
#include "mex.h"
#include "mat.h" 
#define False 0
#define True 1

void Chktype( char *fn, short *Ib );
void loadop4( int Opt, short tp, double *A, FILE *FnI, int Nr, int Nc ); 
void Oops( int n );
void CleanOP4( double **Mat, int Nrow, int Ncol);
void MatrixtoVector( double **Mat, double *Vec, int Nr, int Nc);
void SkipOP4Data( short BinOpt, short Tp, FILE *Fi, int *Ni, int *Nj);

static
		/* Computational Routine */
void loadop4( int Opt, short tp, double *A, FILE *Fi, int Nr, int Nc  ) 
{

  double *Vec1, DDum,  **Data;
  float val, SDum;	
  int i,k, Dum, Nw, Ns, Nw1, ntr, iv, fv, Icol;

/* Want to read each OP4Col at a time and place into proper location of A.
   A is 0-offset vector with Nr*Nc elements. 
   OP4 matrix's col1     col2   col3     ...   col Nc
                ^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
 init-val:       0        Nr    2Nr    ...    (Nc-1)Nr
                
 final-val:    Nr-1     2Nr-1   3Nr-1  ...    NcNr-1
 So  iv = ( CurCol-1 )*Nr;   fv =   CurCol*(Nr - 1);
 */


  if ( Opt )		
      do {
	fread( &Dum, sizeof(int), 1, Fi ); fread( &Icol, sizeof(int), 1, Fi );
		
	if ( Icol > Nc ) /* must check for Icol > Nc; i.e. last col is null */
	  {
	    fread( &Ns, sizeof(int), 1, Fi );
	    fread( &Nw1, sizeof(int), 1, Fi ); 
	    if ( Dum == 16 )	/* 3*4  + 4byte value */
	      fread( &SDum, sizeof(float), 1, Fi );
	    else 
	      if ( Dum == 20 )	/* 3*4  + 8byte value */
		fread( &DDum, sizeof(double), 1, Fi );
	      else  
		Oops( 17 );
	    fread( &Dum,sizeof(int),1,Fi);   
	    break;
	  }	  

	fread( &Ns, sizeof(int), 1, Fi );  fread( &Nw1, sizeof(int), 1, Fi );   
	Nw = Nw1/tp;        Vec1 = dvector( 0, Nw-1 );
	/* don't need to zero out Vec1 since it's all used */
	ntr = fread( Vec1, sizeof(double), Nw, Fi );
	fread( &Dum, sizeof(int), 1, Fi ); 
/* 	printf(" Icol, Ns, Nw, ntr = %d %d %d %d\n", Icol,Ns,Nw,ntr);  */

	if ( ntr != Nw )
	  printf(" WARNING:%d vals read into Vec1 for col #%d\n",ntr, Icol); 
	iv = ( Icol-1 )*Nr  + (Ns-1);	fv =   Icol*(Nr - 1);
	for( i=1, k=0; i <= Nw; i++, k++ )
	  A[ iv++ ] = Vec1[ k ];
	free_dvector( Vec1, 0, Nw-1 );
	if ( Icol == Nc )	/*  read trailer if icol = nc */
	  {
	    fread( &Dum, sizeof(int), 1, Fi ); 
	    fread( &SDum, sizeof(int), 1, Fi );
	    fread( &SDum, sizeof(int), 1, Fi );
	    fread( &Nw1, sizeof(int), 1, Fi ); 
	    if ( Dum == 16 )	/* 3*4  + 4byte value */
	      fread( &SDum, sizeof(float), 1, Fi );
	    else 
	      if ( Dum == 20 )	/* 3*4  + 8byte value */
		fread( &DDum, sizeof(double), 1, Fi );
	      else  
		Oops( 17 );
	    fread( &Dum,sizeof(int),1,Fi);   
	  }
      } while ( Icol < Nc );
  else
    {
      Nw = Nr*Nc;
      if ( Nw > 10000 )
	{
	  printf("\n-> Matrix has > 10000 elements !   It's better to" );
	  printf(" save data in OP4Bin format !\n\n" );
	}
      Data = dmatrix( 1, (Nr+1), 1, (Nc+1) );
      CleanOP4( Data, Nr, Nc);
      RdOP4Data(  Opt, tp, Fi, &Nr, &Nc, Data );
      MatrixtoVector( Data, A, Nr, Nc );
      free_dmatrix( Data, 1, (Nr+1), 1, (Nc+1) );
    }

#ifdef DEBUG
  printf(">  Inside computation routine  \n" );
  printf(">  Opt, Nr, Nc  = %d, %d, %d \n", Opt, Nr, Nc );
  printf(">  Just read %d by %d matrix\n", Nr,Nc );
  printf(">  1st term of vector A = %f \n", A[0] );
#endif
}


		/* GateWay Routine */
void mexFunction( int nlhs, Matrix *plhs[], int nrhs, Matrix *prhs[] )
{
	double	*A, *B, *C, *D, *E, *F, *G, *H, *I, *J, *nsk;
	double	*K, *L, *M, *N, *O, *P, *Q, *R, *S, *T;
	int Nr, Nc, i, j, Nskip, Nmat, nm;
	short Tp, nl,  BinOpt;
	char  Fname[80], Mname[10], ext[5], str1[6], st[7];
	FILE *Fi;
	float  Span;
	clock_t  StaT, EndT;

	StaT = clock();
	printf("\n>>>>>  Entering loadop4: ( v 3.1 )\n" );

	if ( (nrhs < 0) || (nrhs > 2) )    Oops( 21 );
	if ( !mxIsString( prhs[0] )  )     Oops( 22 );
	mxGetString( prhs[ 0 ],  Fname,  80 );
	/* Fname = prhs[ 0 ];didn't work  */
	Nmat = nlhs;  
	if ( (Nmat < 1) || (Nmat > 20) )     Oops( 34 );
	if ( (nrhs > 1) )	/* get # of matrices to Skip past */
	  {
	    nsk = mxGetPr( prhs[1] ); 	    Nskip = (int) *nsk;
	    if ( Nskip <= 0 )	Oops( 33 );
	  }
	else
	  Nskip = 0;

	Chktype( Fname,  &BinOpt );  /* determine op4 type of input file */
	if ( BinOpt )  
	  strncpy( st, "bin", 3);  
	else
	  strncpy( st, "bcd", 3);  
	
#ifdef DEBUG
	nl = strlen( Fname );	/* Using extension to get Opt */
	for( i=0, j=3; i < 3; i++, j-- )
	  ext[ i ] = Fname[ nl-j ];	/* extension = last 3 chars of infn */
	ext[ 3 ] = '\0';
	if ( (strcmp( ext, "bin")) == 0 )
	  Opt = 1;      /*  OP4Bin */
	else if ( (strcmp( ext, "bcd")) == 0 )
	  Opt = 0;  /*  OP4Bcd */
	else
	    Oops( 32 ); 
printf(">  # to skip = %d; filename = %s  \n", Nskip, Fname);
printf(">  %d matrices to load; BinOpt = %d  \n", Nmat, BinOpt);
#endif

	if (( Fi = fopen( Fname, "r")) == NULL)	    Oops( 31 );
	for (i = 1; i <= Nskip;  i++)
	  {
	    RdOP4Hdr( BinOpt, &Tp, Fi, &Nr, &Nc, Mname );
	    SkipOP4Data( BinOpt, Tp, Fi, &Nr, &Nc ); /*  ??? */
	    printf("> Just skip OP4%s matrix %s (%d by %d)\n",st,Mname,Nr,Nc);
	  }
	for ( i=1; i <= Nmat; i++ ) /*  */
	  {
	    RdOP4Hdr( BinOpt, &Tp, Fi, &Nr, &Nc, Mname );
	    printf("> Reading OP4%s matrix %s (%d by %d)\n",st,Mname,Nr,Nc);
	/* Create a matrix for the return argument */
	    plhs[ i-1 ] = mxCreateFull( Nr, Nc, REAL);

	/* Assign pointers to the various params */
	    switch ( i )
	      {
	      case 1:
		A = mxGetPr( plhs[ i-1 ] ); /* A is zero-filled ! */
		loadop4( BinOpt, Tp,  A, Fi, Nr, Nc);
		break;
	      case 2:
		B = mxGetPr( plhs[ i-1 ] ); loadop4( BinOpt,Tp,B, Fi, Nr, Nc);
		break;
	      case 3:
		C = mxGetPr( plhs[ i-1 ] ); loadop4( BinOpt,Tp,C, Fi, Nr, Nc);
		break;
	      case 4:
		D = mxGetPr( plhs[ i-1 ] ); loadop4( BinOpt,Tp,D, Fi, Nr, Nc);
		break;
	      case 5:
		E = mxGetPr( plhs[ i-1 ] ); loadop4( BinOpt,Tp,E, Fi, Nr, Nc);
		break;
	      case 6:
		F = mxGetPr( plhs[ i-1 ] ); loadop4( BinOpt,Tp,F, Fi, Nr, Nc);
		break;
	      case 7:
		G = mxGetPr( plhs[ i-1 ] ); loadop4( BinOpt,Tp,G, Fi, Nr, Nc);
		break;
	      case 8:
		H = mxGetPr( plhs[ i-1 ] ); loadop4( BinOpt,Tp,H, Fi, Nr, Nc);
		break;
	      case 9:
		I = mxGetPr( plhs[ i-1 ] ); loadop4( BinOpt,Tp,I, Fi, Nr, Nc);
		break;
	      case 10:
		J = mxGetPr( plhs[ i-1 ] ); loadop4( BinOpt,Tp,J, Fi, Nr, Nc);
		break;
	      case 11:
		K = mxGetPr( plhs[ i-1 ] ); loadop4( BinOpt,Tp,K, Fi, Nr, Nc);
		break;
	      case 12:
		L = mxGetPr( plhs[ i-1 ] ); loadop4( BinOpt,Tp,L, Fi, Nr, Nc);
		break;
	      case 13:
		M = mxGetPr( plhs[ i-1 ] ); loadop4( BinOpt,Tp,M, Fi, Nr, Nc);
		break;
	      case 14:
		N = mxGetPr( plhs[ i-1 ] ); loadop4( BinOpt,Tp,N, Fi, Nr, Nc);
		break;
	      case 15:
		O = mxGetPr( plhs[ i-1 ] ); loadop4( BinOpt,Tp,O, Fi, Nr, Nc);
		break;
	      case 16:
		P = mxGetPr( plhs[ i-1 ] ); loadop4( BinOpt,Tp,P, Fi, Nr, Nc);
		break;
	      case 17:
		Q = mxGetPr( plhs[ i-1 ] ); loadop4( BinOpt,Tp,Q, Fi, Nr, Nc);
		break;
	      case 18:
		R = mxGetPr( plhs[ i-1 ] ); loadop4( BinOpt,Tp,R, Fi, Nr, Nc);
		break;
	      case 19:
		S = mxGetPr( plhs[ i-1 ] ); loadop4( BinOpt,Tp,S, Fi, Nr, Nc);
		break;
	      case 20:
		T = mxGetPr( plhs[ i-1 ] ); loadop4( BinOpt,Tp,T, Fi, Nr, Nc);
		break;
	      }
	  }

	/* printf("\a"); printf("\a");  printf("\a"); */
	if ( ! BinOpt )  
	  {
	    printf("\n\n> WARNING: loadop4 will only handle OP4Bcd data");
	    printf(" written in 5E16.9 format.\n");
	    printf(">          If more precision is required use OP4Bin,");
	    printf(" which will also yield\n");
	    printf(">          superior I/O performance.\n\n");
	  }
	if ( (fclose( Fi )) != 0 )
	  Oops( 35 );
	EndT = clock();
	Span =  ( (float)(EndT-StaT) )/CLOCKS_PER_SEC;  
	printf("\n>>>>>  Exiting loadop4. (%8.3f cps )\n", Span);
	return;
}


void Oops( int n )
{
char t1[] = "MUST have at least 1 or at most 2 right-hand-side arguments !\n";
char t2[] = "1st right-hand-side argument must be text! (with filename).\n";
char t34[] = "MUST have at least 1 or at most 20 left-hand-side arguments !\n";

  printf("\n\n < loadop4 > failed because of the following error: \n\n");
  switch ( n )
    {
    case 1:
      break;
    case 4:
     printf("Unable to determine OP4type of input file.\n");
      break;
    case 5:
      printf("Unable to close input file.\n");    
      break;
    case 17:
      printf(" Error in reading the OP4Bin Trailer value !\n" ); 
      printf(" ( Neither 16 or 20 bytes for Trailer )\n" ); 
      break;
    case 21 :
      mexErrMsgTxt( t1 );
      break;
    case 22 :
      mexErrMsgTxt( t2 );
      break;
    case 31:
      mexErrMsgTxt("Unable to open OP4 file for input.\n");    
      break;
    case 32:
      mexErrMsgTxt("Invalid filename extension used !\n");
      break;
    case 33:
      mexErrMsgTxt(" 2nd right-hand-side argument MUST be Numeric and > 0 !\n");
      break;
    case 34:
      mexErrMsgTxt( t34 );
      break;
    case 35:
      mexErrMsgTxt( "Problem with closing input FILE *Fi !\n" );
      break;
    default:
      printf("Error code = %d !", n);
      mexErrMsgTxt(" No error message for specified error code.\n");
    }
  return;	/* exit(1) -> file ptrs & memory released */
}

void CleanOP4( double **Mat, int Nrow, int Ncol)
{
  int i,j;
  for(j=1; j <= Ncol; j++)
      for(i=1; i <= Nrow; i++)
	Mat[i][j] = 0.0;
}

void MatrixtoVector( double **Mat, double *Vec, int Nr, int Nc)
{
  int i,j,k;

  for( j=1, k=0; j <= Nc; j++ )
    for( i=1; i <= Nr; i++ )
      Vec[ k++ ] = Mat[ i ][ j ];
}



void SkipOP4Data( short BinOpt, short Tp, FILE *Fi, int *Ni, int *Nj)
{
  double *Vec, DDum;
  kfloat val, SDum;	
  int i,j=1,k, Dum, Nw, Ns, Nw1, Icol, ntr;

  if (BinOpt)
    {
      do
	{			/* Read matrix: @ */
	  fread( &Dum, sizeof(int), 1, Fi ); 
	  fread( &Icol, sizeof(int), 1, Fi );
	  fread( &Ns, sizeof(int), 1, Fi );
	  fread( &Nw1, sizeof(int), 1, Fi );   
	  if ( Icol <= *Nj )
	    {
	      Nw = Nw1/Tp;     Vec = dvector( 0, Nw-1 );
		/* don't need to zero out Vec since it's all used */
	      ntr = fread( Vec, sizeof(double), Nw, Fi );
	      fread( &Dum, sizeof(int), 1, Fi ); 
	      if ( ntr != Nw )	/* oops */
		Oops( 14 );
	      free_dvector( Vec, 0, Nw-1 );       
	    }
	}
      while( Icol < *Nj );
      if ( Icol > *Nj )  /* trailer can be single or double precision! */
	/* Already read 1st portion of Trailer */
	{
	  if ( Nw1 == 1 )
	    fread( &SDum, sizeof(float), 1, Fi );
	  else   if ( Nw1 == 2 )
	    fread( &DDum, sizeof(double), 1, Fi );
	  else  Oops1( 17 );
	  fread( &Dum,sizeof(int),1,Fi);   
	}
      else 	
	{
	  fread( &Dum, sizeof(int), 1, Fi ); 
	  fread( &Icol, sizeof(int), 1, Fi );
	  fread( &Ns, sizeof(int), 1, Fi );
	  fread( &Nw1, sizeof(int), 1, Fi ); 
	  if ( Nw1 == 1 )
	    fread( &SDum, sizeof(float), 1, Fi );
	  else   if ( Nw1 == 2 )
	    fread( &DDum, sizeof(double), 1, Fi );
	  else  Oops1( 17 );
	  fread( &Dum,sizeof(int),1,Fi);   
	}
    }
  else
    {
      do
      {
	fscanf( Fi, "%8d%8d%8d", &j, &Ns, &Nw);
	for( i=1; i<=Nw; i++)
	  fscanf( Fi, "%16E", &val);
      } while( j < *Nj );
      if ( j > *Nj )
	;  /* Already read Trailer, since its col # is Nj+1 */
      else
	{
	  fscanf( Fi, "%8d%8d%8d", &j, &Ns, &Nw);
	  fscanf( Fi, "%16E", &val);
	}
    }
}


void Chktype( char *fn, short *Ib )
{
  FILE *Fi;
  int Dum, i,j, n;
  char junk[10];

  if (( Fi = fopen( fn, "r")) == NULL)
    Oops( 31 );
  n = fscanf( Fi, "%8d%8d%8d%8d%8s", &i, &i, &j, &j, junk);
  if ( n == 5 )
    *Ib = False;
  else 
    {
      if ( (fclose( Fi )) != 0 )
	Oops(5);
      if (( Fi = fopen( fn, "r")) == NULL) 
	Oops( 31 );
      fread( &Dum, sizeof(int), 1, Fi );    
      if ( (Dum == 24) || (Dum == 32) )	 /* assuming 8 or 16bytes mname */
	*Ib = True;
      else
	Oops( 4 );
    }
  if ( (fclose( Fi )) != 0 )
    Oops(5);
}

/*     EXTRA STUF

 nm = Nr*Nc;
		for (j = 0; j < nm;  j++)
		  if ( fabs ( A[ j ] ) > 100*DBL_EPSILON )
		    printf("> Significant value: A[%d] = %g\n", j+1, A[ j ] );
		  else
		    printf("> A[%d] = %g\n", j+1, A[ j ] );


 */
