
/*             ------------------->>>>> op4.c 

  Routines to do OP4 I/O on DEC Alpha.             Nov. '95

  Unlike the Cray version, OP4Bin I/O is now done entirely in C.
  ( Taken & modif. from HP/UX 's op4.c )
  It was observed that OP4Bin format has the following properties:
  1) 8-byte matrix name
  2) Matrix values are double; 
  2.1) Trailer value can be single or double precision !!!
  3) Each instance of a FORTRAN-Write is enclosed between 2 4-byte words.
     So we make use of a dummy int in I/O.

Issue: Type = 2    --> Might change with next MSC Nastran ver !
       Miniheader has Icol, Ns, Nw2  ( Nw2 = 2*Nw, with Type = 2 )
  4) I use 2nd arg in RdOP4__ to pass back the type of the matrix, 1 or 
     2, and use it to get Nw; i.e.  Nw = Nw2/Type.

  5) Using Oops1 below to issue Error messages from op4.c     

     Notes:  1) Iu & Ou are not used, retained for compatibility only. 
             2) Val in RdOP4Data's fscanf must be a float ! (not double)

  6)    Discovery: Aug. 10, 1995 >>> See note in WrtOP4Bin

  7)    Update: Nov. 1995   Using 'Dum' to determine if 
        a) a matrix header is 24bytes or 32, (and read accordingly) or      
        b) a matrix trailer value is single or double

*/


#define kfloat float
#include <float.h> 

   /* Function prototypes 'should' match definition*/
void Oops1( int n );
void RdOP4Hdr( short BinOpt, short *Iu, FILE *Fi, int *Ni,int *Nj,char *Nm);
void RdOP4Data( short BinOpt, short Iu, FILE *Fi, int *Ni, 
		  int *Nj, double **Mat);
void WrtOP4Data( short BinOpt, short Ou, FILE *Fo, int Rs, int Cs,
		 char *Nm, double **Mat);
void WrtOP4Bin( double **Mat, int Ni, int Nj, char *mname, FILE *fpo);
void WrtOP4Bcd( double **Mat, int Ni, int Nj, char *Nam, FILE *fpo);

void SetUp( char *InFn, char *OuFn, short Ib, short Ob, FILE **Fi, FILE **Fo);
void CloseDown( char *OuFn, short Ib, short Ob, FILE **Fi, FILE **Fo);



/*  -------------------------------------------------------------------  */

void RdOP4Hdr( short BinOpt, short *tp, FILE *Fi, int *Ni,int *Nj,char *Nm)
{
  short n;		
  int  i,j,k, Form, Type, Dum, ntr;
  char c, nam[9]="        ", nam2[18]="                ";

  if  ( feof( Fi ) )
    Oops1( 15 );
  if (BinOpt)
    {
   /* Read Main Header */
      fread( &Dum, sizeof(int), 1, Fi );    
      fread( Nj, sizeof(int), 1, Fi );
      fread( Ni, sizeof(int), 1, Fi );  fread( &Form, sizeof(int), 1, Fi );  
      fread( &Type, sizeof(int), 1, Fi );
/*  printf(" Nj & Ni & Form & Typ = %d %d %d %d\n", *Nj, *Ni, Form, Type);  */
      if ( (Type != 2)&&(Type != 1) ) Oops1( 14 ); 
      *tp = Type; /*  returning Type for use in RdOP4Data */
      if ( Dum == 24 )		/* 8byte name */
	{
	  ntr = 8;	
	  i = fread( nam, ntr, 1, Fi );  if ( i == 0 ) Oops1( 16 );
	  strcpy( Nm, nam);
	}
      else  if ( Dum == 32 )		/* 16byte name */
	{
	  ntr = 16;
	  i = fread( nam2, ntr, 1, Fi );  if ( i == 0 ) Oops1( 16 );
	  strncpy( Nm, nam2, 7);
	}
      else
	Oops1( 18 );
/*      printf(" Dum & Name = %d & %s (%d bytes)\n", Dum, Nm, sizeof(Nm) );  */ 
      fread( &Dum, sizeof(int), 1, Fi ); 
 /*     printf(" Final Dum & ntr =  %d & %d\n", Dum, ntr );   */
    }
  else
    {
      n = fscanf( Fi, "%8d%8d%8d%8d%8s", Nj, Ni, &Form, &Type, Nm);
      while (( c = getc( Fi )) != '\n' );  /* to handle v 67.5 OP4Bcd */
      if ( (n != 5) )
	Oops1( 6 );
    }
}


void RdOP4Data( short BinOpt, short tp, FILE *Fi, int *Ni, 
		  int *Nj, double **Mat)
{
  double *Vec, DDum;
  kfloat val, SDum;	
  int i,j=1,k, Dum, Nw, Ns, Nw1, Icol, ntr;

  if (BinOpt) 
    {
      do
	{			/* Read matrix: @ */
	  fread( &Dum, sizeof(int), 1, Fi ); 
	  fread( &Icol, sizeof(int), 1, Fi );
	  fread( &Ns, sizeof(int), 1, Fi );
	  fread( &Nw1, sizeof(int), 1, Fi );   
	/*  printf(" Dum &  Ni & Nj =  %d & %d & %d\n", Dum,*Ni, *Nj); 
         printf(" Icol & Ns & Nw1 & Typ = %d %d %d %d\n", Icol, Ns, Nw1,tp) */; 
	  if ( Icol <= *Nj )
	    {
		/* 	      Nw = Nw1/2;  >> for Type = 2 */
	      Nw = Nw1/tp;
	      Vec = dvector( 0, Nw-1 );
		/* don't need to zero out Vec since it's all used */
	      ntr = fread( Vec, sizeof(double), Nw, Fi );
	      fread( &Dum, sizeof(int), 1, Fi ); 
	      if ( ntr != Nw )
		printf(" %d values read into Vec for col #%d\n", ntr, Icol ); 
	      for( i=Ns, k=0; i <= (Ns+Nw-1); i++, k++ )
		Mat[ i ][ Icol ] = Vec[ k ];
	      free_dvector( Vec, 0, Nw-1 );       
	    }
	  /* 	printf(" Read Col %d OK\n",Icol ); */
	}
      while( Icol < *Nj );

      if ( Icol > *Nj ) /* trailer can be single or double precision! */
	/* Already read 1st portion of Trailer */
	{
	  if ( Dum == 16 )		/* 3*4  + 4byte value */
	    fread( &SDum, sizeof(float), 1, Fi );
	  else 
	    if ( Dum == 20 )		/* 3*4  + 8byte value */
	      fread( &DDum, sizeof(double), 1, Fi );
	    else  
	      Oops1( 17 );
	  fread( &Dum,sizeof(int),1,Fi);   
	}
      else 	
	{
	  fread( &Dum, sizeof(int), 1, Fi ); 
	  fread( &Icol, sizeof(int), 1, Fi );
	  fread( &Ns, sizeof(int), 1, Fi );
	  fread( &Nw1, sizeof(int), 1, Fi ); 
	  if ( Dum == 16 )		/* 3*4  + 4byte value */
	    fread( &SDum, sizeof(float), 1, Fi );
	  else
	    if ( Dum == 20 )		/* 3*4  + 8byte value */
	      fread( &DDum, sizeof(double), 1, Fi );
	    else 
	      {
		 /* printf(" Dum & Icol   = %d & %d\n", Dum,Icol ); */
		Oops1( 17 );
	      }
	  fread( &Dum,sizeof(int),1,Fi);   
	}
/*	  printf(" Icol & Ns & Nw1 & Typ = %d %d %d %d\n", Icol, Ns, Nw1,tp);
	  if ( Nw1 == 1 )
	    fread( &SDum, sizeof(float), 1, Fi );
	  else   if ( Nw1 == 2 )
	    fread( &DDum, sizeof(double), 1, Fi ); */
    }
  else
    {
      do
	{
	  fscanf( Fi, "%8d%8d%8d", &j, &Ns, &Nw);
	  for( i=1; i<=Nw; i++)
	    {
	      fscanf( Fi, "%16E", &val);
	      Mat[ i+Ns-1 ][j] = val; 
	    }
	} while( j < *Nj );
      if ( j > *Nj )
	;  /* Already read Trailer, since its col # is Nj+1 */
      else
	{
	  fscanf( Fi, "%8d%8d%8d", &j, &Ns, &Nw);
	  fscanf( Fi, "%16E", &val);
	}
    }
}




void WrtOP4Data( short BinOpt, short Ou, FILE *Fo, int Rs, int Cs,
		 char *Nm, double **Mat)
{
  if (BinOpt)
    WrtOP4Bin( Mat, Rs, Cs, Nm, Fo );
  else
    WrtOP4Bcd( Mat, Rs, Cs, Nm, Fo );
}



void WrtOP4Bcd( double **Mat, int Ni, int Nj, char *Nam, FILE *fpo)
{
  int i,j,k,i2,i3,i4, form,type, minr,maxr,nwrt;
  double eps;
	/*  Write Ni by Nj matrix Mat to file using OP4BCD format:

	 1) First, the matrix header is written on a line
	 2) Then, the matrix data is written out column by column starting
	 with col #1.
	 3) For each column, we want to find the 1st nonzero value and the last
	 nonzero value;  only values between 1st nonzero and last nonzero are
	 written.
	 4) Prior to writing out the column, a mini-header is printed on a 
	 line.  The mini-header has: the col #, the row # of the first nonzero
	 value in that col, and the number of values written.
	 5) The values for that col are then written in exponential format
	 at 5 values per line.
	 6) Note: there are no mini-header for a null-column.
	 7) Last, a trailer consisting of a mini-header & 1 value is written.
*/

  eps = 100*(DBL_EPSILON);
  type = 1;
  if (Ni != Nj)
    form = 2;
  else
    form = 1;
  fprintf( fpo, "%8d%8d%8d%8d%-8s\n", Nj,Ni,form,type, Nam);

  j=1;
 XX:
  while (j <= Nj)
  {
    for( i=1; i<=Ni; i++)
      if ( fabs(Mat[i][j]) > eps )	/* Not Equal 0  */
	{
	  minr = i;
	  for( i2=Ni; i2>=1; i2--)
	    if ( fabs(Mat[i2][j]) > eps )
	      { maxr = i2;
		nwrt = maxr - minr + 1;	/* # of values written */
		fprintf( fpo, "%8d%8d%8d\n", j,minr,nwrt);
		for( i3=minr, i4=1; i3<=maxr; i3++,i4++)
		  {
		    fprintf( fpo, "%16.9E", Mat[i3][j]);
		    if ( (i4%5) == 0 ) 
		      fprintf( fpo, "\n"); /* 5 per line */
		  }
		if ( (nwrt%5) != 0 ) 
		  fprintf( fpo, "\n"); /* new line for next miniheader */
		j++;
		goto XX;  /* Skip to next column */
	      }
	}
    j++;
    goto XX;  /* Col was Null, skip to next */

  }	/* end while */
  
  fprintf( fpo, "%8d%8d%8d\n", (Nj+1), 1, 1); /* Now writing trailer */
  fprintf( fpo, "%16.9E\n", Mat[1][1] );
}



void WrtOP4Bin( double **Mat, int Ni, int Nj, char *mname, FILE *fpo )
{

  char  matnm[10];		/* get re-init each time */
  int i,j,k,i2,i3, nwrt2, form,type, minr,maxr,nwrt, Dum;
  double eps;
  kfloat  SDum;	

/*                  Discovery: Aug. 10, 1995
    On DEC Alpha, the dummy-value surrounding each FORTRAN Write command
is significant !  It is an int = ( the number of bytes that is output for
that Write command).  At of this time, an int & float are 4bytes each,
double is 8 bytes, and 8-char OP4 matrix name is 8 bytes.   Example:
 an OP4 main-hdr with 4 ints & matrix name would need 16+8 = 24 bytes;
the dummy-val for the main-hdr would be integer 24. For each col,
dummy-val = 4*3 + nwrt*8, where nwrt is # of double values written.  */


  if (Ni != Nj)
    form = 2;
  else
    form = 1; 

 /* Must make C matrix-name match FORTRAN's, where the 8-char string is
    followed by spaces, not null-char.  So we insert spaces at null-char
    and beyond.  Matrix-name occupies position 0 to strlen(matnm)-1, so
    null-char is at postion strlen(matnm). */
  strcpy( matnm, mname );	
  for( i = (strlen(matnm)); i < 9; i++ ) 
    matnm[ i ] = ' ';

  eps = 100*(DBL_EPSILON);
  type = 2;			/* HP double-precision */
  if (Ni != Nj)
    form = 2;
  else
    form = 1;

  Dum = 24;
  fwrite( &Dum, sizeof(int), 1, fpo); /* Main Header */
  fwrite( &Nj, sizeof(int), 1, fpo);  fwrite( &Ni, sizeof(int), 1, fpo);
  fwrite( &form, sizeof(int), 1, fpo);  fwrite( &type, sizeof(int), 1, fpo);
  fwrite( matnm, sizeof(char), 8, fpo); 
  fwrite( &Dum, sizeof(int), 1, fpo);

  j=1;
 XX:
  while (j <= Nj)
  {
    for( i=1; i<=Ni; i++)
      if ( fabs(Mat[i][j]) > eps )	/* Not Equal 0  */
	{
	  minr = i;
	  for( i2=Ni; i2>=1; i2--)
	    if ( fabs(Mat[i2][j]) > eps )
	      { maxr = i2;
		nwrt = maxr - minr + 1;	/* # of values written */
		nwrt2 = 2*nwrt;	/* HP double-precision */
		Dum = 12 + 8*nwrt;
		fwrite( &Dum, sizeof(int), 1, fpo);
		fwrite( &j, sizeof(int), 1, fpo);  
		fwrite( &minr, sizeof(int), 1, fpo);
		fwrite( &nwrt2, sizeof(int), 1, fpo);  
		for( i3=minr; i3<=maxr; i3++)
		  fwrite( &(Mat[i3][j]), sizeof(double), 1, fpo);  
		fwrite( &Dum, sizeof(int), 1, fpo);
		j++;
		goto XX;  /* Skip to next column */
	      }
	}
    j++;
    goto XX;  /* Col was Null, skip to next */

  }	/* end while */

  /* Now writing single-prec. trailer */
  i = Nj + 1;  j = 1;  SDum = Mat[ 1 ][ 1 ]; /* wrt trailer val as float */
  Dum = 16;
  fwrite( &Dum, sizeof(int), 1, fpo);   fwrite( &i, sizeof(int), 1, fpo);
  fwrite( &j, sizeof(int), 1, fpo);   fwrite( &j, sizeof(int), 1, fpo);
  fwrite( &SDum, sizeof(float), 1, fpo); fwrite( &Dum, sizeof(int), 1, fpo);
}


	/* ---------- Setting up files for I/O ---------- */

void SetUp( char *InFn, char *OuFn, short Ib, short Ob, FILE **Fi, FILE **Fo)
{
				/* Ib & Ob no longer needed  */
  if (( *Fi = fopen( InFn, "r")) == NULL)
    Oops1( 5 );
  if (( *Fo=fopen( OuFn, "w"  )) == NULL )
    Oops1( 7 );    
}
void CloseDown( char *OuFn, short Ib, short Ob, FILE **Fi, FILE **Fo)
{
  short i;
				/* Ib & Ob no longer needed  */
  if ( (i=fclose( *Fi )) != 0 )
    Oops1(11);
  if ( (i=fclose( *Fo )) != 0 )
      Oops1(12);
}



void Oops1( int n )
{
  printf("\n OP4 I/O Problem: \n\n");
  switch ( n )
    {
    case 5:
      printf("Unable to open file to determine matrix-size.\n");    
      break;
    case 6:
      printf("Improper OP4BCD data or EOF reached in RdOP4Hdr.\n");
      break;
    case 7:
      printf("Unable to open file to output data in  Operate.\n");    
      break;
    case 11:
      printf("Problem with fclose( FnI ) !\n");
      break;
    case 12:
      printf("Problem with fclose( FnO ) !\n");
      break;
    case 14:
      printf("In an OP4Bin input, Type did NOT equal 1 or 2 !\n");
      printf("This version of op4.c can only handle Type 2 or 1.\n");
      break;
    case 15:
      printf("EOF reached ! \n");
      break;
    case 16:
      printf(" Unable to get matrix-name in RdOP4Hdr (BinOpt) !\n" ); 
      break;
    case 17:
      printf(" Error in reading the OP4Bin Trailer value !\n" ); 
      printf(" ( Neither 16 or 20 bytes for Trailer )\n" ); 
      break;
    case 18:
      printf(" Invalid matrix-header in RdOP4Hdr (BinOpt) !\n" ); 
      printf(" ( Neither 24 or 32 bytes for Header )\n" ); 
      break;
    default:
      printf("No error message for error code #%d !\n", n);
    }
  exit(1);	/* file ptrs & memory released */
}
