
/* Matlab MEX-file to implement  '  saveop4( fn, a,b,c, ... ) '
   in Matlab 4.2c on DEC Alpha.  See saveop4.m for usage instructions.  */

                  /* >>>>>>> saveop4.c <<<<<<< */

#define  __STDC__       
#define mxMAXNAM        20	/* from matrix.h */
#include <math.h>
#include <stdlib.h>
#include <stdio.h>
#include "nrutil.c"
#include "op4.c"
#include "mex.h"
#include "mat.h" 

void saveop4( int Opt, char *Mn, double *A, FILE *FnO, int Nr, int Nc ); 
void Oops( int n );
void VectortoMatrix( double **Mat, double *Vec, int Nr, int Nc);

static
		/* Computational Routine */
void saveop4( int Opt, char *Mn, double *A, FILE *FnO, int Nr, int Nc )
{
  double **Data;
  short Ou;

  Data = dmatrix( 1, (Nr+1), 1, (Nc+1) );
  VectortoMatrix( Data, A, Nr, Nc );
  WrtOP4Data( Opt, Ou, FnO, Nr, Nc, Mn, Data );
  free_dmatrix( Data, 1, (Nr+1), 1, (Nc+1) );

#ifdef DEBUG
  printf(">  Inside computation routine  \n" );
  printf(">  Opt, Nr, Nc  = %d, %d, %d \n", Opt, Nr, Nc );
  printf(">  1st term of vector A = %f \n", A[0] );
#endif
}


		/* GateWay Routine */
void mexFunction( int nlhs, Matrix *plhs[], int nrhs, Matrix *prhs[] )
{
	double	*A;
	int Nr, Nc, i, j, Nskip,  Opt, Nmat;
	short Tp, nl;
	char  Mna[10], Fname[80], *Mname, ext[5], dum[ mxMAXNAM ];
	FILE *Fo;
	float  Span;
	clock_t  StaT, EndT;

	StaT = clock();
	printf("\n>>>>>  Entering saveop4 ( v 1.0 ):\n" );

	if ( (nrhs < 2) )    Oops( 21 );
	if ( !mxIsString( prhs[0] )  )     Oops( 22 );
	mxGetString( prhs[ 0 ],  Fname,  80 );
	nl = strlen( Fname );	/* Using extension to get Opt */
	for( i=0, j=3; i < 3; i++, j-- )
	  ext[ i ] = Fname[ nl-j ];	/* extension = last 3 chars of infn */
	ext[ 3 ] = '\0';
	if ( (strcmp( ext, "bin")) == 0 )
	  Opt = 1;      /*  OP4Bin */
	else if ( (strcmp( ext, "bcd")) == 0 )
	  Opt = 0;  /*  OP4Bcd */
	else
	    Oops( 32 ); 
	Nmat = nrhs - 1;	/* # of matrices to write out */

	if (( Fo = fopen( Fname, "w")) == NULL)	    Oops( 31 );

	for ( i=1; i <= Nmat; i++ ) 
	  {
	    if ( !mxIsNumeric( prhs[ i ] ) )   Oops( 23 );
	    if ( mxIsComplex( prhs[ i ] )  )  Oops( 24 );
	    if ( !mxIsFull( prhs[ i ]   )  )  Oops( 25 );
	    if ( !mxIsDouble( prhs[ i ] )  )  Oops( 26 );
	    Nr = mxGetM( prhs[ i ] );  	Nc = mxGetN( prhs[ i ] );
	    Mname = dum;    Mname = mxGetName( prhs[ i ] );
	    A = mxGetPr( prhs[ i ] );
	     
#ifdef DEBUG
	    printf(">  %d matrices to write; Opt = %d  \n", Nmat, Opt);
	    printf(">  filename = %s; Nr & Nc = %d & %d\n", Fname, Nr,Nc );
	    printf(">  Original matrix-name = %s  \n",Mname);
	    printf(">  Modif matrix-name = %s (%d char)\n",Mna,strlen(Mna));
#endif
	    if ( strlen(Mname) > 8 )
	      {
		for( i=0; i<8; i++ )
		  Mna[ i ] = Mname[ i ];
		Mna[ 8 ] = '\0';	/* chop down to 8 chars only */
	      }
	    else
	      strcpy( Mna, Mname );

	    /*    printf(">  Calling computation routine  \n" ); */
	    saveop4(  Opt, Mna, A, Fo,  Nr, Nc );
	    if (Opt == 1)  
	      printf("> Just wrote OP4Bin matrix %s (%d by %d)\n",Mna,Nr,Nc);
	    else
	      printf("> Just wrote OP4Bcd matrix %s (%d by %d)\n",Mna,Nr,Nc);
	  }

	if ( (fclose( Fo )) != 0 )
	  Oops( 35 );
	EndT = clock();
	Span =  ( (float)(EndT-StaT) )/CLOCKS_PER_SEC;  
	printf(">>>>>  Exiting saveop4. (%8.3f cps)\n\n", Span);
	return;
}


void Oops( int n )
{
char t1[] = "MUST have at least 2 right-hand-side arguments !\n";
char t2[] = "1st right-hand-side argument must be text! (with filename).\n";

  printf("\n\n < saveop4> failed because of the following error: \n\n");
  switch ( n )
    {
    case 1:
      break;
    case 21 :
      mexErrMsgTxt( t1 );
      break;
    case 22 :
      mexErrMsgTxt( t2 );
      break;
    case 23 :
      mexErrMsgTxt("ERROR: Output matrix is NOT numeric !\n" );
      break;
    case 24 :
      mexErrMsgTxt("ERROR: Output matrix is complex !\n" );
      break;
    case 25 :
      mexErrMsgTxt("ERROR: Output matrix is NOT Full !\n" );
      break;
    case 26 :
      mexErrMsgTxt("ERROR: Output matrix is NOT Double-Precision !\n" );
      break;
    case 31:
      mexErrMsgTxt("Unable to open file for OP4 output.\n");    
      break;
    case 32:
      mexErrMsgTxt("Invalid filename extension used !\n");
      break;
    case 35:
      mexErrMsgTxt( "Problem with closing output FILE *Fo !\n" );
      break;
    default:
      printf("Error code = %d !", n);
      mexErrMsgTxt(" No error message for specified error code.\n");
    }
  return;	/* exit(1) -> file ptrs & memory released */
}

void VectortoMatrix( double **Mat, double *Vec, int Nr, int Nc)
{
  int i,j,k;

  for( j=1, k=0; j <= Nc; j++ )
    for( i=1; i <= Nr; i++ )
      Mat[ i ][ j ] = Vec[ k++ ];
}

