function [a,gotit] = sload(fname, var)
%SLOAD	Selective load function.  
%	A = sload('foo','var') will read in the matlab variable var from file 
%	foo.mat and store the result in A.

%		S.N. Bangert 4-1-91
%       Copyright (c) 1985-1991 by the MathWorks, Inc.


% open file read only
nl = length(fname);
if nl <= 4, 
	fname = [fname '.mat']; 
elseif ~strcmp('.mat',fname((nl-3):nl)) 
	fname = [fname '.mat'];
end
fid=fopen(fname,'r');
if ~fid, disp(['Unable to open file ' fname '.']), return, end

gotit = 0;

% read through mat file 
while 1
	% read type, m, n, imag, namelen
	[d,c] = fread(fid,5,'int32');
	if c ~= 5, break, end

	type = d(1);  m = d(2);  n = d(3);  imag = d(4);  namelen = d(5);
	mn = m*n;
	t = rem(type,10);	% 0 - normal, 1 - text, 2 - sparse
	if imag, complex = 'Yes'; else  complex = 'No'; end

	% run some tests on m, n, imag, t, and namelen to verify they have 
	% reasonable values
	if m < 0  |  n < 0  |  mn < 0, break, end
	if imag ~= 0  &  imag ~= 1, break, end
	if t < 0  |  t > 2, break, end
	if namelen < 1  |  namelen > 20, break, end

	% read name and reformat
	[name,c]=fread(fid,namelen,'uchar');
	if c ~= namelen, break, end
	name = setstr(name(1:namelen-1)');

	if strcmp(var,name)

		% found desired variable so read it in
		[x,c] = fread(fid,mn,'double');
		if c ~= mn, break, end

		if imag
			[y,c] = fread(fid, mn, 'double');
			if c ~= mn, break, end
			x = x + sqrt(-1)*y;
		end

		gotit = 1;
		break;
	else

		% skip data
		if fseek(fid,mn*8,'cof'), break, end

		if imag
			if fseek(fid,mn*8,'cof'), break, end
		end
	
	end

end

fclose(fid);

if gotit

	% resize to original size
	a(m,n)=0;
	a(:)=x;

	% convert to sparse if needed
	if t == 2
		if imag
			a = sparse(a(:,1),a(:,2),a(:,3),a(:,4));
		else
			a = sparse(a(:,1),a(:,2),a(:,3));
		end
	end
	% convert to string if needed
	if t == 1
		a = setstr(a);
	end
else

	% could not find desired variable
	a = [];
end
