function [newtree, child] = f(tree, node, which, data)
% AddChild	Add a child to a node
%
% newtree = AddChild(tree, node, which, data)
% Inputs:
%   <tree> = tree matrix;
%   <node> = row index of node that will add the child;
%   <which> = integer of which child to add; must be in [1, Nchildren];
%   <data> = (optional) row-vector of data for the child node; defaults to [].
% Outputs:
%   <newtree> = the new tree matrix with the child added;
%   <child> = (optional) row index of the added child node.  0 if the child
%		node already existed.
%
% JKS
% $Id$

if nargin < 3,
  error('Usage: [newtree, child] = AddChild(tree, node, which, data)')
end
if nargin < 4, data = []; end

[M, N] = size(tree);
Nch = tree(1,1);
Ndata = N - Nch - 1;

which = fix(which);
if (which < 1) | (which > Nch),
  errmsg = sprintf('Invalid child (%.0f); <which> must be in [1, %.0f])',...
			which, Nch);
  error(errmsg)
end
idx = which + 1;			% Column index of child #which
curr = tree(node, idx);			% Current value of child index.
if (curr > 0),				% Child already exists, return 0.
  newtree = tree;
  if nargout > 1,
    child = 0;
  end
else					% Add child to <newtree>
  newtree = zeros(M+1, N);
  newtree(1:M, 1:N) = tree;
  newtree(node, idx) = M+1;
  newtree(M+1, 1:(Nch+1)) = [node, zeros(1, Nch)];
  if ~isempty(data),
    data = data(:)';			% Force row vector.
    L = min([length(data), Ndata]);
    newtree(M+1, (Nch+2):(Nch+L+1)) = data(1:L);
  end
  if nargout > 1,
    child = M+1;
  end
end
return