function f(tree, nodefun, branchfun, clr, style, rootpos)
% DrawTree	Recursively draw a tree in a figure/plot window
%
% DrawTree(tree, nodefun, branchfun, clr, style, rootpos)
% Inputs:
%   <tree> = tree matrix
%   <nodefun> = text display function for labeling a node.  Defaults to
%		'int2str(node)', which is just the row index of the node.
%		See the hints below for more ways to use this argument.
%   <branchfun> = text display function for labeling a branch between a node
%		  and the node's children.  Defaults to	'', which is means
%		  no label.  See the hints below for more ways to use this
%                 argument.
%   <clr> = color for line drawing.  Defaults to 'y' (yellow).
%   <style> = line style for drawing.  Defaults to '-'.
%   <rootpos> = [x0, y0] position of root node; defaults to [0 0].  This can
%		be useful if you want to highlight a subtree by calling
%		DrawTree successively.
% Output: NONE (nifty plot, though)
%
% Hints on usage:
%    Suppose <tree> contains node data such that data(1) is a text label (like
% 'A', 'B', etc.).  Then you can use <nodefun> = 'setstr(data(1))', and
% DrawTree will display data(1) at the node.  If you'd like to see the node
% number (row index) as well, you could use
%           <nodefun> = ['[int2str(node), '': '', setstr(data(1))]'];
% to get nodes labeled '23: A', '5: X', etc.
%    Suppose you have a binary tree, and data(1) is the node label,
% data(2) is the branch cost for going from the node to child(1), and data(3)
% is the branch cost for going from the node to child(2).  Then you could
% use
%           <branchfun> = 'num2str(data(ch+1))';
% to get branches labeled correctly (ch is a built-in variable used by
% DrawTree).
%    If you just want to see the node-child relationship, use
%           <branchfun> = ['[int2str(node), ''-'', int2str(child)]'];
% This will print branch labels like '2-5' for the branch from node 2 to
% node 5.
%    As an example, after you build a tree, try drawing it using
%           DrawTree(tree, 'int2str(node)', ...
%		['[int2str(node), ''-'', int2str(child)]']);
% Note that if you have pruned some parts of the tree, some node numbers
% may appear to be missing.
%
% JKS
% $Id$

if nargin < 2, nodefun = 'int2str(node)'; end
if nargin < 3, branchfun = ''; end
if nargin < 4, clr = 'y'; end
if isempty(clr), clr = 'y'; end
if nargin < 5, style = '-'; end
if isempty(style), style = '-'; end
if nargin < 6, rootpos = [0 0]; end

maxdepth = MaxTreeDepth(tree);
drawtree_rec(tree, 1, nodefun, branchfun, 1, maxdepth, rootpos, clr, style);
v = axis;				% Adjust axes to center the drawing
vv = max(abs(v(1:2)));
axis([-vv, vv, v(3:4)])
axis off
