function children = f(tree, node, which)
% GetChildren	Move from node to one of its children.
%
% children = GetChildren(tree, node, which)
% Inputs:
%   <tree> = tree matrix;
%   <node> = row index of node from which to move;
%   <which> = (optional) vector of which children to visit; values in <which>
%             must be in [1, Nchildren].   If omitted, all children are
%	      checked.
% Output:
%   <children> = vector containing the row indices of the desired child
%		 node(s).  0 wherever such child did not exist.
%
% JKS
% $Id$

if nargin < 2,
  error('Usage: children = GetChildren(tree, node, which)')
end
Nch = tree(1,1);
if nargin < 3,  which = 1:Nch;  end
if isempty(which),
  children = [];
  return
end

if any(which < 1) | any(which > Nch),
  error(sprintf('All values of <which> must be in [1, %.0f]', Nch))
end
children = tree(node, which+1);
