function newtree = f(tree, node, graft)
% GraftTrees	Graft two trees together into a new tree
%
% newtree = GraftTrees(tree, node, graft)
% Inputs:
%  <tree> = tree matrix to receive graft;
%  <node> = row index of node at which to attach the graft;
%  <graft> = tree matrix of grafting tree; its root node will become
%		<node> (so any data at <node> will be overwritten).
% Output:
%  <newtree> = the new tree matrix.
%
% Note: It's OK if <tree> and <graft> have different values of Nchildren
% and Ndata.  This function will automatically use the largest value.
%
% JKS
% $Id$

if nargin < 3,
  error('Usage: newtree = GraftTrees(tree, node, graft)');
end

[M1, N1] = size(tree);  Nch1 = tree(1,1);  Ndata1 = N1 - Nch1 - 1;
[M2, N2] = size(graft); Nch2 = graft(1,1); Ndata2 = N2 - Nch2 - 1;

M = M1+M2;					% Size of the new tree
N = max([N1, N2]);
Nch = max([Nch1, Nch2]);
Ndata = max([Ndata1, Ndata2]);

newtree = zeros(M, N);

newtree(1:M1, 1:(Nch1+1)) = tree(:, 1:(Nch1+1));		% <tree> idxs
newtree(1:M1, (Nch+2):(Nch+Ndata1+1)) = tree(:, (Nch1+2):N1);	% <tree> data
newtree(1,1) = Nch;

i = M1+(1:M2);
f = find(graft(:,1:(Nch2+1)) ~= 0);
graft(f) = graft(f) + M1;
newtree(i, 1:(Nch2+1)) = graft(:, 1:(Nch2+1));			% <graft> idxs
newtree(i, (Nch+2):(Nch+Ndata2+1)) = graft(:, (Nch2+2):N2);	% <graft> data

parent = GetParent(newtree, node);		% Find parent of <graft>
kid = GetChildren(newtree, parent);		% <graft> is <which> child of
which = find(kid == node);			% <node>.
newtree(parent, which+1) = M1+1;
newtree(M1+1, 1) = parent;
