function a = f(tree, node, which)
% HasChildren	Indicate whether or not current node has children.
%
% a = HasChildren(tree, node, which)
% Inputs:
%   <tree> = tree matrix;
%   <node> =  index of node to check;
%   <which> = (optional) vector of children to examine.  If omitted,
%		checks all children.
% Output:
%   <a> = binary vector of test results: a(j) = 0 if child(which(j)) does
%         not exist, 1 otherwise.
%
% JKS
% $Id$

if nargin < 2,
  error('Usage: a = HasChildren(tree, node, which)')
end
Nch = tree(1,1);
if nargin < 3, which = 1:Nch; end
if isempty(which),
  a = [];
  return
end


if any(which < 1) | any(which > Nch),
  error(sprintf('All values of <which> must be in [1, %.0f]', Nch))
end
idx = which + 1;
a = (tree(node, idx) > 0);
