function depth = f(tree, node, dmax, dcurr)
% MaxTreeDepth	Get maximum depth of a tree
%
% depth = MaxTreeDepth(tree)
% Inputs:
%   <tree> = tree matrix.
% Output:
%   <depth> = integer indicating the maximum depth of a tree.  The root is
%		at depth 1; the immediate children of the root are at depth 2;
%		grandchildren of the root are at depth 3, et cetera.
%
% JKS
% $Id$

if nargin < 1,
  error('Usage: depth = MaxTreeDepth(tree)')
end
if nargin < 2,
  node = 1;
  dmax = 1;			% Deepest we've gone so far during recursion
  dcurr = 1;			% Current depth
end
if (node > 0),
  Nch = tree(1,1);
  dmax = max([dmax, dcurr]);
  for j = 1:Nch,
    child = GetChildren(tree, node, j);
    dtemp = MaxTreeDepth(tree, child, dmax, dcurr+1);
    dmax = max([dmax, dtemp]);
  end
end
depth = dmax;