function [tree, root] = f(Nchildren, Ndata)
% NewTree	Make a structure representing the root of a binary tree.
%
% [tree, root] = NewTree(Nchildren, Ndata)
% Inputs:
%  <Nchildren> = maximum number of children a node can have.  Defaults to 2
%		 (a binary tree).
%  <Ndata> = Maximum number of data elements associated with a node.  Defaults
%		 to 0 (no data).
% Outputs:
%  <tree> = a row vector representing the initial (empty) tree.  For a
%	    detailed description of how a tree matrix is organized and
%	    managed, "type" this function (>> type NewTree).
%  <root> = MATLAB index of the root of the tree; always 1.
%
% JKS
% $Id$

% HOW A TREE MATRIX IS ORGANIZED AND MANAGED
%      Let Nchildren and Ndata be as described above, and let tree refer to
% a tree with parameters Nchildren & Ndata.  Basically, each row of tree
% represents a node.  A typical row/node has the form:
%
% tree(node,:) =  [parent child(1) .. child(Nchildren) data(1) .. data(Ndata)],
%
% where node = row index of the node;
%       parent = row index of the parent of this node;
%       child(j) = row index of the j-th child of this node, j = 1, ...,
%			 Nchildren;
%       data(j) = j-th data element associated with this node.
% If child(j) = 0, that means there is no j-th child.  Hence, if child(j) = 0
% for all j = 1, ..., Nchildren, then this node is a leaf.
%      The root node is always the first row of the matrix.  For the root node
% only, the form is
%
% tree(1,:) =  [Nchildren child(1) .. child(Nchildren) data(1) .. data(Ndata)],
%
% where Nchildren has been stored in the (1,1) element of the tree matrix.
% Storing Nchildren here means the entire tree can be stored in one matrix,
% which eliminates the tedium of always carrying Nchildren around as a separate
% variable.
%      Child nodes can be added easily enough by adding a row to the tree
% matrix and setting the appropriate entries in the matrix to link a parent
% and child.  When a node is deleted, its parent node zeros the child(j)
% index, and the node sets its parent index to zero.  So the row is not
% actually removed from the tree matrix.  Since a node is just a row in the
% matrix, actually deleting a row from the matrix will upset all the other
% row indices, and all outside references to nodes will be ruined, too.

if nargin < 1,  Nchildren = 2; end
if nargin < 2,  Ndata = 0; end
tree = [Nchildren, zeros(1, Nchildren), zeros(1, Ndata)];
if nargout > 1, root = 1; end