function [newtree, parent] = f(tree, node)
% Prune		Remove an entire subtree, including the given node.
%
% [newtree, parent] = Prune(tree, node)
% Inputs:
%   <tree> = tree matrix;
%   <node> = row index of node at which to prune the tree.
% Output:
%   <newtree> = the new tree matrix;
%   <parent> = the parent node of the pruned subtree.
%
% Note: If you prune a tree at its root node, you get just the root node.
%
% JKS
% $Id$

if nargin < 2,
  error('Usage: [newtree, parent] = Prune(tree, node)')
end

Nch = tree(1,1);
if (node == 1),				% Treat root node specially.
  newtree = tree(1,:);
  newtree(1,2:(Nch+1)) = zeros(1, Nch);
  parent = 1;
else
  newtree = tree;
  parent = tree(node, 1);
  j = find(newtree(parent, 2:(Nch+1)) == node) + 1;
  newtree(parent, j) = 0;
  newtree(node, parent) = 0;
end
