function newtree = f(tree, node, which)
% PruneChild	Prune child subtree or subtrees from a node.
%
% newtree = PruneChild(tree, node, which)
% Inputs:
%   <tree> = tree matrix;
%   <node> = row index of node that will lose child subtree(s);
%   <which> = which child nodes to prune; must be in [1, Nchildren].
% Output:
%   <newtree> = the new tree matrix.
%
% JKS
% $Id$

if nargin < 3,
  error('Usage: newtree = PruneChild(tree, node, which)')
end

Nch = tree(1,1);
if any(which < 1) | any(which > Nch),
  error(sprintf('All values of <which> must be in [1, %.0f]', Nch))
end

newtree = tree;
idx = which + 1;
toprune = newtree(node, idx);	% Row indices of children to prune
f = find(toprune > 0);		% Don't prune non-existent children
toprune = toprune(f);
newtree(toprune, 1) =zeros(length(toprune), 1);
newtree(node, idx) = zeros(1, length(idx));
