function subtree = f(src, src_node, sub, sub_node)
% Subtree	Recursively extract subtree from a tree.
%
% subtree = Subtree(tree, node)
% Inputs:
%   <tree> = tree matrix;
%   <node> = row index of node that will be the root node of the subtree.
% Output:
%   <subtree> = the subtree tree matrix.
%
% WARNING: The row indices to nodes in <subtree> may not be identical to
% the row indicees in <tree>.  It is always important to remember not only
% which NODE you're working with, but also which TREE.  For example,
% >> [tree, A] = NewTree(2, 1);
% >> tree = TreeNodeData(tree, A, 50);
% >> [tree, B] = AddChild(tree, A, 1, 25);
% >> [tree, C] = AddChild(tree, A, 2, 100);
% >> subtree = Subtree(tree, C);
% >> [subtree, D] = AddChild(subtree, C, 1, 10);% Error because <C> still
%						% refers to a node in <tree>,
%						% not in <subtree>.
%
% JKS
% $Id: Subtree.m,v 1.2 1996/02/21 02:26:22 su Exp $

if nargin < 2,
  error('Usage: subtree = Subtree(tree, node)')
end
Nch = src(1,1);
Ndata = size(src,2) - Nch - 1;
if nargin < 4,					% First call; initialize new
  data = TreeNodeData(src, src_node);		% tree structure and its root.
  sub = NewTree(Nch, Ndata);			% Set index to its root.
  sub_node = 1;
end

data = TreeNodeData(src, src_node);		% Get data for this node
subtree = TreeNodeData(sub, sub_node, data);
for k = 1:Nch,
  child = GetChildren(src, src_node, k);	% Look for k-th child
  if (child),				
    [subtree, sub_child] = AddChild(subtree, sub_node, k);
    subtree = Subtree(src, child, subtree, sub_child);
  end
end
