% TreeDemo	Script that shows how these tree routines can be used.
%
% JKS
% $Id$

clc
pause on
echo on

% Hello.  This is a quick demo of some m-files available for manipulating
% trees in MATLAB.


% First, let's make a simple tree.  We use NewTree() to initialize a tree.
% Here, we make a tree in which each node may have up to 3 children and 
% 5 data elements.
%
% We will initialize the root node with the label 'W' (its first datum)
% and additional data 2+j (its second datum).

j = sqrt(-1);
[tree, W] = NewTree(3, 5);			% <W> is the root.
tree = TreeNodeData(tree, W, [real('W'), 2+j]);
pause

% Next, let's add some children to the root node.

[tree, X] = AddChild(tree, W, 1, [real('X'), 100]);
[tree, Y] = AddChild(tree, W, 2, [real('Y'), -5]);
[tree, Z] = AddChild(tree, W, 3, [real('Z'), 36]);
pause

% Let's draw the tree to see how it looks.
clg
DrawTree(tree, ['[setstr(data(1)), '' ('', num2str(data(2)), '')'']'])
pause
clc
% Now let's examine the data at different nodes with TreeNodeData().
Xdata = TreeNodeData(tree, X)
Zdata = TreeNodeData(tree, Z)
pause

% We can change data with TreeNodeData(), too.  Just supply the new data
% as an additional argument.
newXdata = Xdata;
newXdata(3:5) = [-2, j, 86];
tree = TreeNodeData(tree, X, newXdata);

checkXdata = TreeNodeData(tree, X)

pause
clc
% Let's add some more nodes and see some additional tree-management
% functions.

[tree, B] = AddChild(tree, X, 2, [real('B'), 29, 53*i]);
[tree, A] = AddChild(tree, B, 1, [real('A'), -16]);
[tree, C] = AddChild(tree, X, 3, [real('C'), 2001]);
[tree, M] = AddChild(tree, Y, 1, [real('M'), 5]);
[tree, N] = AddChild(tree, Y, 2, [real('Y'), 12.5, 8, 9]);
[tree, P] = AddChild(tree, N, 2, [real('P'), 1]);
[tree, Q] = AddChild(tree, N, 3, [real('Q'), 2]);
[tree, E] = AddChild(tree, Z, 1, [real('E'), pi]);
[tree, F] = AddChild(tree, Z, 3, [real('F'), -18, 20.6, -3, 1]);
[tree, G] = AddChild(tree, F, 1, [real('G'), 2]);
[tree, H] = AddChild(tree, F, 2, [real('H'), 3]);
[tree, J] = AddChild(tree, F, 3, [real('J'), 20]);


% Now the tree looks like:
pause
clg
DrawTree(tree, ['[setstr(data(1)), '' ('', num2str(data(2)), '')'']'])
pause
clc
% We can prune away parts of the tree.  For example, let's cut off node 'N'
% and its children.

tree = Prune(tree, N);

clg
DrawTree(tree, ['[setstr(data(1)), '' ('', num2str(data(2)), '')'']'])
pause

% We can also copy subtrees from the tree.  Here we copy the subtree at 'Z'.
Ztree = Subtree(tree, Z);

clg
subplot(211)
DrawTree(tree, ['[setstr(data(1)), '' ('', num2str(data(2)), '')'']'])
subplot(212)
DrawTree(Ztree, ['[setstr(data(1)), '' ('', num2str(data(2)), '')'']'])
pause
clc
% It's also possible to graft trees together.  Let's attach <Ztree> onto
% the main tree as a child of node 'M'.

[tree, temp] = AddChild(tree, M, 2);
tree = GraftTrees(tree, temp, Ztree);

clg
subplot(111)
DrawTree(tree, ['[setstr(data(1)), '' ('', num2str(data(2)), '')'']'])
pause
clc
% We can even combine trees of different parameters.  For example, we can
% graft a binary tree with a ternary tree, etc.  Here's an example.

bintree = NewTree(2,1);				% Make a little binary tree
bintree = TreeNodeData(bintree, 1, 'a');
bintree = AddChild(bintree, 1, 1, 'b');
[bintree, t] = AddChild(bintree, 1, 2, 'c');
bintree = AddChild(bintree, t, 1, 'd');
bintree = AddChild(bintree, t, 2, 'e');

clg
DrawTree(bintree, 'setstr(data)');
pause

[tree, temp] = AddChild(tree, X, 1);
largetree = GraftTrees(tree, temp, bintree);	% Combine the trees

clg
DrawTree(largetree, ['[setstr(data(1)), '' ('', num2str(data(2)), '')'']'])
pause
clc
% Finally, we can use additional data elements at a node to store quantities
% associated with its branches.  Earlier in the demo, we added some additional
% data to a few nodes.  We can display them, too.

clg
DrawTree(largetree, ['[setstr(data(1)), '' ('', num2str(data(2)), '')'']'], ...
		'num2str(data(ch+2))');
pause

% That's all.  Hope this demo has provided enough to get you started using
% trees in MATLAB.  The tree functions available are:
%
% AddChild        GetParent       IsLeaf          Subtree
% DrawTree        GraftTrees      MaxTreeDepth    TreeDemo
% GetChildren     HasChildren     NewTree         TreeNodeData
% GetNchildren    IncrNchildren   Prune           TreeNodeDepth
% GetNdata        IncrNdata       PruneChildren
%

echo off