function output = TreeNodeData(tree, nodes, newdata)
% TreeNodeData	Read data from or write data to a nodes in a tree
%
% For reading:
%   data = TreeNodeData(tree, nodes)
%   Inputs:
%     <tree> = tree matrix;
%     <nodes> = row indices of nodes from which to get data.
%   Output:
%     <data> = data at these nodes.
%
% For writing:
%   newtree = TreeNodeData(tree, nodes, data)
%   Inputs:
%     <tree> = tree matrix;
%     <nodes> = row indices of nodes to overwrite;
%     <data> = data to write to these nodes.  If <data> is a row vector and
%              <nodes> is a vector, then each node in <nodes> will be
%	       overwritten with the same contents of <data>.
%   Output:
%     <newtree> = new tree matrix with data replaced.
%
% JKS
% $Id$

[M, N] = size(tree);
Nch = tree(1,1);
Ndata = N - Nch - 1;
D = length(nodes);
if nargin == 2,			% Read data from tree
  output = zeros(D, Ndata);
  for i = 1:D
    output(i,:) = tree(nodes(i), (Nch+2):N);
  end
elseif nargin == 3,		% Writing
  if ~isempty(newdata) & ~isempty(nodes),
    [K, L] = size(newdata);
    L = min([Ndata, L]);	% Clip <newdata> to fit tree, if needed.
    newdata = newdata(:,1:L);
    if (K == 1) & (D > 1),	% <newdata> is a row vector, <nodes> is a vec.
      newdata = ones(D,1)*newdata;
      K = D;
    end
    if (K ~= D)
      error('Mismatch of sizes between <nodes> and <newdata>.');
    end
    for k = 1:K,
      tree(nodes(k), (Nch+2):(Nch+L+1)) = newdata(k, :);
    end
    output = tree;
  else				% <newdata> or <nodes> is empty, so do nothing.
    output = tree;
  end
else
  errmsg = sprintf('Usage: data = TreeNodeData(tree, nodes) OR\n       newtree = TreeNodeData(tree, nodes, data)');
  error(errmsg)
end
