function fannoplt(MNmin,MNmax,Npts,Gamma);
%FANNOPLT    Normalize and plot output from function FANNO.
%	     FANNOPLT() uses function FANNO to compute isentropic and normal
%	     shock flow properties at 250 points between Mach 0.01 and Mach 10.
%	     Each property is then scaled for the range 0.0 to 1.0 and plotted.
%	     Individual curves are labeled with a column number corresponding
%	     to the FANNO output.
%
%	     FANNOPLT(MNmin,MNmax) plots results for a range of user specified
%	     Mach numbers where: MNmin is the minimum Mach No.; and MNmax is
%	     the maximum Mach No.
%
%	     FANNOPLT(MNmin,MNmax,Npts) in addition to allowing user specified
%	     Mach No., allows user to specify number of points per curve.
%
%	     FANNOPLT(MNmin,MNmax,Npts,Gamma) in addition to allowing user
%	     specified Mach No. and number of points per curve, allows user to
%	     specify ratio of specific heats used for calculation of flow
%	     properties.
%
%	     See also, FANNO and FANNOERR.

% Compressible Flow Toolbox, Version 1.1, 23-FEB-96
% Written By: Kevin J. Melcher - 12/94
%             NASA Lewis Research Center, Cleveland, Ohio
%             Cleveland State Univiersity, Cleveland, Ohio

%Check input args
 if nargin==2,
   error('INPUT ARG NOT DEFINED: ARG2 must be specified if ARG1 is specified.');
 end;
 if nargin<4,
   disp('  Note: Using Default. Gamma=1.4');
   Gamma=1.4;
 elseif Gamma<=0,
   disp('  Note: Using Default. Gamma=1.4');
   Gamma=1.4;
 end
 if nargin<3,
   Npts=250;
 end;
 if nargin<1,
   MNmin=0.05;
   MNmax=10;
 end;

%Get table values as a function of Mach Number
%Note: Mn=1 & Mn=sqrt(2) are Points of Interest
 M0(:)=[(MNmax-MNmin)*(0:Npts-3)/(Npts-3)+MNmin 1 sqrt(2)];
 M0=sort(M0);
 FM0=fanno(1,M0,Gamma);
 [n0,m0]=size(FM0);

%Generate Plot of Fanno Functions
 figure(1); clf;
  k=1:m0; m=length(k);
  Fmin=min(FM0(:,k)); Fmax=max(FM0(:,k));
  Fnorm=(FM0(:,k)-ones(n0,1)*Fmin)./(ones(n0,1)*(Fmax-Fmin));
 plot(M0*ones(1,m),Fnorm);
  xlabel('Mach No.');
  ylabel('Normalized Parameters');
  title('FANNO2.M: Fanno Functions, Table Columns 1-7');
  x=[0.9 0.4 0.1 0.7 0.4 0.6 0.01];
  x=MNmin+x*(MNmax-MNmin);
  for i=1:m
    j=max(find(x(k(i))>M0));
    text(M0(j),Fnorm(j,k(i)),sprintf('%d',k(i)), ...
         'HorizontalAlignment','center', ...
         'VerticalAlignment','middle');
  end
