function answ=dbinoml(what,input1,input2,input3,input4)
%DBINOML Calculates all kinds of things for binomial distributions.
%USE:  answ=dbinomial(what,input1,input2,input3,input4)
%   where  y  is the observed y vector; 
%          input1 ... input4 are inputs depending on what is wanted (see below);
%          what  returns what is asked:
%             what== 'varfn' returns the variance function;
%             what== 'scdev' returns the deviance/scaled deviance;
%             what== 'disppar'  returns the dispersion parameter.
%          answ  is the answer asked for.
%Called by  irls, glmfit.

%Peter Dunn
%Last revision: 29/04/96

%   input3 is only useful with the binomial distn, but always contains  m.
%   input4 always contains the weights
%   for varfn,   input1=m,               input2=mu 
%   for scdev,   input1=y,               input2=mu
%   for disppar, input1=scaled deviance, input2=residual df
global SCALEPAR YVAR FITVALS M WEIGHTS DEGREESOFF; 

%Rename variables to something meaningful
m=input3;weights=input4;
if strcmp(what,'varfn')|strcmp(what,'scdev'),
   mu=input2;y=input1;
elseif strcmp(what,'disppar'),
   scdev=input1;resdf=input2;
end;

%Calculate
if strcmp(what,'varfn'),
   mu=mu+0.0001*(mu<0.0001); mu=mu-0.0001*(mu>m-0.0001);
   answ=mu-(mu.^2 ./ m);
 elseif strcmp(what,'scdev');
   %lim(x->0) x*ln(x)=0 but gives NaN
   mu=mu+(mu==0);yfix=y+(y==0).*mu;
   part1=yfix.*log(yfix./mu);
   mmmu=(m-mu)+(m==mu);
   yy=m-y; yy=yy+(yy==0).*(mmmu);
   part2=yy.*log(yy./mmmu);
   answ=2*sum(weights.*(part1+part2));
else %disppar
  if ~isstr(SCALEPAR),
      answ=SCALEPAR;
   else
      answ=scdev/resdf;
   end;
end;
