function answ=dgamma(what,input1,input2,input3,input4)
%DGAMMA Calculates all kinds of things for gamma distributions.
%USE:  answ=dgamma(what,input1,input2,input3,input4)
%   where  y  is the observed y vector; 
%          input1 ... input4 are inputs depending on what is wanted (see below);
%          what  returns what is asked:
%             what== 'varfn' returns the variance function;
%             what== 'scdev' returns the deviance/scaled deviance;
%             what== 'disppar'  returns the dispersion parameter.
%          answ  is the answer asked for.
%Called by  irls, glmfit.

%Copyright 1996 Peter Dunn
%11/11/1996

%   input3 is only useful with the binomial distn, but always contains  m.
%   input4 always contains the weights
%   for varfn,   input1=m,               input2=mu 
%   for scdev,   input1=y,               input2=mu
%   for disppar, input1=scaled deviance, input2=residual df
global SCALEPAR YVAR FITVALS M WEIGHTS DEGREESOFF; 


%Rename variables to something meaningful
m=input3;weights=input4;
if strcmp(what,'varfn')|strcmp(what,'scdev'),
   mu=input2;y=input1;
elseif strcmp(what,'disppar'),
   scdev=input1;resdf=input2;
end;

%Calculate
if strcmp(what,'varfn'),
   answ=(mu.^2)+0.00001*(mu==0);
   answ=answ.*(answ>0)+(answ<=0); %removes negative mu's
elseif strcmp(what,'scdev'),
   mu=mu+0.00001*(mu==0);yy=y+(y==0).*mu;
   answ=2*sum( weights.*(-log(yy./mu) + (y-mu)./mu ) );
else %disppar
   if ~isstr(SCALEPAR), 
      answ=SCALEPAR;
   else 
      answ=scdev/resdf;
   end;
end;
