%GLMLAB  A menu driven method of selecting options using  glmlab.
%USE:     glmlab
%         glmlab  allows the user to alter the  response variable (y),
%          the covariates (x variables), the offset variable and the
%          prior weights variable.
%         Enter the names of the variables in the appropriate window.
%          (The variable must be defined in  matlab.)
%         The constant term can also be chosen to be automatically fitted
%          (rather than explicitly defined in the covariate matrix).
%
%         The variables must be already defined in the workspace.

%Copyright 1996 Peter Dunn
%27/11/1996

global NAMEYV NAMEXV NAMEPW NAMEOS YVAR XVARS WEIGHTS OFFSET INC_CONST;
global DETAILSFILE RESTYPE ERRDISFUNCTION SCALEPAR LINKFUNCTION
global FORMAT RECYCLE

watchon;
%before starting new window, check if glmlab already running.
if figflag('glmlab Main Window'), watchoff; return; end;

%If not running, create new window
figure('Name','glmlab Main Window','tag','main','NextPlot','new',...
 'MenuBar','none','Resize','off','Pointer','watch','Visible','off');
axis off;glmsplsh;

%Load some details that are needed
L1=linklist(which('llist'));L1(:,1)=[];
D1=distlist(which('dlist')); D1(:,1)=[];

%MENU ALONG THE TOP
%FILE
LOADDIR=strrep(which('dummydta'),'dummydta.m','*');
%Default LOAD directory is the glmlab/data directory
uimenu(findobj('tag','main'),'Label','File ','tag','filem')
 uimenu(findobj('tag','filem'),'Label','LOAD Data File','Accelerator','L',...
    'Callback', ['[AA,BB]=uigetfile(''',LOADDIR,''',''Load Data'');',...
    'eval(''load([BB,AA]);ERR_FLAG=0;'',''ERR_FLAG=1;'');',...
    'if ERR_FLAG,opterr(6,AA);else opterr(7,AA); end; clear ERR_FLAG AA BB']);
 clear LOADDIR
 uimenu(findobj('tag','filem'),...
        'Label','CLOSE glmlab Window but Remember Settings',...
        'Accelerator','W','Callback','varok;menuwork(60);');
 uimenu(findobj('tag','filem'),'Label','QUIT glmlab and Lose Settings',...
        'Accelerator','Q',...
        'Callback','menuwork(50);','Separator','on');
 uimenu(findobj('tag','filem'),'Label','EXIT matlab','Accelerator','X',...
        'Callback','quit');

%DISTRIBUTION
if isempty(ERRDISFUNCTION), ERRDISFUNCTION='normal'; end;
CALLBACK=[];
uimenu(findobj('tag','main'),'Label','Distribution ','tag','distm');
for III=1:size(D1,1),
   THISDIST=deblank(D1(III,:));
   CALLBACK=str2mat(CALLBACK,['''menuwork(1,''''',THISDIST,''''');''']);
   uimenu(findobj('tag','distm'),'Label',THISDIST,...
          'tag',deblank(D1(III,:)),'Callback',eval(CALLBACK(III+1,:)));
   %Now indicate selected distribution
   if strcmp(THISDIST,deblank(ERRDISFUNCTION)),
      set(findobj('tag',THISDIST),'Checked','on');
   end;
   if III==5, set(findobj('tag',THISDIST),'Separator','on'); end;
end;

%LINK
if isempty(LINKFUNCTION),
   if strcmp(ERRDISFUNCTION,'poisson'),
      LINKFUNCTION='log';
   elseif strcmp(ERRDISFUNCTION,'binoml'),
      LINKFUNCTION='logit';
   elseif strcmp(ERRDISFUNCTION,'gamma'),
      LINKFUNCTION='recip';
   else 
      LINKFUNCTION='id'; 
   end;
end;
CALLBACK=[];
uimenu(findobj('tag','main'),'Label','Link ','tag','linkm');
for II=1:size(L1,1),
   THISLINK=deblank(L1(II,:));
   CALLBACK=str2mat(CALLBACK,['''menuwork(2,''''',THISLINK,''''');''']);
   uimenu(findobj('tag','linkm'),'Label',THISLINK,...
          'tag',deblank(L1(II,:)),'Callback',eval(CALLBACK(II+1,:)));
   if ~strcmp(ERRDISFUNCTION,'binoml'), %Disable some link functions
      if strcmp(deblank(L1(II,:)),'logit')|...
         strcmp(deblank(L1(II,:)),'complog')|...
         strcmp(deblank(L1(II,:)),'probit'),
            set(findobj('tag',THISLINK),'Enable','off');
      end;
   end;
   %Now indicate selected distribution
   if isstr(LINKFUNCTION),
      if strcmp(THISLINK,deblank(LINKFUNCTION)),
         set(findobj('tag',deblank(L1(II,:))),'Checked','on');
      end;
   else
      if strcmp(THISLINK,'power'),
         set(findobj('tag','power'),'Checked','on',...
             'Label',['power: ',num2str(LINKFUNCTION)]);
      end;
   end;
   if II==9, set(findobj('tag',THISLINK),'Separator','on'); end;
end;
clear CALLBACK III II D1 L1 THISDIST THISLINK

%SCALEPAR
if isempty(SCALEPAR), 
   if strcmp(ERRDISFUNCTION,'binoml')|strcmp(ERRDISFUNCTION,'poisson'),
      SCALEPAR=1;
   else
      SCALEPAR='md'; 
   end;
end;
uimenu(findobj('tag','main'),'Label','Scale Parameter ','tag','scalem');
uimenu(findobj('tag','scalem'),'Label','Mean Deviance',...
       'tag','md','Callback','menuwork(4,1);');
uimenu(findobj('tag','scalem'),'tag','val','Callback','menuwork(4,2);');
if isstr(SCALEPAR),
   set(findobj('tag','val'),'Label','Fixed Value: 1');
   set(findobj('tag','md'),'Checked','on');
else
   set(findobj('tag','val'),'Label',['Fixed Value: ',num2str(SCALEPAR)],...
       'Checked','on');
end;

%RESIDUAL
if isempty(RESTYPE), RESTYPE='Pearson'; end;
uimenu(findobj('tag','main'),'Label','Residuals ','tag','residm');
uimenu(findobj('tag','residm'),'Label','Pearson',...
       'tag','pearson','Callback','menuwork(3,1);');
uimenu(findobj('tag','residm'),'Label','Deviance',...
       'tag','deviance','Callback','menuwork(3,2);');
uimenu(findobj('tag','residm'),'Label','Quantile','Enable','off',...
       'tag','quantile','Callback',';menuwork(3,3);');
if strcmp(ERRDISFUNCTION,'normal')|strcmp(ERRDISFUNCTION,'binoml')|...
   strcmp(ERRDISFUNCTION,'poisson')|strcmp(ERRDISFUNCTION,'gamma'),
   set(findobj('tag','quantile'),'Enable','on');
end;
if strcmp(RESTYPE,'Pearson'),
   set(findobj('tag','pearson'),'Checked','on');
elseif strcmp(RESTYPE,'Deviance'),
   set(findobj('tag','deviance'),'Checked','on');
else
   set(findobj('tag','quantile'),'Checked','on');
end;

%OPTIONS
if isempty(FORMAT), FORMAT=[0,1]; end;
if isempty(RECYCLE), RECYCLE=0; end;
if isempty(INC_CONST), INC_CONST=1; end;
uimenu(findobj('tag','main'),'Label','Options ','tag','optm');
uimenu(findobj('tag','optm'),'Label','Declare New Model',...
       'Accelerator','N','Callback','newmodel;menuwork(7);');
uimenu(findobj('tag','optm'),'Label','Restore Default Settings',...
        'Accelerator','D','Callback','menuwork(7);');
uimenu(findobj('tag','optm'),'Label','Include a Constant Term in Model',...
       'Accelerator','C',...
       'tag','constant','Callback','menuwork(70);','Separator','on');
uimenu(findobj('tag','optm'),'tag','outputm','Label','Output Display');
  uimenu(findobj('tag','outputm'),'Label','Display Fitting Information',...
         'Accelerator','F','tag','fitinf','Callback','menuwork(40,1);');
  uimenu(findobj('tag','outputm'),'Label','Display Parameter Values',...
         'Accelerator','P','tag','pvals','Callback','menuwork(40,2);');
uimenu(findobj('tag','optm'),'Label','Recycle Fitted Values',...
       'Accelerator','R','tag','recycle','Callback','menuwork(40,3);');
          
if INC_CONST, set(findobj('tag','constant'),'checked','on'); end;
if FORMAT(1), set(findobj('tag','fitinf'),'checked','on'); end;
if FORMAT(2), set(findobj('tag','pvals'),'checked','on'); end;
if RECYCLE, set(findobj('tag','recycle'),'checked','on'); end;

%HELP
uimenu(findobj('tag','main'),'Label','Help ','tag','helpm');
  uimenu(findobj('tag','helpm'),'Label','Help with MAIN WINDOW Items',...
         'Callback','helpvars');
  uimenu(findobj('tag','helpm'),'Label','Help with MENU Items',...
         'Callback','helpopt');
  uimenu(findobj('tag','helpm'),'Label','Help with INTERACTIONS',...
         'Callback','helpint');
  uimenu(findobj('tag','helpm'),'Label','Where to get  glmlab',...
         'Callback','helpget','Separator','on');
  uimenu(findobj('tag','helpm'),'Label','How to Contact the Author',...
         'Callback','helpcont');
  uimenu(findobj('tag','helpm'),'Label','Initial Splash Screen',...
         'Callback','glmsplsh(1);');
  uimenu(findobj('tag','helpm'),'Label','Last Revision Date: 27 Nov 1996',...
         'Separator','on');

%UICONTROLS
%response (y) variable
set(findobj('tag','main'),'DefaultUIControlUnits','normalized',...
    'DefaultUIControlStyle','text');

fred=uicontrol(findobj('tag','main'),'String','Response (y):',...
 'HorizontalAlignment','left',...
 'Position',[.05 .80 .20 .08],'ForegroundColor','w','BackgroundColor','k');
uicontrol(findobj('tag','main'),'Style','edit',...
 'Position',[.30 .80 .65 .08],'Callback','yvarcont;','tag','HYV');
if ~isempty(NAMEYV), 
   set(findobj('tag','HYV'),'String',NAMEYV); 
else 
   YVAR=[];
end;

%covariates (X)
uicontrol(findobj('tag','main'),'String','Covariates (X):',...
 'HorizontalAlignment','left',...
 'Position',[.05 .7 .20 .08],'ForegroundColor','w','BackgroundColor','k');
uicontrol(findobj('tag','main'),'Style','edit',...
 'Position',[.30 .7 .65 .08],'Callback','xvarcont;','tag','HXV');
if ~isempty(NAMEXV), 
   set(findobj('tag','HXV'),'String',NAMEXV); 
else 
   XVARS=[];
end;

%weight var
uicontrol(findobj('tag','main'),'String','Prior Weights:',...
 'HorizontalAlignment','left',...
 'Position',[.05 .5 .20 .08],'ForegroundColor','w','BackgroundColor','k');
uicontrol(findobj('tag','main'),'Style','edit',...
 'Position',[.30 .5 .65 .08],'Callback','wvarcont','tag','HPW');
if ~isempty(NAMEPW), 
   set(findobj('tag','HPW'),'String',NAMEPW); 
else 
   WEIGHTS=[];
end;

%offset var
uicontrol(findobj('tag','main'),'String','Offset Variable:',...
 'HorizontalAlignment','left',...
 'Position',[.05 .4 .20 .08],'ForegroundColor','w','BackgroundColor','k');
uicontrol(findobj('tag','main'),'Style','edit',...
 'Position',[.30 .4 .65 .08],'Callback','ovarcont','tag','HOS');
if ~isempty(NAMEOS), 
   set(findobj('tag','HOS'),'String',NAMEOS); 
else 
   OFFSET=[];
end;

%Bottom rows
uicontrol(findobj('tag','main'),'Style','Pushbutton',...
 'String','FIT MODEL AS SPECIFIED','Position',[.05 .05 .40 .1],...
 'Callback',['if ~isempty(NAMEYV),varok;if (~STOPME),',...
 'disp(''[BETA FITS RESIDS COVB COVD DEVLIST]=glmfit;'');',...
  '[BETA FITS RESIDS COVB COVD DEVLIST]=glmfit;end;end;STOPME=0;UNFIT=0;',...
  'return;']);
uicontrol(findobj('tag','main'),'Style','Pushbutton',...
 'String','RESIDUAL PLOTS...','Position',[.55 .05 .40 .1],...
 'Visible','off','Callback','glmplot;return;');
if exist('RESIDS')==1,
   if ~isempty(RESIDS),
      set(findobj('String','RESIDUAL PLOTS...'),'Visible','on');
   end;
end;

if strcmp(computer,'PCWIN'),
   DETAILSFILE=strrep(which('glmlab'),'fit\glmlab.m','DETAILS.m');
elseif strcmp(computer,'MAC2'),
   DETAILSFILE=strrep(which('glmlab'),'fit:glmlab.m','DETAILS.m');
else %unix only
   [DUMMY,OLDDIR]=unix('pwd'); [DUMMY,HOMEDIR]=unix('cd;pwd');
   DETAILSFILE=[HOMEDIR(1:length(HOMEDIR)-1),'/DETAILS.m'];
   unix(['cd ',OLDDIR]); %return to users directory
   clear OLDDIR HOMEDIR DUMMY
end;
%DETAILSFILE  is the file name of the file recording things

delete(findobj('tag','splash'));
set(findobj('Name','glmlab Main Window'),'Visible','on');

watchoff;
return;
