function 	r=axoread(fname,size,numchan)

%AXOREAD  Reading of Axotape/PClamp data files
%
%Syntax	R = axoread(FNAME[, SIZE[, NUMCHAN]]);
%
%Input	FNAME	File name including file path
%	SIZE	Number of data points to read per channel [ALL]
%	NUMCHAN	Number of AD-Channels to read	[ALL]
%
%Comment	Program is only tested for Axotape, continuous recording
%
%	(c) A.K. 5.8.1996

fid=fopen(fname);

disp('********************************************************');
h=fread(fid, 4, 'char');
disp(['File Type: ' setstr(h') ' Version ' num2str(fread(fid, 1, 'float'))]);

fseek(fid, 10, 'bof');
disp(['Number of Samples: ' num2str(fread(fid, 1, 'long'))]);

nignore=fread(fid, 1, 'int16');

% Data format
fseek(fid, 100, 'bof');
df=fread(fid, 1, 'int16');

fseek(fid, 120, 'bof');
nchan=fread(fid, 1, 'int16');
disp(['Number of Channels: ' num2str(nchan)]);

fseek(fid, 122, 'bof');
sample=fread(fid, 1, 'float');
disp(['Sample Interval (us) ' num2str(sample)]);

fseek(fid, 244, 'bof');
ADCRange=fread(fid, 1, 'float');
fseek(fid, 252, 'bof');
ADCResolution=fread(fid, 1, 'long');
counts2volt=ADCRange/ADCResolution;
% Factor 1/4 determined empirically for Axotape files
counts2volt=counts2volt/4;

fseek(fid, 294, 'bof');
h=fread(fid, 16, 'char');
disp(['Created with ' setstr(h')]);
h=fread(fid, 56, 'char');
disp(['User comment: ' setstr(h')]);

fseek(fid, 602, 'bof');
h=fread(fid, 16, 'char');
disp(['User units: ' setstr(h')]);

fseek(fid, 922, 'bof');
scalef=fread(fid, 1, 'float');
disp(['ScaleFactor 0: ' num2str(scalef*1000) 'mv/' setstr(h(1:8)')]);
for i=2:nchan
    scalef=[scalef fread(fid, 1, 'float')];
end %for i
disp('********************************************************');

fseek(fid, 2048+2*nignore, 'bof');
if df==0, 
   h=fread(fid,size*nchan,'int16').*counts2volt;
elseif df==1, 
   h=fread(fid,size*nchan,'float').*counts2volt;
end %if
fclose(fid);

% Each channel in seperate column
r=zeros(length(h)/nchan, numchan);
for i=1:numchan
    r(:,i)=h(i:nchan:length(h))./scalef(i);
end %for i

