%CORRECT	Correction of an eventlist for filter response
%
%Syntax	CEVENT = correct(EVENT, FC, DT)
%
%Input	EVENT   eventlist obtained from thresh or thresh2
%	FC	Filter -3 DB cutoff frequency in Hz (analog and digital filter)
%	DT	Sampling interval in s
%
%Output	CEVENT	Corrected eventlist, the openings are longer
%
%Remark	The correction is done for an gaussian filter. Dont forget the influence
%	of analog lowpass filter like a Bessel filter which is nearly gaussian.
%	(see Colquhoun D., Sigworth F.J. in Single Channel Recording, Sakmann B.,
%	 Neher, E., eds. Plenun Press, New York 1995, p.501)
%
%	(c) A.K. 29.7.1996

function cevent=correct(event, fc, dt)

fc=fc*dt;
cevent=event;
a1=.1787/fc; a2=7.58*fc^2; a3=30.58*fc^3;

if event(2,2)>0,
   idx=2:2:length(event);
else
   idx=3:2:length(event);
end %if

cevent(idx, 1)=round(event(idx,1)+ a1*exp(-event(idx,1)/a1-a2*event(idx,1).^2-a3*event(idx,1).^3));
diff=(event(idx, 1)-cevent(idx,1))/2;
cevent(idx-1,1)=cevent(idx-1,1)+round(diff);
cevent(idx+1,1)=cevent(idx+1,1)+ceil(diff);

