%GFIT	Multiple gaussian fit of data
%
%Syntax	gfit(DATAX, DATAY)
%
%Input	DATAX, DATAY
%
%Output	Parameter in global Variable G1
%
%	(c) A.K. 16.7.1996
%	last modified 28.7.1996

function gfit(datax, datay, action)

global G1 G2 G3 G4
global HFUNC HHEIGHT HMEAN HSDEV HITER HMVAR HTX1 HTX2 HTX3 HTX4 HTX5 HTX6
global G1BOX G2BOX G3BOX G4BOX G5BOX HDONE HRANGE HCURVE HSMEAN HFIT
global FUNC PARAM RANGE HL1 HL2 HPL XDATA YDATA

if nargin<3, action='init'; end
   
if strcmp(action, 'init'),
   G1=datax; G2=datay;
   plot(G1, G2, '.', 'EraseMode', 'xor', 'MarkerSize', 8); set(gca, 'Position', [0.3 0.2 0.67 0.77]); hold on;
   ylim=get(gca, 'YLim'); set(gca, 'YLim', [ylim(1)-.05*(ylim(2)-ylim(1)) ylim(2)]);
   set(gcf, 'backingstore', 'off', 'WindowButtonDownfcn', 'gfit(G1, G2, ''buttondown'')');
   HFUNC=uicontrol('Style', 'popup', 'Units', 'normalized', 'String', 'Gauss 1|Gauss 2|Gauss 3|Gauss 4|Gauss 5', ...
                   'Position', [.01 0.89 .15 .1], 'BackgroundColor', [0.702 0.702 0.702], ...
                   'Callback', 'gfit(G1, G2, ''func'')'); 
   HHEIGHT=uicontrol('Style', 'edit', 'Units', 'normalized', 'Position', [0 0.77 .14 0.04], 'BackgroundColor', [0.702 0.702 0.702], ...
                     'Callback', 'gfit(G1, G2, ''height'')'); 
   HMEAN=uicontrol('Style', 'edit', 'Units', 'normalized', 'Position', [0 0.67 .14 0.04], 'BackgroundColor', [0.702 0.702 0.702], ...
                   'Callback', 'gfit(G1, G2, ''mean'')'); 
   HSDEV=uicontrol('Style', 'edit', 'Units', 'normalized', 'Position', [0 0.57 .14 0.04], 'BackgroundColor', [0.702 0.702 0.702], ...
                   'String', '0.5', 'Callback', 'gfit(G1, G2, ''sdev'')');
   HITER=uicontrol('Style', 'edit', 'Units', 'normalized', 'Position', [0 0.43 .14 0.04], 'BackgroundColor', [0.702 0.702 0.702], ...
                   'String', '200', 'Callback', 'gfit(G1, G2, ''iter'')');
   HMVAR=uicontrol('Style', 'edit', 'Units', 'normalized', 'Position', [0 0.33 .14 0.04], 'BackgroundColor', [0.702 0.702 0.702], ...
                   'String', '0.1', 'Callback', 'gfit(G1, G2, ''mvar'')');                     
   HTX1=uicontrol('Style', 'text', 'Units', 'normalized', 'String', 'Height:', 'Position', [0.01 0.8125 .1 0.04], 'BackgroundColor', [0.702 0.702 0.702]);
   HTX2=uicontrol('Style', 'text', 'Units', 'normalized', 'String', 'Mean:', 'Position', [0.01 0.713 .1 0.04], 'BackgroundColor', [0.702 0.702 0.702]);
   HTX3=uicontrol('Style', 'text', 'Units', 'normalized', 'String', 'Sdev:', 'Position', [0.01 0.612 .1 0.04], 'BackgroundColor', [0.702 0.702 0.702]);
   HTX4=uicontrol('Style', 'text', 'Units', 'normalized', 'String', 'MaxIter:', 'Position', [0.01 0.472 .1 0.04], 'BackgroundColor', [0.702 0.702 0.702]);
   HTX5=uicontrol('Style', 'text', 'Units', 'normalized', 'String', 'MinChange:', 'Position', [0.01 0.372 .13 0.04], 'BackgroundColor', [0.702 0.702 0.702]);
   % Text header for checkboxes
   HTX6=uicontrol('Style', 'text', 'Units', 'normalized', 'String', 'Fit simultaneous', 'Position', [0.01 0.25 .18 0.04], 'BackgroundColor', [0.702 0.702 0.702]);
   G1BOX=uicontrol('Style', 'checkbox', 'Units', 'normalized', 'Position', [0.01 0.21 .18 0.04], 'String', 'Gauss 1', 'BackgroundColor', [0.702 0.702 0.702]);                     
   G2BOX=uicontrol('Style', 'checkbox', 'Units', 'normalized', 'Position', [0.01 0.17 .18 0.04], 'String', 'Gauss 2', 'BackgroundColor', [0.702 0.702 0.702]);
   G3BOX=uicontrol('Style', 'checkbox', 'Units', 'normalized', 'Position', [0.01 0.13 .18 0.04], 'String', 'Gauss 3', 'BackgroundColor', [0.702 0.702 0.702]);
   G4BOX=uicontrol('Style', 'checkbox', 'Units', 'normalized', 'Position', [0.01 0.09 .18 0.04], 'String', 'Gauss 4', 'BackgroundColor', [0.702 0.702 0.702]);
   G5BOX=uicontrol('Style', 'checkbox', 'Units', 'normalized', 'Position', [0.01 0.05 .18 0.04], 'String', 'Gauss 5', 'BackgroundColor', [0.702 0.702 0.702]);
   HDONE=uicontrol('Style', 'pushbutton', 'Units', 'normalized', 'String', 'Done', 'Position', [0.86 0.03 .1 0.08], ...
                  'callback', 'gfit(G1, G2, ''done'')');
   HRANGE=uicontrol('Style', 'pushbutton', 'Units', 'normalized', 'String', 'Set Range', 'Position', [0.2 0.03 .13 0.06], ...
                  'callback', 'gfit(G1, G2, ''range'')');
   HSMEAN=uicontrol('Style', 'pushbutton', 'Units', 'normalized', 'String', 'Set Mean/Height', 'Position', [0.345 0.03 .18 0.06], ...
                  'callback', 'gfit(G1, G2, ''smean'')');
   HCURVE=uicontrol('Style', 'pushbutton', 'Units', 'normalized', 'String', 'Disp Curve', 'Position', [0.54 0.03 .13 0.06], ...
                  'callback', 'gfit(G1, G2, ''curve'')');
   HFIT=uicontrol('Style', 'pushbutton', 'Units', 'normalized', 'String', 'Do Fit', 'Position', [0.69 0.03 .13 0.06], ...
                  'callback', 'gfit(G1, G2, ''fit'')');
   HL1=line([0 0], [0 0], 'EraseMode', 'xor'); HL2=line([0 0], [0 0], 'EraseMode', 'xor');
   PARAM=zeros(5,3);PARAM(:,3)=ones(5,1)*0.5;
   RANGE=get(gca, 'XLim');
   HPL=plot([0], [0]);
elseif strcmp(action, 'func'),
   func=get(HFUNC, 'Value');
   set(HHEIGHT, 'String', num2str(PARAM(func,1)));
   set(HMEAN, 'String', num2str(PARAM(func,2)));
   set(HSDEV, 'String', num2str(PARAM(func,3)));
elseif strcmp(action, 'height'),
   PARAM(get(HFUNC, 'Value'), 1)=str2num(get(HHEIGHT, 'String'));
elseif strcmp(action, 'mean'),
   PARAM(get(HFUNC, 'Value'), 2)=str2num(get(HMEAN, 'String'));
elseif strcmp(action, 'sdev'),
   PARAM(get(HFUNC, 'Value'), 3)=str2num(get(HSDEV, 'String'));
elseif strcmp(action, 'range'),
   set(HSMEAN, 'String', 'Set Mean/Height');
   h1=get(HRANGE, 'String');
   if h1=='Set Range', 
      set(HRANGE, 'String', 'Left     ');
   elseif h1=='Left     ',
      set(HRANGE, 'String', 'Right    ');
   elseif h1=='Right    ',
      set(HRANGE, 'String', 'Set Range');
   end %if
elseif strcmp(action, 'buttondown'),
   h2=get(gca, 'CurrentPoint');
   ylim=get(gca, 'YLim'); 
   if get(HSMEAN, 'String')=='Mean Off       ',
      func=get(HFUNC, 'Value');
      set(HMEAN, 'String', num2str(h2(1,1)));
      PARAM(get(HFUNC, 'Value'),2)=h2(1,1);
      set(HHEIGHT, 'String', num2str(h2(1,2)));
      PARAM(get(HFUNC, 'Value'),1)=h2(1,2);
   else
      h1=get(HRANGE, 'String');
      if h1=='Left     ',
         set(HL1, 'Visible', 'off');
         HL1=line([h2(1,1) h2(1,1)], [ylim(1) ylim(2)], 'LineStyle', ':', 'Color', [0 1 0], 'EraseMode', 'xor');
         RANGE(1,1)=h2(1,1);
      elseif h1=='Right    ',
         set(HL2, 'Visible', 'off');
         HL2=line([h2(1,1) h2(1,1)], [ylim(1) ylim(2)], 'LineStyle', ':', 'Color', [0 1 0], 'EraseMode', 'xor');
         RANGE(1,2)=h2(1,1);
      end %if
   end %if
elseif strcmp(action, 'fit'),
   n=zeros(1,5);
   n(1,1)=get(G1BOX,'Value');n(1,2)=get(G2BOX,'Value');n(1,3)=get(G3BOX,'Value');
   n(1,4)=get(G4BOX,'Value');n(1,5)=get(G5BOX,'Value');
   ns=sum(n);
   % Startvector
   x0=PARAM(n,:);
   x0=reshape(x0', 1, ns*3); %Create row vector
   % Fitting options
   options=zeros(1,14);
   options(2)=1e-4; options(3)=str2num(get(HMVAR, 'String')); options(14)=str2num(get(HITER, 'String'));
   XDATA=G1(find(G1>=RANGE(1,1) & G1<=RANGE(1,2)));
   YDATA=G2(find(G1>=RANGE(1,1) & G1<=RANGE(1,2)));
   fitfun=['gauss' num2str(ns)];
   if ns>=1,
      [x,options]=fmins(fitfun, x0, options);
      disp(['fmin: ' num2str(options(8))]);
   end %if
   %Create new parameter matrix
   if ns>0, 
      x0=reshape(x, 3, ns)';
      PARAM(n,:)=x0;
   end %if
   func=get(HFUNC, 'Value');
   set(HHEIGHT, 'String', num2str(PARAM(func,1)));
   set(HMEAN, 'String', num2str(PARAM(func,2)));
   set(HSDEV, 'String', num2str(PARAM(func,3)));
elseif strcmp(action, 'curve'),
   n=zeros(1,5);
   n(1,1)=get(G1BOX,'Value');n(1,2)=get(G2BOX,'Value');n(1,3)=get(G3BOX,'Value');
   n(1,4)=get(G4BOX,'Value');n(1,5)=get(G5BOX,'Value');
   ns=sum(n);
   p=PARAM(n,:);
   p=reshape(p', 1, ns*3); %Create row vector
   xlim=get(gca, 'XLim');
   x=xlim(1):(xlim(2)-xlim(1))/200:xlim(2);
   if ns==1,
      delete(HPL)
      HPL=plot(x,p(1)*exp(-((x-p(2))/p(3)).^2), 'g', 'EraseMode', 'xor');
   elseif ns==2,
      delete(HPL)
      HPL=plot(x,p(1)*exp(-((x-p(2))/p(3)).^2)+p(4)*exp(-((x-p(5))/p(6)).^2), 'g', 'EraseMode', 'xor');
   elseif ns==3,
      delete(HPL)
      HPL=plot(x,p(1)*exp(-((x-p(2))/p(3)).^2)+p(4)*exp(-((x-p(5))/p(6)).^2)+p(7)*exp(-((x-p(8))/p(9)).^2), 'g', 'EraseMode', 'xor');
   elseif ns==4,
      delete(HPL)
      HPL=plot(x,p(1)*exp(-((x-p(2))/p(3)).^2)+p(4)*exp(-((x-p(5))/p(6)).^2)+p(7)*exp(-((x-p(8))/p(9)).^2)+p(10)*exp(-((x-p(11))/p(12)).^2), 'g', 'EraseMode', 'xor');
   elseif ns==5,
      delete(HPL)
      HPL=plot(x,p(1)*exp(-((x-p(2))/p(3)).^2)+p(4)*exp(-((x-p(5))/p(6)).^2)+p(7)*exp(-((x-p(8))/p(9)).^2)+p(10)*exp(-((x-p(11))/p(12)).^2)+p(13)*exp(-((x-p(14))/p(15)).^2), 'g', 'EraseMode', 'xor');
   end %if
elseif strcmp(action, 'smean'),
   set(HRANGE, 'String', 'Set Range');
   if get(HSMEAN, 'String')=='Set Mean/Height', 
      set(HSMEAN, 'String', 'Mean Off       ');
   else
      set(HSMEAN, 'String', 'Set Mean/Height');
   end %if
elseif strcmp(action, 'done'),
   G1=[]; G2=[]; ar=zeros(1,5);
   for i=1:5
       G2=PARAM(i,1); G3=PARAM(i,2); G4=PARAM(i,3);
       if G4>0, ar(i)=quad8('gaussf', -80, 80); end       
   end %for i
   disp('   Height      Mean         Sdev        Area');
   format short e;
   disp([PARAM ar']);
   format short;
   G1=[]; G2=[]; G3=[]; G4=[];
   n=zeros(1,5);
   n(1,1)=get(G1BOX,'Value');n(1,2)=get(G2BOX,'Value');n(1,3)=get(G3BOX,'Value');
   n(1,4)=get(G4BOX,'Value');n(1,5)=get(G5BOX,'Value');
   ns=sum(n);
   G1=PARAM(n,:);
   G1=reshape(G1', 1, ns*3); %Create row vector
   close(gcf);
   clear global HFUNC HHEIGHT HMEAN HSDEV HITER HMVAR HTX1 HTX2 HTX3 HTX4 HTX5 HTX6
   clear global G1BOX G2BOX G3BOX G4BOX G5BOX HDONE HRANGE HCURVE HSMEAN HFIT
   clear global FUNC PARAM RANGE HL1 HL2 HPL XDATA YDATA
end %if

