%HISTEV	Histogram from eventlist 
%
%Syntax	[H, BIN] = histev(DATA, EVLST)
%
%Input	DATA	vector of data points
%	EVLST	eventlist, output from eventlst.m
%	n	number of bins
%
%Output	H	vector of histogram values
%	BIN	mean of binning interval
%
%Usage	HISTEV builds the histogram from the mean current
%	of a previously detected level from threshold analysis
%	or some other more advanced technique.
%	(c) A.K. 26.7.1996

function [h, bin]=histev(data, evlst, n)

ma=max(data); mi=min(data);
width=(ma-mi)/(n-1);
bin=mi-width:width:ma+width;
h=zeros(1,n+2);
start=1;
for i=1:length(evlst),
    curr=mean(data(start:start+evlst(i,1)-1));
    start=start+evlst(i,1);
    binnum=max(find(bin<=curr));
    h(binnum)=h(binnum)+evlst(i,1);
end % for i
bin=bin(2:n+1);
h=h(2:n+1);

% set bins to interval mean
bin=bin+(bin(2)-bin(1))/2;
if nargout==0, bar(bin, h); end
