%HISTO3	Weighted histogramm (Patlaks Method)
%
%Syntax	[H, BIN] = histo3(DATA, N, W, thresh)
%
%Input	DATA	vector of data points
%	N	number of bins
%	W	width of the window for calculation of variance and mean
%	TRESH	variance threshold for acceptance of data-window for histogram
%
%Output	H	vector of histogram values
%	BIN	mean point of bins
%
%Remark	H(i) contains the data values which belong to bin(i) which falls in the
%	range bin(i) <= data < bin(i+1).
%	H(i) is the distribution of the mean of the window wheras
%	windows which variance is above the threshold are rejected
%
%	(c) A.K. 22.6.1996

function [h, bin]=histo3(data, n, w, thresh)

ma=max(data); mi=min(data);
width=(ma-mi)/(n-1);
bin=mi-width:width:ma+width;
h=zeros(1,n+2);

for i=1:length(data)-w
    variance=std(data(i:i+w))^2;
    if variance<=thresh
       meanw=mean(data(i:i+w));
       binnum=max(find(bin<=meanw));
       h(binnum)=h(binnum)+1;
    end %if
end % for i
bin=bin(2:n+1);
h=h(2:n+1);

% set bins to interval mean
bin=bin+(bin(2)-bin(1))/2;


