%HISTO6	Weighted histogramm	
%
%Syntax	[H, BIN] = histo6(DATA, N, W, SIGMA)
%
%Input	DATA	vector of data points
%	N	number of bins
%	W	width of the window for calculation of variance
%	SIGMA	parameter of gaussian distribution for weigthing coefficient
%
%Output	H	vector of histogram values
%	BIN	mean of binning interval
%
%Remark	H(i) contains the data values which belong to bin(i) which falls in the
%	range bin(i) <= data < bin(i+1).
%	H(i) ist obtained by summing up weigthing coefficients for each data point.
%	The coefficient is obtained from the deviation of the data point from the
%	mean of the actual window. The coefficient is a gaussian function of the
%	deviation characterized by the parameter SIGMA.
%	The window is the to the left or to the right side of the data point, denpending
%	on the smallest variance.
%	For signal/noise = 1 and mean open time of 20 sample points choose w=10
%	and sigma=0.05.
%
%	(c) A.K. 16.6.1996
%	last modified 23.7.1996

function [h, bin]=histo6(data, n, w, sigma)

ma=max(data); mi=min(data);
width=(ma-mi)/(n-1);
bin=mi-width:width:ma+width;
h=zeros(1,n+2);

for i=w+2:length(data)-w-1
    var1=std(data(i-w:i)).^2; var2=std(data(i:i+w)).^2;
    if var2<=var1
       meanw=mean(data(i:i+w));var=var2;
    else
       meanw=mean(data(i-w:i));var=var1;
    end %if
    diff=abs(data(i)-meanw);
    weight=exp(-(diff/sigma)^2/2);
    binnum=max(find(bin<=data(i)));
    h(binnum)=h(binnum)+weight;
end % for i
bin=bin(2:n+1);
h=h(2:n+1);
% set bins to interval mean
bin=bin+(bin(2)-bin(1))/2;
if nargout==0, bar(bin, h); end
