%INTDIS Integral distribution of open or closed times from eventlists
%
%Syntax [y x] = timedis(Z, LEVEL[, BINW])
%
%Input	Z	eventlist or Z-Matrix
%	LEVEL	=0 (closed times) or 1, 2, 
%	BINW	Bin width [1]
%
%Output	y	Number of events which belong to minimum open time x
%	x	time axis-vector set to the mean of the interval
%	
%Remark	Calculates a sort of distribution of the minimum open time
%	which is the cumulative form of the normal pdf=1/tau*exp(-t/tau), 
%	which is given by exp(-t/tau) for one time constant.
%	This form of distibution should never be used for fitting !
%	(see Colquhoun D., Sigworth F.J. in Single Channel Recording, Sakmann B.,
%	 Neher, E., eds. Plenun Press, New York 1995, p.519)
%
%	(c) A.K. 21.7.1995

function [y, x]=intdis(z, level, binw, mode)

if nargin<3, binw=1; end

y = z(z(:,2)==level, 1);
x=(0:binw:max(y))+binw/2;
[y x] = hist(y, x);
y=cumsum(y(length(y):-1:1));
y=y(length(y):-1:1);

if nargout==0, bar(x,y); end
