%MEASURE Measuring of data
%
%Syntax	measure(DATA[, POINTS[ ,VSCALE[, POS]]])
%
%Input	DATA
%	POINTS	Number of points to show
%	VSCALE  Vertical scale factor
%	POS	Starting position
%Remark Vertical mode: taking averages of all points between cursor 1 and cursor 2
%	Horizontal mode: (se above) use cursor 1 as lower cursor
%
%	(c) A.K. 14.8.1995
%	last modified 24.7.1996

function measure(action, data, points, vscale, pos)

global P HPOI HPOIVAL HPOS HVSC HSCVAL HOK HPVAL YLIM HZOOM HCURSOR HCMODE HC1 HC2 HAV POS HVR HDIF
global G1 G2 G3 G4 HL1 HL2

if nargin<2, data=action; action='init'; end
if nargin<3, points=round(length(data)/8); end
if nargin<4, vscale=1; end
if nargin<5, pos=1; end
   
if strcmp(action, 'init'),
   POS=[0 0];
   G1=data; G2=points; G3=vscale; G4=pos;
   YLIM=[min(G1)-.05*abs(min(G1)) max(G1)+0.05*abs(max(G1))];
   YLIM=YLIM/G3; 
   plot((G4:G4+G2), data(G4:G4+G2), 'EraseMode', 'xor'); h=gca; set(h, 'XLim', [G4 G4+G2], 'YLim', YLIM, 'Position', [0.2 0.11 0.7 0.815]);
   HL1=line([0 0], [0 0], 'EraseMode', 'xor'); HL2=line([0 0], [0 0], 'EraseMode', 'xor');
   set(gcf, 'backingstore', 'off', 'WindowButtonDownfcn', 'measure(''buttondown'', G1, G2, G3, G4)');
   HPOI=uicontrol('Style', 'slider', 'Units', 'normalized', 'Value', G2, 'Position', [.02 0.93 0.67 0.04], ...
                  'Min', 3, 'Max', length(G1)-1, 'Callback', 'measure(''numpoints'', G1, G2, G3, G4)');
   HPOIVAL=uicontrol('Style', 'edit', 'Units', 'normalized', 'String', num2str(G2), 'Position', [0.7 0.93 0.15 0.033], 'BackgroundColor', [0.702 0.702 0.702], ...
                     'Callback', 'measure(''poival'', G1, G2, G3, G4)'); 
   HPOS=uicontrol('Style', 'slider', 'Units', 'normalized', 'Value', G4, 'Position', [0 0.97 1 0.04], ...
                  'Min', 1, 'Max', length(G1), 'Callback', 'measure(''position'', G1, G2, G3, G4)');
   HPVAL=uicontrol('Style', 'edit', 'Units', 'normalized', 'String', '1', 'Position', [0.9 0.94 0.1 0.03], 'BackgroundColor', [0.702 0.702 0.702], ...
                   'Max', 1, 'Callback', 'measure(''posval'', G1, G2, G3, G4)'); 
   HVSC=uicontrol('Style', 'slider', 'Units', 'normalized', 'Value', 1, 'Position', [.94 0.62 .03 0.3], ...
                  'Min', .1, 'Max', 10, 'Callback', 'measure(''vscale'', G1, G2, G3, G4)');
   HSCVAL=uicontrol('Style', 'edit', 'Units', 'normalized', 'String', '1', 'Position', [0.93 0.58 0.05 0.03], 'BackgroundColor', [0.702 0.702 0.702], ...
                   'Max', 1, 'Callback', 'measure(''scval'', G1, G2, G3, G4)');                   
   HOK=uicontrol('Style', 'pushbutton', 'Units', 'normalized', 'String', 'OK', 'Position', [0.92 0.1 .08 0.05], ...
                  'callback', 'measure(''ok'', G1, G2, G3, G4)');
   HZOOM=uicontrol('Style', 'pushbutton', 'Units', 'normalized', 'String', 'Zoom on', 'Position', [0.02 0.01 .11 0.05], ...
                   'callback', 'measure(''zoom'', G1, G2, G3, G4)');
   HCMODE=uicontrol('Style', 'pushbutton', 'Units', 'normalized', 'String', 'Vertical  ', 'Position', [0.02 0.14 .11 0.05], ...
                  'callback', 'measure(''cmode'', G1, G2, G3, G4)');
   HCURSOR=uicontrol('Style', 'pushbutton', 'Units', 'normalized', 'String', 'Cursor 1', 'Position', [0.02 0.08 .11 0.05], ...
                  'callback', 'measure(''cursor'', G1, G2, G3, G4)');
   HTX1=uicontrol('Style', 'text', 'Units', 'normalized', 'String', 'Cursor 1:', 'Position', [0.01 0.83 .1 0.04], 'BackgroundColor', [0.702 0.702 0.702]);
   HTX2=uicontrol('Style', 'text', 'Units', 'normalized', 'String', 'Cursor 2:', 'Position', [0.01 0.71 .1 0.04], 'BackgroundColor', [0.702 0.702 0.702]);
   HTX3=uicontrol('Style', 'text', 'Units', 'normalized', 'String', 'Average:', 'Position', [0.01 0.59 .1 0.04], 'BackgroundColor', [0.702 0.702 0.702]);
   HTX4=uicontrol('Style', 'text', 'Units', 'normalized', 'String', 'Variance:', 'Position', [0.01 0.47 .1 0.04], 'BackgroundColor', [0.702 0.702 0.702]);
   HTX5=uicontrol('Style', 'text', 'Units', 'normalized', 'String', 'Cursor2 - Cursor1:', 'Position', [0.01 0.34 .1 0.06], 'BackgroundColor', [0.702 0.702 0.702]);
   HC1=uicontrol('Style', 'text', 'Units', 'normalized', 'String', '         ', 'Position', [0 0.79 .14 0.04], 'BackgroundColor', [0.702 0.702 0.702]);
   HC2=uicontrol('Style', 'text', 'Units', 'normalized', 'String', '         ', 'Position', [0 0.67 .14 0.04], 'BackgroundColor', [0.702 0.702 0.702]);
   HAV=uicontrol('Style', 'text', 'Units', 'normalized', 'String', '        ', 'Position', [0 0.55 .14 0.04], 'BackgroundColor', [0.702 0.702 0.702]);
   HVR=uicontrol('Style', 'text', 'Units', 'normalized', 'String', '        ', 'Position', [0 0.43 .14 0.04], 'BackgroundColor', [0.702 0.702 0.702]);
   HDIF=uicontrol('Style', 'text', 'Units', 'normalized', 'String', '        ', 'Position', [0 0.30 .14 0.04], 'BackgroundColor', [0.702 0.702 0.702]);
elseif strcmp(action, 'position'),
   G4=round(get(HPOS, 'Value'));
   if G4>length(G1)-G2,
      G4=length(G1)-G2; set(HPOS, 'Value', G4);
   end %if
   plot((G4:G4+G2), G1(G4:G4+G2), 'EraseMode', 'xor'); h=gca; set(h, 'XLim', [G4 G4+G2], 'YLim', YLIM/G3);
   HL1=line([0 0], [0 0], 'EraseMode', 'xor'); HL2=line([0 0], [0 0], 'EraseMode', 'xor');
   set(HPVAL, 'String', num2str(G4));
   if get(HCMODE, 'String')=='Horizontal',
      HL1=line([G4 G4+G2], [POS(1) POS(1)], 'LineStyle', ':', 'Color', [0 1 0], 'EraseMode', 'xor');
      HL2=line([G4 G4+G2], [POS(2) POS(2)], 'LineStyle', ':', 'Color', [0 1 0], 'EraseMode', 'xor');
   end %if
elseif strcmp(action, 'posval'),
   G4=str2num(get(HPVAL, 'String'));
   if G4>length(G1)-G2,
      G4=length(G1)-G2; set(HPOS, 'Value', G4); set(HPVAL, 'String', num2str(G4));
   end %if
   plot((G4:G4+G2), G1(G4:G4+G2), 'EraseMode', 'xor'); h=gca; set(h, 'XLim', [G4 G4+G2], 'YLim', YLIM/G3);
   HL1=line([0 0], [0 0], 'EraseMode', 'xor'); HL2=line([0 0], [0 0], 'EraseMode', 'xor');
   set(HPOS, 'Value', G4);
elseif strcmp(action, 'numpoints'),
   G2=round(get(HPOI, 'Value'));
   if G2>length(G1)-G4,
      G2=length(G1)-G4; 
      set(HPOI, 'Value', G2);
   end %if     
   plot((G4:G4+G2), G1(G4:G4+G2), 'EraseMode', 'xor'); h=gca; set(h, 'XLim', [G4 G4+G2], 'YLim', YLIM/G3);
   HL1=line([0 0], [0 0], 'EraseMode', 'xor'); HL2=line([0 0], [0 0], 'EraseMode', 'xor');
   set(HPOIVAL, 'String', num2str(G2));
   if get(HCMODE, 'String')=='Horizontal',
      HL1=line([G4 G4+G2], [POS(1) POS(1)], 'LineStyle', ':', 'Color', [0 1 0], 'EraseMode', 'xor');
      HL2=line([G4 G4+G2], [POS(2) POS(2)], 'LineStyle', ':', 'Color', [0 1 0], 'EraseMode', 'xor');
   end %if
elseif strcmp(action, 'poival'),
   G2=str2num(get(HPOIVAL, 'String'));
   if G2>length(G1)-G4,
      G2=length(G1)-G4; 
      set(HPOIVAL, 'String', num2str(G2));
   end %if     
   plot((G4:G4+G2), G1(G4:G4+G2), 'EraseMode', 'xor'); h=gca; set(h, 'XLim', [G4 G4+G2], 'YLim', YLIM/G3);
   HL1=line([0 0], [0 0], 'EraseMode', 'xor'); HL2=line([0 0], [0 0], 'EraseMode', 'xor');
   set(HPOI, 'Value', G2);
elseif strcmp(action, 'vscale'),
   G3=get(HVSC, 'Value');
   set(gca, 'YLim', YLIM/G3);
   set(HSCVAL, 'String', num2str(G3));
   if get(HCMODE, 'String')=='Horizontal',
      HL1=line([G4 G4+G2], [POS(1) POS(1)], 'LineStyle', ':', 'Color', [0 1 0], 'EraseMode', 'xor');
      HL2=line([G4 G4+G2], [POS(2) POS(2)], 'LineStyle', ':', 'Color', [0 1 0], 'EraseMode', 'xor');
   end %if
elseif strcmp(action, 'scval'),
   G3=str2num(get(HSCVAL, 'String'));
   if G3>10, G3=10; end
   if G3<.1, G3=.1; end
   set(HVSC, 'Value', G3);
   set(gca, 'YLim', YLIM/G3);
elseif strcmp(action, 'buttondown'),
   h1=get(gca, 'CurrentPoint');
   h2=get(HCMODE, 'String'); h3=get(HCURSOR, 'String');
   y0 = YLIM(1); ym = YLIM(2);
   xlim=get(gca, 'XLim');
   if h2=='Vertical  '
      if h3=='Cursor 1'
         set(HL1, 'Visible', 'off');
         POS(1)=h1(1,1);
         HL1=line([POS(1) POS(1)], [y0 ym], 'LineStyle', ':', 'Color', [0 1 0], 'EraseMode', 'xor');
         set(HC1, 'String', num2str(POS(1)));
         h=str2num(get(HC2, 'String'));
         if h==[]
            set(HAV, 'String', num2str(mean(G1(1:POS(1)))));set(HVR, 'String', num2str(std(G1(1:POS(1)))^2));
         else
            set(HAV, 'String', num2str(mean(G1(POS(1):POS(2)))));set(HVR, 'String', num2str(std(G1(POS(1):POS(2)))^2));
	    set(HDIF, 'String', num2str(POS(2)-POS(1)));
         end %if
      else
         set(HL2, 'Visible', 'off');
         POS(2)=h1(1,1);
         HL2=line([POS(2) POS(2)], [y0 ym], 'LineStyle', ':', 'Color', [0 1 0], 'EraseMode', 'xor');
         set(HC2, 'String', num2str(POS(2)));
         set(HAV, 'String', num2str(mean(G1(POS(1):POS(2))))); set(HVR, 'String', num2str(std(G1(POS(1):POS(2)))^2));
	 set(HDIF, 'String', num2str(POS(2)-POS(1)));
      end %if
      
   else
      if h3=='Cursor 1'
         set(HL1, 'Visible', 'off');
         POS(1)=h1(1,2);
         HL1=line([xlim(1) xlim(2)], [POS(1) POS(1)], 'LineStyle', ':', 'Color', [0 1 0], 'EraseMode', 'xor');
         set(HC1, 'String', num2str(POS(1)));
         h=str2num(get(HC2, 'String'));
    	 h2=G1(xlim(1):xlim(2));
         if h==[]
	    m=mean(h2(h2>=POS(1)));vr=std(h2(h2>=POS(1)))^2;
            set(HAV, 'String', num2str(m));set(HVR, 'String', num2str(vr));
         else
	    m=mean(h2(h2>=POS(1) & h2<=POS(2))); vr=std(h2(h2>=POS(1) & h2<=POS(2)))^2;
            set(HAV, 'String', num2str(m)); set(HVR, 'String', num2str(vr));
	    set(HDIF, 'String', num2str(POS(2)-POS(1)));
         end %if
      else
         set(HL2, 'Visible', 'off');
         POS(2)=h1(1,2);
         HL2=line([xlim(1) xlim(2)], [POS(2) POS(2)], 'LineStyle', ':', 'Color', [0 1 0], 'EraseMode', 'xor');
         set(HC2, 'String', num2str(POS(2)));
    	 h=G1(xlim(1):xlim(2));
    	 m=mean(h(h>=POS(1) & h<=POS(2))); vr=std(h(h>=POS(1) & h<=POS(2)))^2;
         set(HAV, 'String', num2str(m)); set(HVR, 'String', num2str(vr));
	 set(HDIF, 'String', num2str(POS(2)-POS(1)));
      end %if
   end %if
elseif strcmp(action, 'cursor'),
   h=get(HCURSOR, 'String');
   if h=='Cursor 1',
      set(HCURSOR, 'String', 'Cursor 2');
   else
      set(HCURSOR, 'String', 'Cursor 1');
   end %if
elseif strcmp(action, 'cmode'),
   h=get(HCMODE, 'String');
   if h=='Vertical  ',
      set(HCMODE, 'String', 'Horizontal');
   else
      set(HCMODE, 'String', 'Vertical  ');
   end %if
elseif strcmp(action, 'zoom'),
   s=get(HZOOM, 'String');
   if strcmp(s, 'Zoom on'), 
      set(HZOOM, 'String', 'Zoom off'); zoom on
   else
      set(HZOOM, 'String', 'Zoom on'); zoom off
      set(gcf, 'WindowButtonDownfcn', 'measure(''buttondown'', G1, G2, G3, G4)');
   end %if
elseif strcmp(action, 'ok'),
   close(gcf);
   clear global P; clear global HPOI; clear global HPOS; clear global P;
   clear global HVSC; clear global HUNDO; clear global HOK; clear global HQUIT;
   clear global HPVAL; clear global HPOIVAL; clear global YLIM;
   clear global HZOOM; clear global HCURSOR; clear global HCMODE
   clear global HC1; clear global HC2; clear global HAV; clear global HL1; clear global HL2;
   clear global HVR
   G1=[];
end %if

