%RANDMIN2  Minimization of a function by random search where the random numbers
%	  are normally distributed and additionally equally distributed
%
%Syntax	[x, iter, fmin]=randmin2(func, x0, steps, ranges, options)
%
%Input	func		name of function as string
%	x0		start parameters (row vector)
%	steps		two-rows matrix for steps (first row: mean step size,
%			second row: standard deviation)
%	ranges		lower and upper ranges for parameters (two rows)
%	options(1)	number of iterations [200]
%	options(2)	termination criterion for fmin [.1]
%	options(3)	= 1 : display of intermediate steps  [0]
%
%Output	x		optimized parameter vector
%	iter		number of iterations
%	fmin		minimum of func reached
%
%	(c) A.K. 12.8.1995

function [x, iter, fmin]=randmin2(func, x0, steps, ranges, options)

if nargin<4, 
   options(1)=200; options(2)=.1; options(3)=0;
end %if
fminalt=0;
lx=length(x0);
del=ranges(2,:)-ranges(1,:);

str=[func '(x0)'];

n=1;
fmin=eval(str); x=x0;
while n<options(1) & fmin>options(2),
      dx=randn(1,lx).*steps(2,:)+steps(1,:);
      h=rand(1,lx); h=(h>.5)-(h<=.5);
      dx=dx.*h;
      xn(1,:)=x+dx;
      h1=xn(1,:)<ranges(1,:); h2=xn(1,:)>ranges(2,:);
      xn(1,h1)=ranges(1, h1);
      xn(1,h2)=ranges(2, h2);
      str=[func '(xn(1,:))'];
      fn(1)=eval(str);
      xn(2,:)=rand(size(x0)).*del+ranges(1,:);
      str=[func '(xn(2,:))'];
      fn(2)=eval(str);
      n=n+1;
      h2=min(fn);
      if h2<fmin
         fminalt=fmin;fmin=h2; x=xn(find(fn==h2),:);
         if options(3)==1, disp(['Iteration:' num2str(n) ' fmin:' num2str(fmin) ' x:' num2str(x)]); end
      end %if
end %while
iter=n;
