function ac = acorr(data, n, u, s)
%ACORR  Calculates the Autocorrelation function in time domain
%
%Syntax	AC = acorr(DATA[, N[, U[, S]]])
%
%Input	DATA	
%	N	Number to calculate (N<length(DATA))
%	U 	Number of subdivisions
%	S	Stepsize in points
%	
%Output	AC	Autocorrelation function
%
%	(see e.g. Castro I.P., An Introduction to the digital analysis
%	of stationary signals, 1989)
%
%	(c) A.K. 28.10.1995

if nargin<4, s=1; end
if nargin<3, u=1; end
if nargin<2, n=length(data)/2; end
bereich=length(data)/u;
len=bereich;

a=zeros(n/s,1); ac=a;
for i=0:u-1
    d=data(bereich*i+1:bereich*(i+1));
    k=1;
    for m=0:s:n-1
	a(k)=1/(len-m)*sum(d(1:len-m).*d(1+m:len));
	k=k+1;
    end %for m
    ac=ac+a;
end %for i
ac=ac./u;

