function pds = powers(data, n)
%POWERS	Calculates the power spectral density
%
%Syntax	PDS = powers(DATA[, N])
%
%Input	DATA	Spaltenvektor mit Daten
%	N	Anzahl Punkte fuer eine FT [length(data)]
%	
%Output	PDS	Leistungsdichtespektrum
%
%Remark	Yields the minimum spectral variance by subdivision of data in
%	k segments (see Numerical Recipes).
%	Uses the triangular window.
%	Scaling of pds is so that sum(pds) = std(data)^2
%	(use powers2 for differnt scaling)
%
%	(c) A.K. 29.7.1994

if nargin<2, n=length(data); end
len = length(data); m = n/2; mm=m+m;
k=len/m-1; %Anzahl Unterteilungen
pds=zeros(m, 1); den = 0;

% Usage of the triangular window
sumw = sum(wtri(ones(mm,1)).^2);

for kk=0:k-1,
%   Usage of the triangular window
    fdata = fft(wtri(data(kk*m+1:kk*m+mm)));
    pds = pds + 2*abs(fdata(1:m)).^2;
    den = den + sumw;
end %for kk
den = n*den;
pds = pds./den;

