function [fr0,fr1] = opCacheWhich(x1, x2, tNow)
% [fr0,fr1] = opCacheWhich(x1, x2)
% Given a start frame x1 and end frame x2, figure out which frames aren't
% in the cache, returning two vectors of start- and end-frames that
% need computing.  Also, time-stamp the frames that ARE in the cache 
% as being used at time tNow.

global opCacheIndex

% Get slot numbers that refer to frames that are in the cache.
present = find(opCacheIndex(1,:) >= x1 & opCacheIndex(1,:) <= x2);

% Set time stamp.
opCacheIndex(2, present) = tNow * ones(1,length(present));

% Make a vector of frame numbers that are missing from the cache.
x = 1 : x2-x1+1;				% in ascending order
x(opCacheIndex(1,present) - x1 + 1) = [];

% Collapse consecutive runs into [start,end] pairs.
[fr0,fr1] = consec(x);
fr0 = fr0 + x1 - 1;
fr1 = fr1 + x1 - 1;
