function hop = opHopSizeF(ch, len)
% opHopSizeF
% Set the hop size of the current channel to whatever the popup
% says.  This is called when the user changes the popup value.
%
% opHopSizeF(ch)
% Set the displayed popup to the correct value for channel ch.
% 
% opHopSizeF('default')
% Initialize the hop size to the default value.
% 
% string = opHopSizeF('string')
% Return the popup string with the |-separated list of names.
 
global opHopSizePopup opHopSize opc

if (nargin < 1)
  x = get(opHopSizePopup, 'Value');
  if (x > 1)
    prev = opHopSize(opc);
    opHopSize(opc) = 2 ^ (x-6);
    if (opHopSize(opc) ~= prev), opRefresh(opc,1); end
  else
    opHopSizeF(opc);			% reset popup to correct value
  end
else
  if (isstr(ch))
    if (strcmp(ch, 'default'))
      opHopSize(len) = 2 ^ (-1); 	% default is 1/2
    elseif (strcmp(ch, 'string'))
      hop = 'Hop Size|  1/16|  1/8|  1/4|  1/2|    1|    2|    4|    8|  16';
    end
  else
    set(opHopSizePopup, 'Value', round(log(opHopSize(ch)) / log(2) + 6));
  end
end
