function ret = opMeasure(cmd, x0, x1, x2)
% opMeasure('init', chan)
%     Initialize for a given channel.
%
% opMeasure('newmenu', chan, menu)
%     Set up the pulldown menu for display.
%
% opMeasure('checkmenu')
%     Set up the check-marks on the menu appropriately.
%
% opMeasure('flip', n)
%     Flip measure #n from on to off or vice versa.
%
% opMeasure('painttext', chan)
%     Display the names of the various measures at location opMeasurePos.
%
% opMeasure('newpt', chan, pt)
%     Display the values of the various measures for the given [t f] point.
%     From opMouseClick.
%
% vec = opMeasure('logpt', chan, pt);
%     Compute and return a line for the data log.  From opMouseClick.
%
% opMeasure('newsel', chan)
%     Display the values of the various measures for the current selection.
%
% opMeasure('setmeasures', chan, measures, prefversion)
%     Use the given vector of measures to set which ones will be shown here.
%     Does not do any redisplay.
%
% x = opMeasure('getone', chan, measurename)
%     Given the name of a measure, return its current value.

global opc opMeas opMeasureNames opMeasureMenus opMeasureTexts opFig
global opMeasureNums opMeasurePos opNsamp opSrate opHopSize opZeroPad opLog
global opSelT0 opSelT1 opSelF0 opSelF1 opWindowAxes opMeasureGram opMeasureSel
global opChannelNum opLastClick

if (strcmp(cmd, 'init'))
  opMeasureNames = ...
    str2mat(...
       str2mat(    'total length',...
                   'sample rate',...
		   'time',...
		   'frequency',...
		   'amplitude',...
		   'sample #',...
		   'start time',...
		   'end time',...
		   'duration'),...
       str2mat(    'low freq',...
                   'high freq',...
		   'bandwidth',...
		   'energy',...
		   'peak freq',...
		   'peak time',...
		   'peak amp',...
		   'centr. time',...
		   'centr. freq'),...
       str2mat(    '# datalogs',...
                   'channel #'));
  newtext = 0;				% need to paint new texts?
  if (x0 == 1 & exist('opMeas') ~= 1)
    % BUMP THE PREFS VERSION NUMBER WHEN CHANGING THESE, also fix 'setmeasures'.
    %
    % In order, these are the initial set of measures, the measures that
    % require a selection to exist, and the measures that need a gram computed.
    opMeas(x0,:) =[0 0 1 1 1 0 0 0 1 0 0 1 0 0 0 0 0 0 0 0];
    opMeasureSel =[0 0 0 0 0 0 1 1 1 1 1 1 1 1 1 1 1 1 0 0];
    opMeasureGram=[0 0 0 0 0 0 0 0 0 0 0 0 1 1 1 1 1 1 0 0];
    newtext = 1;
  else 
    opMeas(x0,:) = opMeas(1,:);
    
    % Retain old text objects?  Many conditions must be satisfied:
    if (x0 > nRows(opMeasureTexts) | ~exist('opFig'))
      newtext = 1;
    elseif (~any(get(0, 'Children') == opFig))
      newtext = 1;
    elseif (~any(get(opFig, 'Children') == opWindowAxes))
      newtext = 1;
    elseif (~any(get(opWindowAxes, 'Children') == opMeasureTexts(x0,1)))
      newtext = 1;
    end
  end
  if (newtext)
    opMeasureTexts(x0,:) = zeros(1,length(opMeas));
    opMeasureNums (x0,:) = zeros(1,length(opMeas));
  end

elseif (strcmp(cmd, 'newmenu'))
  set(x1, 'Callback', 'opMeasure(''checkmenu'');');
  for i = 1:nRows(opMeasureNames)
    opMeasureMenus(x0, i) = uimenu(x1,'Label', opMeasureNames(i,:), ...
	'Callback', ['opMeasure(''flip'', ',num2str(i),')']);
  end

elseif (strcmp(cmd, 'checkmenu'))
  for i = 1:nCols(opMeasureMenus)
    if (opMeas(opc,i))
      set(opMeasureMenus(opc,i), 'Checked', 'on')
    else
      set(opMeasureMenus(opc,i), 'Checked', 'off')
    end
  end
  
elseif (strcmp(cmd, 'flip'))
  opMeas(opc,x0) = ~opMeas(opc,x0);
  opMeasure('painttext', opc);
  
elseif (strcmp(cmd, 'painttext'))
  xoff = 67;				% pixels from name to value
  axes(opWindowAxes);			% background axes, same size as window
  delete(opMeasureTexts(x0, find(opMeasureTexts(x0,:))));
  delete(opMeasureNums (x0, find(opMeasureNums (x0,:))));
  x = find(opMeas(opc,:));
  t = []; n = [];
  if (length(x))
    incr = iff(strncmp(computer, 'SUN', 3) | strncmp(computer, 'SOL', 3), ...
		-7, 0);				     % font size is wrong on Sun
    names = sub([opMeasureNames(x,:), 10*ones(length(x),1)].',0).';
    t = uiMultiText(opMeasurePos(x0,1), opMeasurePos(x0,2), ...
	names(1:length(names)-1), incr, 'FontSize', 10, 'Units','pixels');
    n = uiMultiText(opMeasurePos(x0,1)+xoff, opMeasurePos(x0,2), ...
	setstr(10*ones(1,length(x)-1)), incr, 'FontSize',10, 'Units','pixels');
  end
  opMeasureTexts(x0,:) = [t, zeros(1, nCols(opMeas) - length(t))];
  opMeasureNums (x0,:) = [n, zeros(1, nCols(opMeas) - length(n))];
  opMeasure('newsel',x0);

elseif (strcmp(cmd, 'newpt') | strcmp(cmd, 'newsel') | strcmp(cmd, 'logpt')...
      | strcmp(cmd, 'getone'))

  % p says whether to get 'point' measurements
  % s says whether to get 'selection' measurements

  sel = [];
  if (opSelect(x0))
    sel = [opSelT0(x0) opSelF0(x0) opSelT1(x0) opSelF1(x0)]; 
  end

  axes(opWindowAxes);
  if (strcmp(cmd, 'logpt') | strcmp(cmd, 'newpt'))
    p = 1;
    opLastClick = x1;
  end
  
  % set up list as a boolean vector of which measurements to get
  if (strcmp(cmd, 'getone'))
    p = 1;
    list = strmatch(x1, opMeasureNames)';
    if (sum(list) ~= 1), error(['Unknown measure name: ', x1]); end
    s = opMeasureSel(find(list)) & length(sel);
  else                        
    list = opMeas(x0,:);
    s = (strcmp(cmd, 'logpt') | strcmp(cmd, 'newsel')) & length(sel);
  end
  
  % fetch spect if necessary
  if (s & any(list & opMeasureGram))
    [spect,px,bx] = opGetSpect(x0, sel(1), sel(3), sel(2), sel(4));
    [nr,nc] = size(spect);
  end

  amp = 20 / log(10);
  k = 0;
  lc = opLastClick;
  for i = find(list)
    v = [];
    if     i==1     , v = opNsamp(x0) / opSrate(x0);	suf = 's'; % total len
    elseif i==2     , v = opSrate(x0);			suf = 'Hz';% samp. rate
    elseif i==3  & p, v = lc(1);			suf = 's'; % time
    elseif i==4  & p, v = lc(2);			suf = 'Hz';% frequency
    elseif i==5  & p,						   % amplitude
      v = amp * opGetSpect(x0, lc(1),lc(1),lc(2),lc(2));suf = 'dB';
      if (~length(v)), v = 0; end
    elseif i==6  & p, v = round(lc(1)*opSrate(x0));	suf = '';  % sample no.
    elseif i==7  & s, v = sel(1);			suf = 's'; % start time
    elseif i==8  & s, v = sel(3);			suf = 's'; % end time
    elseif i==9  & s, v = abs(sel(3)-sel(1));		suf = 's'; % duration
    elseif i==10 & s, v = sel(2);			suf = 'Hz';% low freq
    elseif i==11 & s, v = sel(4);			suf = 'Hz';% high freq
    elseif i==12 & s, v = abs(sel(4)-sel(2));		suf = 'Hz';% bandwidth
    elseif i==13 & s,						   % energy
      v = amp * log(sum(sum(exp(spect).^2))*opHopSize(x0) / (1+opZeroPad(x0)));
      suf = 'dB';
    elseif i==14 & s,						   % peak freq
      [dummy,v] = max(spect(:));
      v = (rem(v-1,nr)       + 0.5) / nr * (bx(4)-bx(2)) + bx(2); suf = 'Hz';
    elseif i==15 & s,						   % peak time
      [dummy,v] = max(spect(:));
      v = (floor((v-1) / nr) + 0.5) / nc * (bx(3)-bx(1)) + bx(1); suf = 's';
    elseif i==16 & s, v = amp * max(max(spect));	suf = 'dB';% peak amp
    elseif i==17 & s,						   % centr time
      n = nCols(spect);
      v = sum([zeros(1,n); exp(spect).^2]);		suf = 's';
      v = sum(v .* ((0.5:n) / n * (bx(3)-bx(1)) + bx(1))) / sum(v);
    elseif i==18 & s,						   % centr freq
      n = nRows(spect);
      v = sum([zeros(n,1), exp(spect).^2]');		suf = 's';
      v = sum(v .* ((0.5:n) / n * (bx(4)-bx(2)) + bx(2))) / sum(v);
    elseif i==19, v = nRows(opLog);	                suf = '';  % # datalogs
    elseif i==20, v = opChannelNum;	                suf = '';  % channel #
    end
    k = k+1;
    if (strcmp(cmd, 'logpt') | strcmp(cmd, 'getone'))
      if (~length(v)), v = NaN; end
      ret = [ret, v];
    else
      % figure out number format for v
      if (length(v))
	if (v == round(v) & abs(v) < 100000)		% small integer
	  str = sprintf('%d %s', v, suf);
	else
	  y = floor(log10(abs(v)));
	  if (-3 < y & y < 5), str = sprintf('%-6.*f %s', 4 - y, v, suf);
	  else                 str = sprintf('%-.5ge%d %s', v/10^y, y,suf);
	  end
	end
	set(opMeasureNums(x0,k), 'String', str);
      elseif (strcmp(cmd, 'newsel') & opMeasureSel(i))
	% no v and it's a selection-display ==> erase selection measures
	set(opMeasureNums(x0,k), 'String', '');
      end
    end
  end

elseif (strcmp(cmd, 'setmeasures'))
  chan = x0;
  measures = x1;
  version = x2;
  if (version <= 1), opMeas(chan,:) = [measures, 0]; end	% # datalogs
  if (version <= 3), opMeas(chan,:) = [measures, 0]; end	% channel #
  if (version <= 4), opMeas(chan,:) = measures; end
  if (version <= 5), opMeas(chan,:) = [measures(1:16) 0 0 measures(17:18)];
  else
    error('Osprey internal error: Version number of prefs file is too large.');
  end

else
  error(['Osprey internal error: Unknown command: ', cmd]);
end
