function opMenus(ch)
% opMenus(ch)
% Create the pulldown menus in the menu bar.
% If they already exist, return immediately.

global opFig opFileMenu opChannelMenu opHScrollMenu opVScrollMenu
global opDataLogMenu

if (length(opFileMenu) & any(get(opFig, 'Children') == opFileMenu))
  return;
end

% Menus.
opFileMenu = uimenu('Label', 'File  ');
f = opFileMenu;
uimenu(f, 'Label', 'Open...',         'Callback', 'opOpen(''open'');');
uimenu(f, 'Label', 'Store gram',      'Callback', 'opSaveSpect');
uimenu(f, 'Label', 'Play whole sound','Callback', 'opPlay(''all'')');
pr = uimenu(f, 'Label', 'Print');
uimenu(pr, 'Label', 'full page',      'Callback', 'opPrint(''fullpage'')');
uimenu(pr, 'Label', 'screen size',    'Callback', 'opPrint(''wysiwyg'')');
uimenu(pr, 'Label', 'many pages...',  'Callback', 'opPrint(''manypages'')');
uimenu(pr, 'Label', 'EPS file...',    'Callback', 'opPrint(''eps'')');
opChannelMenu = uimenu(f, 'Label', 'Channel');
opChannel('makemenu');
uimenu(f, 'Label', 'Quit',	      'Callback', 'opOpen(''quit'')');

e = uimenu('Label','Edit  ');
uimenu(e, 'Label', 'Copy',	      'Callback', 'opEdit(''copy'');');

s = uimenu('Label', 'Select  ');
uimenu(s, 'Label', 'None',            'Callback', 'opSelect(''none'')');
uimenu(s, 'Label', 'All',             'Callback', 'opSelect(''all'')');
uimenu(s, 'Label', 'All, H only',     'Callback', 'opSelect(''all-h'')');
uimenu(s, 'Label', 'All, V only',     'Callback', 'opSelect(''all-v'')');
uimenu(s, 'Label', 'Window, H only',  'Callback', 'opSelect(''win-h'')');
uimenu(s, 'Label', 'Window, V only',  'Callback', 'opSelect(''win-v'')');

z = uimenu('Label', 'Zoom  ');
uimenu(z, 'Label', 'to whole sound',  'Callback', 'opZoom(''all'')');
uimenu(z, 'Label', 'to selection',    'Callback', 'opZoom(''sel'')');
uimenu(z, 'Label', 'to sel., H only', 'Callback', 'opZoom(''sel-h'')');
uimenu(z, 'Label', 'to sel., V only', 'Callback', 'opZoom(''sel-v'')');

w = uimenu('Label','Window  ');
uimenu(w, 'Label', 'Redraw',    	'Callback', 'opRedraw(''position'')');
uimenu(w, 'Label', 'Manual sizing...',  'Callback', 'opRedraw(''mansize'')');
uimenu(w, 'Label', 'Manual scaling...', 'Callback', 'opRedraw(''manscale'')');
uimenu(w, 'Label', 'Manual T/F limits...','Callback','opRedraw(''manTF'')');
drawnow;

p = uimenu('Label', 'Preferences  ');
uimenu(p, 'Label', 'Load...', 'Callback', 'opPrefSave(''load'');');
uimenu(p, 'Label', 'Save...', 'Callback', 'opPrefSave(''save'');');
ms = uimenu(p, 'Label', 'Measurements');
opMeasure('newmenu', ch, ms);
hs = uimenu(p, 'Label', 'H Scroll', 'Callback','opScrollAmount(''s'')');
opHScrollMenu = hs;		% see opScrollAmount
uimenu(hs, 'Label', 'H slider scrolls by...');
uimenu(hs, 'Label', '     1/4 screen', 'Callback','opScrollAmount(''h'',1/4)');
uimenu(hs, 'Label', '     1/2 screen', 'Callback','opScrollAmount(''h'',1/2)');
uimenu(hs, 'Label', '     3/4 screen', 'Callback','opScrollAmount(''h'',3/4)');
uimenu(hs, 'Label', '      1   screen','Callback','opScrollAmount(''h'',1)');
vs = uimenu(p, 'Label', 'V Scroll', 'Callback','opScrollAmount(''s'')');
opVScrollMenu = vs;
uimenu(vs, 'Label', 'V slider scrolls by...');
uimenu(vs, 'Label', '     1/4 screen', 'Callback','opScrollAmount(''v'',1/4)');
uimenu(vs, 'Label', '     1/2 screen', 'Callback','opScrollAmount(''v'',1/2)');
uimenu(vs, 'Label', '     3/4 screen', 'Callback','opScrollAmount(''v'',3/4)');
uimenu(vs, 'Label', '      1   screen','Callback','opScrollAmount(''v'',1)');
gc = uimenu(p, 'Label', 'Colormap');
x = 'opColorMap(''setgram'', '; y = ');';
uimenu(gc, 'Label','     gray',     'Callback', [x '''flipud(gray(n))''' y]);
uimenu(gc, 'Label','inverted gray', 'Callback', [x '''gray(n)'''         y]);
uimenu(gc, 'Label','     bone',     'Callback', [x '''flipud(bone(n))''' y]);
uimenu(gc, 'Label','inverted bone', 'Callback', [x '''bone(n)'''         y]);
uimenu(gc, 'Label','      hot',     'Callback', [x '''hot(n)'''          y]);
cs = uimenu(p, 'Label', 'Selection Color');
x = 'opColorMap(''setsel'', '; y = ');';
uimenu(cs, 'Label','Yellow    ', 'Callback', [x '[1 1 0]' y]);
uimenu(cs, 'Label','  Red',      'Callback', [x '[1 0 0]' y]);
uimenu(cs, 'Label','Green',      'Callback', [x '[0 1 0]' y]);
uimenu(cs, 'Label',' Aqua',      'Callback', [x '[0 1 1]' y]);
uimenu(cs, 'Label','Purple',     'Callback', [x '[1 0 1]' y]);
uimenu(cs, 'Label',' Blue',      'Callback', [x '[0 0 1]' y]);
ss = uimenu(p, 'Label', 'Misc.', 'Callback', 'opPrefs(''checkmenu'');');
opPrefs('newmenu', ch, ss);

% Datalog menu is not always present.
d = uimenu('Label', 'Datalog  ');
opDataLogMenu = uimenu(d,'Label','Enable', 'Callback','opDataLog(''switch'')');
uimenu(d, 'Label', 'Save...',       'Callback', 'opDataLog(''save'')');
uimenu(d, 'Label', 'Save ASCII...', 'Callback', 'opDataLog(''saveASCII'')');
uimenu(d, 'Label', 'Clear', 'Callback', 'opDataLog(''clear'')');
uimenu(d, 'Label', 'Remove last entry', 'Callback', 'opDataLog(''truncate'')');
