function win = opWinTypeF(cmd, ch)
% opWinTypeF
% Set the window type of the current channel to whatever the popup
% says.  This is called when the user changes the popup value.
%
% opWinTypeF(ch)
% Set the displayed popup to the correct value for channel ch.
% Same as 'disp', below.
% 
% win = opWinTypeF(len, ch)
% Return a window of length len (as a column vector) to multiply the
% samples by before FFTing.  This is called from the spectrogram
% calculator in opComputeSpect.  The Kaiser window uses beta=5.
%
% num = opWinTypeF('default', chan)
% Set the window type to the default value (Hamming).
% 
% str = opWinTypeF('string')
% Return the popup string with the |-separated list of names.
%
% opWinTypeF('disp', ch)
% Set the displayed popup to the correct name for channel ch.
%
% win = opWinTypeF('name', ch)
% Return the name of the window for channel ch. Used in printing.

global opWinTypePopup opWinType opc

if (nargin < 1)
  x = get(opWinTypePopup, 'Value');
  if (x > 1)
    prev = opWinType(opc);
    opWinType(opc) = x;
    if (prev ~= x), opRefresh(opc,1); end
  else
    opWinTypeF('disp', opc);			% reset popup to correct value
  end
elseif (isstr(cmd))
  if (strcmp(cmd, 'default'))
    opWinType(ch) = 5;				% default is Hamming
  elseif (strcmp(cmd, 'string'))
    win = ['Window Type|    Kaiser|   Bartlett|  Hanning| Hamming', ...
	    '| Blackman|Rectangular'];
  elseif (strcmp(cmd, 'name'))
    win = 'Kaiser   Bartlett Hanning  Hamming  Blackman Rectangle';
    win = win(opWinType(ch)*9-17 : opWinType(ch)*9-9);
  elseif (strcmp(cmd, 'disp'))
    set(opWinTypePopup, 'Value', opWinType(ch));
  else 
    error('Osprey internal error: Bad string passed to opWinTypeF.');
  end
else
  if (nargin < 2)
    opWinTypeF('disp', cmd);
  else
    len = cmd;
    typ = opWinType(ch);
    if (typ == 2)
      win = kaiser(len, 5);
    elseif (typ == 3)
      win = bartlett(len);
    elseif (typ == 4)
      win = hanning(len);
    elseif (typ == 5)
      win = hamming(len);
    elseif (typ == 6)
      win = blackman(len);
    elseif (typ == 7)
      win = ones(len, 1);			% rectangular
    else
      error('Hmmm.  Unknown window type, which should be impossible.');
    end
  end
end
