function osprey(filename, srate)
%osprey      Display a spectrogram with various tunable parameters.
%
% This version is 1.2, dated 18 Nov 96.
%
% Osprey is a spectrogram viewer that allows manipulation of a sound 
% spectrogram in various ways.  A more detailed explanation, including 
% where to get it, how to run it, and how to troubleshoot it, is found
% in the README file in the osprey directory.
%
% There are several commands for starting up Osprey:
%
%    osprey
%    osprey('filename.ext')
%    osprey('filename', 'type')
%    osprey('filename', samplingrate)
%    osprey(samplevector, samplingrate)
%
% The simplest way to start Osprey is just to type "osprey" at a MATLAB prompt,
% then pick a sound file in the dialog box that shows up.  You can also type
% "osprey filename.ext" to start it up looking at the given file.
%
% Osprey determines the sound file type from the file extension. If your file
% name does not have an extension, you start Osprey with two arguments: the
% first is the file name, and the second is an extension specifying the file
% type.  For instance, "osprey('myfile','wav')" would start up Osprey on the
% WAV file 'myfile'.
%
% If you use binary files of linear 16-bit mono samples, then you can
% type "osprey('filename', samplingRate)" to specify the file name and
% sampling rate of the file.  For example, "osprey('myfile', 800)"
% will start up Osprey with a binary file sampled at 800 Hz.
%
% Finally, you can start up Osprey on a vector of samples.  In this case, the
% second argument passed in must be the sampling rate.

if (~exist('uiMultiText'))
  disp(' ')
  disp('Osprey cannot access the "utils" directory.  Make sure that this')
  disp('directory is installed inside the osprey directory, and that both')
  disp('of these directories are included in your path.  Do "help path" to')
  disp('find out about MATLAB''s search path and adding directories to it.')
  disp(' ')
  disp('Also, try "help matlabrc" to find out about executing commands when')
  disp('MATLAB starts up.')
  return
end

if (~isstr(filename) & nargin < 2)
  disp(' ')
  disp('When passing a signal for osprey to display, you must also specify')
  disp('the sampling rate.  Like this:  osprey(myvector, 44100)')
  disp(' ')
  return
end

if (nargin < 1)
  opOpen('open');
  return
end

if (isstr(filename) & nargin >= 2)
  % If srate was specified, create a second row of filename.  See soundIn.m.
  if (isstr(srate))
    ext = srate;
  else
    ext = ['b' num2str(floor(srate/100))];
    r = rem(srate, 100);
    if (r)
      ext = [ext, '_', num2str(r)];
    end
  end
  filename = str2mat(filename, ext);
end

ch = 1;
opMeasure('init',ch);			% initialize the measurements
opNewChan(ch);				% initialize most parameters
if (isstr(filename))
  opSetFileInfo(ch, filename);		% get file info (name,srate,length,...)
else
  opSetFileInfo(ch, filename, srate);	% set signal info (name,srate,length,..)
end
f = opFileName(ch, 'getsound');		% get filename, or '' for sample vectors
opInitialFrame(ch)			% initial time and freq bounds
opRedraw('repaint', f, 1);		% compute spect, paint window
opPlay('setratetext', ch);		% set up popup

opDataSizeF(ch);
opZeroPadF(ch);
opHopSizeF(ch);
opWinTypeF(ch);
