function bool = yesno(query, def)
%YESNO		Ask the user a yes-or-no question, return 1 or 0 accordingly.
%
% bool = yesno(query [,def])
%    Prompt the user with the query.  Get a typed answer, and return 1 if
%    the answer is 'Y' or 'y' or '1', 0 otherwise.  Def says what to return
%    if the user just presses return; it defaults to 1.

if (nargin < 2)
  def = 1;
end

% Add a trailing space if necessary.
if (last(query) ~= ' ')
  query = [query ' '];
end

x = deblank(setstr(input(query, 's')));
if (length(x) == 0)
  bool = def;
elseif (x(1) == '1' | lower(x(1)) == 'y')
  bool = 1;
elseif (x(1) == '0' | lower(x(1)) == 'n')
  bool = 0;
else
  disp(' ')
  disp('Please answer yes or no.')
  bool = yesno(query, def);
end
