function [ret,x0,str,ts,xts]=gribs(t,x,u,flag);
%GRIBS	is the M-file description of the SIMULINK system named GRIBS.
%	The block-diagram can be displayed by typing: GRIBS.
%
%	SYS=GRIBS(T,X,U,FLAG) returns depending on FLAG certain
%	system values given time point, T, current state vector, X,
%	and input vector, U.
%	FLAG is used to indicate the type of output to be returned in SYS.
%
%	Setting FLAG=1 causes GRIBS to return state derivatives, FLAG=2
%	discrete states, FLAG=3 system outputs and FLAG=4 next sample
%	time. For more information and other options see SFUNC.
%
%	Calling GRIBS with a FLAG of zero:
%	[SIZES]=GRIBS([],[],[],0),  returns a vector, SIZES, which
%	contains the sizes of the state vector and other parameters.
%		SIZES(1) number of states
%		SIZES(2) number of discrete states
%		SIZES(3) number of outputs
%		SIZES(4) number of inputs
%		SIZES(5) number of roots (currently unsupported)
%		SIZES(6) direct feedthrough flag
%		SIZES(7) number of sample times
%
%	For the definition of other parameters in SIZES, see SFUNC.
%	See also, TRIM, LINMOD, LINSIM, EULER, RK23, RK45, ADAMS, GEAR.

% Note: This M-file is only used for saving graphical information;
%       after the model is loaded into memory an internal model
%       representation is used.

% the system will take on the name of this mfile:
sys = mfilename;
new_system(sys)
simver(1.3)
if (0 == (nargin + nargout))
     set_param(sys,'Location',[109,76,894,581])
     open_system(sys)
end;
set_param(sys,'algorithm',     'RK-45')
set_param(sys,'Start time',    '0.0')
set_param(sys,'Stop time',     '999999')
set_param(sys,'Min step size', '0.0001')
set_param(sys,'Max step size', '10')
set_param(sys,'Relative error','1e-3')
set_param(sys,'Return vars',   '')
set_param(sys,'AssignWideVectorLines','on');


%     Subsystem  ['GRIBS',13,'(Quaternions)'].

new_system([sys,'/',['GRIBS',13,'(Quaternions)']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)']],'Location',[21,61,555,559])


%     Subsystem  ['GRIBS',13,'(Quaternions)/Atmosphere',13,'+ params'].

new_system([sys,'/',['GRIBS',13,'(Quaternions)/Atmosphere',13,'+ params']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Atmosphere',13,'+ params']],'Location',[61,139,873,665])

add_block('built-in/Note',[sys,'/',['GRIBS',13,'(Quaternions)/Atmosphere',13,'+ params/alpha deg']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Atmosphere',13,'+ params/alpha deg']],...
		'ForeGround',1,...
		'BackGround',3,...
		'Font Size',9,...
		'position',[600,295,605,300])

add_block('built-in/Note',[sys,'/',['GRIBS',13,'(Quaternions)/Atmosphere',13,'+ params/sigma deg']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Atmosphere',13,'+ params/sigma deg']],...
		'ForeGround',1,...
		'BackGround',3,...
		'Font Size',9,...
		'position',[600,365,605,370])

add_block('built-in/Note',[sys,'/',['GRIBS',13,'(Quaternions)/Atmosphere',13,'+ params/lambda deg']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Atmosphere',13,'+ params/lambda deg']],...
		'ForeGround',1,...
		'BackGround',3,...
		'Font Size',9,...
		'position',[595,400,600,405])

add_block('built-in/Note',[sys,'/',['GRIBS',13,'(Quaternions)/Atmosphere',13,'+ params/beta deg']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Atmosphere',13,'+ params/beta deg']],...
		'ForeGround',1,...
		'BackGround',3,...
		'Font Size',9,...
		'position',[605,330,610,335])

add_block('built-in/Inport',[sys,'/',['GRIBS',13,'(Quaternions)/Atmosphere',13,'+ params/NED']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Atmosphere',13,'+ params/NED']],...
		'ForeGround',1,...
		'BackGround',4,...
		'Port','2',...
		'position',[65,370,85,390])

add_block('built-in/Inport',[sys,'/',['GRIBS',13,'(Quaternions)/Atmosphere',13,'+ params/U,V,W',13,'P,Q,R']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Atmosphere',13,'+ params/U,V,W',13,'P,Q,R']],...
		'ForeGround',1,...
		'BackGround',4,...
		'position',[65,250,85,270])


%     Subsystem  ['GRIBS',13,'(Quaternions)/Atmosphere',13,'+ params/Scheduling',13,'Parameters'].

new_system([sys,'/',['GRIBS',13,'(Quaternions)/Atmosphere',13,'+ params/Scheduling',13,'Parameters']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Atmosphere',13,'+ params/Scheduling',13,'Parameters']],'Location',[379,197,1007,751])


%     Subsystem  ['GRIBS',13,'(Quaternions)/Atmosphere',13,'+ params/Scheduling',13,'Parameters/Lambda (-180 to +180)'].

new_system([sys,'/',['GRIBS',13,'(Quaternions)/Atmosphere',13,'+ params/Scheduling',13,'Parameters/Lambda (-180 to +180)']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Atmosphere',13,'+ params/Scheduling',13,'Parameters/Lambda (-180 to +180)']],'Location',[302,252,602,429])

add_block('built-in/Inport',[sys,'/',['GRIBS',13,'(Quaternions)/Atmosphere',13,'+ params/Scheduling',13,'Parameters/Lambda (-180 to +180)/U,V,W,',13,'P,Q,R']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Atmosphere',13,'+ params/Scheduling',13,'Parameters/Lambda (-180 to +180)/U,V,W,',13,'P,Q,R']],...
		'ForeGround',1,...
		'BackGround',4,...
		'position',[25,70,45,90])

add_block('built-in/MATLAB Fcn',[sys,'/',['GRIBS',13,'(Quaternions)/Atmosphere',13,'+ params/Scheduling',13,'Parameters/Lambda (-180 to +180)/MATLAB Fcn']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Atmosphere',13,'+ params/Scheduling',13,'Parameters/Lambda (-180 to +180)/MATLAB Fcn']],...
		'ForeGround',1,...
		'BackGround',3,...
		'MATLAB Fcn','r2d*atan2(u(2),u(3))',...
		'Output Width','1')
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Atmosphere',13,'+ params/Scheduling',13,'Parameters/Lambda (-180 to +180)/MATLAB Fcn']],...
		'position',[125,63,185,97])

add_block('built-in/Outport',[sys,'/',['GRIBS',13,'(Quaternions)/Atmosphere',13,'+ params/Scheduling',13,'Parameters/Lambda (-180 to +180)/lamda']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Atmosphere',13,'+ params/Scheduling',13,'Parameters/Lambda (-180 to +180)/lamda']],...
		'ForeGround',1,...
		'BackGround',4,...
		'position',[250,70,270,90])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Atmosphere',13,'+ params/Scheduling',13,'Parameters/Lambda (-180 to +180)']],[50,80;120,80])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Atmosphere',13,'+ params/Scheduling',13,'Parameters/Lambda (-180 to +180)']],[190,80;245,80])


%     Finished composite block ['GRIBS',13,'(Quaternions)/Atmosphere',13,'+ params/Scheduling',13,'Parameters/Lambda (-180 to +180)'].

set_param([sys,'/',['GRIBS',13,'(Quaternions)/Atmosphere',13,'+ params/Scheduling',13,'Parameters/Lambda (-180 to +180)']],...
		'ForeGround',1,...
		'BackGround',2,...
		'position',[360,300,390,350])


%     Subsystem  ['GRIBS',13,'(Quaternions)/Atmosphere',13,'+ params/Scheduling',13,'Parameters/Sigma (0 to +180)'].

new_system([sys,'/',['GRIBS',13,'(Quaternions)/Atmosphere',13,'+ params/Scheduling',13,'Parameters/Sigma (0 to +180)']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Atmosphere',13,'+ params/Scheduling',13,'Parameters/Sigma (0 to +180)']],'Location',[177,216,810,400])

add_block('built-in/Inport',[sys,'/',['GRIBS',13,'(Quaternions)/Atmosphere',13,'+ params/Scheduling',13,'Parameters/Sigma (0 to +180)/Vt']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Atmosphere',13,'+ params/Scheduling',13,'Parameters/Sigma (0 to +180)/Vt']],...
		'ForeGround',1,...
		'BackGround',4,...
		'Port','2',...
		'position',[65,105,85,125])

add_block('built-in/Inport',[sys,'/',['GRIBS',13,'(Quaternions)/Atmosphere',13,'+ params/Scheduling',13,'Parameters/Sigma (0 to +180)/U,V,W',13,'P,Q,R']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Atmosphere',13,'+ params/Scheduling',13,'Parameters/Sigma (0 to +180)/U,V,W',13,'P,Q,R']],...
		'ForeGround',1,...
		'BackGround',4,...
		'position',[65,45,85,65])

add_block('built-in/Mux',[sys,'/',['GRIBS',13,'(Quaternions)/Atmosphere',13,'+ params/Scheduling',13,'Parameters/Sigma (0 to +180)/Mux1']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Atmosphere',13,'+ params/Scheduling',13,'Parameters/Sigma (0 to +180)/Mux1']],...
		'ForeGround',1,...
		'BackGround',0,...
		'inputs','2',...
		'position',[290,55,320,90])

add_block('built-in/MATLAB Fcn',[sys,'/',['GRIBS',13,'(Quaternions)/Atmosphere',13,'+ params/Scheduling',13,'Parameters/Sigma (0 to +180)/MATLAB Fcn']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Atmosphere',13,'+ params/Scheduling',13,'Parameters/Sigma (0 to +180)/MATLAB Fcn']],...
		'ForeGround',1,...
		'BackGround',3,...
		'MATLAB Fcn','r2d*acos(u(1)/u(2))',...
		'Output Width','1')
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Atmosphere',13,'+ params/Scheduling',13,'Parameters/Sigma (0 to +180)/MATLAB Fcn']],...
		'position',[385,58,445,92])

add_block('built-in/Demux',[sys,'/',['GRIBS',13,'(Quaternions)/Atmosphere',13,'+ params/Scheduling',13,'Parameters/Sigma (0 to +180)/Demux']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Atmosphere',13,'+ params/Scheduling',13,'Parameters/Sigma (0 to +180)/Demux']],...
		'ForeGround',1,...
		'BackGround',0,...
		'outputs','[1,5]',...
		'position',[165,35,205,70])

add_block('built-in/Outport',[sys,'/',['GRIBS',13,'(Quaternions)/Atmosphere',13,'+ params/Scheduling',13,'Parameters/Sigma (0 to +180)/out_2']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Atmosphere',13,'+ params/Scheduling',13,'Parameters/Sigma (0 to +180)/out_2']],...
		'ForeGround',1,...
		'BackGround',4,...
		'position',[520,65,540,85])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Atmosphere',13,'+ params/Scheduling',13,'Parameters/Sigma (0 to +180)']],[450,75;515,75])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Atmosphere',13,'+ params/Scheduling',13,'Parameters/Sigma (0 to +180)']],[210,45;250,45;250,65;285,65])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Atmosphere',13,'+ params/Scheduling',13,'Parameters/Sigma (0 to +180)']],[325,75;380,75])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Atmosphere',13,'+ params/Scheduling',13,'Parameters/Sigma (0 to +180)']],[90,55;160,55])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Atmosphere',13,'+ params/Scheduling',13,'Parameters/Sigma (0 to +180)']],[90,115;250,115;250,80;285,80])


%     Finished composite block ['GRIBS',13,'(Quaternions)/Atmosphere',13,'+ params/Scheduling',13,'Parameters/Sigma (0 to +180)'].

set_param([sys,'/',['GRIBS',13,'(Quaternions)/Atmosphere',13,'+ params/Scheduling',13,'Parameters/Sigma (0 to +180)']],...
		'ForeGround',1,...
		'BackGround',2,...
		'position',[360,221,390,274])

add_block('built-in/Outport',[sys,'/',['GRIBS',13,'(Quaternions)/Atmosphere',13,'+ params/Scheduling',13,'Parameters/Vt']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Atmosphere',13,'+ params/Scheduling',13,'Parameters/Vt']],...
		'ForeGround',1,...
		'BackGround',4,...
		'position',[535,45,555,65])

add_block('built-in/Outport',[sys,'/',['GRIBS',13,'(Quaternions)/Atmosphere',13,'+ params/Scheduling',13,'Parameters/alpha deg']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Atmosphere',13,'+ params/Scheduling',13,'Parameters/alpha deg']],...
		'ForeGround',1,...
		'BackGround',4,...
		'Port','4',...
		'position',[535,105,555,125])

add_block('built-in/Outport',[sys,'/',['GRIBS',13,'(Quaternions)/Atmosphere',13,'+ params/Scheduling',13,'Parameters/sigma deg']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Atmosphere',13,'+ params/Scheduling',13,'Parameters/sigma deg']],...
		'ForeGround',1,...
		'BackGround',4,...
		'Port','6',...
		'position',[535,240,555,260])

add_block('built-in/Outport',[sys,'/',['GRIBS',13,'(Quaternions)/Atmosphere',13,'+ params/Scheduling',13,'Parameters/lambda deg']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Atmosphere',13,'+ params/Scheduling',13,'Parameters/lambda deg']],...
		'ForeGround',1,...
		'BackGround',4,...
		'Port','7',...
		'position',[535,315,555,335])

add_block('built-in/Outport',[sys,'/',['GRIBS',13,'(Quaternions)/Atmosphere',13,'+ params/Scheduling',13,'Parameters/beta deg']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Atmosphere',13,'+ params/Scheduling',13,'Parameters/beta deg']],...
		'ForeGround',1,...
		'BackGround',4,...
		'Port','5',...
		'position',[535,160,555,180])

add_block('built-in/Mux',[sys,'/',['GRIBS',13,'(Quaternions)/Atmosphere',13,'+ params/Scheduling',13,'Parameters/Mux1']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Atmosphere',13,'+ params/Scheduling',13,'Parameters/Mux1']],...
		'ForeGround',1,...
		'BackGround',2,...
		'inputs','[6,1]',...
		'position',[320,151,350,184])

add_block('built-in/Fcn',[sys,'/',['GRIBS',13,'(Quaternions)/Atmosphere',13,'+ params/Scheduling',13,'Parameters/beta (+90 to -90)']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Atmosphere',13,'+ params/Scheduling',13,'Parameters/beta (+90 to -90)']],...
		'ForeGround',1,...
		'BackGround',2,...
		'Expr','r2d*asin(u[2]/u[7])',...
		'position',[400,160,440,180])

add_block('built-in/Fcn',[sys,'/',['GRIBS',13,'(Quaternions)/Atmosphere',13,'+ params/Scheduling',13,'Parameters/alpha (+180 to -180)']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Atmosphere',13,'+ params/Scheduling',13,'Parameters/alpha (+180 to -180)']],...
		'ForeGround',1,...
		'BackGround',2,...
		'Expr','r2d*atan2(u[3],u[1])',...
		'position',[400,105,440,125])


%     Subsystem  ['GRIBS',13,'(Quaternions)/Atmosphere',13,'+ params/Scheduling',13,'Parameters/height'].

new_system([sys,'/',['GRIBS',13,'(Quaternions)/Atmosphere',13,'+ params/Scheduling',13,'Parameters/height']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Atmosphere',13,'+ params/Scheduling',13,'Parameters/height']],'Location',[4,257,455,464])

add_block('built-in/Gain',[sys,'/',['GRIBS',13,'(Quaternions)/Atmosphere',13,'+ params/Scheduling',13,'Parameters/height/-1']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Atmosphere',13,'+ params/Scheduling',13,'Parameters/height/-1']],...
		'ForeGround',1,...
		'BackGround',3,...
		'Gain','-1',...
		'position',[195,62,220,88])

add_block('built-in/Constant',[sys,'/',['GRIBS',13,'(Quaternions)/Atmosphere',13,'+ params/Scheduling',13,'Parameters/height/const']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Atmosphere',13,'+ params/Scheduling',13,'Parameters/height/const']],...
		'ForeGround',1,...
		'BackGround',7,...
		'Value','0',...
		'position',[205,115,240,135])

add_block('built-in/Outport',[sys,'/',['GRIBS',13,'(Quaternions)/Atmosphere',13,'+ params/Scheduling',13,'Parameters/height/height']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Atmosphere',13,'+ params/Scheduling',13,'Parameters/height/height']],...
		'ForeGround',1,...
		'BackGround',4,...
		'position',[360,90,380,110])

add_block('built-in/Switch',[sys,'/',['GRIBS',13,'(Quaternions)/Atmosphere',13,'+ params/Scheduling',13,'Parameters/height/Switch']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Atmosphere',13,'+ params/Scheduling',13,'Parameters/height/Switch']],...
		'ForeGround',1,...
		'BackGround',5,...
		'position',[290,64,320,136])

add_block('built-in/Demux',[sys,'/',['GRIBS',13,'(Quaternions)/Atmosphere',13,'+ params/Scheduling',13,'Parameters/height/Demux']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Atmosphere',13,'+ params/Scheduling',13,'Parameters/height/Demux']],...
		'ForeGround',1,...
		'BackGround',0,...
		'outputs','[2,1]',...
		'position',[100,51,140,84])

add_block('built-in/Inport',[sys,'/',['GRIBS',13,'(Quaternions)/Atmosphere',13,'+ params/Scheduling',13,'Parameters/height/NED']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Atmosphere',13,'+ params/Scheduling',13,'Parameters/height/NED']],...
		'ForeGround',1,...
		'BackGround',4,...
		'position',[30,60,50,80])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Atmosphere',13,'+ params/Scheduling',13,'Parameters/height']],[225,75;255,75;255,100;285,100])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Atmosphere',13,'+ params/Scheduling',13,'Parameters/height']],[225,75;285,75])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Atmosphere',13,'+ params/Scheduling',13,'Parameters/height']],[245,125;285,125])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Atmosphere',13,'+ params/Scheduling',13,'Parameters/height']],[145,75;190,75])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Atmosphere',13,'+ params/Scheduling',13,'Parameters/height']],[55,70;95,70])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Atmosphere',13,'+ params/Scheduling',13,'Parameters/height']],[325,100;355,100])


%     Finished composite block ['GRIBS',13,'(Quaternions)/Atmosphere',13,'+ params/Scheduling',13,'Parameters/height'].

set_param([sys,'/',['GRIBS',13,'(Quaternions)/Atmosphere',13,'+ params/Scheduling',13,'Parameters/height']],...
		'ForeGround',1,...
		'BackGround',2,...
		'position',[200,375,230,425])

add_block('built-in/Outport',[sys,'/',['GRIBS',13,'(Quaternions)/Atmosphere',13,'+ params/Scheduling',13,'Parameters/alt']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Atmosphere',13,'+ params/Scheduling',13,'Parameters/alt']],...
		'ForeGround',1,...
		'BackGround',4,...
		'Port','3',...
		'position',[515,440,535,460])

add_block('built-in/Gain',[sys,'/',['GRIBS',13,'(Quaternions)/Atmosphere',13,'+ params/Scheduling',13,'Parameters/altitude (km)']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Atmosphere',13,'+ params/Scheduling',13,'Parameters/altitude (km)']],...
		'ForeGround',1,...
		'BackGround',2,...
		'Gain','0.001',...
		'position',[395,430,460,470])

add_block('built-in/Outport',[sys,'/',['GRIBS',13,'(Quaternions)/Atmosphere',13,'+ params/Scheduling',13,'Parameters/H']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Atmosphere',13,'+ params/Scheduling',13,'Parameters/H']],...
		'ForeGround',1,...
		'BackGround',4,...
		'Port','2',...
		'position',[515,390,535,410])

add_block('built-in/Inport',[sys,'/',['GRIBS',13,'(Quaternions)/Atmosphere',13,'+ params/Scheduling',13,'Parameters/NED']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Atmosphere',13,'+ params/Scheduling',13,'Parameters/NED']],...
		'ForeGround',1,...
		'BackGround',4,...
		'Port','2',...
		'position',[35,390,55,410])


%     Subsystem  ['GRIBS',13,'(Quaternions)/Atmosphere',13,'+ params/Scheduling',13,'Parameters/Total',13,'velocity'].

new_system([sys,'/',['GRIBS',13,'(Quaternions)/Atmosphere',13,'+ params/Scheduling',13,'Parameters/Total',13,'velocity']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Atmosphere',13,'+ params/Scheduling',13,'Parameters/Total',13,'velocity']],'Location',[208,250,621,395])

add_block('built-in/Outport',[sys,'/',['GRIBS',13,'(Quaternions)/Atmosphere',13,'+ params/Scheduling',13,'Parameters/Total',13,'velocity/Vt']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Atmosphere',13,'+ params/Scheduling',13,'Parameters/Total',13,'velocity/Vt']],...
		'ForeGround',1,...
		'BackGround',4,...
		'position',[320,50,340,70])

add_block('built-in/MATLAB Fcn',[sys,'/',['GRIBS',13,'(Quaternions)/Atmosphere',13,'+ params/Scheduling',13,'Parameters/Total',13,'velocity/Func']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Atmosphere',13,'+ params/Scheduling',13,'Parameters/Total',13,'velocity/Func']],...
		'ForeGround',1,...
		'BackGround',3,...
		'MATLAB Fcn','norm(u,2)',...
		'Output Width','1')
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Atmosphere',13,'+ params/Scheduling',13,'Parameters/Total',13,'velocity/Func']],...
		'position',[205,37,270,83])

add_block('built-in/Demux',[sys,'/',['GRIBS',13,'(Quaternions)/Atmosphere',13,'+ params/Scheduling',13,'Parameters/Total',13,'velocity/Demux']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Atmosphere',13,'+ params/Scheduling',13,'Parameters/Total',13,'velocity/Demux']],...
		'ForeGround',1,...
		'BackGround',0,...
		'outputs','[3,3]',...
		'position',[120,51,160,84])

add_block('built-in/Inport',[sys,'/',['GRIBS',13,'(Quaternions)/Atmosphere',13,'+ params/Scheduling',13,'Parameters/Total',13,'velocity/U,V,W',13,'P,Q,R']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Atmosphere',13,'+ params/Scheduling',13,'Parameters/Total',13,'velocity/U,V,W',13,'P,Q,R']],...
		'ForeGround',1,...
		'BackGround',4,...
		'position',[50,60,70,80])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Atmosphere',13,'+ params/Scheduling',13,'Parameters/Total',13,'velocity']],[75,70;115,70])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Atmosphere',13,'+ params/Scheduling',13,'Parameters/Total',13,'velocity']],[165,60;200,60])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Atmosphere',13,'+ params/Scheduling',13,'Parameters/Total',13,'velocity']],[275,60;315,60])


%     Finished composite block ['GRIBS',13,'(Quaternions)/Atmosphere',13,'+ params/Scheduling',13,'Parameters/Total',13,'velocity'].

set_param([sys,'/',['GRIBS',13,'(Quaternions)/Atmosphere',13,'+ params/Scheduling',13,'Parameters/Total',13,'velocity']],...
		'ForeGround',1,...
		'BackGround',2,...
		'position',[160,30,190,80])

add_block('built-in/Inport',[sys,'/',['GRIBS',13,'(Quaternions)/Atmosphere',13,'+ params/Scheduling',13,'Parameters/U,V,W',13,'P,Q,R']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Atmosphere',13,'+ params/Scheduling',13,'Parameters/U,V,W',13,'P,Q,R']],...
		'ForeGround',1,...
		'BackGround',4,...
		'position',[25,45,45,65])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Atmosphere',13,'+ params/Scheduling',13,'Parameters']],[395,250;530,250])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Atmosphere',13,'+ params/Scheduling',13,'Parameters']],[195,55;255,55;255,260;355,260])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Atmosphere',13,'+ params/Scheduling',13,'Parameters']],[50,55;85,55;85,235;355,235])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Atmosphere',13,'+ params/Scheduling',13,'Parameters']],[50,55;85,55;85,325;355,325])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Atmosphere',13,'+ params/Scheduling',13,'Parameters']],[395,325;530,325])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Atmosphere',13,'+ params/Scheduling',13,'Parameters']],[50,55;85,55;85,160;315,160])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Atmosphere',13,'+ params/Scheduling',13,'Parameters']],[50,55;85,55;85,115;395,115])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Atmosphere',13,'+ params/Scheduling',13,'Parameters']],[445,170;530,170])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Atmosphere',13,'+ params/Scheduling',13,'Parameters']],[235,400;510,400])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Atmosphere',13,'+ params/Scheduling',13,'Parameters']],[465,450;510,450])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Atmosphere',13,'+ params/Scheduling',13,'Parameters']],[445,115;530,115])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Atmosphere',13,'+ params/Scheduling',13,'Parameters']],[50,55;155,55])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Atmosphere',13,'+ params/Scheduling',13,'Parameters']],[60,400;195,400])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Atmosphere',13,'+ params/Scheduling',13,'Parameters']],[195,55;530,55])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Atmosphere',13,'+ params/Scheduling',13,'Parameters']],[195,55;255,55;255,175;315,175])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Atmosphere',13,'+ params/Scheduling',13,'Parameters']],[355,170;395,170])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Atmosphere',13,'+ params/Scheduling',13,'Parameters']],[235,400;350,400;350,450;390,450])


%     Finished composite block ['GRIBS',13,'(Quaternions)/Atmosphere',13,'+ params/Scheduling',13,'Parameters'].

set_param([sys,'/',['GRIBS',13,'(Quaternions)/Atmosphere',13,'+ params/Scheduling',13,'Parameters']],...
		'ForeGround',1,...
		'BackGround',3,...
		'position',[145,199,235,441])

add_block('built-in/Outport',[sys,'/',['GRIBS',13,'(Quaternions)/Atmosphere',13,'+ params/out_1']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Atmosphere',13,'+ params/out_1']],...
		'ForeGround',1,...
		'BackGround',4,...
		'position',[740,260,760,280])

add_block('built-in/Mux',[sys,'/',['GRIBS',13,'(Quaternions)/Atmosphere',13,'+ params/Mux']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Atmosphere',13,'+ params/Mux']],...
		'ForeGround',1,...
		'BackGround',0,...
		'inputs','10',...
		'position',[650,99,690,436])

add_block('built-in/Demux',[sys,'/',['GRIBS',13,'(Quaternions)/Atmosphere',13,'+ params/Demux']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Atmosphere',13,'+ params/Demux']],...
		'ForeGround',1,...
		'BackGround',0,...
		'position',[480,91,510,234])

add_block('built-in/Note',[sys,'/',['GRIBS',13,'(Quaternions)/Atmosphere',13,'+ params/mach no.']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Atmosphere',13,'+ params/mach no.']],...
		'ForeGround',1,...
		'Font Size',9,...
		'position',[610,85,615,90])

add_block('built-in/Note',[sys,'/',['GRIBS',13,'(Quaternions)/Atmosphere',13,'+ params/V_t']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Atmosphere',13,'+ params/V_t']],...
		'ForeGround',1,...
		'BackGround',3,...
		'Font Size',9,...
		'position',[620,120,625,125])

add_block('built-in/Note',[sys,'/',['GRIBS',13,'(Quaternions)/Atmosphere',13,'+ params/speed of sound']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Atmosphere',13,'+ params/speed of sound']],...
		'ForeGround',1,...
		'BackGround',3,...
		'Font Size',9,...
		'position',[590,155,595,160])

add_block('built-in/Note',[sys,'/',['GRIBS',13,'(Quaternions)/Atmosphere',13,'+ params/rho']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Atmosphere',13,'+ params/rho']],...
		'ForeGround',1,...
		'BackGround',3,...
		'Font Size',9,...
		'position',[620,190,625,195])

add_block('built-in/Note',[sys,'/',['GRIBS',13,'(Quaternions)/Atmosphere',13,'+ params/q_bar']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Atmosphere',13,'+ params/q_bar']],...
		'ForeGround',1,...
		'BackGround',3,...
		'Font Size',9,...
		'position',[615,225,620,230])

add_block('built-in/Note',[sys,'/',['GRIBS',13,'(Quaternions)/Atmosphere',13,'+ params/altitude']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Atmosphere',13,'+ params/altitude']],...
		'ForeGround',1,...
		'BackGround',3,...
		'Font Size',9,...
		'position',[615,260,620,265])

add_block('built-in/Note',[sys,'/',['GRIBS',13,'(Quaternions)/Atmosphere',13,'+ params/Note that sigma is assumed to ',13,'be theta here!!!']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Atmosphere',13,'+ params/Note that sigma is assumed to ',13,'be theta here!!!']],...
		'ForeGround',1,...
		'position',[180,50,185,55])


%     Subsystem  ['GRIBS',13,'(Quaternions)/Atmosphere',13,'+ params/Atmospheric Model',13,'(Horton)'].

new_system([sys,'/',['GRIBS',13,'(Quaternions)/Atmosphere',13,'+ params/Atmospheric Model',13,'(Horton)']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Atmosphere',13,'+ params/Atmospheric Model',13,'(Horton)']],'Location',[71,149,658,628])


%     Subsystem  ['GRIBS',13,'(Quaternions)/Atmosphere',13,'+ params/Atmospheric Model',13,'(Horton)/Air Density'].

new_system([sys,'/',['GRIBS',13,'(Quaternions)/Atmosphere',13,'+ params/Atmospheric Model',13,'(Horton)/Air Density']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Atmosphere',13,'+ params/Atmospheric Model',13,'(Horton)/Air Density']],'Location',[85,419,535,658])

add_block('built-in/Gain',[sys,'/',['GRIBS',13,'(Quaternions)/Atmosphere',13,'+ params/Atmospheric Model',13,'(Horton)/Air Density/0.094']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Atmosphere',13,'+ params/Atmospheric Model',13,'(Horton)/Air Density/0.094']],...
		'ForeGround',1,...
		'BackGround',3,...
		'Gain','0.000094',...
		'position',[160,130,180,150])

add_block('built-in/Inport',[sys,'/',['GRIBS',13,'(Quaternions)/Atmosphere',13,'+ params/Atmospheric Model',13,'(Horton)/Air Density/height']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Atmosphere',13,'+ params/Atmospheric Model',13,'(Horton)/Air Density/height']],...
		'ForeGround',1,...
		'BackGround',4,...
		'position',[60,130,80,150])

add_block('built-in/Constant',[sys,'/',['GRIBS',13,'(Quaternions)/Atmosphere',13,'+ params/Atmospheric Model',13,'(Horton)/Air Density/rho_sl']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Atmosphere',13,'+ params/Atmospheric Model',13,'(Horton)/Air Density/rho_sl']],...
		'ForeGround',1,...
		'BackGround',7,...
		'Value','rho_sl',...
		'position',[60,57,115,83])

add_block('built-in/Sum',[sys,'/',['GRIBS',13,'(Quaternions)/Atmosphere',13,'+ params/Atmospheric Model',13,'(Horton)/Air Density/Sum']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Atmosphere',13,'+ params/Atmospheric Model',13,'(Horton)/Air Density/Sum']],...
		'ForeGround',1,...
		'BackGround',5,...
		'inputs','+-',...
		'position',[280,35,300,175])

add_block('built-in/Outport',[sys,'/',['GRIBS',13,'(Quaternions)/Atmosphere',13,'+ params/Atmospheric Model',13,'(Horton)/Air Density/rho']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Atmosphere',13,'+ params/Atmospheric Model',13,'(Horton)/Air Density/rho']],...
		'ForeGround',1,...
		'BackGround',4,...
		'position',[365,95,385,115])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Atmosphere',13,'+ params/Atmospheric Model',13,'(Horton)/Air Density']],[85,140;155,140])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Atmosphere',13,'+ params/Atmospheric Model',13,'(Horton)/Air Density']],[305,105;360,105])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Atmosphere',13,'+ params/Atmospheric Model',13,'(Horton)/Air Density']],[120,70;275,70])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Atmosphere',13,'+ params/Atmospheric Model',13,'(Horton)/Air Density']],[185,140;275,140])


%     Finished composite block ['GRIBS',13,'(Quaternions)/Atmosphere',13,'+ params/Atmospheric Model',13,'(Horton)/Air Density'].

set_param([sys,'/',['GRIBS',13,'(Quaternions)/Atmosphere',13,'+ params/Atmospheric Model',13,'(Horton)/Air Density']],...
		'ForeGround',1,...
		'BackGround',2,...
		'position',[165,345,195,395])


%     Subsystem  ['GRIBS',13,'(Quaternions)/Atmosphere',13,'+ params/Atmospheric Model',13,'(Horton)/Speed of',13,'Sound'].

new_system([sys,'/',['GRIBS',13,'(Quaternions)/Atmosphere',13,'+ params/Atmospheric Model',13,'(Horton)/Speed of',13,'Sound']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Atmosphere',13,'+ params/Atmospheric Model',13,'(Horton)/Speed of',13,'Sound']],'Location',[181,246,607,438])

add_block('built-in/Gain',[sys,'/',['GRIBS',13,'(Quaternions)/Atmosphere',13,'+ params/Atmospheric Model',13,'(Horton)/Speed of',13,'Sound/4.0']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Atmosphere',13,'+ params/Atmospheric Model',13,'(Horton)/Speed of',13,'Sound/4.0']],...
		'ForeGround',1,...
		'BackGround',3,...
		'Gain','0.004',...
		'position',[130,110,150,130])

add_block('built-in/Sum',[sys,'/',['GRIBS',13,'(Quaternions)/Atmosphere',13,'+ params/Atmospheric Model',13,'(Horton)/Speed of',13,'Sound/Sum']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Atmosphere',13,'+ params/Atmospheric Model',13,'(Horton)/Speed of',13,'Sound/Sum']],...
		'ForeGround',1,...
		'BackGround',5,...
		'inputs','+-',...
		'position',[220,44,245,146])

add_block('built-in/Outport',[sys,'/',['GRIBS',13,'(Quaternions)/Atmosphere',13,'+ params/Atmospheric Model',13,'(Horton)/Speed of',13,'Sound/s']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Atmosphere',13,'+ params/Atmospheric Model',13,'(Horton)/Speed of',13,'Sound/s']],...
		'ForeGround',1,...
		'BackGround',4,...
		'position',[285,85,305,105])

add_block('built-in/Constant',[sys,'/',['GRIBS',13,'(Quaternions)/Atmosphere',13,'+ params/Atmospheric Model',13,'(Horton)/Speed of',13,'Sound/s_sl']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Atmosphere',13,'+ params/Atmospheric Model',13,'(Horton)/Speed of',13,'Sound/s_sl']],...
		'ForeGround',1,...
		'BackGround',7,...
		'Value','s_sl',...
		'position',[60,60,100,80])

add_block('built-in/Inport',[sys,'/',['GRIBS',13,'(Quaternions)/Atmosphere',13,'+ params/Atmospheric Model',13,'(Horton)/Speed of',13,'Sound/height']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Atmosphere',13,'+ params/Atmospheric Model',13,'(Horton)/Speed of',13,'Sound/height']],...
		'ForeGround',1,...
		'BackGround',4,...
		'position',[65,110,85,130])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Atmosphere',13,'+ params/Atmospheric Model',13,'(Horton)/Speed of',13,'Sound']],[90,120;125,120])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Atmosphere',13,'+ params/Atmospheric Model',13,'(Horton)/Speed of',13,'Sound']],[250,95;280,95])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Atmosphere',13,'+ params/Atmospheric Model',13,'(Horton)/Speed of',13,'Sound']],[105,70;215,70])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Atmosphere',13,'+ params/Atmospheric Model',13,'(Horton)/Speed of',13,'Sound']],[155,120;215,120])


%     Finished composite block ['GRIBS',13,'(Quaternions)/Atmosphere',13,'+ params/Atmospheric Model',13,'(Horton)/Speed of',13,'Sound'].

set_param([sys,'/',['GRIBS',13,'(Quaternions)/Atmosphere',13,'+ params/Atmospheric Model',13,'(Horton)/Speed of',13,'Sound']],...
		'ForeGround',1,...
		'BackGround',2,...
		'position',[165,250,195,300])


%     Subsystem  ['GRIBS',13,'(Quaternions)/Atmosphere',13,'+ params/Atmospheric Model',13,'(Horton)/Mach'].

new_system([sys,'/',['GRIBS',13,'(Quaternions)/Atmosphere',13,'+ params/Atmospheric Model',13,'(Horton)/Mach']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Atmosphere',13,'+ params/Atmospheric Model',13,'(Horton)/Mach']],'Location',[94,86,502,278])

add_block('built-in/Mux',[sys,'/',['GRIBS',13,'(Quaternions)/Atmosphere',13,'+ params/Atmospheric Model',13,'(Horton)/Mach/Mux1']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Atmosphere',13,'+ params/Atmospheric Model',13,'(Horton)/Mach/Mux1']],...
		'ForeGround',1,...
		'BackGround',0,...
		'inputs','2',...
		'position',[110,44,140,131])

add_block('built-in/Fcn',[sys,'/',['GRIBS',13,'(Quaternions)/Atmosphere',13,'+ params/Atmospheric Model',13,'(Horton)/Mach/Mach no.']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Atmosphere',13,'+ params/Atmospheric Model',13,'(Horton)/Mach/Mach no.']],...
		'ForeGround',1,...
		'BackGround',3,...
		'Expr','u[1]/u[2]',...
		'position',[195,80,235,100])

add_block('built-in/Outport',[sys,'/',['GRIBS',13,'(Quaternions)/Atmosphere',13,'+ params/Atmospheric Model',13,'(Horton)/Mach/out_1']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Atmosphere',13,'+ params/Atmospheric Model',13,'(Horton)/Mach/out_1']],...
		'ForeGround',1,...
		'BackGround',4,...
		'position',[290,80,310,100])

add_block('built-in/Inport',[sys,'/',['GRIBS',13,'(Quaternions)/Atmosphere',13,'+ params/Atmospheric Model',13,'(Horton)/Mach/Vt']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Atmosphere',13,'+ params/Atmospheric Model',13,'(Horton)/Mach/Vt']],...
		'ForeGround',1,...
		'BackGround',4,...
		'position',[35,55,55,75])

add_block('built-in/Inport',[sys,'/',['GRIBS',13,'(Quaternions)/Atmosphere',13,'+ params/Atmospheric Model',13,'(Horton)/Mach/s']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Atmosphere',13,'+ params/Atmospheric Model',13,'(Horton)/Mach/s']],...
		'ForeGround',1,...
		'BackGround',4,...
		'Port','2',...
		'position',[35,100,55,120])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Atmosphere',13,'+ params/Atmospheric Model',13,'(Horton)/Mach']],[145,90;190,90])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Atmosphere',13,'+ params/Atmospheric Model',13,'(Horton)/Mach']],[60,65;105,65])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Atmosphere',13,'+ params/Atmospheric Model',13,'(Horton)/Mach']],[240,90;285,90])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Atmosphere',13,'+ params/Atmospheric Model',13,'(Horton)/Mach']],[60,110;105,110])


%     Finished composite block ['GRIBS',13,'(Quaternions)/Atmosphere',13,'+ params/Atmospheric Model',13,'(Horton)/Mach'].

set_param([sys,'/',['GRIBS',13,'(Quaternions)/Atmosphere',13,'+ params/Atmospheric Model',13,'(Horton)/Mach']],...
		'ForeGround',1,...
		'BackGround',2,...
		'position',[320,54,350,116])


%     Subsystem  ['GRIBS',13,'(Quaternions)/Atmosphere',13,'+ params/Atmospheric Model',13,'(Horton)/Dynamic',13,'Pressure'].

new_system([sys,'/',['GRIBS',13,'(Quaternions)/Atmosphere',13,'+ params/Atmospheric Model',13,'(Horton)/Dynamic',13,'Pressure']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Atmosphere',13,'+ params/Atmospheric Model',13,'(Horton)/Dynamic',13,'Pressure']],'Location',[366,71,805,339])

add_block('built-in/Inport',[sys,'/',['GRIBS',13,'(Quaternions)/Atmosphere',13,'+ params/Atmospheric Model',13,'(Horton)/Dynamic',13,'Pressure/Vt']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Atmosphere',13,'+ params/Atmospheric Model',13,'(Horton)/Dynamic',13,'Pressure/Vt']],...
		'ForeGround',1,...
		'BackGround',4,...
		'Port','2',...
		'position',[30,140,50,160])

add_block('built-in/Outport',[sys,'/',['GRIBS',13,'(Quaternions)/Atmosphere',13,'+ params/Atmospheric Model',13,'(Horton)/Dynamic',13,'Pressure/q_bar']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Atmosphere',13,'+ params/Atmospheric Model',13,'(Horton)/Dynamic',13,'Pressure/q_bar']],...
		'ForeGround',1,...
		'BackGround',4,...
		'position',[305,110,325,130])

add_block('built-in/Product',[sys,'/',['GRIBS',13,'(Quaternions)/Atmosphere',13,'+ params/Atmospheric Model',13,'(Horton)/Dynamic',13,'Pressure/Product']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Atmosphere',13,'+ params/Atmospheric Model',13,'(Horton)/Dynamic',13,'Pressure/Product']],...
		'ForeGround',1,...
		'BackGround',3,...
		'inputs','4',...
		'position',[230,58,255,182])

add_block('built-in/Inport',[sys,'/',['GRIBS',13,'(Quaternions)/Atmosphere',13,'+ params/Atmospheric Model',13,'(Horton)/Dynamic',13,'Pressure/Rho']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Atmosphere',13,'+ params/Atmospheric Model',13,'(Horton)/Dynamic',13,'Pressure/Rho']],...
		'ForeGround',1,...
		'BackGround',4,...
		'position',[30,95,50,115])

add_block('built-in/Constant',[sys,'/',['GRIBS',13,'(Quaternions)/Atmosphere',13,'+ params/Atmospheric Model',13,'(Horton)/Dynamic',13,'Pressure/half']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Atmosphere',13,'+ params/Atmospheric Model',13,'(Horton)/Dynamic',13,'Pressure/half']],...
		'ForeGround',1,...
		'BackGround',7,...
		'Value','0.5',...
		'position',[80,35,110,65])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Atmosphere',13,'+ params/Atmospheric Model',13,'(Horton)/Dynamic',13,'Pressure']],[115,50;140,50;140,75;225,75])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Atmosphere',13,'+ params/Atmospheric Model',13,'(Horton)/Dynamic',13,'Pressure']],[260,120;300,120])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Atmosphere',13,'+ params/Atmospheric Model',13,'(Horton)/Dynamic',13,'Pressure']],[55,105;225,105])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Atmosphere',13,'+ params/Atmospheric Model',13,'(Horton)/Dynamic',13,'Pressure']],[55,150;135,150;135,135;225,135])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Atmosphere',13,'+ params/Atmospheric Model',13,'(Horton)/Dynamic',13,'Pressure']],[55,150;135,150;135,165;225,165])


%     Finished composite block ['GRIBS',13,'(Quaternions)/Atmosphere',13,'+ params/Atmospheric Model',13,'(Horton)/Dynamic',13,'Pressure'].

set_param([sys,'/',['GRIBS',13,'(Quaternions)/Atmosphere',13,'+ params/Atmospheric Model',13,'(Horton)/Dynamic',13,'Pressure']],...
		'ForeGround',1,...
		'BackGround',2,...
		'position',[320,149,350,211])

add_block('built-in/Mux',[sys,'/',['GRIBS',13,'(Quaternions)/Atmosphere',13,'+ params/Atmospheric Model',13,'(Horton)/Mux']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Atmosphere',13,'+ params/Atmospheric Model',13,'(Horton)/Mux']],...
		'ForeGround',1,...
		'BackGround',0,...
		'position',[405,34,435,421])

add_block('built-in/Outport',[sys,'/',['GRIBS',13,'(Quaternions)/Atmosphere',13,'+ params/Atmospheric Model',13,'(Horton)/Atmosphere']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Atmosphere',13,'+ params/Atmospheric Model',13,'(Horton)/Atmosphere']],...
		'ForeGround',1,...
		'BackGround',4,...
		'position',[485,220,505,240])

add_block('built-in/Inport',[sys,'/',['GRIBS',13,'(Quaternions)/Atmosphere',13,'+ params/Atmospheric Model',13,'(Horton)/Height']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Atmosphere',13,'+ params/Atmospheric Model',13,'(Horton)/Height']],...
		'ForeGround',1,...
		'BackGround',4,...
		'Port','2',...
		'position',[50,265,70,285])

add_block('built-in/Inport',[sys,'/',['GRIBS',13,'(Quaternions)/Atmosphere',13,'+ params/Atmospheric Model',13,'(Horton)/Vt']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Atmosphere',13,'+ params/Atmospheric Model',13,'(Horton)/Vt']],...
		'ForeGround',1,...
		'BackGround',4,...
		'position',[50,60,70,80])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Atmosphere',13,'+ params/Atmospheric Model',13,'(Horton)']],[75,275;115,275;115,370;160,370])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Atmosphere',13,'+ params/Atmospheric Model',13,'(Horton)']],[75,275;160,275])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Atmosphere',13,'+ params/Atmospheric Model',13,'(Horton)']],[200,275;400,275])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Atmosphere',13,'+ params/Atmospheric Model',13,'(Horton)']],[200,275;230,275;230,100;315,100])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Atmosphere',13,'+ params/Atmospheric Model',13,'(Horton)']],[200,370;400,370])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Atmosphere',13,'+ params/Atmospheric Model',13,'(Horton)']],[200,370;260,370;260,165;315,165])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Atmosphere',13,'+ params/Atmospheric Model',13,'(Horton)']],[75,70;115,70;115,195;315,195])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Atmosphere',13,'+ params/Atmospheric Model',13,'(Horton)']],[75,70;315,70])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Atmosphere',13,'+ params/Atmospheric Model',13,'(Horton)']],[355,180;400,180])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Atmosphere',13,'+ params/Atmospheric Model',13,'(Horton)']],[355,85;400,85])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Atmosphere',13,'+ params/Atmospheric Model',13,'(Horton)']],[440,230;480,230])


%     Finished composite block ['GRIBS',13,'(Quaternions)/Atmosphere',13,'+ params/Atmospheric Model',13,'(Horton)'].

set_param([sys,'/',['GRIBS',13,'(Quaternions)/Atmosphere',13,'+ params/Atmospheric Model',13,'(Horton)']],...
		'ForeGround',1,...
		'BackGround',3,...
		'position',[360,88,440,237])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Atmosphere',13,'+ params']],[240,425;645,425])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Atmosphere',13,'+ params']],[240,390;645,390])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Atmosphere',13,'+ params']],[240,215;295,215;295,50;570,50;570,145;645,145])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Atmosphere',13,'+ params']],[240,355;645,355])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Atmosphere',13,'+ params']],[240,320;645,320])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Atmosphere',13,'+ params']],[240,285;645,285])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Atmosphere',13,'+ params']],[240,250;320,250;320,200;355,200])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Atmosphere',13,'+ params']],[240,215;295,215;295,125;355,125])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Atmosphere',13,'+ params']],[515,215;645,215])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Atmosphere',13,'+ params']],[515,180;645,180])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Atmosphere',13,'+ params']],[515,145;540,145;540,250;645,250])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Atmosphere',13,'+ params']],[515,110;645,110])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Atmosphere',13,'+ params']],[445,165;475,165])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Atmosphere',13,'+ params']],[90,380;140,380])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Atmosphere',13,'+ params']],[90,260;140,260])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Atmosphere',13,'+ params']],[695,270;735,270])


%     Finished composite block ['GRIBS',13,'(Quaternions)/Atmosphere',13,'+ params'].

set_param([sys,'/',['GRIBS',13,'(Quaternions)/Atmosphere',13,'+ params']],...
		'ForeGround',1,...
		'BackGround',2,...
		'position',[365,204,410,291])

add_block('built-in/Outport',[sys,'/',['GRIBS',13,'(Quaternions)/NED']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/NED']],...
		'ForeGround',1,...
		'BackGround',4,...
		'Port','3',...
		'position',[275,330,295,350])

add_block('built-in/Outport',[sys,'/',['GRIBS',13,'(Quaternions)/Rates']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Rates']],...
		'ForeGround',1,...
		'BackGround',4,...
		'Port','2',...
		'position',[275,265,295,285])

add_block('built-in/Outport',[sys,'/',['GRIBS',13,'(Quaternions)/States']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/States']],...
		'ForeGround',1,...
		'BackGround',4,...
		'position',[275,175,295,195])


%     Subsystem  ['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)'].

new_system([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)']],'Location',[37,187,721,625])

add_block('built-in/Outport',[sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/NED']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/NED']],...
		'ForeGround',1,...
		'BackGround',4,...
		'Port','3',...
		'position',[475,80,495,100])

add_block('built-in/Outport',[sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/Rates']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/Rates']],...
		'ForeGround',1,...
		'BackGround',4,...
		'Port','2',...
		'position',[315,210,335,230])

add_block('built-in/Outport',[sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States']],...
		'ForeGround',1,...
		'BackGround',4,...
		'position',[475,35,495,55])


%     Subsystem  ['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)'].

new_system([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)']],'Location',[88,219,705,541])

add_block('built-in/Inport',[sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)/States']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)/States']],...
		'ForeGround',1,...
		'BackGround',4,...
		'position',[45,130,65,150])

add_block('built-in/Demux',[sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)/Demux']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)/Demux']],...
		'ForeGround',1,...
		'BackGround',0,...
		'outputs','[3 3]',...
		'position',[95,34,150,241])

add_block('built-in/Note',[sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)/P,Q,R']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)/P,Q,R']],...
		'ForeGround',1,...
		'position',[183,160,188,165])

add_block('built-in/Note',[sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)/U,V,W']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)/U,V,W']],...
		'ForeGround',1,...
		'position',[187,55,192,60])


%     Subsystem  ['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)/DCM',13,'(Quaternions)'].

new_system([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)/DCM',13,'(Quaternions)']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)/DCM',13,'(Quaternions)']],'Location',[185,299,576,539])

add_block('built-in/Note',[sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)/DCM',13,'(Quaternions)/e0,e1,e2,e3']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)/DCM',13,'(Quaternions)/e0,e1,e2,e3']],...
		'ForeGround',1,...
		'BackGround',3,...
		'position',[175,90,180,95])

add_block('built-in/Inport',[sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)/DCM',13,'(Quaternions)/in_1']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)/DCM',13,'(Quaternions)/in_1']],...
		'ForeGround',1,...
		'BackGround',4,...
		'position',[15,110,35,130])


%     Subsystem  ['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)/DCM',13,'(Quaternions)/Quaternions'].

new_system([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)/DCM',13,'(Quaternions)/Quaternions']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)/DCM',13,'(Quaternions)/Quaternions']],'Location',[5,201,943,742])

add_block('built-in/Gain',[sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)/DCM',13,'(Quaternions)/Quaternions/Gain2']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)/DCM',13,'(Quaternions)/Quaternions/Gain2']],...
		'Gain','0.5',...
		'position',[635,310,655,330])

add_block('built-in/Sum',[sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)/DCM',13,'(Quaternions)/Quaternions/Sum1']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)/DCM',13,'(Quaternions)/Quaternions/Sum1']],...
		'inputs','+-+',...
		'position',[550,302,570,338])

add_block('built-in/Outport',[sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)/DCM',13,'(Quaternions)/Quaternions/out_1']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)/DCM',13,'(Quaternions)/Quaternions/out_1']],...
		'position',[1010,400,1030,420])

add_block('built-in/Inport',[sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)/DCM',13,'(Quaternions)/Quaternions/in_1']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)/DCM',13,'(Quaternions)/Quaternions/in_1']],...
		'position',[80,115,100,135])

add_block('built-in/Sum',[sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)/DCM',13,'(Quaternions)/Quaternions/Sum']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)/DCM',13,'(Quaternions)/Quaternions/Sum']],...
		'inputs','+++',...
		'position',[560,112,580,148])

add_block('built-in/Gain',[sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)/DCM',13,'(Quaternions)/Quaternions/Gain']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)/DCM',13,'(Quaternions)/Quaternions/Gain']],...
		'Gain','-0.5',...
		'position',[625,117,660,143])

add_block('built-in/Demux',[sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)/DCM',13,'(Quaternions)/Quaternions/Demux']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)/DCM',13,'(Quaternions)/Quaternions/Demux']],...
		'outputs','3',...
		'position',[315,109,355,141])

add_block('built-in/Demux',[sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)/DCM',13,'(Quaternions)/Quaternions/Demux1']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)/DCM',13,'(Quaternions)/Quaternions/Demux1']],...
		'position',[90,167,130,213])

add_block('built-in/Product',[sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)/DCM',13,'(Quaternions)/Quaternions/Product5']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)/DCM',13,'(Quaternions)/Quaternions/Product5']],...
		'position',[445,60,470,80])

add_block('built-in/Product',[sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)/DCM',13,'(Quaternions)/Quaternions/Product6']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)/DCM',13,'(Quaternions)/Quaternions/Product6']],...
		'position',[445,120,470,140])

add_block('built-in/Product',[sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)/DCM',13,'(Quaternions)/Quaternions/Product7']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)/DCM',13,'(Quaternions)/Quaternions/Product7']],...
		'position',[445,170,470,190])

add_block('built-in/Product',[sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)/DCM',13,'(Quaternions)/Quaternions/Product8']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)/DCM',13,'(Quaternions)/Quaternions/Product8']],...
		'position',[455,360,480,380])

add_block('built-in/Product',[sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)/DCM',13,'(Quaternions)/Quaternions/Product9']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)/DCM',13,'(Quaternions)/Quaternions/Product9']],...
		'position',[455,310,480,330])

add_block('built-in/Product',[sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)/DCM',13,'(Quaternions)/Quaternions/Product10']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)/DCM',13,'(Quaternions)/Quaternions/Product10']],...
		'position',[455,250,480,270])

add_block('built-in/Demux',[sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)/DCM',13,'(Quaternions)/Quaternions/Demux2']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)/DCM',13,'(Quaternions)/Quaternions/Demux2']],...
		'outputs','3',...
		'position',[325,299,365,331])

add_block('built-in/Sum',[sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)/DCM',13,'(Quaternions)/Quaternions/Sum2']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)/DCM',13,'(Quaternions)/Quaternions/Sum2']],...
		'inputs','++-',...
		'position',[570,472,590,508])

add_block('built-in/Gain',[sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)/DCM',13,'(Quaternions)/Quaternions/Gain3']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)/DCM',13,'(Quaternions)/Quaternions/Gain3']],...
		'Gain','0.5',...
		'position',[640,480,660,500])

add_block('built-in/Demux',[sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)/DCM',13,'(Quaternions)/Quaternions/Demux3']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)/DCM',13,'(Quaternions)/Quaternions/Demux3']],...
		'outputs','3',...
		'position',[325,469,365,501])

add_block('built-in/Product',[sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)/DCM',13,'(Quaternions)/Quaternions/Product11']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)/DCM',13,'(Quaternions)/Quaternions/Product11']],...
		'position',[455,420,480,440])

add_block('built-in/Product',[sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)/DCM',13,'(Quaternions)/Quaternions/Product12']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)/DCM',13,'(Quaternions)/Quaternions/Product12']],...
		'position',[455,480,480,500])

add_block('built-in/Product',[sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)/DCM',13,'(Quaternions)/Quaternions/Product13']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)/DCM',13,'(Quaternions)/Quaternions/Product13']],...
		'position',[455,535,480,555])

add_block('built-in/Product',[sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)/DCM',13,'(Quaternions)/Quaternions/Product14']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)/DCM',13,'(Quaternions)/Quaternions/Product14']],...
		'position',[455,710,480,730])

add_block('built-in/Product',[sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)/DCM',13,'(Quaternions)/Quaternions/Product15']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)/DCM',13,'(Quaternions)/Quaternions/Product15']],...
		'position',[455,660,480,680])

add_block('built-in/Product',[sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)/DCM',13,'(Quaternions)/Quaternions/Product16']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)/DCM',13,'(Quaternions)/Quaternions/Product16']],...
		'position',[455,610,480,630])

add_block('built-in/Demux',[sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)/DCM',13,'(Quaternions)/Quaternions/Demux4']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)/DCM',13,'(Quaternions)/Quaternions/Demux4']],...
		'outputs','3',...
		'position',[325,649,365,681])

add_block('built-in/Gain',[sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)/DCM',13,'(Quaternions)/Quaternions/Gain4']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)/DCM',13,'(Quaternions)/Quaternions/Gain4']],...
		'Gain','0.5',...
		'position',[640,660,660,680])

add_block('built-in/Sum',[sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)/DCM',13,'(Quaternions)/Quaternions/Sum3']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)/DCM',13,'(Quaternions)/Quaternions/Sum3']],...
		'inputs','-++',...
		'position',[570,652,590,688])

add_block('built-in/Mux',[sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)/DCM',13,'(Quaternions)/Quaternions/Mux1']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)/DCM',13,'(Quaternions)/Quaternions/Mux1']],...
		'position',[800,378,855,437])

add_block('built-in/Integrator',[sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)/DCM',13,'(Quaternions)/Quaternions/Integrator']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)/DCM',13,'(Quaternions)/Quaternions/Integrator']],...
		'Initial','[e0_0 e1_0 e2_0 e3_0]''',...
		'position',[910,400,930,420])

add_block('built-in/Fcn',[sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)/DCM',13,'(Quaternions)/Quaternions/Fcn']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)/DCM',13,'(Quaternions)/Quaternions/Fcn']],...
		'orientation',2,...
		'Expr','(1-u[1]*u[1]-u[2]*u[2]-u[3]*u[3]-u[4]*u[4])*u')
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)/DCM',13,'(Quaternions)/Quaternions/Fcn']],...
		'position',[855,290,895,310])

add_block('built-in/Gain',[sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)/DCM',13,'(Quaternions)/Quaternions/kquat']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)/DCM',13,'(Quaternions)/Quaternions/kquat']],...
		'orientation',2,...
		'Gain','kquat',...
		'position',[815,290,835,310])

add_block('built-in/Product',[sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)/DCM',13,'(Quaternions)/Quaternions/Product17']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)/DCM',13,'(Quaternions)/Quaternions/Product17']],...
		'position',[620,210,645,230])

add_block('built-in/Sum',[sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)/DCM',13,'(Quaternions)/Quaternions/Sum4']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)/DCM',13,'(Quaternions)/Quaternions/Sum4']],...
		'position',[690,152,710,188])

add_block('built-in/Sum',[sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)/DCM',13,'(Quaternions)/Quaternions/Sum5']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)/DCM',13,'(Quaternions)/Quaternions/Sum5']],...
		'position',[690,312,710,348])

add_block('built-in/Product',[sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)/DCM',13,'(Quaternions)/Quaternions/Product18']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)/DCM',13,'(Quaternions)/Quaternions/Product18']],...
		'position',[635,365,660,385])

add_block('built-in/Product',[sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)/DCM',13,'(Quaternions)/Quaternions/Product19']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)/DCM',13,'(Quaternions)/Quaternions/Product19']],...
		'position',[640,530,665,550])

add_block('built-in/Sum',[sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)/DCM',13,'(Quaternions)/Quaternions/Sum6']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)/DCM',13,'(Quaternions)/Quaternions/Sum6']],...
		'position',[685,477,705,513])

add_block('built-in/Sum',[sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)/DCM',13,'(Quaternions)/Quaternions/Sum7']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)/DCM',13,'(Quaternions)/Quaternions/Sum7']],...
		'position',[700,642,720,678])

add_block('built-in/Product',[sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)/DCM',13,'(Quaternions)/Quaternions/Product20']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)/DCM',13,'(Quaternions)/Quaternions/Product20']],...
		'position',[640,590,665,610])

add_block('built-in/Note',[sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)/DCM',13,'(Quaternions)/Quaternions/M Ahmed and J King',13,'Cranfield University',13,'RMCS',13,'Shrivenham',13,'SWINDON',13,'Wilts SN6 8LA   UK']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)/DCM',13,'(Quaternions)/Quaternions/M Ahmed and J King',13,'Cranfield University',13,'RMCS',13,'Shrivenham',13,'SWINDON',13,'Wilts SN6 8LA   UK']],...
		'position',[90,525,95,530])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)/DCM',13,'(Quaternions)/Quaternions']],[105,125;310,125])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)/DCM',13,'(Quaternions)/Quaternions']],[280,125;280,315;320,315])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)/DCM',13,'(Quaternions)/Quaternions']],[280,315;280,485;320,485])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)/DCM',13,'(Quaternions)/Quaternions']],[280,485;280,665;320,665])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)/DCM',13,'(Quaternions)/Quaternions']],[360,125;440,125])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)/DCM',13,'(Quaternions)/Quaternions']],[585,130;620,130])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)/DCM',13,'(Quaternions)/Quaternions']],[475,70;555,120])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)/DCM',13,'(Quaternions)/Quaternions']],[475,130;555,130])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)/DCM',13,'(Quaternions)/Quaternions']],[475,180;555,140])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)/DCM',13,'(Quaternions)/Quaternions']],[360,115;375,115;375,65;440,65])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)/DCM',13,'(Quaternions)/Quaternions']],[360,135;375,135;375,175;440,175])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)/DCM',13,'(Quaternions)/Quaternions']],[370,325;385,325;385,365;450,365])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)/DCM',13,'(Quaternions)/Quaternions']],[370,305;385,305;385,255;450,255])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)/DCM',13,'(Quaternions)/Quaternions']],[485,370;545,330])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)/DCM',13,'(Quaternions)/Quaternions']],[485,320;545,320])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)/DCM',13,'(Quaternions)/Quaternions']],[485,260;545,310])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)/DCM',13,'(Quaternions)/Quaternions']],[370,315;450,315])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)/DCM',13,'(Quaternions)/Quaternions']],[370,485;450,485])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)/DCM',13,'(Quaternions)/Quaternions']],[595,490;635,490])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)/DCM',13,'(Quaternions)/Quaternions']],[485,430;565,480])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)/DCM',13,'(Quaternions)/Quaternions']],[485,490;565,490])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)/DCM',13,'(Quaternions)/Quaternions']],[485,545;565,500])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)/DCM',13,'(Quaternions)/Quaternions']],[370,475;385,475;385,425;450,425])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)/DCM',13,'(Quaternions)/Quaternions']],[370,495;385,495;385,540;450,540])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)/DCM',13,'(Quaternions)/Quaternions']],[370,675;385,675;385,715;450,715])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)/DCM',13,'(Quaternions)/Quaternions']],[370,655;385,655;385,615;450,615])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)/DCM',13,'(Quaternions)/Quaternions']],[485,720;565,680])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)/DCM',13,'(Quaternions)/Quaternions']],[485,670;565,670])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)/DCM',13,'(Quaternions)/Quaternions']],[485,620;565,660])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)/DCM',13,'(Quaternions)/Quaternions']],[595,670;635,670])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)/DCM',13,'(Quaternions)/Quaternions']],[370,665;450,665])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)/DCM',13,'(Quaternions)/Quaternions']],[135,175;200,175;200,725;450,725])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)/DCM',13,'(Quaternions)/Quaternions']],[200,265;450,265])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)/DCM',13,'(Quaternions)/Quaternions']],[200,520;395,520;395,495;450,495])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)/DCM',13,'(Quaternions)/Quaternions']],[135,185;390,185;390,75;440,75])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)/DCM',13,'(Quaternions)/Quaternions']],[230,185;230,550;450,550])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)/DCM',13,'(Quaternions)/Quaternions']],[230,550;230,700;430,700;430,675;450,675])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)/DCM',13,'(Quaternions)/Quaternions']],[850,300;840,300])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)/DCM',13,'(Quaternions)/Quaternions']],[935,410;1005,410])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)/DCM',13,'(Quaternions)/Quaternions']],[945,410;945,20;50,20;50,190;85,190])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)/DCM',13,'(Quaternions)/Quaternions']],[945,300;900,300])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)/DCM',13,'(Quaternions)/Quaternions']],[860,410;905,410])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)/DCM',13,'(Quaternions)/Quaternions']],[200,215;615,215])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)/DCM',13,'(Quaternions)/Quaternions']],[650,220;685,180])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)/DCM',13,'(Quaternions)/Quaternions']],[665,130;685,160])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)/DCM',13,'(Quaternions)/Quaternions']],[665,375;685,340])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)/DCM',13,'(Quaternions)/Quaternions']],[660,320;685,320])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)/DCM',13,'(Quaternions)/Quaternions']],[230,380;630,380])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)/DCM',13,'(Quaternions)/Quaternions']],[575,320;630,320])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)/DCM',13,'(Quaternions)/Quaternions']],[665,670;695,670])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)/DCM',13,'(Quaternions)/Quaternions']],[810,300;610,300;615,225])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)/DCM',13,'(Quaternions)/Quaternions']],[615,300;615,370;630,370])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)/DCM',13,'(Quaternions)/Quaternions']],[620,370;620,595;635,595])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)/DCM',13,'(Quaternions)/Quaternions']],[620,535;635,535])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)/DCM',13,'(Quaternions)/Quaternions']],[670,540;680,505])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)/DCM',13,'(Quaternions)/Quaternions']],[665,490;680,485])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)/DCM',13,'(Quaternions)/Quaternions']],[135,195;405,195;405,135;440,135])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)/DCM',13,'(Quaternions)/Quaternions']],[405,195;405,375;450,375])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)/DCM',13,'(Quaternions)/Quaternions']],[405,375;405,625;450,625])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)/DCM',13,'(Quaternions)/Quaternions']],[405,545;635,545])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)/DCM',13,'(Quaternions)/Quaternions']],[135,205;415,205;415,185;440,185])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)/DCM',13,'(Quaternions)/Quaternions']],[415,205;415,325;450,325])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)/DCM',13,'(Quaternions)/Quaternions']],[415,325;415,435;450,435])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)/DCM',13,'(Quaternions)/Quaternions']],[420,435;420,605;635,605])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)/DCM',13,'(Quaternions)/Quaternions']],[670,600;695,650])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)/DCM',13,'(Quaternions)/Quaternions']],[725,660;770,660;770,430;795,430])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)/DCM',13,'(Quaternions)/Quaternions']],[710,495;755,495;755,415;795,415])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)/DCM',13,'(Quaternions)/Quaternions']],[715,330;755,330;755,400;795,400])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)/DCM',13,'(Quaternions)/Quaternions']],[715,170;770,170;770,385;795,385])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)/DCM',13,'(Quaternions)/Quaternions']],...
		'Mask Display','')


%     Finished composite block ['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)/DCM',13,'(Quaternions)/Quaternions'].

set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)/DCM',13,'(Quaternions)/Quaternions']],...
		'ForeGround',1,...
		'BackGround',3,...
		'position',[60,52,130,188])

add_block('built-in/Outport',[sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)/DCM',13,'(Quaternions)/out_1']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)/DCM',13,'(Quaternions)/out_1']],...
		'ForeGround',1,...
		'BackGround',4,...
		'position',[340,110,360,130])


%     Subsystem  ['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)/DCM',13,'(Quaternions)/DCM'].

new_system([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)/DCM',13,'(Quaternions)/DCM']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)/DCM',13,'(Quaternions)/DCM']],'Location',[5,86,983,710])

add_block('built-in/Gain',[sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)/DCM',13,'(Quaternions)/DCM/Gain5']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)/DCM',13,'(Quaternions)/DCM/Gain5']],...
		'Gain','2',...
		'position',[480,560,500,580])

add_block('built-in/Gain',[sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)/DCM',13,'(Quaternions)/DCM/Gain4']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)/DCM',13,'(Quaternions)/DCM/Gain4']],...
		'Gain','2',...
		'position',[480,520,500,540])

add_block('built-in/Gain',[sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)/DCM',13,'(Quaternions)/DCM/Gain3']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)/DCM',13,'(Quaternions)/DCM/Gain3']],...
		'Gain','2',...
		'position',[475,460,495,480])

add_block('built-in/Gain',[sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)/DCM',13,'(Quaternions)/DCM/Gain2']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)/DCM',13,'(Quaternions)/DCM/Gain2']],...
		'Gain','2',...
		'position',[475,400,495,420])

add_block('built-in/Gain',[sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)/DCM',13,'(Quaternions)/DCM/Gain1']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)/DCM',13,'(Quaternions)/DCM/Gain1']],...
		'Gain','2',...
		'position',[475,340,495,360])

add_block('built-in/Gain',[sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)/DCM',13,'(Quaternions)/DCM/Gain']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)/DCM',13,'(Quaternions)/DCM/Gain']],...
		'Gain','2',...
		'position',[475,300,495,320])

add_block('built-in/Sum',[sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)/DCM',13,'(Quaternions)/DCM/dcmeb31']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)/DCM',13,'(Quaternions)/DCM/dcmeb31']],...
		'inputs','-+',...
		'position',[410,340,430,360])

add_block('built-in/Sum',[sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)/DCM',13,'(Quaternions)/DCM/dcmeb32']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)/DCM',13,'(Quaternions)/DCM/dcmeb32']],...
		'position',[415,520,435,540])

add_block('built-in/Sum',[sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)/DCM',13,'(Quaternions)/DCM/dcmeb23']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)/DCM',13,'(Quaternions)/DCM/dcmeb23']],...
		'inputs','-+',...
		'position',[415,560,435,580])

add_block('built-in/Sum',[sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)/DCM',13,'(Quaternions)/DCM/dcmeb33']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)/DCM',13,'(Quaternions)/DCM/dcmeb33']],...
		'inputs','+--+',...
		'position',[435,217,455,263])

add_block('built-in/Sum',[sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)/DCM',13,'(Quaternions)/DCM/dcmeb22']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)/DCM',13,'(Quaternions)/DCM/dcmeb22']],...
		'inputs','+-+-',...
		'position',[435,147,455,193])

add_block('built-in/Sum',[sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)/DCM',13,'(Quaternions)/DCM/dcmeb21']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)/DCM',13,'(Quaternions)/DCM/dcmeb21']],...
		'position',[410,460,430,480])

add_block('built-in/Sum',[sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)/DCM',13,'(Quaternions)/DCM/dcmeb13']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)/DCM',13,'(Quaternions)/DCM/dcmeb13']],...
		'position',[410,300,430,320])

add_block('built-in/Sum',[sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)/DCM',13,'(Quaternions)/DCM/dcmeb12']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)/DCM',13,'(Quaternions)/DCM/dcmeb12']],...
		'inputs','-+',...
		'position',[410,400,430,420])

add_block('built-in/Sum',[sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)/DCM',13,'(Quaternions)/DCM/dcmeb11']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)/DCM',13,'(Quaternions)/DCM/dcmeb11']],...
		'inputs','++--',...
		'position',[435,72,455,118])

add_block('built-in/Product',[sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)/DCM',13,'(Quaternions)/DCM/e2e3']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)/DCM',13,'(Quaternions)/DCM/e2e3']],...
		'position',[260,565,285,585])

add_block('built-in/Product',[sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)/DCM',13,'(Quaternions)/DCM/e1e3']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)/DCM',13,'(Quaternions)/DCM/e1e3']],...
		'position',[260,345,285,365])

add_block('built-in/Product',[sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)/DCM',13,'(Quaternions)/DCM/e1e2']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)/DCM',13,'(Quaternions)/DCM/e1e2']],...
		'position',[260,465,285,485])

add_block('built-in/Product',[sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)/DCM',13,'(Quaternions)/DCM/e0e3']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)/DCM',13,'(Quaternions)/DCM/e0e3']],...
		'position',[260,395,285,415])

add_block('built-in/Product',[sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)/DCM',13,'(Quaternions)/DCM/e0e2']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)/DCM',13,'(Quaternions)/DCM/e0e2']],...
		'position',[260,295,285,315])

add_block('built-in/Product',[sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)/DCM',13,'(Quaternions)/DCM/e0e1']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)/DCM',13,'(Quaternions)/DCM/e0e1']],...
		'position',[260,515,285,535])

add_block('built-in/Product',[sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)/DCM',13,'(Quaternions)/DCM/e3e3']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)/DCM',13,'(Quaternions)/DCM/e3e3']],...
		'position',[260,215,285,235])

add_block('built-in/Note',[sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)/DCM',13,'(Quaternions)/DCM/1,   e0^2+e1^2-e2^2-e3^3']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)/DCM',13,'(Quaternions)/DCM/1,   e0^2+e1^2-e2^2-e3^3']],...
		'position',[710,25,715,30])

add_block('built-in/Note',[sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)/DCM',13,'(Quaternions)/DCM/2,  2(e1e2-e0e3)']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)/DCM',13,'(Quaternions)/DCM/2,  2(e1e2-e0e3)']],...
		'position',[690,50,695,55])

add_block('built-in/Note',[sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)/DCM',13,'(Quaternions)/DCM/3,  2(e0e2+e1e3)']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)/DCM',13,'(Quaternions)/DCM/3,  2(e0e2+e1e3)']],...
		'position',[695,75,700,80])

add_block('built-in/Note',[sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)/DCM',13,'(Quaternions)/DCM/4,  2(e1e2+e0e3)']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)/DCM',13,'(Quaternions)/DCM/4,  2(e1e2+e0e3)']],...
		'position',[850,25,855,30])

add_block('built-in/Mux',[sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)/DCM',13,'(Quaternions)/DCM/Mux']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)/DCM',13,'(Quaternions)/DCM/Mux']],...
		'inputs','9',...
		'position',[790,94,820,556])

add_block('built-in/Outport',[sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)/DCM',13,'(Quaternions)/DCM/out_1']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)/DCM',13,'(Quaternions)/DCM/out_1']],...
		'position',[850,315,870,335])

add_block('built-in/Demux',[sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)/DCM',13,'(Quaternions)/DCM/Demux']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)/DCM',13,'(Quaternions)/DCM/Demux']],...
		'position',[70,35,110,260])

add_block('built-in/Inport',[sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)/DCM',13,'(Quaternions)/DCM/in_1']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)/DCM',13,'(Quaternions)/DCM/in_1']],...
		'position',[25,140,45,160])

add_block('built-in/Product',[sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)/DCM',13,'(Quaternions)/DCM/e2e2']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)/DCM',13,'(Quaternions)/DCM/e2e2']],...
		'position',[260,170,285,190])

add_block('built-in/Product',[sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)/DCM',13,'(Quaternions)/DCM/e1e1']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)/DCM',13,'(Quaternions)/DCM/e1e1']],...
		'position',[260,115,285,135])

add_block('built-in/Product',[sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)/DCM',13,'(Quaternions)/DCM/e0e0']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)/DCM',13,'(Quaternions)/DCM/e0e0']],...
		'position',[260,60,285,80])

add_block('built-in/Note',[sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)/DCM',13,'(Quaternions)/DCM/M Ahmed and J King',13,'Cranfield University',13,'RMCS',13,'Shrivenham',13,'SWINDON',13,'Wilts SN6 8LA   UK']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)/DCM',13,'(Quaternions)/DCM/M Ahmed and J King',13,'Cranfield University',13,'RMCS',13,'Shrivenham',13,'SWINDON',13,'Wilts SN6 8LA   UK']],...
		'position',[85,485,90,490])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)/DCM',13,'(Quaternions)/DCM']],[115,120;255,120])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)/DCM',13,'(Quaternions)/DCM']],[205,120;205,470;255,470])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)/DCM',13,'(Quaternions)/DCM']],[205,350;255,350])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)/DCM',13,'(Quaternions)/DCM']],[205,470;205,530;255,530])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)/DCM',13,'(Quaternions)/DCM']],[115,175;255,175])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)/DCM',13,'(Quaternions)/DCM']],[185,175;185,480;255,480])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)/DCM',13,'(Quaternions)/DCM']],[190,480;190,570;255,570])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)/DCM',13,'(Quaternions)/DCM']],[115,230;255,230])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)/DCM',13,'(Quaternions)/DCM']],[170,230;170,410;255,410])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)/DCM',13,'(Quaternions)/DCM']],[170,410;170,580;255,580])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)/DCM',13,'(Quaternions)/DCM']],[500,310;750,310;750,225;785,225])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)/DCM',13,'(Quaternions)/DCM']],[500,410;605,410;605,175;785,175])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)/DCM',13,'(Quaternions)/DCM']],[500,470;620,470;620,275;785,275])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)/DCM',13,'(Quaternions)/DCM']],[505,570;635,570;635,375;785,375])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)/DCM',13,'(Quaternions)/DCM']],[500,350;585,350;585,425;785,425])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)/DCM',13,'(Quaternions)/DCM']],[505,530;670,530;670,475;785,475])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)/DCM',13,'(Quaternions)/DCM']],[435,350;470,350])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)/DCM',13,'(Quaternions)/DCM']],[435,410;470,410])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)/DCM',13,'(Quaternions)/DCM']],[435,470;470,470])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)/DCM',13,'(Quaternions)/DCM']],[440,530;475,530])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)/DCM',13,'(Quaternions)/DCM']],[440,570;475,570])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)/DCM',13,'(Quaternions)/DCM']],[435,310;470,310])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)/DCM',13,'(Quaternions)/DCM']],[50,150;65,150])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)/DCM',13,'(Quaternions)/DCM']],[825,325;845,325])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)/DCM',13,'(Quaternions)/DCM']],[460,240;575,240;575,525;785,525])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)/DCM',13,'(Quaternions)/DCM']],[240,120;240,130;255,130])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)/DCM',13,'(Quaternions)/DCM']],[115,65;255,65])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)/DCM',13,'(Quaternions)/DCM']],[240,65;240,75;255,75])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)/DCM',13,'(Quaternions)/DCM']],[240,175;240,185;255,185])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)/DCM',13,'(Quaternions)/DCM']],[230,230;230,220;255,220])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)/DCM',13,'(Quaternions)/DCM']],[290,225;325,225;325,110;430,110])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)/DCM',13,'(Quaternions)/DCM']],[325,185;430,185])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)/DCM',13,'(Quaternions)/DCM']],[290,70;430,80])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)/DCM',13,'(Quaternions)/DCM']],[395,78;395,155;430,155])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)/DCM',13,'(Quaternions)/DCM']],[395,155;395,225;430,225])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)/DCM',13,'(Quaternions)/DCM']],[290,125;305,125;305,90;430,90])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)/DCM',13,'(Quaternions)/DCM']],[390,90;390,165;430,165])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)/DCM',13,'(Quaternions)/DCM']],[390,165;390,235;430,235])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)/DCM',13,'(Quaternions)/DCM']],[290,180;315,180;315,100;430,100])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)/DCM',13,'(Quaternions)/DCM']],[380,100;380,175;430,175])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)/DCM',13,'(Quaternions)/DCM']],[380,175;380,245;430,245])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)/DCM',13,'(Quaternions)/DCM']],[325,225;325,255;430,255])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)/DCM',13,'(Quaternions)/DCM']],[170,360;255,360])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)/DCM',13,'(Quaternions)/DCM']],[220,65;220,400;255,400])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)/DCM',13,'(Quaternions)/DCM']],[220,400;220,520;255,520])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)/DCM',13,'(Quaternions)/DCM']],[290,475;315,475;315,415;405,415])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)/DCM',13,'(Quaternions)/DCM']],[315,475;405,475])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)/DCM',13,'(Quaternions)/DCM']],[290,405;405,405])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)/DCM',13,'(Quaternions)/DCM']],[340,405;340,465;405,465])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)/DCM',13,'(Quaternions)/DCM']],[220,300;255,300])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)/DCM',13,'(Quaternions)/DCM']],[185,310;255,310])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)/DCM',13,'(Quaternions)/DCM']],[290,525;315,525;315,565;410,565])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)/DCM',13,'(Quaternions)/DCM']],[315,525;410,525])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)/DCM',13,'(Quaternions)/DCM']],[290,575;410,575])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)/DCM',13,'(Quaternions)/DCM']],[330,575;330,535;410,535])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)/DCM',13,'(Quaternions)/DCM']],[290,355;305,355;305,315;405,315])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)/DCM',13,'(Quaternions)/DCM']],[305,355;405,355])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)/DCM',13,'(Quaternions)/DCM']],[290,305;405,305])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)/DCM',13,'(Quaternions)/DCM']],[330,305;330,345;405,345])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)/DCM',13,'(Quaternions)/DCM']],[460,95;625,95;625,125;785,125])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)/DCM',13,'(Quaternions)/DCM']],[460,170;595,170;595,325;785,325])


%     Finished composite block ['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)/DCM',13,'(Quaternions)/DCM'].

set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)/DCM',13,'(Quaternions)/DCM']],...
		'ForeGround',1,...
		'BackGround',3,...
		'position',[235,54,300,186])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)/DCM',13,'(Quaternions)']],[135,120;230,120])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)/DCM',13,'(Quaternions)']],[40,120;55,120])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)/DCM',13,'(Quaternions)']],[305,120;335,120])


%     Finished composite block ['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)/DCM',13,'(Quaternions)'].

set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)/DCM',13,'(Quaternions)']],...
		'ForeGround',1,...
		'BackGround',2,...
		'position',[235,142,295,238])

add_block('built-in/Outport',[sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)/North,East,Down']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)/North,East,Down']],...
		'ForeGround',1,...
		'BackGround',4,...
		'position',[500,100,520,120])

add_block('built-in/Outport',[sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)/Direction',13,'cosines']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)/Direction',13,'cosines']],...
		'ForeGround',1,...
		'BackGround',4,...
		'Port','2',...
		'position',[500,180,520,200])


%     Subsystem  ['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)/NED'].

new_system([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)/NED']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)/NED']],'Location',[61,99,911,438])

add_block('built-in/Note',[sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)/NED/M Ahmed and J King',13,'Cranfield University',13,'RMCS',13,'Shrivenham',13,'SWINDON',13,'Wilts SN6 8LA   UK']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)/NED/M Ahmed and J King',13,'Cranfield University',13,'RMCS',13,'Shrivenham',13,'SWINDON',13,'Wilts SN6 8LA   UK']],...
		'ForeGround',1)
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)/NED/M Ahmed and J King',13,'Cranfield University',13,'RMCS',13,'Shrivenham',13,'SWINDON',13,'Wilts SN6 8LA   UK']],...
		'position',[735,211,740,216])

add_block('built-in/Product',[sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)/NED/Product1']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)/NED/Product1']],...
		'ForeGround',1,...
		'BackGround',3,...
		'position',[305,125,330,145])

add_block('built-in/Outport',[sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)/NED/NED']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)/NED/NED']],...
		'ForeGround',1,...
		'BackGround',4,...
		'position',[720,125,740,145])

add_block('built-in/MATLAB Fcn',[sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)/NED/We']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)/NED/We']],...
		'ForeGround',1,...
		'BackGround',3,...
		'MATLAB Fcn','sum',...
		'Output Width','1',...
		'position',[385,177,455,213])

add_block('built-in/MATLAB Fcn',[sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)/NED/Ve']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)/NED/Ve']],...
		'ForeGround',1,...
		'BackGround',3,...
		'MATLAB Fcn','sum',...
		'Output Width','1',...
		'position',[385,115,455,155])

add_block('built-in/MATLAB Fcn',[sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)/NED/Ue']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)/NED/Ue']],...
		'ForeGround',1,...
		'BackGround',3,...
		'MATLAB Fcn','sum',...
		'Output Width','1',...
		'position',[385,55,455,95])

add_block('built-in/Product',[sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)/NED/Product2']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)/NED/Product2']],...
		'ForeGround',1,...
		'BackGround',3,...
		'position',[305,65,330,85])

add_block('built-in/Product',[sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)/NED/Product']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)/NED/Product']],...
		'ForeGround',1,...
		'BackGround',3,...
		'position',[305,185,330,205])

add_block('built-in/Inport',[sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)/NED/U,V,W']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)/NED/U,V,W']],...
		'ForeGround',1,...
		'BackGround',4,...
		'position',[30,57,55,83])

add_block('built-in/Inport',[sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)/NED/DCM']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)/NED/DCM']],...
		'ForeGround',1,...
		'BackGround',4,...
		'Port','2',...
		'position',[25,250,45,270])

add_block('built-in/Demux',[sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)/NED/Demux1']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)/NED/Demux1']],...
		'ForeGround',1,...
		'BackGround',0,...
		'outputs','[3 3 3]',...
		'position',[90,231,140,289])

add_block('built-in/Mux',[sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)/NED/Mux']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)/NED/Mux']],...
		'ForeGround',1,...
		'BackGround',0,...
		'inputs','3',...
		'position',[585,43,630,227])

add_block('built-in/Integrator',[sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)/NED/Down']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)/NED/Down']],...
		'ForeGround',1,...
		'BackGround',6,...
		'Initial','Down_0',...
		'position',[510,180,535,210])

add_block('built-in/Integrator',[sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)/NED/East']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)/NED/East']],...
		'ForeGround',1,...
		'BackGround',6,...
		'Initial','East_0',...
		'position',[510,120,535,150])

add_block('built-in/Integrator',[sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)/NED/North']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)/NED/North']],...
		'ForeGround',1,...
		'BackGround',6,...
		'Initial','North_0',...
		'position',[510,60,535,90])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)/NED']],[335,195;380,195])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)/NED']],[335,135;380,135])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)/NED']],[335,75;380,75])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)/NED']],[60,70;300,70])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)/NED']],[145,240;220,240;220,80;300,80])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)/NED']],[145,260;240,260;240,140;300,140])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)/NED']],[145,280;260,280;260,200;300,200])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)/NED']],[50,260;85,260])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)/NED']],[635,135;715,135])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)/NED']],[60,70;120,70;120,130;300,130])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)/NED']],[60,70;90,70;90,190;300,190])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)/NED']],[460,75;505,75])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)/NED']],[540,75;580,75])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)/NED']],[460,135;505,135])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)/NED']],[540,135;580,135])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)/NED']],[460,195;505,195])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)/NED']],[540,195;580,195])


%     Finished composite block ['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)/NED'].

set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)/NED']],...
		'ForeGround',1,...
		'BackGround',2,...
		'position',[385,60,445,155])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)']],[155,85;380,85])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)']],[300,190;495,190])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)']],[155,190;230,190])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)']],[450,110;495,110])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)']],[70,140;90,140])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)']],[300,190;330,190;330,130;380,130])


%     Finished composite block ['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)'].

set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/States2NED',13,'(Quaternions)']],...
		'ForeGround',1,...
		'BackGround',3,...
		'position',[330,64,395,171])

add_block('built-in/Inport',[sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/M + I']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/M + I']],...
		'ForeGround',1,...
		'BackGround',4,...
		'Port','2',...
		'position',[55,95,75,115])

add_block('built-in/Inport',[sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/X,Y,Z,',13,'L,M,N']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/X,Y,Z,',13,'L,M,N']],...
		'ForeGround',1,...
		'BackGround',4,...
		'position',[55,160,75,180])

add_block('built-in/Outport',[sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/DCM']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/DCM']],...
		'ForeGround',1,...
		'BackGround',4,...
		'Port','4',...
		'position',[475,135,495,155])


%     Subsystem  ['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion'].

new_system([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion']],'Location',[91,265,890,742])

add_block('built-in/Inport',[sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/Mass and',13,'Inertias']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/Mass and',13,'Inertias']],...
		'ForeGround',1,...
		'BackGround',4,...
		'position',[55,360,75,380])


%     Subsystem  ['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)'].

new_system([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)']],'Location',[184,219,999,665])


%     Subsystem  ['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/R'].

new_system([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/R']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/R']],'Location',[469,483,993,736])

add_block('built-in/Outport',[sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/R/out_1']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/R/out_1']],...
		'ForeGround',1,...
		'BackGround',4,...
		'position',[440,90,460,110])

add_block('built-in/Switch',[sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/R/Switch']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/R/Switch']],...
		'ForeGround',1,...
		'BackGround',5,...
		'Threshold','1',...
		'position',[340,84,370,116])

add_block('built-in/Constant',[sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/R/R_0']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/R/R_0']],...
		'ForeGround',1,...
		'BackGround',7,...
		'Value','R_0',...
		'position',[225,150,275,170])

add_block('built-in/Constant',[sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/R/R_dof']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/R/R_dof']],...
		'ForeGround',1,...
		'BackGround',7,...
		'Value','R_dof',...
		'position',[230,90,280,110])

add_block('built-in/Integrator',[sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/R/R']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/R/R']],...
		'ForeGround',1,...
		'BackGround',6,...
		'Initial','R_0',...
		'position',[235,22,270,58])

add_block('built-in/Inport',[sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/R/in_1']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/R/in_1']],...
		'ForeGround',1,...
		'BackGround',4,...
		'position',[80,30,100,50])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/R']],[285,100;335,100])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/R']],[280,160;315,160;315,110;335,110])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/R']],[275,40;300,40;300,90;335,90])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/R']],[105,40;230,40])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/R']],[375,100;435,100])


%     Finished composite block ['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/R'].

set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/R']],...
		'ForeGround',1,...
		'BackGround',3,...
		'position',[485,293,515,347])


%     Subsystem  ['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/Q'].

new_system([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/Q']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/Q']],'Location',[469,483,993,736])

add_block('built-in/Inport',[sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/Q/in_1']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/Q/in_1']],...
		'ForeGround',1,...
		'BackGround',4,...
		'position',[80,30,100,50])

add_block('built-in/Integrator',[sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/Q/Q']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/Q/Q']],...
		'ForeGround',1,...
		'BackGround',6,...
		'Initial','Q_0',...
		'position',[235,22,270,58])

add_block('built-in/Constant',[sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/Q/Q_dof']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/Q/Q_dof']],...
		'ForeGround',1,...
		'BackGround',7,...
		'Value','Q_dof',...
		'position',[230,90,280,110])

add_block('built-in/Constant',[sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/Q/Q_0']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/Q/Q_0']],...
		'ForeGround',1,...
		'BackGround',7,...
		'Value','Q_0',...
		'position',[225,150,275,170])

add_block('built-in/Switch',[sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/Q/Switch']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/Q/Switch']],...
		'ForeGround',1,...
		'BackGround',5,...
		'Threshold','1',...
		'position',[340,84,370,116])

add_block('built-in/Outport',[sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/Q/out_1']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/Q/out_1']],...
		'ForeGround',1,...
		'BackGround',4,...
		'position',[440,90,460,110])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/Q']],[375,100;435,100])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/Q']],[105,40;230,40])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/Q']],[275,40;300,40;300,90;335,90])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/Q']],[280,160;315,160;315,110;335,110])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/Q']],[285,100;335,100])


%     Finished composite block ['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/Q'].

set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/Q']],...
		'ForeGround',1,...
		'BackGround',3,...
		'position',[485,193,515,247])


%     Subsystem  ['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/P'].

new_system([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/P']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/P']],'Location',[56,420,519,686])

add_block('built-in/Inport',[sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/P/P dot']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/P/P dot']],...
		'ForeGround',1,...
		'BackGround',4,...
		'position',[60,30,80,50])

add_block('built-in/Integrator',[sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/P/P']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/P/P']],...
		'ForeGround',1,...
		'BackGround',6,...
		'Initial','P_0',...
		'position',[130,22,165,58])

add_block('built-in/Constant',[sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/P/P_dof']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/P/P_dof']],...
		'ForeGround',1,...
		'BackGround',7,...
		'Value','P_dof',...
		'position',[125,90,175,110])

add_block('built-in/Constant',[sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/P/P_0']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/P/P_0']],...
		'ForeGround',1,...
		'BackGround',7,...
		'Value','P_0',...
		'position',[120,150,170,170])

add_block('built-in/Outport',[sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/P/P_out']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/P/P_out']],...
		'ForeGround',1,...
		'BackGround',4,...
		'position',[335,90,355,110])

add_block('built-in/Switch',[sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/P/Switch']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/P/Switch']],...
		'ForeGround',1,...
		'BackGround',5,...
		'Threshold','1',...
		'position',[235,47,265,153])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/P']],[180,100;230,100])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/P']],[175,160;210,160;210,135;230,135])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/P']],[170,40;195,40;195,65;230,65])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/P']],[85,40;125,40])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/P']],[270,100;330,100])


%     Finished composite block ['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/P'].

set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/P']],...
		'ForeGround',1,...
		'BackGround',3,...
		'position',[485,93,515,147])

add_block('built-in/Mux',[sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/Mux1']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/Mux1']],...
		'ForeGround',1,...
		'BackGround',0,...
		'inputs','3',...
		'position',[575,165,615,275])

add_block('built-in/Outport',[sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/p,q,r ']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/p,q,r ']],...
		'ForeGround',1,...
		'BackGround',4,...
		'position',[710,207,730,233])

add_block('built-in/Outport',[sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/Pdot, Qdot,',13,'Rdot']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/Pdot, Qdot,',13,'Rdot']],...
		'ForeGround',1,...
		'BackGround',4,...
		'Port','2')
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/Pdot, Qdot,',13,'Rdot']],...
		'position',[710,357,730,383])

add_block('built-in/Mux',[sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/Mux2']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/Mux2']],...
		'ForeGround',1,...
		'BackGround',0,...
		'inputs','3',...
		'position',[605,337,645,403])

add_block('built-in/Inport',[sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/moments']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/moments']],...
		'ForeGround',1,...
		'BackGround',4,...
		'position',[55,255,75,275])

add_block('built-in/Inport',[sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/Mass and',13,'Inertias']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/Mass and',13,'Inertias']],...
		'ForeGround',1,...
		'BackGround',4,...
		'Port','2')
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/Mass and',13,'Inertias']],...
		'position',[55,345,75,365])


%     Subsystem  ['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)'].

new_system([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)']],'Location',[4,58,1008,751])

add_block('built-in/Outport',[sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/Rdot']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/Rdot']],...
		'ForeGround',1,...
		'BackGround',4,...
		'Port','3')
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/Rdot']],...
		'position',[1185,425,1205,445])

add_block('built-in/Outport',[sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/Pdot ']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/Pdot ']],...
		'ForeGround',1,...
		'BackGround',4,...
		'position',[1185,240,1205,260])

add_block('built-in/Outport',[sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/Qdot']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/Qdot']],...
		'ForeGround',1,...
		'BackGround',4,...
		'Port','2')
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/Qdot']],...
		'position',[1185,328,1205,352])

add_block('built-in/Inport',[sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/N']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/N']],...
		'ForeGround',1,...
		'BackGround',4,...
		'Port','6')
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/N']],...
		'position',[70,105,90,125])

add_block('built-in/Inport',[sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/M']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/M']],...
		'ForeGround',1,...
		'BackGround',4,...
		'Port','5',...
		'position',[70,65,90,85])

add_block('built-in/Inport',[sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/r']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/r']],...
		'ForeGround',1,...
		'BackGround',4,...
		'Port','3')
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/r']],...
		'position',[70,450,90,470])

add_block('built-in/Inport',[sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/q']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/q']],...
		'ForeGround',1,...
		'BackGround',4,...
		'Port','2')
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/q']],...
		'position',[70,330,90,350])

add_block('built-in/Inport',[sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/L']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/L']],...
		'ForeGround',1,...
		'BackGround',4,...
		'Port','4',...
		'position',[70,24,90,46])

add_block('built-in/Inport',[sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/p']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/p']],...
		'ForeGround',1,...
		'BackGround',4,...
		'position',[70,210,90,230])


%     Subsystem  ['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/RHS(y)'].

new_system([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/RHS(y)']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/RHS(y)']],'Location',[5,59,941,561])

add_block('built-in/Demux',[sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/RHS(y)/Demux']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/RHS(y)/Demux']],...
		'orientation',3,...
		'ForeGround',1,...
		'BackGround',0)
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/RHS(y)/Demux']],...
		'outputs','7',...
		'position',[378,370,462,410])

add_block('built-in/Outport',[sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/RHS(y)/Y(rhs)']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/RHS(y)/Y(rhs)']],...
		'ForeGround',1,...
		'BackGround',4,...
		'position',[710,175,730,195])

add_block('built-in/Inport',[sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/RHS(y)/M ']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/RHS(y)/M ']],...
		'ForeGround',1,...
		'BackGround',4,...
		'position',[55,50,75,70])

add_block('built-in/Sum',[sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/RHS(y)/Sum ']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/RHS(y)/Sum ']],...
		'ForeGround',1,...
		'BackGround',5,...
		'inputs','++-+-')
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/RHS(y)/Sum ']],...
		'position',[630,151,675,219])

add_block('built-in/Sum',[sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/RHS(y)/p*p-r*r']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/RHS(y)/p*p-r*r']],...
		'ForeGround',1,...
		'BackGround',3,...
		'inputs','+-')
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/RHS(y)/p*p-r*r']],...
		'position',[335,170,355,190])

add_block('built-in/Product',[sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/RHS(y)/rp ( Iz - Ix )']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/RHS(y)/rp ( Iz - Ix )']],...
		'ForeGround',1,...
		'BackGround',3)
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/RHS(y)/rp ( Iz - Ix )']],...
		'position',[520,90,545,110])

add_block('built-in/Product',[sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/RHS(y)/(p*p - r*r ) Ixz']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/RHS(y)/(p*p - r*r ) Ixz']],...
		'ForeGround',1,...
		'BackGround',3)
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/RHS(y)/(p*p - r*r ) Ixz']],...
		'position',[520,175,545,195])

add_block('built-in/Product',[sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/RHS(y)/qr * Ixy']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/RHS(y)/qr * Ixy']],...
		'ForeGround',1,...
		'BackGround',3,...
		'position',[520,255,545,275])

add_block('built-in/Product',[sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/RHS(y)/pq * Iyz']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/RHS(y)/pq * Iyz']],...
		'ForeGround',1,...
		'BackGround',3,...
		'position',[520,320,545,340])

add_block('built-in/Sum',[sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/RHS(y)/Iz - Ix']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/RHS(y)/Iz - Ix']],...
		'orientation',3,...
		'ForeGround',1,...
		'BackGround',3)
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/RHS(y)/Iz - Ix']],...
		'inputs','-+',...
		'position',[391,120,429,140])

add_block('built-in/Inport',[sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/RHS(y)/M and I']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/RHS(y)/M and I']],...
		'ForeGround',1,...
		'BackGround',4,...
		'Port','3')
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/RHS(y)/M and I']],...
		'position',[60,425,80,445])

add_block('built-in/Demux',[sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/RHS(y)/Demux1']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/RHS(y)/Demux1']],...
		'ForeGround',1,...
		'BackGround',0,...
		'outputs','6')
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/RHS(y)/Demux1']],...
		'position',[130,202,170,268])

add_block('built-in/Inport',[sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/RHS(y)/Inport']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/RHS(y)/Inport']],...
		'ForeGround',1,...
		'BackGround',4,...
		'Port','2')
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/RHS(y)/Inport']],...
		'position',[55,225,75,245])

add_block('built-in/Note',[sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/RHS(y)/M + (R^2-P^2)Ixz + RP(Iz-Ix) + Q(RIxy-PIyz)']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/RHS(y)/M + (R^2-P^2)Ixz + RP(Iz-Ix) + Q(RIxy-PIyz)']],...
		'ForeGround',1)
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/RHS(y)/M + (R^2-P^2)Ixz + RP(Iz-Ix) + Q(RIxy-PIyz)']],...
		'position',[760,270,765,275])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/RHS(y)']],[680,185;705,185])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/RHS(y)']],[80,60;595,60;595,155;625,155])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/RHS(y)']],[360,180;515,180])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/RHS(y)']],[550,100;575,100;575,170;625,170])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/RHS(y)']],[420,365;420,145])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/RHS(y)']],[410,115;410,105;515,105])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/RHS(y)']],[400,365;400,145])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/RHS(y)']],[550,185;625,185])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/RHS(y)']],[440,365;440,190;515,190])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/RHS(y)']],[450,365;450,270;515,270])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/RHS(y)']],[550,265;575,265;575,200;625,200])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/RHS(y)']],[550,330;595,330;595,215;625,215])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/RHS(y)']],[430,365;430,335;515,335])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/RHS(y)']],[85,435;420,435;420,415])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/RHS(y)']],[175,260;230,260;230,95;515,95])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/RHS(y)']],[175,210;200,210;200,175;330,175])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/RHS(y)']],[175,250;215,250;215,185;330,185])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/RHS(y)']],[175,240;270,240;270,260;515,260])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/RHS(y)']],[175,220;285,220;285,325;515,325])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/RHS(y)']],[80,235;125,235])


%     Finished composite block ['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/RHS(y)'].

set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/RHS(y)']],...
		'ForeGround',1,...
		'BackGround',2,...
		'position',[575,268,645,372])


%     Subsystem  ['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/RHS(z)'].

new_system([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/RHS(z)']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/RHS(z)']],'Location',[5,59,969,569])

add_block('built-in/Demux',[sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/RHS(z)/Demux']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/RHS(z)/Demux']],...
		'orientation',3,...
		'ForeGround',1,...
		'BackGround',0)
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/RHS(z)/Demux']],...
		'outputs','7',...
		'position',[371,420,459,460])

add_block('built-in/Outport',[sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/RHS(z)/RHS(z)']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/RHS(z)/RHS(z)']],...
		'ForeGround',1,...
		'BackGround',4,...
		'position',[740,200,760,220])

add_block('built-in/Inport',[sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/RHS(z)/N']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/RHS(z)/N']],...
		'ForeGround',1,...
		'BackGround',4,...
		'position',[50,20,70,40])

add_block('built-in/Sum',[sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/RHS(z)/Sum']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/RHS(z)/Sum']],...
		'ForeGround',1,...
		'BackGround',5,...
		'inputs','++-+-')
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/RHS(z)/Sum']],...
		'position',[625,176,670,244])

add_block('built-in/Sum',[sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/RHS(z)/q*q-p*p']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/RHS(z)/q*q-p*p']],...
		'ForeGround',1,...
		'BackGround',3,...
		'inputs','-+')
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/RHS(z)/q*q-p*p']],...
		'position',[330,195,350,215])

add_block('built-in/Product',[sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/RHS(z)/Ix - Iy']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/RHS(z)/Ix - Iy']],...
		'ForeGround',1,...
		'BackGround',3,...
		'position',[485,80,510,100])

add_block('built-in/Product',[sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/RHS(z)/Ixy']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/RHS(z)/Ixy']],...
		'ForeGround',1,...
		'BackGround',3,...
		'position',[485,200,510,220])

add_block('built-in/Product',[sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/RHS(z)/Iyz']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/RHS(z)/Iyz']],...
		'ForeGround',1,...
		'BackGround',3,...
		'position',[485,295,510,315])

add_block('built-in/Product',[sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/RHS(z)/Ixz']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/RHS(z)/Ixz']],...
		'ForeGround',1,...
		'BackGround',3,...
		'position',[485,370,510,390])

add_block('built-in/Sum',[sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/RHS(z)/Sum1']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/RHS(z)/Sum1']],...
		'orientation',3,...
		'ForeGround',1,...
		'BackGround',3)
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/RHS(z)/Sum1']],...
		'inputs','+-',...
		'position',[390,115,410,135])

add_block('built-in/Inport',[sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/RHS(z)/M and I']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/RHS(z)/M and I']],...
		'ForeGround',1,...
		'BackGround',4,...
		'Port','3')
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/RHS(z)/M and I']],...
		'position',[50,470,70,490])

add_block('built-in/Demux',[sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/RHS(z)/Demux1']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/RHS(z)/Demux1']],...
		'ForeGround',1,...
		'BackGround',0,...
		'outputs','6')
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/RHS(z)/Demux1']],...
		'position',[140,222,180,288])

add_block('built-in/Inport',[sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/RHS(z)/Inport']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/RHS(z)/Inport']],...
		'ForeGround',1,...
		'BackGround',4,...
		'Port','2')
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/RHS(z)/Inport']],...
		'position',[60,245,80,265])

add_block('built-in/Note',[sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/RHS(z)/N + (P^2-Q^2)Ixy + PQ(Ix-Iy) + R(PIyz-QIxz)']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/RHS(z)/N + (P^2-Q^2)Ixy + PQ(Ix-Iy) + R(PIyz-QIxz)']],...
		'ForeGround',1)
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/RHS(z)/N + (P^2-Q^2)Ixy + PQ(Ix-Iy) + R(PIyz-QIxz)']],...
		'position',[755,285,760,290])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/RHS(z)']],[675,210;735,210])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/RHS(z)']],[75,30;570,30;570,180;620,180])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/RHS(z)']],[355,205;480,205])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/RHS(z)']],[395,415;395,140])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/RHS(z)']],[515,90;550,90;550,195;620,195])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/RHS(z)']],[515,210;620,210])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/RHS(z)']],[400,110;400,95;480,95])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/RHS(z)']],[405,415;405,140])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/RHS(z)']],[445,415;445,215;480,215])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/RHS(z)']],[515,305;550,305;550,225;620,225])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/RHS(z)']],[425,415;425,310;480,310])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/RHS(z)']],[515,380;570,380;570,240;620,240])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/RHS(z)']],[435,415;435,385;480,385])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/RHS(z)']],[75,480;415,480;415,465])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/RHS(z)']],[85,255;135,255])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/RHS(z)']],[185,240;235,240;235,85;480,85])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/RHS(z)']],[185,230;215,230;215,200;325,200])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/RHS(z)']],[185,250;250,250;250,210;325,210])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/RHS(z)']],[185,280;215,280;215,300;480,300])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/RHS(z)']],[185,260;250,260;250,375;480,375])


%     Finished composite block ['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/RHS(z)'].

set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/RHS(z)']],...
		'ForeGround',1,...
		'BackGround',2,...
		'position',[575,428,645,532])


%     Subsystem  ['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/RHS(x)'].

new_system([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/RHS(x)']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/RHS(x)']],'Location',[77,163,959,702])

add_block('built-in/Inport',[sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/RHS(x)/M and I']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/RHS(x)/M and I']],...
		'ForeGround',1,...
		'BackGround',4,...
		'Port','3')
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/RHS(x)/M and I']],...
		'position',[65,490,85,510])

add_block('built-in/Sum',[sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/RHS(x)/Sum']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/RHS(x)/Sum']],...
		'orientation',3,...
		'ForeGround',1,...
		'BackGround',3,...
		'inputs','+-')
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/RHS(x)/Sum']],...
		'position',[330,115,350,135])

add_block('built-in/Product',[sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/RHS(x)/Ixy']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/RHS(x)/Ixy']],...
		'ForeGround',1,...
		'BackGround',3,...
		'position',[415,325,440,345])

add_block('built-in/Product',[sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/RHS(x)/Ixz']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/RHS(x)/Ixz']],...
		'ForeGround',1,...
		'BackGround',3,...
		'position',[415,245,440,265])

add_block('built-in/Product',[sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/RHS(x)/Iyz']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/RHS(x)/Iyz']],...
		'ForeGround',1,...
		'BackGround',3,...
		'position',[415,165,440,185])

add_block('built-in/Product',[sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/RHS(x)/Iy - Iz']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/RHS(x)/Iy - Iz']],...
		'ForeGround',1,...
		'BackGround',3,...
		'position',[415,85,440,105])

add_block('built-in/Outport',[sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/RHS(x)/X(rhs)']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/RHS(x)/X(rhs)']],...
		'ForeGround',1,...
		'BackGround',4,...
		'position',[605,165,625,185])

add_block('built-in/Inport',[sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/RHS(x)/L']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/RHS(x)/L']],...
		'ForeGround',1,...
		'BackGround',4,...
		'position',[55,30,75,50])

add_block('built-in/Sum',[sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/RHS(x)/Sum ']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/RHS(x)/Sum ']],...
		'ForeGround',1,...
		'BackGround',5,...
		'inputs','++-+-')
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/RHS(x)/Sum ']],...
		'position',[530,141,575,209])

add_block('built-in/Sum',[sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/RHS(x)/r*r-q*q']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/RHS(x)/r*r-q*q']],...
		'ForeGround',1,...
		'BackGround',3,...
		'inputs','-+')
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/RHS(x)/r*r-q*q']],...
		'position',[280,160,300,180])

add_block('built-in/Demux',[sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/RHS(x)/Demux1']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/RHS(x)/Demux1']],...
		'ForeGround',1,...
		'BackGround',0,...
		'outputs','6')
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/RHS(x)/Demux1']],...
		'position',[155,232,195,298])

add_block('built-in/Inport',[sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/RHS(x)/Inport']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/RHS(x)/Inport']],...
		'ForeGround',1,...
		'BackGround',4,...
		'Port','2')
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/RHS(x)/Inport']],...
		'position',[60,255,80,275])

add_block('built-in/Note',[sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/RHS(x)/L + (Q^2-R^2)Iyz + QR(Iy-Iz) + P(QIxz-RIxy)']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/RHS(x)/L + (Q^2-R^2)Iyz + QR(Iy-Iz) + P(QIxz-RIxy)']],...
		'ForeGround',1)
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/RHS(x)/L + (Q^2-R^2)Iyz + QR(Iy-Iz) + P(QIxz-RIxy)']],...
		'position',[670,255,675,260])

add_block('built-in/Demux',[sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/RHS(x)/Demux']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/RHS(x)/Demux']],...
		'orientation',3,...
		'ForeGround',1,...
		'BackGround',0)
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/RHS(x)/Demux']],...
		'outputs','7',...
		'position',[303,415,387,455])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/RHS(x)']],[375,410;375,340;410,340])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/RHS(x)']],[445,335;495,335;495,205;525,205])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/RHS(x)']],[365,410;365,260;410,260])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/RHS(x)']],[445,255;475,255;475,190;525,190])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/RHS(x)']],[355,410;355,180;410,180])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/RHS(x)']],[445,175;525,175])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/RHS(x)']],[345,410;345,140])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/RHS(x)']],[335,410;335,140])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/RHS(x)']],[90,500;345,500;345,460])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/RHS(x)']],[340,110;340,100;410,100])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/RHS(x)']],[445,95;475,95;475,160;525,160])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/RHS(x)']],[580,175;600,175])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/RHS(x)']],[80,40;500,40;500,145;525,145])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/RHS(x)']],[305,170;410,170])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/RHS(x)']],[200,290;260,290;260,330;410,330])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/RHS(x)']],[200,250;410,250])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/RHS(x)']],[200,260;230,260;230,165;275,165])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/RHS(x)']],[200,280;260,280;260,175;275,175])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/RHS(x)']],[200,270;245,270;245,90;410,90])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/RHS(x)']],[85,265;150,265])


%     Finished composite block ['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/RHS(x)'].

set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/RHS(x)']],...
		'ForeGround',1,...
		'BackGround',2,...
		'position',[575,117,645,223])

add_block('built-in/Product',[sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/p*p']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/p*p']],...
		'ForeGround',1,...
		'BackGround',2,...
		'position',[235,154,260,181])

add_block('built-in/Product',[sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/q*q']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/q*q']],...
		'ForeGround',1,...
		'BackGround',2,...
		'position',[235,274,260,301])

add_block('built-in/Product',[sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/r*r']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/r*r']],...
		'ForeGround',1,...
		'BackGround',2,...
		'position',[235,394,260,421])

add_block('built-in/Product',[sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/rp']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/rp']],...
		'ForeGround',1,...
		'BackGround',2,...
		'position',[235,454,260,481])

add_block('built-in/Product',[sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/qr']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/qr']],...
		'ForeGround',1,...
		'BackGround',2,...
		'position',[235,334,260,361])

add_block('built-in/Product',[sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/pq']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/pq']],...
		'ForeGround',1,...
		'BackGround',2,...
		'position',[235,214,260,241])

add_block('built-in/Product',[sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/Product']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/Product']],...
		'ForeGround',1,...
		'BackGround',2,...
		'position',[780,235,805,255])

add_block('built-in/Fcn',[sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/1//det']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/1//det']],...
		'orientation',3,...
		'ForeGround',1,...
		'BackGround',2)
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/1//det']],...
		'Expr','1/(u[2]*u[3]*u[4]-u[2]*u[5]*u[5]-u[3]*u[6]*u[6]-u[4]*u[7]*u[7]-2*u[5]*u[6]*u[7])')
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/1//det']],...
		'position',[725,455,765,475])


%     Subsystem  ['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/pdot calc'].

new_system([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/pdot calc']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/pdot calc']],'Location',[365,291,993,672])

add_block('built-in/Demux',[sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/pdot calc/Demux']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/pdot calc/Demux']],...
		'ForeGround',1,...
		'BackGround',0,...
		'outputs','3')
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/pdot calc/Demux']],...
		'position',[90,34,125,296])

add_block('built-in/Sum',[sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/pdot calc/Sum']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/pdot calc/Sum']],...
		'ForeGround',1,...
		'BackGround',5,...
		'inputs','+++')
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/pdot calc/Sum']],...
		'position',[460,45,480,295])

add_block('built-in/Product',[sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/pdot calc/Product1']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/pdot calc/Product1']],...
		'ForeGround',1,...
		'BackGround',3)
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/pdot calc/Product1']],...
		'position',[370,75,395,95])

add_block('built-in/Fcn',[sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/pdot calc/IyIxz+IyzIxy']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/pdot calc/IyIxz+IyzIxy']],...
		'ForeGround',1,...
		'BackGround',3)
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/pdot calc/IyIxz+IyzIxy']],...
		'Expr','u[3]*u[6]+u[5]*u[7]',...
		'position',[260,270,300,290])

add_block('built-in/Fcn',[sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/pdot calc/IyzIxz+IzIxy']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/pdot calc/IyzIxz+IzIxy']],...
		'ForeGround',1,...
		'BackGround',3)
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/pdot calc/IyzIxz+IzIxy']],...
		'Expr','u[5]*u[6]+u[4]*u[7]',...
		'position',[260,185,300,205])

add_block('built-in/Fcn',[sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/pdot calc/IyIz-Iyz^2']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/pdot calc/IyIz-Iyz^2']],...
		'ForeGround',1,...
		'BackGround',3)
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/pdot calc/IyIz-Iyz^2']],...
		'Expr','u[3]*u[4]-u[5]*u[5]',...
		'position',[260,100,300,120])

add_block('built-in/Product',[sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/pdot calc/Product3']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/pdot calc/Product3']],...
		'ForeGround',1,...
		'BackGround',3)
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/pdot calc/Product3']],...
		'position',[370,245,395,265])

add_block('built-in/Product',[sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/pdot calc/Product2']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/pdot calc/Product2']],...
		'ForeGround',1,...
		'BackGround',3)
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/pdot calc/Product2']],...
		'position',[370,160,395,180])

add_block('built-in/Inport',[sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/pdot calc/M and I']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/pdot calc/M and I']],...
		'ForeGround',1,...
		'BackGround',4,...
		'Port','2')
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/pdot calc/M and I']],...
		'position',[25,340,45,360])

add_block('built-in/Inport',[sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/pdot calc/in_1 ']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/pdot calc/in_1 ']],...
		'ForeGround',1,...
		'BackGround',4,...
		'position',[20,155,40,175])

add_block('built-in/Outport',[sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/pdot calc/P_dot']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/pdot calc/P_dot']],...
		'ForeGround',1,...
		'BackGround',4,...
		'position',[515,160,535,180])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/pdot calc']],[130,250;365,250])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/pdot calc']],[130,165;365,165])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/pdot calc']],[400,255;455,255])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/pdot calc']],[400,170;455,170])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/pdot calc']],[400,85;455,85])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/pdot calc']],[305,110;330,110;330,90;365,90])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/pdot calc']],[130,80;365,80])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/pdot calc']],[45,165;85,165])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/pdot calc']],[485,170;510,170])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/pdot calc']],[305,195;330,195;330,175;365,175])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/pdot calc']],[305,280;330,280;330,260;365,260])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/pdot calc']],[50,350;185,350;185,110;255,110])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/pdot calc']],[185,195;255,195])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/pdot calc']],[185,280;255,280])


%     Finished composite block ['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/pdot calc'].

set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/pdot calc']],...
		'ForeGround',1,...
		'BackGround',2,...
		'position',[1085,222,1115,273])


%     Subsystem  ['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/qdot calc'].

new_system([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/qdot calc']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/qdot calc']],'Location',[362,311,999,742])

add_block('built-in/Outport',[sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/qdot calc/out_1']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/qdot calc/out_1']],...
		'ForeGround',1,...
		'BackGround',4,...
		'position',[575,170,595,190])

add_block('built-in/Inport',[sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/qdot calc/in_1 ']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/qdot calc/in_1 ']],...
		'ForeGround',1,...
		'BackGround',4,...
		'position',[80,165,100,185])

add_block('built-in/Inport',[sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/qdot calc/M and I']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/qdot calc/M and I']],...
		'ForeGround',1,...
		'BackGround',4,...
		'Port','2')
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/qdot calc/M and I']],...
		'position',[85,350,105,370])

add_block('built-in/Product',[sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/qdot calc/Product1']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/qdot calc/Product1']],...
		'ForeGround',1,...
		'BackGround',3)
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/qdot calc/Product1']],...
		'position',[430,85,455,105])

add_block('built-in/Product',[sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/qdot calc/Product2']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/qdot calc/Product2']],...
		'ForeGround',1,...
		'BackGround',3)
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/qdot calc/Product2']],...
		'position',[430,170,455,190])

add_block('built-in/Product',[sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/qdot calc/Product3']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/qdot calc/Product3']],...
		'ForeGround',1,...
		'BackGround',3)
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/qdot calc/Product3']],...
		'position',[430,255,455,275])

add_block('built-in/Fcn',[sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/qdot calc/IzIxy+IyzIxz']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/qdot calc/IzIxy+IyzIxz']],...
		'ForeGround',1,...
		'BackGround',3)
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/qdot calc/IzIxy+IyzIxz']],...
		'Expr','u[4]*u[7]+u[5]*u[6]',...
		'position',[320,110,360,130])

add_block('built-in/Fcn',[sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/qdot calc/IxIz-Ixz^2']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/qdot calc/IxIz-Ixz^2']],...
		'ForeGround',1,...
		'BackGround',3)
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/qdot calc/IxIz-Ixz^2']],...
		'Expr','u[2]*u[4]-u[6]*u[6]',...
		'position',[320,195,360,215])

add_block('built-in/Fcn',[sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/qdot calc/IxIyz+IxzIxy']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/qdot calc/IxIyz+IxzIxy']],...
		'ForeGround',1,...
		'BackGround',3)
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/qdot calc/IxIyz+IxzIxy']],...
		'Expr','u[2]*u[5]+u[6]*u[7]',...
		'position',[320,280,360,300])

add_block('built-in/Demux',[sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/qdot calc/Demux']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/qdot calc/Demux']],...
		'ForeGround',1,...
		'BackGround',0,...
		'outputs','3')
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/qdot calc/Demux']],...
		'position',[150,44,185,306])

add_block('built-in/Sum',[sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/qdot calc/Sum']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/qdot calc/Sum']],...
		'ForeGround',1,...
		'BackGround',5,...
		'inputs','+++')
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/qdot calc/Sum']],...
		'position',[520,55,540,305])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/qdot calc']],[110,360;245,360;245,120;315,120])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/qdot calc']],[245,290;315,290])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/qdot calc']],[245,205;315,205])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/qdot calc']],[365,290;390,290;390,270;425,270])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/qdot calc']],[365,205;390,205;390,185;425,185])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/qdot calc']],[545,180;570,180])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/qdot calc']],[105,175;145,175])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/qdot calc']],[190,90;425,90])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/qdot calc']],[365,120;390,120;390,100;425,100])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/qdot calc']],[460,95;515,95])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/qdot calc']],[460,180;515,180])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/qdot calc']],[460,265;515,265])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/qdot calc']],[190,175;425,175])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/qdot calc']],[190,260;425,260])


%     Finished composite block ['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/qdot calc'].

set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/qdot calc']],...
		'ForeGround',1,...
		'BackGround',2,...
		'position',[1085,311,1115,364])


%     Subsystem  ['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/rdot calc'].

new_system([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/rdot calc']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/rdot calc']],'Location',[244,194,856,654])

add_block('built-in/Outport',[sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/rdot calc/Rdot']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/rdot calc/Rdot']],...
		'ForeGround',1,...
		'BackGround',4,...
		'position',[530,200,550,220])

add_block('built-in/Inport',[sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/rdot calc/in_1 ']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/rdot calc/in_1 ']],...
		'ForeGround',1,...
		'BackGround',4,...
		'position',[35,195,55,215])

add_block('built-in/Inport',[sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/rdot calc/M and I']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/rdot calc/M and I']],...
		'ForeGround',1,...
		'BackGround',4,...
		'Port','2')
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/rdot calc/M and I']],...
		'position',[40,380,60,400])

add_block('built-in/Product',[sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/rdot calc/Product1']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/rdot calc/Product1']],...
		'ForeGround',1,...
		'BackGround',3)
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/rdot calc/Product1']],...
		'position',[385,115,410,135])

add_block('built-in/Product',[sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/rdot calc/Product2']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/rdot calc/Product2']],...
		'ForeGround',1,...
		'BackGround',3)
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/rdot calc/Product2']],...
		'position',[385,200,410,220])

add_block('built-in/Product',[sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/rdot calc/Product3']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/rdot calc/Product3']],...
		'ForeGround',1,...
		'BackGround',3)
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/rdot calc/Product3']],...
		'position',[385,285,410,305])

add_block('built-in/Fcn',[sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/rdot calc/IyIxz+IxyIyz']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/rdot calc/IyIxz+IxyIyz']],...
		'ForeGround',1,...
		'BackGround',3)
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/rdot calc/IyIxz+IxyIyz']],...
		'Expr','u[3]*u[6]+u[5]*u[7]',...
		'position',[275,140,315,160])

add_block('built-in/Fcn',[sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/rdot calc/IxIyz+IxyIxz']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/rdot calc/IxIyz+IxyIxz']],...
		'ForeGround',1,...
		'BackGround',3)
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/rdot calc/IxIyz+IxyIxz']],...
		'Expr','u[2]*u[5]+u[6]*u[7]',...
		'position',[275,225,315,245])

add_block('built-in/Fcn',[sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/rdot calc/IxIy-Ixy^2']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/rdot calc/IxIy-Ixy^2']],...
		'ForeGround',1,...
		'BackGround',3)
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/rdot calc/IxIy-Ixy^2']],...
		'Expr','u[2]*u[3]-u[7]*u[7]',...
		'position',[275,310,315,330])

add_block('built-in/Demux',[sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/rdot calc/Demux']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/rdot calc/Demux']],...
		'ForeGround',1,...
		'BackGround',0,...
		'outputs','3')
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/rdot calc/Demux']],...
		'position',[105,74,140,336])

add_block('built-in/Sum',[sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/rdot calc/Sum']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/rdot calc/Sum']],...
		'ForeGround',1,...
		'BackGround',5,...
		'inputs','+++')
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/rdot calc/Sum']],...
		'position',[475,85,495,335])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/rdot calc']],[65,390;200,390;200,150;270,150])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/rdot calc']],[200,320;270,320])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/rdot calc']],[200,235;270,235])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/rdot calc']],[320,320;345,320;345,300;380,300])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/rdot calc']],[320,235;345,235;345,215;380,215])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/rdot calc']],[500,210;525,210])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/rdot calc']],[60,205;100,205])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/rdot calc']],[145,120;380,120])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/rdot calc']],[320,150;345,150;345,130;380,130])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/rdot calc']],[415,125;470,125])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/rdot calc']],[415,210;470,210])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/rdot calc']],[415,295;470,295])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/rdot calc']],[145,205;380,205])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/rdot calc']],[145,290;380,290])


%     Finished composite block ['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/rdot calc'].

set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/rdot calc']],...
		'ForeGround',1,...
		'BackGround',2,...
		'position',[1085,407,1115,458])

add_block('built-in/Inport',[sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/M and I']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/M and I']],...
		'ForeGround',1,...
		'BackGround',4,...
		'Port','7')
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/M and I']],...
		'position',[70,550,90,570])

add_block('built-in/Mux',[sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/Mux1']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/Mux1']],...
		'ForeGround',1,...
		'BackGround',0,...
		'inputs','6')
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/Mux1']],...
		'position',[320,140,355,500])

add_block('built-in/Product',[sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/Product1']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/Product1']],...
		'ForeGround',1,...
		'BackGround',2,...
		'position',[780,315,805,335])

add_block('built-in/Product',[sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/Product2']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/Product2']],...
		'ForeGround',1,...
		'BackGround',2,...
		'position',[780,380,805,400])

add_block('built-in/Mux',[sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/Mux']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/Mux']],...
		'ForeGround',1,...
		'BackGround',0,...
		'inputs','3')
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/Mux']],...
		'position',[860,309,890,341])

add_block('built-in/Note',[sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/J King and S Crook',13,'Cranfield University',13,'RMCS',13,'Shrivenham',13,'SWINDON',13,'Wilts SN6 8LA   UK']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/J King and S Crook',13,'Cranfield University',13,'RMCS',13,'Shrivenham',13,'SWINDON',13,'Wilts SN6 8LA   UK']],...
		'ForeGround',1)
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)/J King and S Crook',13,'Cranfield University',13,'RMCS',13,'Shrivenham',13,'SWINDON',13,'Wilts SN6 8LA   UK']],...
		'position',[800,35,805,40])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)']],[95,220;230,220])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)']],[95,460;230,460])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)']],[95,340;230,340])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)']],[650,170;700,170;700,240;775,240])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)']],[650,320;775,320])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)']],[650,480;700,480;700,385;775,385])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)']],[1120,435;1180,435])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)']],[1120,340;1180,340])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)']],[1120,250;1180,250])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)']],[95,220;135,220;135,160;230,160])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)']],[205,160;205,175;230,175])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)']],[95,340;130,340;130,280;230,280])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)']],[205,280;205,295;230,295])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)']],[205,280;205,235;230,235])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)']],[95,460;130,460;130,400;230,400])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)']],[205,400;205,415;230,415])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)']],[205,400;205,355;230,355])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)']],[95,220;170,220;170,475;230,475])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)']],[265,170;315,170])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)']],[265,230;315,230])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)']],[265,290;315,290])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)']],[265,350;315,350])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)']],[265,410;315,410])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)']],[265,470;315,470])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)']],[360,320;535,320;535,170;570,170])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)']],[360,320;570,320])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)']],[95,35;460,35;460,135;570,135])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)']],[95,75;425,75;425,285;570,285])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)']],[95,115;395,115;395,445;570,445])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)']],[95,560;460,560;460,205;570,205])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)']],[460,355;570,355])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)']],[460,515;570,515])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)']],[360,320;535,320;535,480;570,480])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)']],[95,560;745,560;745,480])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)']],[95,560;1010,560;1010,260;1080,260])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)']],[1010,350;1080,350])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)']],[1010,445;1080,445])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)']],[745,450;745,250;775,250])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)']],[745,330;775,330])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)']],[745,395;775,395])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)']],[810,325;855,325])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)']],[810,245;830,245;830,315;855,315])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)']],[810,390;830,390;830,335;855,335])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)']],[895,325;955,325;955,235;1080,235])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)']],[895,325;1080,325])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)']],[895,325;955,325;955,420;1080,420])


%     Finished composite block ['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)'].

set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/EQN (MOMENTS)']],...
		'ForeGround',1,...
		'BackGround',3,...
		'position',[320,67,385,373])

add_block('built-in/Demux',[sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/Demux2']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/Demux2']],...
		'ForeGround',1,...
		'BackGround',0,...
		'outputs','3',...
		'position',[125,196,170,334])

add_block('built-in/Demux',[sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/Demux1 ']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)/Demux1 ']],...
		'ForeGround',1,...
		'BackGround',0,...
		'outputs','3',...
		'position',[190,60,240,200])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)']],[390,320;480,320])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)']],[410,320;410,390;600,390])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)']],[390,220;480,220])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)']],[435,220;435,370;600,370])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)']],[390,120;480,120])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)']],[455,120;455,350;600,350])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)']],[650,370;705,370])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)']],[520,320;540,320;540,255;570,255])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)']],[520,220;570,220])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)']],[520,120;540,120;540,185;570,185])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)']],[620,220;705,220])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)']],[80,265;120,265])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)']],[175,220;315,220])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)']],[175,265;315,265])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)']],[175,310;315,310])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)']],[80,355;315,355])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)']],[245,130;315,130])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)']],[245,85;315,85])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)']],[245,175;315,175])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)']],[620,220;640,220;640,20;75,20;75,130;185,130])


%     Finished composite block ['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)'].

set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(MOMENTS)']],...
		'ForeGround',1,...
		'BackGround',2,...
		'position',[305,273,370,402])

add_block('built-in/Outport',[sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/Rates']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/Rates']],...
		'ForeGround',1,...
		'BackGround',4,...
		'Port','2',...
		'position',[690,180,710,200])

add_block('built-in/Mux',[sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/Mux1']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/Mux1']],...
		'ForeGround',1,...
		'BackGround',0,...
		'inputs','[3,3]',...
		'position',[585,170,615,205])

add_block('built-in/Mux',[sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/Mux']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/Mux']],...
		'ForeGround',1,...
		'BackGround',0,...
		'inputs','[3,3]',...
		'position',[585,50,615,85])

add_block('built-in/Outport',[sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/U,V,W,',13,'P,Q,R']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/U,V,W,',13,'P,Q,R']],...
		'ForeGround',1,...
		'BackGround',4,...
		'position',[690,60,710,80])


%     Subsystem  ['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(FORCES)',13,''].

new_system([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(FORCES)',13,'']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(FORCES)',13,'']],'Location',[21,273,943,742])

add_block('built-in/Outport',[sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(FORCES)',13,'/U,V,W']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(FORCES)',13,'/U,V,W']],...
		'ForeGround',1,...
		'BackGround',4,...
		'position',[775,165,795,185])

add_block('built-in/Outport',[sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(FORCES)',13,'/Udot, Vdot,',13,'Wdot']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(FORCES)',13,'/Udot, Vdot,',13,'Wdot']],...
		'ForeGround',1,...
		'BackGround',4,...
		'Port','2')
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(FORCES)',13,'/Udot, Vdot,',13,'Wdot']],...
		'position',[770,315,790,335])

add_block('built-in/Product',[sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(FORCES)',13,'/Product']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(FORCES)',13,'/Product']],...
		'ForeGround',1,...
		'BackGround',3,...
		'position',[380,90,405,110])

add_block('built-in/Fcn',[sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(FORCES)',13,'/1//mass']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(FORCES)',13,'/1//mass']],...
		'ForeGround',1,...
		'BackGround',5,...
		'Expr','1/u',...
		'position',[230,45,260,65])


%     Subsystem  ['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(FORCES)',13,'/EQN(FORCES)'].

new_system([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(FORCES)',13,'/EQN(FORCES)']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(FORCES)',13,'/EQN(FORCES)']],'Location',[4,58,1008,751])


%     Subsystem  ['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(FORCES)',13,'/EQN(FORCES)/W'].

new_system([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(FORCES)',13,'/EQN(FORCES)/W']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(FORCES)',13,'/EQN(FORCES)/W']],'Location',[475,489,999,742])

add_block('built-in/Switch',[sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(FORCES)',13,'/EQN(FORCES)/W/Switch']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(FORCES)',13,'/EQN(FORCES)/W/Switch']],...
		'ForeGround',1,...
		'BackGround',5,...
		'Threshold','1')
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(FORCES)',13,'/EQN(FORCES)/W/Switch']],...
		'position',[340,9,370,191])

add_block('built-in/Inport',[sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(FORCES)',13,'/EQN(FORCES)/W/W dot']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(FORCES)',13,'/EQN(FORCES)/W/W dot']],...
		'ForeGround',1,...
		'BackGround',4,...
		'position',[80,30,100,50])

add_block('built-in/Integrator',[sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(FORCES)',13,'/EQN(FORCES)/W/W']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(FORCES)',13,'/EQN(FORCES)/W/W']],...
		'ForeGround',1,...
		'BackGround',6,...
		'Initial','W_0')
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(FORCES)',13,'/EQN(FORCES)/W/W']],...
		'position',[235,22,270,58])

add_block('built-in/Constant',[sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(FORCES)',13,'/EQN(FORCES)/W/W_dof']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(FORCES)',13,'/EQN(FORCES)/W/W_dof']],...
		'ForeGround',1,...
		'BackGround',7,...
		'Value','W_dof')
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(FORCES)',13,'/EQN(FORCES)/W/W_dof']],...
		'position',[230,90,280,110])

add_block('built-in/Constant',[sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(FORCES)',13,'/EQN(FORCES)/W/W_0']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(FORCES)',13,'/EQN(FORCES)/W/W_0']],...
		'ForeGround',1,...
		'BackGround',7,...
		'Value','W_0')
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(FORCES)',13,'/EQN(FORCES)/W/W_0']],...
		'position',[225,150,275,170])

add_block('built-in/Outport',[sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(FORCES)',13,'/EQN(FORCES)/W/W_out']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(FORCES)',13,'/EQN(FORCES)/W/W_out']],...
		'ForeGround',1,...
		'BackGround',4,...
		'position',[440,90,460,110])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(FORCES)',13,'/EQN(FORCES)/W']],[375,100;435,100])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(FORCES)',13,'/EQN(FORCES)/W']],[105,40;230,40])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(FORCES)',13,'/EQN(FORCES)/W']],[275,40;335,40])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(FORCES)',13,'/EQN(FORCES)/W']],[280,160;335,160])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(FORCES)',13,'/EQN(FORCES)/W']],[285,100;335,100])


%     Finished composite block ['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(FORCES)',13,'/EQN(FORCES)/W'].

set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(FORCES)',13,'/EQN(FORCES)/W']],...
		'ForeGround',1,...
		'BackGround',2,...
		'position',[805,338,835,392])


%     Subsystem  ['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(FORCES)',13,'/EQN(FORCES)/V'].

new_system([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(FORCES)',13,'/EQN(FORCES)/V']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(FORCES)',13,'/EQN(FORCES)/V']],'Location',[475,489,999,742])

add_block('built-in/Outport',[sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(FORCES)',13,'/EQN(FORCES)/V/V_out']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(FORCES)',13,'/EQN(FORCES)/V/V_out']],...
		'ForeGround',1,...
		'BackGround',4,...
		'position',[440,90,460,110])

add_block('built-in/Constant',[sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(FORCES)',13,'/EQN(FORCES)/V/V_0']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(FORCES)',13,'/EQN(FORCES)/V/V_0']],...
		'ForeGround',1,...
		'BackGround',7,...
		'Value','V_0')
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(FORCES)',13,'/EQN(FORCES)/V/V_0']],...
		'position',[225,150,275,170])

add_block('built-in/Constant',[sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(FORCES)',13,'/EQN(FORCES)/V/V_dof']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(FORCES)',13,'/EQN(FORCES)/V/V_dof']],...
		'ForeGround',1,...
		'BackGround',7,...
		'Value','V_dof')
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(FORCES)',13,'/EQN(FORCES)/V/V_dof']],...
		'position',[230,90,280,110])

add_block('built-in/Integrator',[sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(FORCES)',13,'/EQN(FORCES)/V/V']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(FORCES)',13,'/EQN(FORCES)/V/V']],...
		'ForeGround',1,...
		'BackGround',6,...
		'Initial','V_0')
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(FORCES)',13,'/EQN(FORCES)/V/V']],...
		'position',[235,22,270,58])

add_block('built-in/Inport',[sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(FORCES)',13,'/EQN(FORCES)/V/V dot']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(FORCES)',13,'/EQN(FORCES)/V/V dot']],...
		'ForeGround',1,...
		'BackGround',4,...
		'position',[80,30,100,50])

add_block('built-in/Switch',[sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(FORCES)',13,'/EQN(FORCES)/V/Switch']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(FORCES)',13,'/EQN(FORCES)/V/Switch']],...
		'ForeGround',1,...
		'BackGround',5,...
		'Threshold','1')
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(FORCES)',13,'/EQN(FORCES)/V/Switch']],...
		'position',[340,9,370,191])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(FORCES)',13,'/EQN(FORCES)/V']],[285,100;335,100])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(FORCES)',13,'/EQN(FORCES)/V']],[280,160;335,160])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(FORCES)',13,'/EQN(FORCES)/V']],[275,40;335,40])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(FORCES)',13,'/EQN(FORCES)/V']],[105,40;230,40])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(FORCES)',13,'/EQN(FORCES)/V']],[375,100;435,100])


%     Finished composite block ['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(FORCES)',13,'/EQN(FORCES)/V'].

set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(FORCES)',13,'/EQN(FORCES)/V']],...
		'ForeGround',1,...
		'BackGround',2,...
		'position',[805,208,835,262])

add_block('built-in/Inport',[sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(FORCES)',13,'/EQN(FORCES)/p']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(FORCES)',13,'/EQN(FORCES)/p']],...
		'ForeGround',1,...
		'BackGround',4,...
		'Port','4')
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(FORCES)',13,'/EQN(FORCES)/p']],...
		'position',[45,350,65,370])

add_block('built-in/Product',[sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(FORCES)',13,'/EQN(FORCES)/pv']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(FORCES)',13,'/EQN(FORCES)/pv']],...
		'ForeGround',1,...
		'BackGround',2,...
		'position',[290,350,335,385])


%     Subsystem  ['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(FORCES)',13,'/EQN(FORCES)/U'].

new_system([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(FORCES)',13,'/EQN(FORCES)/U']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(FORCES)',13,'/EQN(FORCES)/U']],'Location',[475,489,999,742])

add_block('built-in/Switch',[sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(FORCES)',13,'/EQN(FORCES)/U/Switch']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(FORCES)',13,'/EQN(FORCES)/U/Switch']],...
		'ForeGround',1,...
		'BackGround',5,...
		'Threshold','1')
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(FORCES)',13,'/EQN(FORCES)/U/Switch']],...
		'position',[340,9,370,191])

add_block('built-in/Inport',[sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(FORCES)',13,'/EQN(FORCES)/U/U dot']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(FORCES)',13,'/EQN(FORCES)/U/U dot']],...
		'ForeGround',1,...
		'BackGround',4,...
		'position',[80,30,100,50])

add_block('built-in/Integrator',[sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(FORCES)',13,'/EQN(FORCES)/U/U']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(FORCES)',13,'/EQN(FORCES)/U/U']],...
		'ForeGround',1,...
		'BackGround',6,...
		'Initial','U_0')
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(FORCES)',13,'/EQN(FORCES)/U/U']],...
		'position',[235,22,270,58])

add_block('built-in/Constant',[sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(FORCES)',13,'/EQN(FORCES)/U/U_dof']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(FORCES)',13,'/EQN(FORCES)/U/U_dof']],...
		'ForeGround',1,...
		'BackGround',7,...
		'Value','U_dof')
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(FORCES)',13,'/EQN(FORCES)/U/U_dof']],...
		'position',[230,90,280,110])

add_block('built-in/Outport',[sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(FORCES)',13,'/EQN(FORCES)/U/U_out']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(FORCES)',13,'/EQN(FORCES)/U/U_out']],...
		'ForeGround',1,...
		'BackGround',4,...
		'position',[440,90,460,110])

add_block('built-in/Constant',[sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(FORCES)',13,'/EQN(FORCES)/U/U_0']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(FORCES)',13,'/EQN(FORCES)/U/U_0']],...
		'ForeGround',1,...
		'BackGround',7,...
		'Value','U_0')
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(FORCES)',13,'/EQN(FORCES)/U/U_0']],...
		'position',[230,150,280,170])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(FORCES)',13,'/EQN(FORCES)/U']],[375,100;435,100])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(FORCES)',13,'/EQN(FORCES)/U']],[105,40;230,40])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(FORCES)',13,'/EQN(FORCES)/U']],[275,40;335,40])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(FORCES)',13,'/EQN(FORCES)/U']],[285,160;335,160])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(FORCES)',13,'/EQN(FORCES)/U']],[285,100;335,100])


%     Finished composite block ['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(FORCES)',13,'/EQN(FORCES)/U'].

set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(FORCES)',13,'/EQN(FORCES)/U']],...
		'ForeGround',1,...
		'BackGround',2,...
		'position',[805,78,835,132])

add_block('built-in/Mux',[sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(FORCES)',13,'/EQN(FORCES)/Mux']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(FORCES)',13,'/EQN(FORCES)/Mux']],...
		'ForeGround',1,...
		'BackGround',0,...
		'inputs','3')
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(FORCES)',13,'/EQN(FORCES)/Mux']],...
		'position',[955,103,990,367])

add_block('built-in/Outport',[sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(FORCES)',13,'/EQN(FORCES)/U,V,W']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(FORCES)',13,'/EQN(FORCES)/U,V,W']],...
		'ForeGround',1,...
		'BackGround',4,...
		'position',[1060,225,1080,245])

add_block('built-in/Mux',[sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(FORCES)',13,'/EQN(FORCES)/Mux1']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(FORCES)',13,'/EQN(FORCES)/Mux1']],...
		'ForeGround',1,...
		'BackGround',0,...
		'inputs','3')
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(FORCES)',13,'/EQN(FORCES)/Mux1']],...
		'position',[955,403,990,667])

add_block('built-in/Outport',[sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(FORCES)',13,'/EQN(FORCES)/Udot,Vdot,',13,'Wdot']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(FORCES)',13,'/EQN(FORCES)/Udot,Vdot,',13,'Wdot']],...
		'ForeGround',1,...
		'BackGround',4,...
		'Port','2')
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(FORCES)',13,'/EQN(FORCES)/Udot,Vdot,',13,'Wdot']],...
		'position',[1055,525,1075,545])

add_block('built-in/Sum',[sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(FORCES)',13,'/EQN(FORCES)/Sum2']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(FORCES)',13,'/EQN(FORCES)/Sum2']],...
		'ForeGround',1,...
		'BackGround',0,...
		'inputs','++-+')
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(FORCES)',13,'/EQN(FORCES)/Sum2']],...
		'position',[635,329,665,396])

add_block('built-in/Inport',[sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(FORCES)',13,'/EQN(FORCES)/r']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(FORCES)',13,'/EQN(FORCES)/r']],...
		'ForeGround',1,...
		'BackGround',4,...
		'Port','6')
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(FORCES)',13,'/EQN(FORCES)/r']],...
		'position',[45,570,65,590])

add_block('built-in/Inport',[sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(FORCES)',13,'/EQN(FORCES)/q']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(FORCES)',13,'/EQN(FORCES)/q']],...
		'ForeGround',1,...
		'BackGround',4,...
		'Port','5')
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(FORCES)',13,'/EQN(FORCES)/q']],...
		'position',[45,460,65,480])

add_block('built-in/Inport',[sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(FORCES)',13,'/EQN(FORCES)/Z//m']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(FORCES)',13,'/EQN(FORCES)/Z//m']],...
		'ForeGround',1,...
		'BackGround',4,...
		'Port','3')
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(FORCES)',13,'/EQN(FORCES)/Z//m']],...
		'position',[45,180,65,200])

add_block('built-in/Inport',[sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(FORCES)',13,'/EQN(FORCES)/Y//m']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(FORCES)',13,'/EQN(FORCES)/Y//m']],...
		'ForeGround',1,...
		'BackGround',4,...
		'Port','2')
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(FORCES)',13,'/EQN(FORCES)/Y//m']],...
		'position',[45,125,65,145])

add_block('built-in/Inport',[sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(FORCES)',13,'/EQN(FORCES)/X//m']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(FORCES)',13,'/EQN(FORCES)/X//m']],...
		'ForeGround',1,...
		'BackGround',4,...
		'position',[45,70,65,90])

add_block('built-in/Sum',[sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(FORCES)',13,'/EQN(FORCES)/Sum']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(FORCES)',13,'/EQN(FORCES)/Sum']],...
		'ForeGround',1,...
		'BackGround',0,...
		'inputs','+-++')
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(FORCES)',13,'/EQN(FORCES)/Sum']],...
		'position',[635,69,665,136])

add_block('built-in/Sum',[sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(FORCES)',13,'/EQN(FORCES)/Sum1']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(FORCES)',13,'/EQN(FORCES)/Sum1']],...
		'ForeGround',1,...
		'BackGround',0,...
		'inputs','++-+')
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(FORCES)',13,'/EQN(FORCES)/Sum1']],...
		'position',[635,199,665,266])

add_block('built-in/Product',[sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(FORCES)',13,'/EQN(FORCES)/pw']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(FORCES)',13,'/EQN(FORCES)/pw']],...
		'ForeGround',1,...
		'BackGround',2,...
		'position',[290,405,335,440])

add_block('built-in/Product',[sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(FORCES)',13,'/EQN(FORCES)/qw']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(FORCES)',13,'/EQN(FORCES)/qw']],...
		'ForeGround',1,...
		'BackGround',2,...
		'position',[285,515,330,550])

add_block('built-in/Product',[sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(FORCES)',13,'/EQN(FORCES)/qU']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(FORCES)',13,'/EQN(FORCES)/qU']],...
		'ForeGround',1,...
		'BackGround',2,...
		'position',[285,460,330,495])

add_block('built-in/Product',[sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(FORCES)',13,'/EQN(FORCES)/rv']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(FORCES)',13,'/EQN(FORCES)/rv']],...
		'ForeGround',1,...
		'BackGround',2,...
		'position',[285,630,330,665])

add_block('built-in/Product',[sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(FORCES)',13,'/EQN(FORCES)/rU']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(FORCES)',13,'/EQN(FORCES)/rU']],...
		'ForeGround',1,...
		'BackGround',2,...
		'position',[285,570,330,605])

add_block('built-in/Inport',[sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(FORCES)',13,'/EQN(FORCES)/Xg']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(FORCES)',13,'/EQN(FORCES)/Xg']],...
		'ForeGround',1,...
		'BackGround',4,...
		'Port','7')
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(FORCES)',13,'/EQN(FORCES)/Xg']],...
		'position',[45,705,65,725])

add_block('built-in/Inport',[sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(FORCES)',13,'/EQN(FORCES)/Yg']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(FORCES)',13,'/EQN(FORCES)/Yg']],...
		'ForeGround',1,...
		'BackGround',4,...
		'Port','8')
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(FORCES)',13,'/EQN(FORCES)/Yg']],...
		'position',[45,750,65,770])

add_block('built-in/Inport',[sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(FORCES)',13,'/EQN(FORCES)/Zg']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(FORCES)',13,'/EQN(FORCES)/Zg']],...
		'ForeGround',1,...
		'BackGround',4,...
		'Port','9')
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(FORCES)',13,'/EQN(FORCES)/Zg']],...
		'position',[45,790,65,810])

add_block('built-in/Note',[sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(FORCES)',13,'/EQN(FORCES)/J King and S Crook',13,'Cranfield University',13,'RMCS',13,'Shrivenham',13,'SWINDON',13,'Wilts SN6 8LA   UK']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(FORCES)',13,'/EQN(FORCES)/J King and S Crook',13,'Cranfield University',13,'RMCS',13,'Shrivenham',13,'SWINDON',13,'Wilts SN6 8LA   UK']],...
		'position',[1070,20,1075,25])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(FORCES)',13,'/EQN(FORCES)']],[840,365;870,365;870,325;950,325])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(FORCES)',13,'/EQN(FORCES)']],[840,235;950,235])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(FORCES)',13,'/EQN(FORCES)']],[840,105;870,105;870,145;950,145])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(FORCES)',13,'/EQN(FORCES)']],[840,105;870,105;870,15;145,15;145,595;280,595])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(FORCES)',13,'/EQN(FORCES)']],[840,105;870,105;870,15;145,15;145,485;280,485])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(FORCES)',13,'/EQN(FORCES)']],[670,365;800,365])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(FORCES)',13,'/EQN(FORCES)']],[695,365;695,625;950,625])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(FORCES)',13,'/EQN(FORCES)']],[670,235;800,235])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(FORCES)',13,'/EQN(FORCES)']],[725,235;725,535;950,535])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(FORCES)',13,'/EQN(FORCES)']],[670,105;800,105])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(FORCES)',13,'/EQN(FORCES)']],[750,105;750,445;950,445])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(FORCES)',13,'/EQN(FORCES)']],[995,535;1050,535])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(FORCES)',13,'/EQN(FORCES)']],[995,235;1055,235])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(FORCES)',13,'/EQN(FORCES)']],[335,590;525,590;525,240;630,240])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(FORCES)',13,'/EQN(FORCES)']],[340,425;505,425;505,225;630,225])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(FORCES)',13,'/EQN(FORCES)']],[840,365;870,365;870,305;210,305;210,430;285,430])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(FORCES)',13,'/EQN(FORCES)']],[210,430;210,540;280,540])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(FORCES)',13,'/EQN(FORCES)']],[840,235;870,235;870,170;180,170;180,375;285,375])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(FORCES)',13,'/EQN(FORCES)']],[180,370;180,655;280,655])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(FORCES)',13,'/EQN(FORCES)']],[70,580;280,580])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(FORCES)',13,'/EQN(FORCES)']],[245,580;245,640;280,640])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(FORCES)',13,'/EQN(FORCES)']],[70,470;280,470])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(FORCES)',13,'/EQN(FORCES)']],[245,470;245,525;280,525])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(FORCES)',13,'/EQN(FORCES)']],[70,360;285,360])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(FORCES)',13,'/EQN(FORCES)']],[250,360;250,415;285,415])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(FORCES)',13,'/EQN(FORCES)']],[70,190;95,190;95,340;630,340])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(FORCES)',13,'/EQN(FORCES)']],[70,135;120,135;120,210;630,210])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(FORCES)',13,'/EQN(FORCES)']],[70,80;630,80])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(FORCES)',13,'/EQN(FORCES)']],[340,370;630,370])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(FORCES)',13,'/EQN(FORCES)']],[335,480;585,480;585,355;630,355])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(FORCES)',13,'/EQN(FORCES)']],[335,535;400,535;400,95;630,95])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(FORCES)',13,'/EQN(FORCES)']],[335,650;420,650;420,110;630,110])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(FORCES)',13,'/EQN(FORCES)']],[70,715;440,715;440,125;630,125])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(FORCES)',13,'/EQN(FORCES)']],[70,760;545,760;545,255;630,255])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(FORCES)',13,'/EQN(FORCES)']],[70,800;600,800;600,385;630,385])


%     Finished composite block ['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(FORCES)',13,'/EQN(FORCES)'].

set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(FORCES)',13,'/EQN(FORCES)']],...
		'ForeGround',1,...
		'BackGround',3,...
		'position',[490,98,590,402])

add_block('built-in/Inport',[sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(FORCES)',13,'/p,q,r']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(FORCES)',13,'/p,q,r']],...
		'ForeGround',1,...
		'BackGround',4,...
		'Port','2',...
		'position',[45,240,65,260])

add_block('built-in/Demux',[sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(FORCES)',13,'/Demux1']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(FORCES)',13,'/Demux1']],...
		'ForeGround',1,...
		'BackGround',0,...
		'outputs','3')
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(FORCES)',13,'/Demux1']],...
		'position',[325,200,355,300])

add_block('built-in/Inport',[sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(FORCES)',13,'/forces']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(FORCES)',13,'/forces']],...
		'ForeGround',1,...
		'BackGround',4,...
		'position',[45,140,65,160])

add_block('built-in/Demux',[sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(FORCES)',13,'/Demux']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(FORCES)',13,'/Demux']],...
		'ForeGround',1,...
		'BackGround',0,...
		'outputs','3')
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(FORCES)',13,'/Demux']],...
		'position',[230,115,260,185])

add_block('built-in/Inport',[sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(FORCES)',13,'/DCM']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(FORCES)',13,'/DCM']],...
		'ForeGround',1,...
		'BackGround',4,...
		'Port','3',...
		'position',[45,345,65,365])

add_block('built-in/Product',[sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(FORCES)',13,'/Product1']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(FORCES)',13,'/Product1']],...
		'ForeGround',1,...
		'BackGround',3,...
		'position',[380,135,405,155])

add_block('built-in/Product',[sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(FORCES)',13,'/Product2']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(FORCES)',13,'/Product2']],...
		'ForeGround',1,...
		'BackGround',3,...
		'position',[380,170,405,190])


%     Subsystem  ['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(FORCES)',13,'/Gravity'].

new_system([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(FORCES)',13,'/Gravity']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(FORCES)',13,'/Gravity']],'Location',[69,163,719,478])

add_block('built-in/Constant',[sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(FORCES)',13,'/Gravity/g_0']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(FORCES)',13,'/Gravity/g_0']],...
		'ForeGround',1,...
		'BackGround',7,...
		'Value','g_0')
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(FORCES)',13,'/Gravity/g_0']],...
		'position',[50,41,90,69])

add_block('built-in/Outport',[sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(FORCES)',13,'/Gravity/Yg//m']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(FORCES)',13,'/Gravity/Yg//m']],...
		'ForeGround',1,...
		'BackGround',4,...
		'Port','2')
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(FORCES)',13,'/Gravity/Yg//m']],...
		'position',[450,135,470,155])

add_block('built-in/Outport',[sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(FORCES)',13,'/Gravity/Xg//m']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(FORCES)',13,'/Gravity/Xg//m']],...
		'ForeGround',1,...
		'BackGround',4,...
		'position',[450,50,470,70])

add_block('built-in/Outport',[sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(FORCES)',13,'/Gravity/Zg//m']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(FORCES)',13,'/Gravity/Zg//m']],...
		'ForeGround',1,...
		'BackGround',4,...
		'Port','3')
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(FORCES)',13,'/Gravity/Zg//m']],...
		'position',[450,225,470,245])

add_block('built-in/Product',[sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(FORCES)',13,'/Gravity/Product']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(FORCES)',13,'/Gravity/Product']],...
		'ForeGround',1,...
		'BackGround',2,...
		'position',[350,50,375,70])

add_block('built-in/Product',[sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(FORCES)',13,'/Gravity/Product1']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(FORCES)',13,'/Gravity/Product1']],...
		'ForeGround',1,...
		'BackGround',2,...
		'position',[350,135,375,155])

add_block('built-in/Product',[sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(FORCES)',13,'/Gravity/Product2']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(FORCES)',13,'/Gravity/Product2']],...
		'ForeGround',1,...
		'BackGround',2,...
		'position',[350,225,375,245])

add_block('built-in/Inport',[sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(FORCES)',13,'/Gravity/DCM']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(FORCES)',13,'/Gravity/DCM']],...
		'ForeGround',1,...
		'BackGround',4,...
		'position',[60,100,80,120])

add_block('built-in/Demux',[sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(FORCES)',13,'/Gravity/Demux']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(FORCES)',13,'/Gravity/Demux']],...
		'ForeGround',1,...
		'BackGround',0,...
		'outputs','[6,1,1,1]')
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(FORCES)',13,'/Gravity/Demux']],...
		'position',[140,90,180,130])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(FORCES)',13,'/Gravity']],[380,235;445,235])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(FORCES)',13,'/Gravity']],[95,55;280,55;280,230;345,230])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(FORCES)',13,'/Gravity']],[380,145;445,145])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(FORCES)',13,'/Gravity']],[95,55;280,55;280,140;345,140])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(FORCES)',13,'/Gravity']],[380,60;445,60])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(FORCES)',13,'/Gravity']],[95,55;345,55])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(FORCES)',13,'/Gravity']],[85,110;135,110])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(FORCES)',13,'/Gravity']],[185,105;240,105;240,65;345,65])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(FORCES)',13,'/Gravity']],[185,115;240,115;240,150;345,150])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(FORCES)',13,'/Gravity']],[185,125;230,125;230,240;345,240])


%     Finished composite block ['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(FORCES)',13,'/Gravity'].

set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(FORCES)',13,'/Gravity']],...
		'ForeGround',1,...
		'BackGround',3,...
		'position',[175,316,220,394])

add_block('built-in/Demux',[sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(FORCES)',13,'/Demux3']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(FORCES)',13,'/Demux3']],...
		'ForeGround',1,...
		'BackGround',0,...
		'outputs','7')
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(FORCES)',13,'/Demux3']],...
		'position',[145,55,195,115])

add_block('built-in/Inport',[sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(FORCES)',13,'/M and I']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(FORCES)',13,'/M and I']],...
		'ForeGround',1,...
		'BackGround',4,...
		'Port','4',...
		'position',[45,75,65,95])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(FORCES)',13,'']],[595,325;765,325])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(FORCES)',13,'']],[360,285;485,285])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(FORCES)',13,'']],[360,250;485,250])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(FORCES)',13,'']],[360,215;485,215])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(FORCES)',13,'']],[70,85;140,85])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(FORCES)',13,'']],[200,55;225,55])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(FORCES)',13,'']],[265,55;325,55;325,95;375,95])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(FORCES)',13,'']],[595,175;770,175])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(FORCES)',13,'']],[70,250;320,250])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(FORCES)',13,'']],[225,355;485,355])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(FORCES)',13,'']],[225,330;450,330;450,320;485,320])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(FORCES)',13,'']],[225,380;450,380;450,390;485,390])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(FORCES)',13,'']],[70,355;170,355])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(FORCES)',13,'']],[70,150;225,150])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(FORCES)',13,'']],[410,100;435,100;435,110;485,110])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(FORCES)',13,'']],[410,145;485,145])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(FORCES)',13,'']],[410,180;485,180])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(FORCES)',13,'']],[265,125;275,125;275,105;375,105])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(FORCES)',13,'']],[265,150;375,150])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(FORCES)',13,'']],[265,175;275,175;275,185;375,185])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(FORCES)',13,'']],[265,55;325,55;325,175;375,175])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(FORCES)',13,'']],[265,55;325,55;325,140;375,140])


%     Finished composite block ['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(FORCES)',13,''].

set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/EQUATIONS OF MOTION',13,'(FORCES)',13,'']],...
		'ForeGround',1,...
		'BackGround',2,...
		'position',[305,24,370,161])

add_block('built-in/Inport',[sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/X,Y,Z',13,'L,M,N']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/X,Y,Z',13,'L,M,N']],...
		'ForeGround',1,...
		'BackGround',4,...
		'Port','2',...
		'position',[45,40,65,60])

add_block('built-in/Inport',[sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/DCM']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/DCM']],...
		'ForeGround',1,...
		'BackGround',4,...
		'Port','3',...
		'position',[45,99,65,121])

add_block('built-in/Demux',[sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/Demux']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion/Demux']],...
		'ForeGround',1,...
		'BackGround',0,...
		'outputs','[3,3]',...
		'position',[105,30,145,65])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion']],[375,370;515,370;515,195;580,195])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion']],[620,190;685,190])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion']],[375,130;515,130;515,180;580,180])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion']],[70,110;300,110])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion']],[375,305;435,305;435,75;580,75])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion']],[80,370;300,370])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion']],[620,70;685,70])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion']],[375,60;580,60])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion']],[375,305;435,305;435,220;200,220;200,75;300,75])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion']],[70,50;100,50])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion']],[150,40;300,40])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion']],[150,55;165,55;165,305;300,305])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion']],[80,370;240,370;240,145;300,145])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion']],...
		'Mask Display','plot(-2,-3.5,2,3.5,[0 -.5 -.866 -1 -.866 -.5 0 .5 .866 1 .866 .5 0],[-1 -.866 -.5 0 .5 .866 1 .866 .5 0 -.5 -.866 -1],[.987 1.394 1.493 1.261 .75 .023 -.709 -1.263 -1.497 -1.353 -.867],[.162 -.073 -.291 -.445 -.5 -.437 -.263 -.023 .223 .412 .498])')
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion']],...
		'Mask Type','GRIBS',...
		'Mask Dialogue','General RIgid Body Simulation')


%     Finished composite block ['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion'].

set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)/GRIBS',13,'Equations of Motion']],...
		'ForeGround',7,...
		'BackGround',0,...
		'position',[150,69,255,271])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)']],[400,90;470,90])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)']],[80,105;145,105])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)']],[260,220;310,220])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)']],[260,120;325,120])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)']],[80,170;145,170])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)']],[260,120;290,120;290,45;470,45])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)']],[400,145;425,145;425,320;130,320;130,235;145,235])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)']],[400,145;470,145])


%     Finished composite block ['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)'].

set_param([sys,'/',['GRIBS',13,'(Quaternions)/Main',13,'(quaternions)']],...
		'ForeGround',1,...
		'BackGround',2,...
		'position',[120,199,230,401])


%     Subsystem  ['GRIBS',13,'(Quaternions)/DCM to',13,'Euler Angles'].

new_system([sys,'/',['GRIBS',13,'(Quaternions)/DCM to',13,'Euler Angles']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/DCM to',13,'Euler Angles']],'Location',[5,59,447,294])

add_block('built-in/Outport',[sys,'/',['GRIBS',13,'(Quaternions)/DCM to',13,'Euler Angles/attutude']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/DCM to',13,'Euler Angles/attutude']],...
		'ForeGround',1,...
		'BackGround',4,...
		'position',[335,105,355,125])

add_block('built-in/Fcn',[sys,'/',['GRIBS',13,'(Quaternions)/DCM to',13,'Euler Angles/PHI']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/DCM to',13,'Euler Angles/PHI']],...
		'ForeGround',1,...
		'BackGround',3,...
		'Expr','atan2(u[8],u[9])',...
		'position',[155,60,195,80])

add_block('built-in/Fcn',[sys,'/',['GRIBS',13,'(Quaternions)/DCM to',13,'Euler Angles/PSI']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/DCM to',13,'Euler Angles/PSI']],...
		'ForeGround',1,...
		'BackGround',3,...
		'Expr','atan2(u[4],u[1])',...
		'position',[155,155,195,175])

add_block('built-in/Fcn',[sys,'/',['GRIBS',13,'(Quaternions)/DCM to',13,'Euler Angles/THETA']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/DCM to',13,'Euler Angles/THETA']],...
		'ForeGround',1,...
		'BackGround',3,...
		'Expr','asin(-u[7])',...
		'position',[155,105,195,125])

add_block('built-in/Mux',[sys,'/',['GRIBS',13,'(Quaternions)/DCM to',13,'Euler Angles/Mux']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/DCM to',13,'Euler Angles/Mux']],...
		'ForeGround',1,...
		'BackGround',0,...
		'inputs','3',...
		'position',[260,99,290,131])

add_block('built-in/Inport',[sys,'/',['GRIBS',13,'(Quaternions)/DCM to',13,'Euler Angles/in 1']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/DCM to',13,'Euler Angles/in 1']],...
		'ForeGround',1,...
		'BackGround',4,...
		'position',[60,105,80,125])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/DCM to',13,'Euler Angles']],[295,115;330,115])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/DCM to',13,'Euler Angles']],[200,165;220,165;220,125;255,125])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/DCM to',13,'Euler Angles']],[200,115;255,115])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/DCM to',13,'Euler Angles']],[200,70;220,70;220,105;255,105])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/DCM to',13,'Euler Angles']],[85,115;150,115])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/DCM to',13,'Euler Angles']],[115,115;115,165;150,165])
add_line([sys,'/',['GRIBS',13,'(Quaternions)/DCM to',13,'Euler Angles']],[115,115;115,70;150,70])


%     Finished composite block ['GRIBS',13,'(Quaternions)/DCM to',13,'Euler Angles'].

set_param([sys,'/',['GRIBS',13,'(Quaternions)/DCM to',13,'Euler Angles']],...
		'ForeGround',1,...
		'BackGround',2,...
		'position',[365,345,405,405])

add_block('built-in/Inport',[sys,'/',['GRIBS',13,'(Quaternions)/F+M']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/F+M']],...
		'ForeGround',1,...
		'BackGround',4,...
		'position',[45,240,65,260])

add_block('built-in/Inport',[sys,'/',['GRIBS',13,'(Quaternions)/M+I']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/M+I']],...
		'ForeGround',1,...
		'BackGround',4,...
		'Port','2',...
		'position',[45,340,65,360])

add_block('built-in/Outport',[sys,'/',['GRIBS',13,'(Quaternions)/Atmos']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Atmos']],...
		'ForeGround',1,...
		'BackGround',4,...
		'Port','5',...
		'position',[445,240,465,260])

add_block('built-in/Outport',[sys,'/',['GRIBS',13,'(Quaternions)/Euler',13,'Angles']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Euler',13,'Angles']],...
		'ForeGround',1,...
		'BackGround',4,...
		'Port','4',...
		'position',[445,365,465,385])


%     Subsystem  ['GRIBS',13,'(Quaternions)/Text',13,'Block'].

new_system([sys,'/',['GRIBS',13,'(Quaternions)/Text',13,'Block']])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Text',13,'Block']],'Location',[4,344,729,570])
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Text',13,'Block']],...
		'Mask Display','GRIBS may be freely distributed provided the\nusual reference/acknowledgement is made:\n\n"Robust Multivariable Control Law Design for Missile Autopilots",\n PhD Thesis - J King, Cranfield University, RMCS')
set_param([sys,'/',['GRIBS',13,'(Quaternions)/Text',13,'Block']],...
		'Mask Type','TEXT',...
		'Mask Dialogue','eval(''error'')')


%     Finished composite block ['GRIBS',13,'(Quaternions)/Text',13,'Block'].

set_param([sys,'/',['GRIBS',13,'(Quaternions)/Text',13,'Block']],...
		'ForeGround',2,...
		'hide name',0,...
		'position',[46,32,456,106])
add_line([sys,'/',['GRIBS',13,'(Quaternions)']],[235,375;360,375])
add_line([sys,'/',['GRIBS',13,'(Quaternions)']],[235,325;325,325;325,270;360,270])
add_line([sys,'/',['GRIBS',13,'(Quaternions)']],[235,225;360,225])
add_line([sys,'/',['GRIBS',13,'(Quaternions)']],[70,250;115,250])
add_line([sys,'/',['GRIBS',13,'(Quaternions)']],[70,350;115,350])
add_line([sys,'/',['GRIBS',13,'(Quaternions)']],[235,225;245,225;245,185;270,185])
add_line([sys,'/',['GRIBS',13,'(Quaternions)']],[235,275;270,275])
add_line([sys,'/',['GRIBS',13,'(Quaternions)']],[235,325;245,325;245,340;270,340])
add_line([sys,'/',['GRIBS',13,'(Quaternions)']],[410,375;440,375])
add_line([sys,'/',['GRIBS',13,'(Quaternions)']],[415,250;440,250])
set_param([sys,'/',['GRIBS',13,'(Quaternions)']],...
		'Mask Display','plot(-2,-3.5,2,3.5,[0 -.5 -.866 -1 -.866 -.5 0 .5 .866 1 .866 .5 0],[-1 -.866 -.5 0 .5 .866 1 .866 .5 0 -.5 -.866 -1],[.987 1.394 1.493 1.261 .75 .023 -.709 -1.263 -1.497 -1.353 -.867],[.162 -.073 -.291 -.445 -.5 -.437 -.263 -.023 .223 .412 .498])')
set_param([sys,'/',['GRIBS',13,'(Quaternions)']],...
		'Mask Type','GRIBS',...
		'Mask Dialogue','General RIgid Body Simulation')


%     Finished composite block ['GRIBS',13,'(Quaternions)'].

set_param([sys,'/',['GRIBS',13,'(Quaternions)']],...
		'ForeGround',6,...
		'BackGround',0,...
		'position',[325,236,420,424])

add_block('built-in/Note',[sys,'/',['General Rigid Body Simulation (GRIBS)',13,'version 0.1',13,'',13,'Jon King',13,'Cranfield University',13,'RMCS',13,'Shrivenham',13,'SWINDON ',13,' Wilts SN6 8LA   UK',13,'',13,'15th January 1995']])
set_param([sys,'/',['General Rigid Body Simulation (GRIBS)',13,'version 0.1',13,'',13,'Jon King',13,'Cranfield University',13,'RMCS',13,'Shrivenham',13,'SWINDON ',13,' Wilts SN6 8LA   UK',13,'',13,'15th January 1995']],...
		'position',[130,5,135,10])

add_block('built-in/Note',[sys,'/',['To set up the initial parameters it is necessary to run',13,'GRIBSINI.M',13,'in the workspace prior to using this block']])
set_param([sys,'/',['To set up the initial parameters it is necessary to run',13,'GRIBSINI.M',13,'in the workspace prior to using this block']],...
		'position',[370,175,375,180])


%     Subsystem  ['Text',13,'Block'].

new_system([sys,'/',['Text',13,'Block']])
set_param([sys,'/',['Text',13,'Block']],'Location',[4,344,729,570])
set_param([sys,'/',['Text',13,'Block']],...
		'Mask Display','GRIBS may be freely distributed provided the\nusual reference/acknowledgement is made:\n\n"Robust Multivariable Control Law Design for Missile Autopilots",\n PhD Thesis - J King, Cranfield University, RMCS')
set_param([sys,'/',['Text',13,'Block']],...
		'Mask Type','TEXT',...
		'Mask Dialogue','eval(''error'')')


%     Finished composite block ['Text',13,'Block'].

set_param([sys,'/',['Text',13,'Block']],...
		'ForeGround',2,...
		'hide name',0,...
		'position',[320,37,730,111])


%     Subsystem  ['Text',13,'Block3'].

new_system([sys,'/',['Text',13,'Block3']])
set_param([sys,'/',['Text',13,'Block3']],'Location',[132,402,265,498])

add_block('built-in/Outport',[sys,'/',['Text',13,'Block3/Outport']])
set_param([sys,'/',['Text',13,'Block3/Outport']],...
		'position',[60,50,80,70])
set_param([sys,'/',['Text',13,'Block3']],...
		'Mask Display','Mass and Inertias = [m,Ix,Iy,Iz,Ixy,Ixz,Iyz]',...
		'Mask Type','TEXT',...
		'Mask Dialogue','eval(''error'')')


%     Finished composite block ['Text',13,'Block3'].

set_param([sys,'/',['Text',13,'Block3']],...
		'hide name',0,...
		'position',[25,360,295,400])


%     Subsystem  ['Text',13,'Block2'].

new_system([sys,'/',['Text',13,'Block2']])
set_param([sys,'/',['Text',13,'Block2']],'Location',[132,402,265,498])

add_block('built-in/Outport',[sys,'/',['Text',13,'Block2/Outport']])
set_param([sys,'/',['Text',13,'Block2/Outport']],...
		'position',[60,50,80,70])
set_param([sys,'/',['Text',13,'Block2']],...
		'Mask Display','Forces and Moments at CG= [X,Y,Z,L,M,N]\n(body axes)',...
		'Mask Type','TEXT',...
		'Mask Dialogue','eval(''error'')')


%     Finished composite block ['Text',13,'Block2'].

set_param([sys,'/',['Text',13,'Block2']],...
		'hide name',0,...
		'position',[25,263,295,307])


%     Subsystem  ['Text',13,'Block7'].

new_system([sys,'/',['Text',13,'Block7']])
set_param([sys,'/',['Text',13,'Block7']],'Location',[132,402,265,498])

add_block('built-in/Inport',[sys,'/',['Text',13,'Block7/Inport']])
set_param([sys,'/',['Text',13,'Block7/Inport']],...
		'position',[60,35,80,55])
set_param([sys,'/',['Text',13,'Block7']],...
		'Mask Display','[Phi,Theta,Psi] = Euler Angles',...
		'Mask Type','TEXT',...
		'Mask Dialogue','eval(''error'')')


%     Finished composite block ['Text',13,'Block7'].

set_param([sys,'/',['Text',13,'Block7']],...
		'hide name',0,...
		'position',[450,354,755,376])


%     Subsystem  ['Text',13,'Block6'].

new_system([sys,'/',['Text',13,'Block6']])
set_param([sys,'/',['Text',13,'Block6']],'Location',[132,402,265,498])

add_block('built-in/Inport',[sys,'/',['Text',13,'Block6/Inport']])
set_param([sys,'/',['Text',13,'Block6/Inport']],...
		'position',[60,35,80,55])
set_param([sys,'/',['Text',13,'Block6']],...
		'Mask Display','[North,East,Down] = NED Coordinates',...
		'Mask Type','TEXT',...
		'Mask Dialogue','eval(''error'')')


%     Finished composite block ['Text',13,'Block6'].

set_param([sys,'/',['Text',13,'Block6']],...
		'hide name',0,...
		'position',[450,318,755,342])


%     Subsystem  ['Text',13,'Block5'].

new_system([sys,'/',['Text',13,'Block5']])
set_param([sys,'/',['Text',13,'Block5']],'Location',[132,402,265,498])

add_block('built-in/Inport',[sys,'/',['Text',13,'Block5/Inport']])
set_param([sys,'/',['Text',13,'Block5/Inport']],...
		'position',[60,35,80,55])
set_param([sys,'/',['Text',13,'Block5']],...
		'Mask Display','[Udt,Vdt,Wdt,Pdt,Qdt,Rdt] = Body Rates',...
		'Mask Type','TEXT',...
		'Mask Dialogue','eval(''error'')')


%     Finished composite block ['Text',13,'Block5'].

set_param([sys,'/',['Text',13,'Block5']],...
		'hide name',0,...
		'position',[450,283,755,307])


%     Subsystem  ['Text',13,'Block4'].

new_system([sys,'/',['Text',13,'Block4']])
set_param([sys,'/',['Text',13,'Block4']],'Location',[132,402,265,498])

add_block('built-in/Inport',[sys,'/',['Text',13,'Block4/Inport']])
set_param([sys,'/',['Text',13,'Block4/Inport']],...
		'position',[60,35,80,55])
set_param([sys,'/',['Text',13,'Block4']],...
		'Mask Display','[U,V,W,P,Q,R] = Body States',...
		'Mask Type','TEXT',...
		'Mask Dialogue','eval(''error'')')


%     Finished composite block ['Text',13,'Block4'].

set_param([sys,'/',['Text',13,'Block4']],...
		'hide name',0,...
		'position',[450,248,755,272])


%     Subsystem  ['Text',13,'Block8'].

new_system([sys,'/',['Text',13,'Block8']])
set_param([sys,'/',['Text',13,'Block8']],'Location',[132,402,265,498])

add_block('built-in/Inport',[sys,'/',['Text',13,'Block8/Inport']])
set_param([sys,'/',['Text',13,'Block8/Inport']],...
		'position',[60,35,80,55])
set_param([sys,'/',['Text',13,'Block8']],...
		'Mask Display','[Mach,Vt,sos,rho,qbar,alt,alpha,beta,sigma,lambda]\n=\nAtmospheric and Scheduling Parameters',...
		'Mask Type','TEXT',...
		'Mask Dialogue','eval(''error'')')


%     Finished composite block ['Text',13,'Block8'].

set_param([sys,'/',['Text',13,'Block8']],...
		'hide name',0,...
		'position',[450,377,755,423])
add_line(sys,[300,285;320,285])
add_line(sys,[300,380;320,380])
add_line(sys,[425,260;445,260])
add_line(sys,[425,295;445,295])
add_line(sys,[425,330;445,330])
add_line(sys,[425,365;445,365])
add_line(sys,[425,400;445,400])

drawnow

% Return any arguments.
if (nargin | nargout)
	% Must use feval here to access system in memory
	if (nargin > 3)
		if (flag == 0)
			eval(['[ret,x0,str,ts,xts]=',sys,'(t,x,u,flag);'])
		else
			eval(['ret =', sys,'(t,x,u,flag);'])
		end
	else
		[ret,x0,str,ts,xts] = feval(sys);
	end
else
	drawnow % Flash up the model and execute load callback
end
